/**
 * This adds Ext JS 3.4 Legacy API to <code>Ext.container.Container</code>.
 */
Ext.define('JooOverrides.Ext.container.Container', {
  override: 'Ext.container.Container',
  // restore ext 3.4 behaviour
  bubbleEvents: ["add", "remove"],
  /**
   * Find a component under this container at any level by property
   * @param {String} prop
   * @param {String} value
   * @deprecated Use <code>down(...)</code> or <code>query(...)</code> with selector <code>"[prop=value]"</code> instead.
   * @return {Array} Array of Ext.Components
   */
  find: function (prop, value) {
    return this.queryBy(function (c) {
      return c[prop] === value;
    });
  },

  /**
   * Find a component under this container at any level by xtype or class
   * @param {String/Class} xtype The xtype string for a component, or the class of the component directly
   * @param {Boolean} shallow (optional) False to check whether this Component is descended from the xtype (this is
   * the default), or true to check whether this Component is directly of the specified xtype.
   * @deprecated Use <code>down(...)</code> or <code>query(...)</code> with selector <code>"xtype"</code> instead. Use selector <code>"xtype(true)"</code> for shallow xtype lookup.
   * @return {Array} Array of Ext.Components
   */
  findByType: function (xtype, shallow) {
    return this.queryBy(function (c) {
      return typeof xtype === "function" ? c instanceof xtype : c.isXType(xtype, shallow);
    });
  }

}, function() {
  Object.defineProperty(Ext.container.Container.prototype, "itemCollection", {
    get: function() {
      return this.items;
    },
    enumerable: false,
    configurable: false
  });
});
