// @override Ext.Loader
(function() {
    var oldGetPath = Ext.Loader.getPath;
    if (typeof oldGetPath === "function") {
        // extended path lookup mechanism by taking Ext.manifest.loadOrder into account (normally only used by Microloader
        // in a development build), so Ext classes can be loaded dynamically without using an explicit Ext.require statement
        // as long as they are on any Ext module the application depends on (or the app itself).
        Ext.Loader.getPath = function(className) {
            var me = this,
                manifest = Ext.manifest,
                manager = Ext.ClassManager;
            if (!manager.isCreated(className)) {
                if (manifest && manifest.classes && manifest.loadOrder) {
                    var classEntry = manifest.classes[className];
                    if (classEntry && classEntry.idx) {
                        var path = manifest.loadOrder[classEntry.idx].path;
                        if (path) {
                            me.setPath(className, path);
                        }
                    }
                }
            }
            return oldGetPath.apply(me, arguments);
        };
    }
})();

Ext.define("mx.resources.IResourceManager", function(IResourceManager) {
    /* ////////////////////////////////////////////////////////////////////////////////
//
//  Licensed to the Apache Software Foundation (ASF) under one or more
//  contributor license agreements.  See the NOTICE file distributed with
//  this work for additional information regarding copyright ownership.
//  The ASF licenses this file to You under the Apache License, Version 2.0
//  (the "License"); you may not use this file except in compliance with
//  the License.  You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
//
////////////////////////////////////////////////////////////////////////////////

package mx.resources
{

/**
 *  The APIs of the IResourceManager interface
 *  provide localization support for Flex applications.
 *
 *  <p>There are three main concepts involved in localization:
 *  locales, resources, and resource bundles.</p>
 *
 *  <p>A locale specifies a language and a country
 *  for which your application has been localized.
 *  For example, the locale <code>"en_US"</code>
 *  specifies English as spoken in the United States.
 *  (See the mx.resources.Locale class for more information.)</p>
 *
 *  <p>A resource is a named value that is locale-dependent.
 *  For example, your application might have a resource
 *  whose name is <code>"OPEN"</code>
 *  and whose value for an English locale is <code>"Open"</code>
 *  but whose value for a French locale is <code>"Ouvrir"</code>.</p>
 *
 *  <p>A resource bundle is a named group of resources
 *  whose values have been localized for a particular locale.
 *  A resource bundle is identified by the combination of its
 *  <code>bundleName</code> and its <code>locale</code>,
 *  and has a <code>content</code> object that contains
 *  the name-value pairs for the bundle's resources.
 *  See the documentation for mx.resources.IResourceBundle
 *  for information about how you typically create resource
 *  bundles from properties files.</p>
 *
 *  <p>A single ResourceManager object implementing the IResourceManager
 *  interface manages multiple resource bundles, possibly for multiple
 *  locales, and provides access to the resources that they contain.
 *  For example, you can retrieve a specific resource as a String by calling
 *  <code>resourceManager.getString(bundleName, resourceName)</code>.</p>
 *
 *  <p>All classes that extend UIComponent, Formatter, or Validator
 *  have a <code>resourceManager</code> property
 *  that provides a reference to the object implementing this interface.
 *  Other classes can call <code>ResourceManager.getInstance()</code>
 *  to obtain this object.</p>
 *
 *  <p>Resource retrieval methods such as <code>getString()</code>
 *  search for resources in the locales specified
 *  by the <code>localeChain</code> property.
 *  By changing this property, you can make your application
 *  suddenly use, for example, Japanese rather than English resources.</p>
 *
 *  <p>When your application starts, the ResourceManager is automatically
 *  populated with whatever resource bundles were compiled
 *  into the application.
 *  If you create a code module, by default the resources that its classes
 *  need are compiled into the module.
 *  When the module is loaded into an application, any bundles that the
 *  application does not already have are added to the ResourceManager.</p>
 *
 *  <p>You can compile "resource modules" which have only resources in them,
 *  and load them with the <code>loadResourceModule()</code> method
 *  of IResourceManager.
 *  With resource modules, you can support multiple locales by loading
 *  the resources you need at run time rather than compiling them into
 *  your application.</p>
 *
 *  <p>Although the ResourceManager is normally populated with resource bundles
 *  that were compiled into your application or loaded from modules,
 *  you can also programmatically create resource bundles and add them
 *  to the ResourceManager yourself with the <code>addResourceBundle()</code>
 *  method.</p>
 *
 *  @see mx.resources.ResourceManager
 *  @see mx.resources.IResourceBundle
 *  @see mx.resources.ResourceBundle
 *
 *  @langversion 3.0
 *  @playerversion Flash 9
 *  @playerversion AIR 1.1
 *  @productversion Flex 3
 * /
public interface IResourceManager 
{
  //--------------------------------------------------------------------------
  //
  //  Properties
  //
  //--------------------------------------------------------------------------

  //----------------------------------
  //  localeChain
  //----------------------------------

  /**
   *  An Array of locale Strings, such as <code>[ "en_US" ]</code>,
   *  which specifies one or more locales to be searched for resources.
   *
   *  <p>When you call the ResourceManager methods <code>getObject()</code>,
   *  <code>getString()</code>, <code>getStringArray()</code>,
   *  <code>getNumber()</code>, <code>getInt()</code>,
   *  <code>getUint()</code>, <code>getBoolean()</code>, or
   *  <code>getClass()</code> to get the value of a resource,
   *  you specify a bundle name and a resource name,
   *  but not a locale.
   *  The ResourceManager starts with the first locale in the
   *  <code>localeChain</code> and looks for a ResourceBundle
   *  with the specified bundle name for that locale.
   *  If such a ResourceBundle exists, and the specified resource
   *  exists in it, then the value of that resource is returned.
   *  Otherwise, the ResourceManager proceeds on to the other
   *  locales in the <code>localeChain</code>.</p>
   *
   *  <p>This scheme makes it possible to have locales that do not
   *  necessarily contain a complete set of localized resources.
   *  For example, if you are localizing your application for
   *  Indian English rather than U.S. English, you need only
   *  supply resources for the <code>en_IN</code> locale in which the
   *  Indian spelling or usage differs from that in the U.S.,
   *  and then set the <code>localeChain</code> property
   *  to <code>[ "en_IN", "en_US" ]</code>.</p>
   *
   *  <p>Many framework classes assume that they can always
   *  obtain, from some locale, the resources that they expect,
   *  and they will throw errors if they cannot do so.
   *  Therefore, you must ensure that the <code>localeChain</code>
   *  always contains a complete set of resources.
   *  Unless you have done a complete localization of all the
   *  framework's resources as well as your own application's
   *  resources, you can keep the <code>"en_US"</code> locale
   *  at the end of your <code>localeChain</code> to ensure this.</p>
   *
   *  <p>Setting this property causes the ResourceManager to dispatch
   *  a <code>"change"</code> Event.</p>
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function get localeChain():Array /* of String * /;

  function set localeChain(value:Array /* of String * /):void;

  //--------------------------------------------------------------------------
  //
  //  Methods
  //
  //--------------------------------------------------------------------------

  /**
   *  Begins unloading a loaded resource module.
   *
   *  <p>When the module is unloaded, its resource bundles
   *  are removed from the ResourceManager, but the <code>localeChain</code>
   *  is left unchanged.
   *  If the <code>update</code> parameter is <code>true</code>,
   *  the <code>update()</code> method will be called.</p>
   *
   *  @param url The URL that was used to load the resource module.
   *
   *  @param update Whether to call
   *  the <code>update()</code> method when the module finishes unloading.
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function unloadResourceModule(url:String, update:Boolean = true):void;

  /**
   *  Adds the specified ResourceBundle to the ResourceManager
   *  so that its resources can be accessed by ResourceManager
   *  methods such as <code>getString()</code>.
   *
   *  @param resourceBundle The resource bundle to be added.
   *  @param useWeakReference Determines if the ResourceManager
   *  keeps a weak reference to the resource bundle.
   *  If <code>useWeakReference</code> is <code>true</code> then the ResourceManager
   *  provides a weak reference to the resource bundle. When the
   *  caller chooses to use a weak reference it becomes the
   *  caller's responsibility to keep a hard reference the resource bundle
   *  so it is not garbaged collected prematurely. If <code>useWeakReference</code> is
   *  <code>false</code>, the ResourceManager keeps a hard reference to the resource
   *  bundle so it will not be garbage collected.
   *
   *  <p>When a Flex sub-application or module automatically adds its compiled
   *  resource bundles to the ResourceManager, it calls the <code>addResourceBundle()</code>
   *  with <code>useWeakReference</code> set to <code>true</code>, to avoid becoming pinned in memory.
   *  If you create resource bundles at runtime in a sub-application or
   *  module, you should do the same. You then need to hold on to these
   *  resource bundles with a hard reference to prevent them from being
   *  garbage collected.</p>
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function addResourceBundle(resourceBundle:IResourceBundle,
                             useWeakReference:Boolean = false):void;

  /**
   *  Removes the specified ResourceBundle from the ResourceManager
   *  so that its resources can no longer be accessed by ResourceManager
   *  methods such as <code>getString()</code>.
   *
   *  @param locale A locale string such as <code>"en_US"</code>.
   *
   *  @param bundleName A bundle name such as <code>"MyResources"</code>.
   *
   *  @see mx.resources.IResourceBundle
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function removeResourceBundle(locale:String, bundleName:String):void;

  /**
   *  Removes all ResourceBundles for the specified locale
   *  from the ResourceManager so that their resources
   *  can no longer be accessed by ResourceManager methods
   *  such as <code>getString()</code>.
   *
   *  @param locale A locale string such as <code>"en_US"</code>.
   *
   *  @see mx.resources.IResourceBundle
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function removeResourceBundlesForLocale(locale:String):void;

  /**
   *  Dispatches a <code>change</code> event from the
   *  ResourceManager.
   *
   *  <p>This causes binding expressions to re-evaluate
   *  if they involve the ResourceManager methods
   *  <code>getObject()</code>, <code>getString()</code>,
   *  <code>getStringArray()</code>, <code>getNumber()</code>,
   *  <code>getInt()</code>, <code>getUint()</code>,
   *  <code>getBoolean()</code>, or <code>getClass()</code>.</p>
   *
   *  <p>This also causes the <code>resourcesChanged()</code> method
   *  of a UIComponent, Formatter, or Validator to execute.
   *  Many components implement this method to update
   *  their state based on the latest resources.</p>
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function update():void;

  /**
   *  Returns an Array of Strings specifying all locales for which
   *  ResourceBundle objects exist in the ResourceManager.
   *
   *  <p>The order of locales in this array is not specified.</p>
   *
   *  @return An Array of locale Strings.
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function getLocales():Array /* of String * /;

  /**
   *  Returns an Array of Strings specifying all locales for which
   *  ResourceBundle objects exist in the ResourceManager,
   *  ordered using  user preferences as reported by
   *  <code>Capabilities.language</code> or
   *  <code>Capabilities.languages</code>.
   *
   *  @return An Array of locale Strings.
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function getPreferredLocaleChain():Array /* of String * /;

  /**
   *  Returns an Array of Strings specifying the bundle names
   *  for all ResourceBundle objects that exist in the ResourceManager
   *  and that belong to the specified locale.
   *
   *  <p>The order of bundle names in this Array is not specified.</p>
   *
   *  @param locale A locale string such as <code>"en_US"</code>.
   *
   *  @return An Array of bundle names.
   *
   *  @see mx.resources.IResourceBundle
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function getBundleNamesForLocale(locale:String):Array /* of String * /;

  /**
   *  Returns a ResourceBundle with the specified <code>locale</code>
   *  and <code>bundleName</code> that has been previously added
   *  to the ResourceManager with <code>addResourceBundle()</code>.
   *  If no such ResourceBundle exists, this method returns <code>null</code>.
   *
   *  @param locale A locale string such as <code>"en_US"</code>.
   *
   *  @param bundleName A bundle name such as <code>"MyResources"</code>.
   *
   *  @return The ResourceBundle with the specified <code>locale</code>
   *  and <code>bundleName</code> if one exists; otherwise <code>null</code>.
   *
   *  @see mx.resources.IResourceBundle
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function getResourceBundle(locale:String,
                             bundleName:String):IResourceBundle;

  /**
   *  Searches the locales in the <code>localeChain</code>
   *  for the specified resource and returns
   *  the first resource bundle in which it is found.
   *  If the resource isn't found, this method returns <code>null</code>.
   *
   *  @param bundleName A bundle name such as <code>"MyResources"</code>.
   *
   *  @param resourceName The name of a resource in the resource bundle.
   *
   *  @return The first ResourceBundle in the <code>localeChain</code>
   *  that contains the specified resource, or <code>null</code>.
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function findResourceBundleWithResource(
          bundleName:String,
          resourceName:String):IResourceBundle;

  [Bindable("change")]

  /**
   *  Gets the value of a specified resource as an Object.
   *
   *  <p>The value is returned exactly as it is stored
   *  in the <code>content</code> Object of the ResourceBundle,
   *  with no conversion.
   *  If the resource was compiled from a properties files,
   *  the resource value in the <code>content</code> Object
   *  is always a String unless you used the <code>Embed()</code>
   *  or <code>ClassReference()</code> directive, in which case
   *  it is a Class.
   *  Use the <code>getString()</code>, <code>getStringArray()</code>,
   *  <code>getNumber()</code>, <code>getInt()</code>
   *  <code>getUint()</code>, <code>getBoolean()</code>, and
   *  <code>getClass()</code> methods to convert the value
   *  to more specific types.</p>
   *
   *  <p>If the specified resource is not found,
   *  this method returns <code>undefined</code>.</p>
   *
   *  @param bundleName The name of a resource bundle.
   *
   *  @param resourceName The name of a resource in the resource bundle.
   *
   *  @param locale A specific locale to be used for the lookup,
   *  or <code>null</code> to search all locales
   *  in the <code>localeChain</code>.
   *  This parameter is optional and defaults to <code>null</code>;
   *  you should seldom need to specify it.
   *
   *  @return The resource value, exactly as it is stored
   *  in the <code>content</code> Object,
   *  or <code>undefined</code> if the resource is not found.
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function getObject(bundleName:String, resourceName:String,
                     locale:String = null):*;

  [Bindable("change")]

  /**
   *  Gets the value of a specified resource as a String,
   *  after substituting specified values for placeholders.
   *
   *  <p>This method calls <code>getObject()</code>
   *  and then casts the result to a String.</p>
   *
   *  <p>If a <code>parameters</code> Array is passed to this method,
   *  the parameters in it are converted to Strings
   *  and then substituted, in order, for the placeholders
   *  <code>"{0}"</code>, <code>"{1}"</code>, and so on, in the String
   *  before it is returned.</p>
   *
   *  <p>If the specified resource is not found,
   *  this method returns <code>null</code>.</p>
   *
   *  @param bundleName The name of a resource bundle.
   *
   *  @param resourceName The name of a resource in the resource bundle.
   *
   *  @param parameters An Array of parameters that are
   *  substituted for the placeholders.
   *  Each parameter is converted to a String with the <code>toString()</code> method
   *  before being substituted.
   *
   *  @param locale A specific locale to be used for the lookup,
   *  or <code>null</code> to search all locales
   *  in the <code>localeChain</code>.
   *  This parameter is optional and defaults to <code>null</code>;
   *  you should seldom need to specify it.
   *
   *  @return The resource value, as a String,
   *  or <code>null</code> if it is not found.
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function getString(bundleName:String, resourceName:String,
                     parameters:Array = null,
                     locale:String = null):String;

  [Bindable("change")]

  /**
   *  Gets the value of a specified resource as an Array of Strings.
   *
   *  <p>This method assumes that the resource value is a String
   *  containing a comma-separated list of items.
   *  It calls the <code>getString()</code> method, splits the String
   *  into items at the commas, and trims white space
   *  before and after each item.
   *  It is useful if you have written a line such as:</p>
   *
   *  <pre>
   *  COUNTRIES=India, China, Japan
   *  </pre>
   *
   *  <p>in a properties file and you want to obtain the value
   *  <code>[ "India", "China", "Japan" ]</code>
   *  rather than the value <code>"India, China, Japan"</code>.</p>
   *
   *  <p>If the specified resource is not found,
   *  this method returns <code>null</code>.</p>
   *
   *  @param bundleName The name of a resource bundle.
   *
   *  @param resourceName The name of a resource in the resource bundle.
   *
   *  @param locale A specific locale to be used for the lookup,
   *  or <code>null</code> to search all locales
   *  in the <code>localeChain</code>.
   *  This parameter is optional and defaults to <code>null</code>;
   *  you should seldom need to specify it.
   *
   *  @return The resource value, as an Array of Strings,
   *  or <code>null</code> if it is not found.
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function getStringArray(bundleName:String,
                          resourceName:String,
                          locale:String = null):Array /* of String * /;

  [Bindable("change")]

  /**
   *  Gets the value of a specified resource as a Number.
   *
   *  <p>This method calls <code>getObject()</code>
   *  and casts the result to a Number.
   *  It is useful if you have written a line such as:</p>
   *
   *  <pre>
   *  LONGITUDE=170.3
   *  </pre>
   *
   *  <p>in a properties file and want to obtain the value
   *  170.3 rather than <code>"170.3"</code>.</p>
   *
   *  <p>If the specified resource is not found,
   *  this method returns <code>NaN</code>.</p>
   *
   *  @param bundleName The name of a resource bundle.
   *
   *  @param resourceName The name of a resource in the resource bundle.
   *
   *  @param locale A specific locale to be used for the lookup,
   *  or <code>null</code> to search all locales
   *  in the <code>localeChain</code>.
   *  This parameter is optional and defaults to <code>null</code>;
   *  you should seldom need to specify it.
   *
   *  @return The resource value, as a Number,
   *  or <code>NaN</code> if it is not found.
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function getNumber(bundleName:String, resourceName:String,
                     locale:String = null):Number;

  [Bindable("change")]

  /**
   *  Gets the value of a specified resource as an int.
   *
   *  <p>This method calls <code>getObject()</code>
   *  and casts the result to an int.
   *  It is useful if you have written a line such as:</p>
   *
   *  <pre>
   *  MINIMUM=5
   *  </pre>
   *
   *  <p>in a properties file and want to obtain the value
   *  5 rather than <code>"5"</code>.</p>
   *
   *  <p>If the specified resource is not found,
   *  this method returns 0.</p>
   *
   *  @param bundleName The name of a resource bundle.
   *
   *  @param resourceName The name of a resource in the resource bundle.
   *
   *  @param locale A specific locale to be used for the lookup,
   *  or <code>null</code> to search all locales
   *  in the <code>localeChain</code>.
   *  This parameter is optional and defaults to <code>null</code>;
   *  you should seldom need to specify it.
   *
   *  @return The resource value, as an int,
   *  or 0 if it is not found.
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function getInt(bundleName:String, resourceName:String,
                  locale:String = null):int;

  [Bindable("change")]

  /**
   *  Gets the value of a specified resource as a uint.
   *
   *  <p>This method calls the <code>getObject()</code> method
   *  and casts the result to a uint.
   *  It is useful if you have written a line such as:</p>
   *
   *  <pre>
   *  MINIMUM=5
   *  </pre>
   *
   *  <p>in a properties file and want to obtain the value
   *  5 rather than <code>"5"</code>.</p>
   *
   *  <p>If the specified resource is not found,
   *  this method returns 0.</p>
   *
   *  @param bundleName The name of a resource bundle.
   *
   *  @param resourceName The name of a resource in the resource bundle.
   *
   *  @param locale A specific locale to be used for the lookup,
   *  or <code>null</code> to search all locales
   *  in the <code>localeChain</code>.
   *  This parameter is optional and defaults to <code>null</code>;
   *  you should seldom need to specify it.
   *
   *  @return The resource value, as a uint,
   *  or 0 if it is not found.
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function getUint(bundleName:String, resourceName:String,
                   locale:String = null):uint;

  [Bindable("change")]

  /**
   *  Gets the value of a specified resource as a Boolean.
   *
   *  <p>This method first calls <code>getString()</code>
   *  and converts the result to lowercase.
   *  It then returns <code>true</code>
   *  if the result was <code>"true"</code>.
   *  and <code>false</code> otherwise.</p>
   *
   *  <p>If the specified resource is not found,
   *  this method returns <code>false</code>.</p>
   *
   *  @param bundleName The name of a resource bundle.
   *
   *  @param resourceName The name of a resource in the resource bundle.
   *
   *  @param locale A specific locale to be used for the lookup,
   *  or <code>null</code> to search all locales
   *  in the <code>localeChain</code>.
   *  This parameter is optional and defaults to <code>null</code>;
   *  you should seldom need to specify it.
   *
   *  @return The resource value, as a Boolean,
   *  or <code>false</code> if it is not found.
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function getBoolean(bundleName:String, resourceName:String,
                      locale:String = null):Boolean;

  [Bindable("change")]

  /**
   *  Gets the value of a specified resource as a Class.
   *
   *  <p>This method calls <code>getObject()</code>
   *  and coerces it to type Class using the <code>as</code> operator.
   *  The result will be <code>null</code> if the resource value
   *  was not a class reference.
   *  It is useful if you have written a lines such as</p>
   *
   *  <pre>
   *  IMAGE=Embed("image.jpg")
   *  BUTTON_SKIN=ClassReference("skins.ButtonSkin_en_US")
   *  </pre>
   *
   *  <p>in a properties file and want to obtain
   *  the Class that the <code>Embed()</code>
   *  or <code>ClassReference()</code> directive produced.</p>
   *
   *  <p>If the specified resource is not found,
   *  this method returns <code>null</code>.</p>
   *
   *  @param bundleName The name of a resource bundle.
   *
   *  @param resourceName The name of a resource in the resource bundle.
   *
   *  @param locale A specific locale to be used for the lookup,
   *  or <code>null</code> to search all locales
   *  in the <code>localeChain</code>.
   *  This parameter is optional and defaults to <code>null</code>;
   *  you should seldom need to specify it.
   *
   *  @return The resource value, as a <code>Class</code>,
   *  or <code>null</code> if it is not found.
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function getClass(bundleName:String, resourceName:String,
                    locale:String = null):Class;


  /**
   *  Initializes the <code>localeChain</code> property of the ResourceManager
   *  using an algorithm that compares the operating system's list of user-preferred
   *  locales with the list of locales available in the SWF.
   *
   *  <p>For example, if the user has indicated in the operating system that she
   *  prefers French, and the SWF was compiled for the locales en_US, fr_FR, and de_DE,
   *  then the <code>localeChain</code> will be set so that the first locale in it
   *  is fr_FR.</p>
   *
   *  <p>This method is used only by classes that implement the IFlexModuleFactory interface.</p>
   *
   *  @param  compiledLocales An Array of Strings specifying the locales
   *  for which the SWF was compiled.
   *
   * @see mx.core.IFlexModuleFactory
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function initializeLocaleChain(compiledLocales:Array):void;
}

}

============================================== Jangaroo part ==============================================*/
    return {};
});

Ext.define("mx.resources.IResourceBundle", function(IResourceBundle) {
    /* ////////////////////////////////////////////////////////////////////////////////
//
//  Licensed to the Apache Software Foundation (ASF) under one or more
//  contributor license agreements.  See the NOTICE file distributed with
//  this work for additional information regarding copyright ownership.
//  The ASF licenses this file to You under the Apache License, Version 2.0
//  (the "License"); you may not use this file except in compliance with
//  the License.  You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
//  Unless required by applicable law or agreed to in writing, software
//  distributed under the License is distributed on an "AS IS" BASIS,
//  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  See the License for the specific language governing permissions and
//  limitations under the License.
//
////////////////////////////////////////////////////////////////////////////////

package mx.resources
{

/**
 *  The IResourceBundle and IResourceManager interfaces work together
 *  to provide localization support for Flex applications.
 *
 *  <p>There are three main concepts involved in localization:
 *  locales, resources, and resource bundles.</p>
 *
 *  <p>A locale specifies a language and a country
 *  for which your application has been localized.
 *  For example, the locale <code>"en_US"</code>
 *  specifies English as spoken in the United States.
 *  (See the mx.resources.Locale class for more information.)</p>
 *
 *  <p>A resource is a named value that is locale-dependent.
 *  For example, your application might have a resource
 *  whose name is <code>"OPEN"</code>
 *  and whose value for an English locale is <code>"Open"</code>
 *  but whose value for a French locale is <code>"Ouvrir"</code>.</p>
 *
 *  <p>A resource bundle is a named group of resources
 *  whose values have been localized for a particular locale.
 *  A resource bundle is identified by the combination of its
 *  <code>bundleName</code> and its <code>locale</code>,
 *  and has a <code>content</code> Object that contains
 *  the name-value pairs for the bundle's resources.</p>
 *
 *  <p>The IResourceBundle interface represents a specific resource bundle.
 *  However, most applications will only need to use IResourceManager.
 *  A single ResourceManager object implementing this interface
 *  manages multiple resource bundles, possibly for multiple locales,
 *  and provides access to the resources that they contain.
 *  For example, you can retrieve a specific resource as a String by calling
 *  <code>resourceManager.getString(bundleName, resourceName)</code>.
 *  By changing the <code>localeChain</code> property of the ResourceManager,
 *  you can change which resource bundles are searched for resource values.</p>
 *
 *  <p>Generally, you do not create resource bundles yourself;
 *  instead, they are usually compiled from ~~.properties files.
 *  A properties file named MyResources.properties
 *  produces a resource bundle with <code>"MyResources"</code>
 *  for its <code>bundleName</code>.
 *  You generally produce multiple versions of each properties file,
 *  one for each locale that your application supports.</p>
 *
 *  <p>Flex properties files are similar to Java properties files,
 *  except that they also support MXML's <code>Embed()</code>
 *  and <code>ClassReference()</code> directives.
 *  These directives work the same way in a properties file
 *  as they do in a CSS file, producing class references.
 *  Also, the encoding for Flex properties files
 *  is always assumed to be UTF-8.</p>
 *
 *  <p>The Flex framework's resources have been localized
 *  for U.S. English (the <code>"en_US"</code> locale) and
 *  for Japanese (the <code>"ja_JP"</code> locale).
 *  The framework resources are organized into multiple bundles
 *  corresponding to framework packages; for example, the "formatters"
 *  bundle is used by classes in the mx.formatters package.
 *  (There is also a "SharedResources" bundle for resources used by
 *  multiple packages.)</p>
 *
 *  <p>The properties files for the framework resources,
 *  such as formatters.properties, can be found in the
 *  frameworks/projects/framework/bundles/{locale}/src directories
 *  of the Flex SDK.
 *  Your applications normally link against the Flex framework
 *  as a precompiled library, framework.swc,
 *  in the frameworks/libs directory.
 *  This library has no resources in it.
 *  Instead, the framework resources have been compiled into separate
 *  resource bundle libraries such as framework_rb.swc.
 *  These are located in the frameworks/locales/{locale} directories
 *  and your application must also link in one or more of these.</p>
 *
 *  <p>You are free to organize your application's own resources
 *  into whatever bundles you find convenient.
 *  If you localize your application for locales
 *  other than <code>"en_US"</code> and <code>"ja_JP"</code>,
 *  you should localize the framework's properties files for those locales
 *  as well and compile additional resource bundle libaries for them.</p>
 *
 *  <p>When your application starts, the ResourceManager is automatically
 *  populated with whatever resource bundles were compiled
 *  into the application.
 *  If you create a code module, by default the resources that its classes
 *  need are compiled into the module.
 *  When the module is loaded into an application, any bundles that the
 *  application does not already have are added to the ResourceManager.</p>
 *
 *  <p>You can compile "resource modules" that have only resources in them,
 *  and load them with the <code>loadResourceModule()</code> method
 *  of the ResourceManager.
 *  With resource modules, you can support multiple locales by loading
 *  the resources you need at run time rather than compiling them into
 *  your application.</p>
 *
 *  <p>Although the ResourceManager is normally populated with resource bundles
 *  that were compiled into your application or loaded from modules,
 *  you can also programmatically create resource bundles and add them
 *  to the ResourceManager yourself with the <code>addResourceBundle()</code>
 *  method.</p>
 *
 *  @see mx.resources.ResourceBundle
 *  @see mx.resources.IResourceManager
 *  @see mx.resources.ResourceManager
 *
 *  @langversion 3.0
 *  @playerversion Flash 9
 *  @playerversion AIR 1.1
 *  @productversion Flex 3
 * /
public interface IResourceBundle
{
  //--------------------------------------------------------------------------
  //
  //  Properties
  //
  //--------------------------------------------------------------------------

  //----------------------------------
  //  bundleName
  //----------------------------------

  /**
   *  A name that identifies this resource bundle,
   *  such as <code>"MyResources"</code>.
   *
   *  <p>This read-only property is set
   *  when a resource bundle is constructed.</p>
   *
   *  <p>Resource bundles that are automatically created from compiled
   *  properties files have bundle names based on the names of those files.
   *  For example, a properties file named MyResources.properties
   *  will produce a resource bundle whose <code>bundleName</code>
   *  is <code>"MyResources"</code>.</p>
   *
   *  <p>The ResourceManager can manage multiple bundles with the same
   *  <code>bundleName</code> as long as they have different values
   *  for their <code>locale</code> property.</p>
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function get bundleName():String;

  //----------------------------------
  //  content
  //----------------------------------

  /**
   *  An object containing key-value pairs for the resources
   *  in this resource bundle.
   *
   *  <p>In general, you should access resources by using IResourceManager
   *  methods such as <code>getString()</code>, rather than directly
   *  accessing them in a resource bundle.
   *  However, if you are programmatically creating your own
   *  resource bundles, you can initialize them with resources,
   *  as follows:</p>
   *
   *  <pre>
   *  var rb:IResourceBundle = new ResourceBundle("fr_FR", "MyResources");
   *  rb.content["LANGUAGE"] = "Francais";
   *  rb.content["GREETING"] = "Bonjour";
   *  </pre>
   *
   *  <p>When a resource bundle is produced by compiling a properties
   *  file, its resource values are either of type String or Class.
   *  For example, if the properties file contains</p>
   *
   *  <pre>
   *  LANGUAGE=English
   *  MINIMUM_AGE=18
   *  ENABLED=true
   *  LOGO=Embed("logo.png")
   *  </pre>
   *
   *  <p>then the value of the <code>LANGUAGE</code> resource
   *  is the String <code>"English"</code>,
   *  the value of the <code>MINIMUM_AGE</code> resource
   *  is the String <code>"18"</code>,
   *  the value of the <code>ENABLED</code> resource
   *  is the String <code>"true"</code>,
   *  and the value of the <code>LOGO</code> resource
   *  is a Class that represents the embedded PNG file.</p>
   *
   *  <p>You can use IResourceManager methods such as <code>getInt()</code>
   *  and <code>getBoolean()</code> to convert resource strings like
   *  <code>"18"</code> and <code>"true"</code> into the type
   *  that your code expects.</p>
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function get content():Object;

  //----------------------------------
  //  locale
  //----------------------------------

  /**
   *  The locale for which this bundle's resources have been localized.
   *  This is a String such as <code>"en_US"</code> for U.S. English.
   *
   *  <p>This read-only property is set
   *  when a resource bundle is constructed.</p>
   *
   *  <p>Resource bundles that are automatically created from compiled
   *  properties files have locales based on the
   *  <code>-compiler.locale</code> option of the mxmlc or compc compilers.
   *  For example, suppose that you compile your application with the option
   *  <code>-compiler.locale=en_US,ja_JP</code> and that you have specified
   *  <code>-compiler.source-path=resources/{locale}</code> so that
   *  your application's resources, located in
   *  resources/en_US/MyResources.properties and
   *  resources/ja_JP/MyResources.properties, are found.
   *  Then your application will have two resource bundles
   *  whose <code>bundleName</code> is <code>"MyResources"</code>,
   *  one whose <code>locale</code> is <code>"en_US"</code>
   *  and one whose <code>locale</code> is <code>"ja_JP"</code>.</p>
   *
   *  @langversion 3.0
   *  @playerversion Flash 9
   *  @playerversion AIR 1.1
   *  @productversion Flex 3
   * /
  function get locale():String;
}

}

============================================== Jangaroo part ==============================================*/
    return {};
});

Ext.define("mx.resources.ResourceBundle", function(ResourceBundle) {
    /* /**
 * Created by fwienber on 08.04.2016.
 * /
package mx.resources {
import ext.Ext;

public class ResourceBundle implements IResourceBundle {

  public*/
    function ResourceBundle$(locale, /*:String*/
    bundleName, /*:String*/
    content) /*:Object*/
    {
        Ext.apply(this, {
            locale: locale,
            bundleName: bundleName,
            content: content
        });
    }
    /*

  /**
   * @inheritDoc
   * /
  public native function get locale():String;

  /**
   * @inheritDoc
   * /
  public native function get bundleName():String;

  /**
   * @inheritDoc
   * /
  public native function get content():Object;

}
}

============================================== Jangaroo part ==============================================*/
    return {
        mixins: [
            "mx.resources.IResourceBundle"
        ],
        constructor: ResourceBundle$,
        requires: [
            "mx.resources.IResourceBundle"
        ],
        uses: [
            "Ext"
        ]
    };
});

Ext.define("mx.resources.ResourceManager", function(ResourceManager) {
    /*package mx.resources {
import ext.StringUtil;

import joo.getQualifiedObject;

public class ResourceManager implements IResourceManager {

  private static const*/
    var resourceManager$static;
    /*:ResourceManager*/
    /* =*/
    function resourceManager$static_() {
        resourceManager$static = (new ResourceManager());
    }
    
    /*

  public static*/
    function getInstance$static() /*:IResourceManager*/
    {
        return resourceManager$static;
    }
    /*

  public*/
    function get$localeChain() /*:Array*/
    {
        throw new AS3.Error("not implemented");
    }
    /*

  public*/
    function set$localeChain(value) /*:Array*/
    /*:void*/
    {
        throw new AS3.Error("not implemented");
    }
    /*

  public*/
    function unloadResourceModule(url, /*:String*/
    update) /*:Boolean = true*/
    /*:void*/
    {
        if (arguments.length <= 1)  {
            update = true;
        }
        
        throw new AS3.Error("not implemented");
    }
    /*

  public*/
    function addResourceBundle(resourceBundle, /*:IResourceBundle*/
    useWeakReference) /*:Boolean = false*/
    /*:void*/
    {
        if (arguments.length <= 1)  {
            useWeakReference = false;
        }
        
        throw new AS3.Error("not implemented");
    }
    /*

  public*/
    function removeResourceBundle(locale, /*:String*/
    bundleName) /*:String*/
    /*:void*/
    {
        throw new AS3.Error("not implemented");
    }
    /*

  public*/
    function removeResourceBundlesForLocale(locale) /*:String*/
    /*:void*/
    {
        throw new AS3.Error("not implemented");
    }
    /*

  public*/
    function update() /*:void*/
    {
        throw new AS3.Error("not implemented");
    }
    /*

  public*/
    function getLocales() /*:Array*/
    {
        throw new AS3.Error("not implemented");
    }
    /*

  public*/
    function getPreferredLocaleChain() /*:Array*/
    {
        throw new AS3.Error("not implemented");
    }
    /*

  public*/
    function getBundleNamesForLocale(locale) /*:String*/
    /*:Array*/
    {
        throw new AS3.Error("not implemented");
    }
    /*

  /**
   * @inheritDoc
   * /
  public*/
    function getResourceBundle(locale, /*:String*/
    bundleName) /*:String*/
    /*:IResourceBundle*/
    {
        var content = /*:Object*/
            getContent$static(bundleName);
        return content ? new mx.resources.ResourceBundle(locale, bundleName, content) : null;
    }
    /*

  private static*/
    function getContent$static(bundleName) /*:String*/
    /*:Object*/
    {
        return AS3.as(joo.getQualifiedObject(bundleName + "_properties.INSTANCE"), Object);
    }
    /*

  public*/
    function findResourceBundleWithResource(bundleName, /*:String*/
    resourceName) /*:String*/
    /*:IResourceBundle*/
    {
        throw new AS3.Error("not implemented");
    }
    /*

  [Bindable("change")]
  public*/
    function getObject(bundleName, /*:String*/
    resourceName, /*:String*/
    locale) /*:String = null*/
    /*:**/
    {
        if (arguments.length <= 2)  {
            locale = null;
        }
        
        return null;
    }
    /*

  [Bindable("change")]
  /**
   * @inheritDoc
   * /
  public*/
    function getString(bundleName, /*:String*/
    resourceName, /*:String*/
    parameters, /*:Array = null*/
    locale) /*:String = null*/
    /*:String*/
    {
        switch (Math.max(arguments.length, 2)) {
            case 2:
                parameters = null;
            case 3:
                locale = null;
        }
        var content = /*:Object*/
            getContent$static(bundleName);
        if (!content) {
            return null;
        }
        var string = /*:String*/
            AS3.as(content[resourceName], String);
        if (string && parameters && parameters.length) {
            string = Ext.String.format.apply(null, [
                string
            ].concat(parameters));
        }
        return string;
    }
    /*

  [Bindable("change")]
  public*/
    function getStringArray(bundleName, /*:String*/
    resourceName, /*:String*/
    locale) /*:String = null*/
    /*:Array*/
    {
        if (arguments.length <= 2)  {
            locale = null;
        }
        
        throw new AS3.Error("not implemented");
    }
    /*

  [Bindable("change")]
  public*/
    function getNumber(bundleName, /*:String*/
    resourceName, /*:String*/
    locale) /*:String = null*/
    /*:Number*/
    {
        if (arguments.length <= 2)  {
            locale = null;
        }
        
        throw new AS3.Error("not implemented");
    }
    /*

  [Bindable("change")]
  public*/
    function getInt(bundleName, /*:String*/
    resourceName, /*:String*/
    locale) /*:String = null*/
    /*:int*/
    {
        if (arguments.length <= 2)  {
            locale = null;
        }
        
        throw new AS3.Error("not implemented");
    }
    /*

  [Bindable("change")]
  public*/
    function getUint(bundleName, /*:String*/
    resourceName, /*:String*/
    locale) /*:String = null*/
    /*:uint*/
    {
        if (arguments.length <= 2)  {
            locale = null;
        }
        
        throw new AS3.Error("not implemented");
    }
    /*

  [Bindable("change")]
  public*/
    function getBoolean(bundleName, /*:String*/
    resourceName, /*:String*/
    locale) /*:String = null*/
    /*:Boolean*/
    {
        if (arguments.length <= 2)  {
            locale = null;
        }
        
        throw new AS3.Error("not implemented");
    }
    /*

  [Bindable("change")]
  public*/
    function getClass(bundleName, /*:String*/
    resourceName, /*:String*/
    locale) /*:String = null*/
    /*:Class*/
    {
        if (arguments.length <= 2)  {
            locale = null;
        }
        
        throw new AS3.Error("not implemented");
    }
    /*

  public*/
    function initializeLocaleChain(compiledLocales) /*:Array*/
    /*:void*/
    {
        throw new AS3.Error("not implemented");
    }
    /*
}*/
    function ResourceManager$() {}
    /*
}

============================================== Jangaroo part ==============================================*/
    return {
        mixins: [
            "mx.resources.IResourceManager"
        ],
        unloadResourceModule: unloadResourceModule,
        addResourceBundle: addResourceBundle,
        removeResourceBundle: removeResourceBundle,
        removeResourceBundlesForLocale: removeResourceBundlesForLocale,
        update: update,
        getLocales: getLocales,
        getPreferredLocaleChain: getPreferredLocaleChain,
        getBundleNamesForLocale: getBundleNamesForLocale,
        getResourceBundle: getResourceBundle,
        findResourceBundleWithResource: findResourceBundleWithResource,
        getObject: getObject,
        getString: getString,
        getStringArray: getStringArray,
        getNumber: getNumber,
        getInt: getInt,
        getUint: getUint,
        getBoolean: getBoolean,
        getClass: getClass,
        initializeLocaleChain: initializeLocaleChain,
        constructor: ResourceManager$,
        statics: {
            resourceManager: undefined,
            getInstance: getInstance$static,
            __initStatics__: function() {
                resourceManager$static_();
            }
        },
        __accessors__: {
            localeChain: {
                get: get$localeChain,
                set: set$localeChain
            }
        },
        requires: [
            "AS3.Error",
            "Ext",
            "Ext.String",
            "mx.resources.IResourceBundle",
            "mx.resources.IResourceManager",
            "mx.resources.ResourceBundle"
        ]
    };
});

Ext.define('JooOverrides.Ext.Component', {
    override: 'Ext.Component',
    requires: [
        "mx.resources.ResourceManager"
    ],
    /**
   * Find a container above this component at any level by xtype or class
   *
   * See also the {@link Ext.Component#up up} method.
   *
   * @param {String/Ext.Class} xtype The xtype string for a component, or the class of the component directly
   * @param {Boolean} shallow (optional) False to check whether this Component is descended from the xtype (this is
   * the default), or true to check whether this Component is directly of the specified xtype.
   * @return {Ext.container.Container} The first Container which matches the given xtype or class
   */
    findParentByType: function(xtype, shallow) {
        var componentQuery;
        if (Ext.isFunction(xtype)) {
            xtype = xtype.xtype;
        }
        if (Ext.isString(xtype)) {
            componentQuery = xtype.replace(/\./g, "\\.");
            if (shallow) {
                componentQuery += "(true)";
            }
        }
        return this.up(componentQuery);
    },
    // patch for Actions being added to a Component via config's baseAction;
    // apply config options to component
    initConfig: function(config) {
        if (config.baseAction) {
            this.baseAction = config.baseAction;
            if (config.baseAction.initialConfig) {
                for (var i in config.baseAction.initialConfig) {
                    if (config.baseAction.initialConfig.hasOwnProperty(i) && !(i in config)) {
                        config[i] = config.baseAction.initialConfig[i];
                    }
                }
            }
            delete config.baseAction;
        }
        return this.callParent(arguments);
    },
    // Patch for missing 'show' event in the case that a component:
    // (1) is hidden
    // (2) is not rendered
    // (3) show() gets called
    // Might seem a bit odd to fire 'show' for a non-rendered component.
    // However, not firing the event at all is not good as well.
    show: function(animateTarget, cb, scope) {
        var me = this,
            rendered = me.rendered;
        if (me.hierarchicallyHidden || (me.floating && !rendered && me.isHierarchicallyHidden())) {
            // If this is a hierarchically hidden floating component, we need to stash
            // the arguments to this call so that the call can be deferred until the next
            // time syncHidden() is called.
            if (!rendered) {
                // If the component has not yet been rendered it requires special treatment.
                // Normally, for rendered components we can just set the pendingShow property
                // and syncHidden() listens to events in the hierarchyEventSource and calls
                // show() when this component becomes hierarchically visible.  However,
                // if the component has not yet been rendered the hierarchy event listeners
                // have not yet been attached (since Floating is initialized during the
                // render phase.  This means we have to initialize the hierarchy event
                // listeners right now to ensure that the component will show itself when
                // it becomes hierarchically visible.
                me.initHierarchyEvents();
            }
            // defer the show call until next syncHidden(), but ignore animateTarget.
            if (arguments.length > 1) {
                arguments[0] = null;
                // jshint ignore:line
                me.pendingShow = arguments;
            } else {
                me.pendingShow = true;
            }
        } else if (rendered && me.isVisible()) {
            if (me.floating) {
                me.onFloatShow();
            }
        } else {
            if (me.fireEvent('beforeshow', me) !== false) {
                me.hidden = false;
                delete this.getInherited().hidden;
                // Render on first show if there is an autoRender config, or if this
                // is a floater (Window, Menu, BoundList etc).
                // We suspend layouts here because floaters/autoRenders
                // will layout when onShow is called. If the render succeeded,
                // the layout will be trigger inside onShow, so we don't flush
                // in the first block. If, for some reason we couldn't render, then
                // we resume layouts and force a flush because we don't know if something
                // will force it.
                Ext.suspendLayouts();
                if (!rendered && (me.autoRender || me.floating)) {
                    me.doAutoRender();
                    rendered = me.rendered;
                }
                if (rendered) {
                    me.beforeShow();
                    Ext.resumeLayouts();
                    me.onShow.apply(me, arguments);
                    me.afterShow.apply(me, arguments);
                } else {
                    Ext.resumeLayouts(true);
                    // Here is the fix. Maybe wait for 'afterrender' before firing 'show'?
                    me.fireEvent("show", me);
                }
            } else {
                me.onShowVeto();
            }
        }
        return me;
    }
}, function() {
    Ext.Component.prototype.resourceManager = mx.resources.ResourceManager.getInstance();
});

/**
 * This supports the "is" operator for NodeInterface through duck typing.
 */
Ext.define('JooOverrides.Ext.data.NodeInterface', {
    override: 'Ext.data.NodeInterface',
    statics: {
        __isInstance__: function(object) {
            return object.isNode === true;
        }
    }
});

Ext.define('JooOverrides.Ext.Action', {
    override: 'Ext.Action',
    // patch constructor to avoid Actions being copied when their Component is added to a Container:
    constructor: function(config) {
        delete config.xclass;
        // prevent xclass from being applied to the component!
        config.baseAction = this;
        // self-reference, so that button references me, not my copy!
        this.callParent(arguments);
    },
    // patch for Actions being added to a Component via config's baseAction:
    addComponent: function(component) {
        component.setDisabled(this.isDisabled());
        component.setHidden(this.isHidden());
        return this.callParent(arguments);
    },
    /**
   * Sets the tooltip to be displayed by all components configured by this Action.
   * @param {String} tooltip The tooltip to display
   */
    setTooltip: function(tooltip) {
        this.initialConfig.tooltip = tooltip;
        this.callEach('setTooltip', [
            tooltip
        ]);
    },
    /**
   * Gets the tooltip currently displayed by all components configured by this Action.
   */
    getTooltip: function() {
        return this.initialConfig.tooltip;
    }
});

/**
 * This adds Ext JS 3.4 Legacy API to <code>Ext.container.Container</code>.
 */
Ext.define('JooOverrides.Ext.container.Container', {
    override: 'Ext.container.Container',
    // restore ext 3.4 behaviour
    bubbleEvents: [
        "add",
        "remove"
    ],
    /**
   * Find a component under this container at any level by property
   * @param {String} prop
   * @param {String} value
   * @deprecated Use <code>down(...)</code> or <code>query(...)</code> with selector <code>"[prop=value]"</code> instead.
   * @return {Array} Array of Ext.Components
   */
    find: function(prop, value) {
        return this.queryBy(function(c) {
            return c[prop] === value;
        });
    },
    /**
   * Find a component under this container at any level by xtype or class
   * @param {String/Class} xtype The xtype string for a component, or the class of the component directly
   * @param {Boolean} shallow (optional) False to check whether this Component is descended from the xtype (this is
   * the default), or true to check whether this Component is directly of the specified xtype.
   * @deprecated Use <code>down(...)</code> or <code>query(...)</code> with selector <code>"xtype"</code> instead. Use selector <code>"xtype(true)"</code> for shallow xtype lookup.
   * @return {Array} Array of Ext.Components
   */
    findByType: function(xtype, shallow) {
        return this.queryBy(function(c) {
            return typeof xtype === "function" ? c instanceof xtype : c.isXType(xtype, shallow);
        });
    }
}, function() {
    Object.defineProperty(Ext.container.Container.prototype, "itemCollection", {
        get: function() {
            return this.items;
        },
        enumerable: false,
        configurable: false
    });
});

/**
 * Fixes two things:
 * - When the title is attached to another container, remove the classes representing the container again that were
 *   introduced with the native onAdded method
 * - When changing the ui if the component, the correct css classes will be applied to the DOM. (applied the same way
 *   as the setUI fix for Buttons was provided by Sencha)
 */
Ext.define('JooOverrides.com.Ext.panel.Title', {
    override: 'Ext.panel.Title',
    updateChildElsUICls: function(add) {
        var me = this,
            ui = me.ui,
            state = add ? 'addCls' : 'removeCls',
            elClsMap = {
                'textEl': '_textCls',
                'iconEl': '_baseIconCls',
                'iconWrapEl': '_iconWrapCls'
            },
            key, el, mapCls, cls;
        for (key in elClsMap) {
            el = me[key];
            mapCls = elClsMap[key];
            cls = me[mapCls];
            if (el && cls) {
                el[state](cls + '-' + ui);
            }
        }
    },
    onRemoved: function(destroying) {
        var me = this,
            container = me.ownerCt;
        me.callParent([
            destroying
        ]);
        // makes only sense if the component is not destroyed anyway
        if (!destroying && container) {
            var suffix = me._titleSuffix,
                baseCls = container.baseCls;
            me.removeCls([
                baseCls + suffix,
                baseCls + suffix + '-' + container.ui
            ]);
        }
    },
    privates: {
        addUIToElement: function() {
            var me = this;
            me.callParent(arguments);
            me.updateChildElsUICls(true);
        },
        removeUIFromElement: function() {
            var me = this;
            me.updateChildElsUICls(false);
            me.callParent(arguments);
        }
    }
});

/**
 * Fixes setUI so that ui change will be delegated to the panel title if existing.
 */
Ext.define('JooOverrides.com.Ext.panel.Header', {
    override: 'Ext.panel.Header',
    /**
   * @inheritdoc
   */
    setUI: function(ui) {
        var me = this,
            title = me.title;
        if (title.rendered) {
            // panel title has set a class representing the container it was added to
            // this class must be removed before the ui change
            me.remove(title, false);
        }
        me.callParent(arguments);
        if (title.rendered) {
            // readd the title to the header
            me.add(title);
            title.setUI(ui);
        }
    }
});

/**
 * This adds Ext JS 3.4 Legacy API to <code>Ext.panel.Panel</code>.
 */
Ext.define('JooOverrides.Ext.panel.Panel', {
    override: 'Ext.panel.Panel',
    /**
   * Returns the {@link Ext.toolbar.Toolbar toolbar} from the top section of the panel.
   * @deprecated Use <code>getDockedItems(...)</code>, <code>down(...)</code> or <code>query(...)</code> with selector <code>'toolbar[dock="top"]'</code> instead.
   * @return {Ext.toolbar.Toolbar} The toolbar
   */
    getTopToolbar: function() {
        return this.getDockedItems('toolbar[dock="top"]')[0] || null;
    },
    /**
   * Returns the {@link Ext.toolbar.Toolbar toolbar} from the bottom section of the panel.
   * @deprecated Use <code>getDockedItems(...)</code>, <code>down(...)</code> or <code>query(...)</code> with selector <code>'toolbar[dock="bottom"][ui!="footer"]'</code> instead. Use selector <code>'toolbar[dock="bottom"]'</code> for not filtering out footer toolbars. Adapt <code>ui</code> parameter if your footer UI style has a different name.
   * @return {Ext.toolbar.Toolbar} The toolbar
   */
    getBottomToolbar: function() {
        return this.getDockedItems('toolbar[dock="bottom"][ui!="footer"]')[0] || null;
    },
    /**
   * Returns the {@link Ext.toolbar.Toolbar toolbar} from the footer section of the panel.
   * @deprecated Use <code>getDockedItems(...)</code>, <code>down(...)</code> or <code>query(...)</code> with selector <code>'toolbar[dock="bottom"][ui="footer"]'</code> instead. Adapt <code>ui</code> parameter if your footer UI style has a different name.
   * @return {Ext.toolbar.Toolbar} The toolbar
   */
    getFooterToolbar: function() {
        return this.getDockedItems('toolbar[dock="bottom"][ui="footer"]')[0] || null;
    }
});

// TODO: can be removed as soon as EXTJS-15982 is fixed.
Ext.define('Patch.form.field.Text', {
    override: 'Ext.form.field.Text',
    updateChildElsUICls: function(add) {
        var me = this,
            ui = me.ui,
            state = add ? 'addCls' : 'removeCls',
            elClsMap = {
                'triggerWrap': 'triggerWrapCls',
                'inputWrap': 'inputWrapCls',
                'inputEl': 'inputElCls'
            },
            key, el, mapCls, cls;
        for (key in elClsMap) {
            el = me[key];
            mapCls = elClsMap[key];
            cls = me[mapCls];
            if (el && cls) {
                el[state](cls + '-' + ui);
            }
        }
    },
    privates: {
        addUIToElement: function() {
            var me = this;
            me.callParent(arguments);
            me.updateChildElsUICls(true);
        },
        removeUIFromElement: function() {
            var me = this;
            me.callParent(arguments);
            me.updateChildElsUICls(false);
        }
    }
});

/**
 * This makes the constants of Ext.window.MessageBox static
 */
Ext.define('JooOverrides.Ext.window.MessageBox', {
    override: 'Ext.window.MessageBox'
}, function() {
    var consts = [
            "OK",
            "YES",
            "NO",
            "CANCEL",
            "OKCANCEL",
            "YESNO",
            "YESNOCANCEL",
            "INFO",
            "WARNING",
            "QUESTION",
            "ERROR"
        ];
    Ext.copyIf(Ext.window.MessageBox, Ext.window.MessageBox.prototype, consts);
});

/**
 * Override to fix componentLayout wrong calculation of height when labelAlign='top'
 *
 * See post forum:
 * {@link https://www.sencha.com/forum/showthread.php?311212-Fieldcontainer-incorrectly-displays-in-toolbar-with-label-aligned-top}
 *
 * Fixed in Ext 6.2.0
 */
Ext.define('MyApp.overrides.layout.component.field.FieldContainer', {
    override: 'Ext.layout.component.field.FieldContainer',
    compatibility: [
        '6.0.0',
        '6.0.1',
        '6.0.2'
    ],
    /* Begin Definitions */
    calculateOwnerHeightFromContentHeight: function(ownerContext, contentHeight) {
        var h = this.callSuper([
                ownerContext,
                contentHeight
            ]);
        return h + this.getHeightAdjustment();
    },
    calculateOwnerWidthFromContentWidth: function(ownerContext, contentWidth) {
        var w = this.callSuper([
                ownerContext,
                contentWidth
            ]);
        return w + this.getWidthAdjustment();
    },
    measureContentHeight: function(ownerContext) {
        // since we are measuring the outer el, we have to wait for whatever is in our
        // container to be flushed to the DOM... especially for things like box layouts
        // that size the innerCt since that is all that will contribute to our size!
        return ownerContext.hasDomProp('containerLayoutDone') ? this.callSuper([
            ownerContext
        ]) : NaN;
    },
    measureContentWidth: function(ownerContext) {
        // see measureContentHeight
        return ownerContext.hasDomProp('containerLayoutDone') ? this.callSuper([
            ownerContext
        ]) : NaN;
    },
    publishInnerHeight: function(ownerContext, height) {
        height -= this.getHeightAdjustment();
        ownerContext.containerElContext.setHeight(height);
    },
    publishInnerWidth: function(ownerContext, width) {
        width -= this.getWidthAdjustment();
        ownerContext.containerElContext.setWidth(width);
    },
    privates: {
        getHeightAdjustment: function() {
            var owner = this.owner,
                h = 0;
            if (owner.labelAlign === 'top' && owner.hasVisibleLabel()) {
                h += owner.labelEl.getHeight();
            }
            if (owner.msgTarget === 'under' && owner.hasActiveError()) {
                h += owner.errorWrapEl.getHeight();
            }
            return h + owner.bodyEl.getPadding('tb');
        },
        getWidthAdjustment: function() {
            var owner = this.owner,
                w = 0;
            if (owner.labelAlign !== 'top' && owner.hasVisibleLabel()) {
                w += (owner.labelWidth + (owner.labelPad || 0));
            }
            if (owner.msgTarget === 'side' && owner.hasActiveError()) {
                w += owner.errorWrapEl.getWidth();
            }
            return w + owner.bodyEl.getPadding('lr');
        }
    }
});

Ext.define("ext.Plugin", function(Plugin) {
    /*package ext {

/**
 * <p>A Plugin provides custom functionality for a component. The only requirement for
 * a valid plugin is that it contain an <code>init</code> method that accepts a reference of type <a href="#!/api/Ext.Component" rel="Ext.Component" class="docClass">Ext.Component</a>. When a component
 * is created, if any plugins are available, the component will call the init method on each plugin, passing a
 * reference to itself. Each plugin can then call methods or respond to events on the component as needed to provide
 * its functionality.</p>
 *
 * <p>Plugins can be added to component by either directly referencing the plugin instance:</p>
 *
 * <pre><code>plugins: [<a href="#!/api/Ext-method-create" rel="Ext-method-create" class="docClass">Ext.create</a>('<a href="#!/api/Ext.grid.plugin.CellEditing" rel="Ext.grid.plugin.CellEditing" class="docClass">Ext.grid.plugin.CellEditing</a>', {clicksToEdit: 1})],
 * </code></pre>
 *
 * <p>By using config object with ptype:</p>
 *
 * <pre><code>plugins: {ptype: 'cellediting', clicksToEdit: 1},
 * </code></pre>
 *
 * <p>Or with just a ptype:</p>
 *
 * <pre><code>plugins: ['cellediting', 'gridviewdragdrop'],
 * </code></pre>
 *
 * <p>See <a href="#!/api/Ext.enums.Plugin" rel="Ext.enums.Plugin" class="docClass">Ext.enums.Plugin</a> for list of all ptypes.</p>
 * @since 2.3.0
 *
 * @see ext.Component#plugins
 * @see ext.ComponentMgr#registerPlugin()
 * @see ext.ComponentMgr#createPlugin()
 * /
public interface Plugin {

  /**
   * The init method is invoked after initComponent method has been run for the client Component.
   *
   * <p>The supplied implementation is empty. Subclasses should perform plugin initialization, and set up bidirectional
   * links between the plugin and its client Component in their own implementation of this method.</p>
   * @param client The client Component which owns this plugin.
   * /
  function init(client:Component):void;

}
}

============================================== Jangaroo part ==============================================*/
    return {};
});

Ext.define("net.jangaroo.ext.FlExtEvent", function(FlExtEvent) {
    /* /**
 * Abstract base class of all Jangaroo Ext event classes.
 * /
package net.jangaroo.ext {

public class FlExtEvent {

  public*/
    function FlExtEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        this['type'] = type;
        var parameterSequence = /*:Array*/
            this['self'].__PARAMETER_SEQUENCE__;
        for (var i = /*:int*/
            0; i < parameterSequence.length; i++) {
            this[parameterSequence[i]] = arguments[i];
        }
    }
    /*

  /**
   * The type of event. The type is case-sensitive.
   * @see http://help.adobe.com/en_US/as3/dev/WS5b3ccc516d4fbf351e63e3d118a9b90204-7e55.html Event objects
   *
   * /
  public native function get type():String;

  /**
   * The options object passed to <a href="#!/api/Ext.util.Observable-method-addListener" rel="Ext.util.Observable-method-addListener" class="docClass">Ext.util.Observable.addListener</a>.
   * /
  public native function get eOpts():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        constructor: FlExtEvent$
    };
});

Ext.define("ext.button.events.Button_eEvent", function(Button_eEvent) {
    /*package ext.button.events {
import ext.button.Button;

import js.Event;

import net.jangaroo.ext.FlExtEvent;

public class Button_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Button_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when this button is clicked, before the configured <a href="#!/api/Ext.button.Button-cfg-handler" rel="Ext.button.Button-cfg-handler" class="docClass">handler</a> is invoked. Execution of the
   * <a href="#!/api/Ext.button.Button-cfg-handler" rel="Ext.button.Button-cfg-handler" class="docClass">handler</a> may be vetoed by returning <code>false</code> to this event.
   * @see ext.button.Button
   * @eventType onClick
   * /
  public static const CLICK:String = "onClick";
  /**
   * "Fires when the mouse exits the button
   * @see ext.button.Button
   * @eventType onMouseOut
   * /
  public static const MOUSE_OUT:String = "onMouseOut";
  /**
   * "Fires when the mouse hovers over the button
   * @see ext.button.Button
   * @eventType onMouseOver
   * /
  public static const MOUSE_OVER:String = "onMouseOver";

  public*/
    function Button_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Button;

  /**
   * The click event
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Button_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CLICK: "onClick",
            MOUSE_OUT: "onMouseOut",
            MOUSE_OVER: "onMouseOver",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.button.events.Button_menuEvent", function(Button_menuEvent) {
    /*package ext.button.events {
import ext.button.Button;
import ext.menu.Menu;

import net.jangaroo.ext.FlExtEvent;

public class Button_menuEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Button_menuEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "menu",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "If this button has a menu, this event fires when it is hidden
   * @see ext.button.Button
   * @eventType onMenuHide
   * /
  public static const MENU_HIDE:String = "onMenuHide";
  /**
   * "If this button has a menu, this event fires when it is shown
   * @see ext.button.Button
   * @eventType onMenuShow
   * /
  public static const MENU_SHOW:String = "onMenuShow";

  public*/
    function Button_menuEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Button;

  public native function get menu():Menu;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Button_menuEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            MENU_HIDE: "onMenuHide",
            MENU_SHOW: "onMenuShow",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.button.events.Button_menu_eEvent", function(Button_menu_eEvent) {
    /*package ext.button.events {
import ext.button.Button;
import ext.menu.Menu;

import js.Event;

import net.jangaroo.ext.FlExtEvent;

public class Button_menu_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Button_menu_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "menu",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "If this button has a menu, this event fires when the mouse leaves the menu triggering element
   * @see ext.button.Button
   * @eventType onMenuTriggerOut
   * /
  public static const MENU_TRIGGER_OUT:String = "onMenuTriggerOut";
  /**
   * "If this button has a menu, this event fires when the mouse enters the menu triggering element
   * @see ext.button.Button
   * @eventType onMenuTriggerOver
   * /
  public static const MENU_TRIGGER_OVER:String = "onMenuTriggerOver";

  public*/
    function Button_menu_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Button;

  public native function get menu():Menu;

  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Button_menu_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            MENU_TRIGGER_OUT: "onMenuTriggerOut",
            MENU_TRIGGER_OVER: "onMenuTriggerOver",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.button.events.Button_newGlyph_oldGlyphEvent", function(Button_newGlyph_oldGlyphEvent) {
    /*package ext.button.events {
import ext.button.Button;

import net.jangaroo.ext.FlExtEvent;

public class Button_newGlyph_oldGlyphEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Button_newGlyph_oldGlyphEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "newGlyph",
            "oldGlyph",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when the button's glyph is changed by the <a href="#!/api/Ext.button.Button-method-setGlyph" rel="Ext.button.Button-method-setGlyph" class="docClass">setGlyph</a> method.
   * @see ext.button.Button
   * @eventType onGlyphChange
   * /
  public static const GLYPH_CHANGE:String = "onGlyphChange";

  public*/
    function Button_newGlyph_oldGlyphEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Button;

  public native function get newGlyph():*;

  public native function get oldGlyph():*;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Button_newGlyph_oldGlyphEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            GLYPH_CHANGE: "onGlyphChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.button.events.Button_oldIcon_newIconEvent", function(Button_oldIcon_newIconEvent) {
    /*package ext.button.events {
import ext.button.Button;

import net.jangaroo.ext.FlExtEvent;

public class Button_oldIcon_newIconEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Button_oldIcon_newIconEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "oldIcon",
            "newIcon",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when the button's icon is changed by the <a href="#!/api/Ext.button.Button-method-setIcon" rel="Ext.button.Button-method-setIcon" class="docClass">setIcon</a> or <a href="#!/api/Ext.button.Button-method-setIconCls" rel="Ext.button.Button-method-setIconCls" class="docClass">setIconCls</a> methods.
   * @see ext.button.Button
   * @eventType onIconChange
   * /
  public static const ICON_CHANGE:String = "onIconChange";

  public*/
    function Button_oldIcon_newIconEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Button;

  public native function get oldIcon():String;

  public native function get newIcon():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Button_oldIcon_newIconEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ICON_CHANGE: "onIconChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.button.events.Button_oldText_newTextEvent", function(Button_oldText_newTextEvent) {
    /*package ext.button.events {
import ext.button.Button;

import net.jangaroo.ext.FlExtEvent;

public class Button_oldText_newTextEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Button_oldText_newTextEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "oldText",
            "newText",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when the button's text is changed by the <a href="#!/api/Ext.button.Button-method-setText" rel="Ext.button.Button-method-setText" class="docClass">setText</a> method.
   * @see ext.button.Button
   * @eventType onTextChange
   * /
  public static const TEXT_CHANGE:String = "onTextChange";

  public*/
    function Button_oldText_newTextEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Button;

  public native function get oldText():String;

  public native function get newText():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Button_oldText_newTextEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            TEXT_CHANGE: "onTextChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.button.events.Button_pressedEvent", function(Button_pressedEvent) {
    /*package ext.button.events {
import ext.button.Button;

import net.jangaroo.ext.FlExtEvent;

public class Button_pressedEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Button_pressedEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "pressed",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the 'pressed' state of this button changes (only if enableToggle = true)
   * If a handler returns <code>false</code>, the toggle is vetoed.
   * @see ext.button.Button
   * @eventType onBeforeToggle
   * /
  public static const BEFORE_TOGGLE:String = "onBeforeToggle";
  /**
   * "Fires when the 'pressed' state of this button changes (only if enableToggle = true)
   * @see ext.button.Button
   * @eventType onToggle
   * /
  public static const TOGGLE:String = "onToggle";

  public*/
    function Button_pressedEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Button;

  public native function get pressed():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Button_pressedEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_TOGGLE: "onBeforeToggle",
            TOGGLE: "onToggle",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.button.events.CycleButton_itemEvent", function(CycleButton_itemEvent) {
    /*package ext.button.events {
import ext.button.CycleButton;
import ext.menu.CheckItem;

import net.jangaroo.ext.FlExtEvent;

public class CycleButton_itemEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        CycleButton_itemEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "item",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after the button's active menu item has changed. Note that if a <a href="#!/api/Ext.button.Cycle-cfg-changeHandler" rel="Ext.button.Cycle-cfg-changeHandler" class="docClass">changeHandler</a> function is
   * set on this CycleButton, it will be called instead on active item change and this change event will not
   * be fired.
   * @see ext.button.CycleButton
   * @eventType onChange
   * /
  public static const CHANGE:String = "onChange";

  public*/
    function CycleButton_itemEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():CycleButton;

  /**
   * The menu item that was selected
   * /
  public native function get item():CheckItem;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: CycleButton_itemEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CHANGE: "onChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.button.events.SegmentedButton_button_isPressedEvent", function(SegmentedButton_button_isPressedEvent) {
    /*package ext.button.events {
import ext.button.Button;
import ext.button.SegmentedButton;

import net.jangaroo.ext.FlExtEvent;

public class SegmentedButton_button_isPressedEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        SegmentedButton_button_isPressedEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "button",
            "isPressed",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when any child button's pressed state has changed.
   * @see ext.button.SegmentedButton
   * @eventType onToggle
   * /
  public static const TOGGLE:String = "onToggle";

  public*/
    function SegmentedButton_button_isPressedEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():SegmentedButton;

  /**
   * The toggled button.
   * /
  public native function get button():Button;

  /**
   * <code>true</code> to indicate if the button was pressed.
   * /
  public native function get isPressed():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: SegmentedButton_button_isPressedEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            TOGGLE: "onToggle",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.button.events.SegmentedButton_newValue_oldValueEvent", function(SegmentedButton_newValue_oldValueEvent) {
    /*package ext.button.events {
import ext.button.SegmentedButton;

import net.jangaroo.ext.FlExtEvent;

public class SegmentedButton_newValue_oldValueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        SegmentedButton_newValue_oldValueEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "newValue",
            "oldValue",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when any child button's pressed state has changed and caused the value to change.
   * @see ext.button.SegmentedButton
   * @eventType onChange
   * /
  public static const CHANGE:String = "onChange";

  public*/
    function SegmentedButton_newValue_oldValueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():SegmentedButton;

  /**
   * The new value.
   * /
  public native function get newValue():Array;

  /**
   * The old value.
   * /
  public native function get oldValue():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: SegmentedButton_newValue_oldValueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CHANGE: "onChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.button.events.SplitButton_eEvent", function(SplitButton_eEvent) {
    /*package ext.button.events {
import ext.button.SplitButton;

import js.Event;

import net.jangaroo.ext.FlExtEvent;

public class SplitButton_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        SplitButton_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when this button's arrow is clicked.
   * @see ext.button.SplitButton
   * @eventType onArrowClick
   * /
  public static const ARROW_CLICK:String = "onArrowClick";

  public*/
    function SplitButton_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():SplitButton;

  /**
   * The click event.
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: SplitButton_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ARROW_CLICK: "onArrowClick",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.container.events.Container_componentEvent", function(Container_componentEvent) {
    /*package ext.container.events {
import ext.Component;
import ext.container.Container;

import net.jangaroo.ext.FlExtEvent;

public class Container_componentEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Container_componentEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "component",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before any <a href="#!/api/Ext.Component" rel="Ext.Component" class="docClass">Ext.Component</a> is removed from the container.  A handler can return
   * false to cancel the remove.
   * @since 2.3.0
   * @see ext.container.Container
   * @eventType onBeforeRemove
   * /
  public static const BEFORE_REMOVE:String = "onBeforeRemove";
  /**
   * "Fires after any <a href="#!/api/Ext.Component" rel="Ext.Component" class="docClass">Ext.Component</a> is removed from the container.
   * @since 2.3.0
   * @see ext.container.Container
   * @eventType onRemove
   * /
  public static const REMOVE:String = "onRemove";

  public*/
    function Container_componentEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Container;

  /**
   * The component being removed
   * /
  public native function get component():Component;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Container_componentEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_REMOVE: "onBeforeRemove",
            REMOVE: "onRemove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.container.events.Container_component_indexEvent", function(Container_component_indexEvent) {
    /*package ext.container.events {
import ext.Component;
import ext.container.Container;

import net.jangaroo.ext.FlExtEvent;

public class Container_component_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Container_component_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "component",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after any <a href="#!/api/Ext.Component" rel="Ext.Component" class="docClass">Ext.Component</a> is added or inserted into the container.
   * @since 2.3.0
   * @see ext.container.Container
   * @eventType onAdd
   * /
  public static const ADD:String = "onAdd";
  /**
   * "Fires before any <a href="#!/api/Ext.Component" rel="Ext.Component" class="docClass">Ext.Component</a> is added or inserted into the container.
   * A handler can return false to cancel the add.
   * @since 2.3.0
   * @see ext.container.Container
   * @eventType onBeforeAdd
   * /
  public static const BEFORE_ADD:String = "onBeforeAdd";

  public*/
    function Container_component_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Container;

  /**
   * The component that was added
   * /
  public native function get component():Component;

  /**
   * The index at which the component was added to the container's items collection
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Container_component_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ADD: "onAdd",
            BEFORE_ADD: "onBeforeAdd",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.container.events.Container_component_prevIndex_newIndexEvent", function(Container_component_prevIndex_newIndexEvent) {
    /*package ext.container.events {
import ext.Component;
import ext.container.Container;

import net.jangaroo.ext.FlExtEvent;

public class Container_component_prevIndex_newIndexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Container_component_prevIndex_newIndexEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "component",
            "prevIndex",
            "newIndex",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after any <a href="#!/api/Ext.Component" rel="Ext.Component" class="docClass">Ext.Component</a> has changed its ordinal position within the container.
   * @see ext.container.Container
   * @eventType onChildMove
   * /
  public static const CHILD_MOVE:String = "onChildMove";

  public*/
    function Container_component_prevIndex_newIndexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Container;

  /**
   * The component that was moved
   * /
  public native function get component():Component;

  /**
   * The previous ordinal position of the Component
   * /
  public native function get prevIndex():Number;

  /**
   * The new ordinal position of the Component
   * /
  public native function get newIndex():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Container_component_prevIndex_newIndexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CHILD_MOVE: "onChildMove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.container.events.Container_layoutEvent", function(Container_layoutEvent) {
    /*package ext.container.events {
import ext.container.Container;
import ext.layout.container.ContainerLayout;

import net.jangaroo.ext.FlExtEvent;

public class Container_layoutEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Container_layoutEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "layout",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the components in this container are arranged by the associated layout manager.
   * @since 2.3.0
   * @see ext.container.Container
   * @eventType onAfterLayout
   * /
  public static const AFTER_LAYOUT:String = "onAfterLayout";

  public*/
    function Container_layoutEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Container;

  /**
   * The ContainerLayout implementation for this container
   * /
  public native function get layout():ContainerLayout;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Container_layoutEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            AFTER_LAYOUT: "onAfterLayout",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.container.events.DockingContainer_componentEvent", function(DockingContainer_componentEvent) {
    /*package ext.container.events {
import ext.Component;
import ext.panel.Panel;

import net.jangaroo.ext.FlExtEvent;

public class DockingContainer_componentEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DockingContainer_componentEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "component",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when any <a href="#!/api/Ext.Component" rel="Ext.Component" class="docClass">Ext.Component</a> is removed from the docked items.
   * @see ext.container.DockingContainer
   * @eventType onDockedRemove
   * /
  public static const DOCKED_REMOVE:String = "onDockedRemove";

  public*/
    function DockingContainer_componentEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Panel;

  /**
   * The component being removed
   * /
  public native function get component():Component;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DockingContainer_componentEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DOCKED_REMOVE: "onDockedRemove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.container.events.DockingContainer_component_indexEvent", function(DockingContainer_component_indexEvent) {
    /*package ext.container.events {
import ext.Component;
import ext.panel.Panel;

import net.jangaroo.ext.FlExtEvent;

public class DockingContainer_component_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DockingContainer_component_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "component",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when any <a href="#!/api/Ext.Component" rel="Ext.Component" class="docClass">Ext.Component</a> is added or inserted as a docked item.
   * @see ext.container.DockingContainer
   * @eventType onDockedAdd
   * /
  public static const DOCKED_ADD:String = "onDockedAdd";

  public*/
    function DockingContainer_component_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Panel;

  /**
   * The component being added
   * /
  public native function get component():Component;

  /**
   * The index at which the component will be added docked items collection
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DockingContainer_component_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DOCKED_ADD: "onDockedAdd",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.dashboard.events.DashboardEvent", function(DashboardEvent) {
    /*package ext.dashboard.events {
import net.jangaroo.ext.FlExtEvent;

public class DashboardEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DashboardEvent.__PARAMETER_SEQUENCE__ = ([
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @see ext.dashboard.Dashboard
   * @eventType onBeforeDragOver
   * /
  public static const BEFORE_DRAG_OVER:String = "onBeforeDragOver";
  /**
   * "
   * @see ext.dashboard.Dashboard
   * @eventType onBeforeDrop
   * /
  public static const BEFORE_DROP:String = "onBeforeDrop";
  /**
   * "
   * @see ext.dashboard.Dashboard
   * @eventType onDragOver
   * /
  public static const DRAG_OVER:String = "onDragOver";
  /**
   * "
   * @see ext.dashboard.Dashboard
   * @eventType onDrop
   * /
  public static const DROP:String = "onDrop";
  /**
   * "
   * @see ext.dashboard.Dashboard
   * @eventType onValidateDrop
   * /
  public static const VALIDATE_DROP:String = "onValidateDrop";

  public*/
    function DashboardEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DashboardEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_DRAG_OVER: "onBeforeDragOver",
            BEFORE_DROP: "onBeforeDrop",
            DRAG_OVER: "onDragOver",
            DROP: "onDrop",
            VALIDATE_DROP: "onValidateDrop",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.AbstractStoreEvent", function(AbstractStoreEvent) {
    /*package ext.data.events {
import net.jangaroo.ext.FlExtEvent;

public class AbstractStoreEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractStoreEvent.__PARAMETER_SEQUENCE__ = ([
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the <a href="#!/api/Ext.data.AbstractStore-method-beginUpdate" rel="Ext.data.AbstractStore-method-beginUpdate" class="docClass">beginUpdate</a> method is called. Automatic synchronization as configured
   * by the <a href="#!/api/Ext.data.ProxyStore-cfg-autoSync" rel="Ext.data.ProxyStore-cfg-autoSync" class="docClass">autoSync</a> flag is deferred until the <a href="#!/api/Ext.data.AbstractStore-method-endUpdate" rel="Ext.data.AbstractStore-method-endUpdate" class="docClass">endUpdate</a> method is called, so multiple
   * mutations can be coalesced into one synchronization operation.
   * @see ext.data.AbstractStore
   * @eventType onBeginUpdate
   * /
  public static const BEGIN_UPDATE:String = "onBeginUpdate";
  /**
   * "Fired after the <a href="#!/api/Ext.data.Store-method-removeAll" rel="Ext.data.Store-method-removeAll" class="docClass">removeAll</a> method is called.
   * @since 1.1.0
   * @see ext.data.AbstractStore
   * @eventType onClear
   * /
  public static const CLEAR:String = "onClear";
  /**
   * "Fires whenever records are added to or removed from the Store.
   *
   * <p>To hook into modifications of records in this Store use the <a href="#!/api/Ext.data.AbstractStore-event-update" rel="Ext.data.AbstractStore-event-update" class="docClass">update</a> event.</p>
   * @since 1.1.0
   * @see ext.data.AbstractStore
   * @eventType onDataChanged
   * /
  public static const DATA_CHANGED:String = "onDataChanged";
  /**
   * "Fires when the <a href="#!/api/Ext.data.AbstractStore-method-endUpdate" rel="Ext.data.AbstractStore-method-endUpdate" class="docClass">endUpdate</a> method is called. Automatic synchronization as configured
   * by the <a href="#!/api/Ext.data.ProxyStore-cfg-autoSync" rel="Ext.data.ProxyStore-cfg-autoSync" class="docClass">autoSync</a> flag is deferred until the <a href="#!/api/Ext.data.AbstractStore-method-endUpdate" rel="Ext.data.AbstractStore-method-endUpdate" class="docClass">endUpdate</a> method is called, so multiple
   * mutations can be coalesced into one synchronization operation.
   * @see ext.data.AbstractStore
   * @eventType onEndUpdate
   * /
  public static const END_UPDATE:String = "onEndUpdate";
  /**
   * "Fires when the data cache has changed in a bulk manner (e.g., it has been sorted, filtered, etc.) and a
   * widget that is using this Store as a Record cache should refresh its view.
   * @see ext.data.AbstractStore
   * @eventType onRefresh
   * /
  public static const REFRESH:String = "onRefresh";

  public*/
    function AbstractStoreEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractStoreEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEGIN_UPDATE: "onBeginUpdate",
            CLEAR: "onClear",
            DATA_CHANGED: "onDataChanged",
            END_UPDATE: "onEndUpdate",
            REFRESH: "onRefresh",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.AbstractStore_record_operation_modifiedFieldNames_detailsEvent", function(AbstractStore_record_operation_modifiedFieldNames_detailsEvent) {
    /*package ext.data.events {
import ext.data.Model;
import ext.data.Store;

import net.jangaroo.ext.FlExtEvent;

public class AbstractStore_record_operation_modifiedFieldNames_detailsEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractStore_record_operation_modifiedFieldNames_detailsEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "record",
            "operation",
            "modifiedFieldNames",
            "details",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a Model instance has been updated.
   * @since 1.1.0
   * @see ext.data.AbstractStore
   * @eventType onUpdate
   * /
  public static const UPDATE:String = "onUpdate";

  public*/
    function AbstractStore_record_operation_modifiedFieldNames_detailsEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Store;

  /**
   * The Model instance that was updated
   * /
  public native function get record():Model;

  /**
   * The update operation being performed. Value may be one of:
   * <pre><code><a href="#!/api/Ext.data.Model-static-property-EDIT" rel="Ext.data.Model-static-property-EDIT" class="docClass">Ext.data.Model.EDIT</a>
   * <a href="#!/api/Ext.data.Model-static-property-REJECT" rel="Ext.data.Model-static-property-REJECT" class="docClass">Ext.data.Model.REJECT</a>
   * <a href="#!/api/Ext.data.Model-static-property-COMMIT" rel="Ext.data.Model-static-property-COMMIT" class="docClass">Ext.data.Model.COMMIT</a>
   * </code></pre>
   * /
  public native function get operation():String;

  /**
   * Array of field names changed during edit.
   * /
  public native function get modifiedFieldNames():Array;

  /**
   * An object describing the change. See the
   * <a href="#!/api/Ext.util.Collection-event-itemchange" rel="Ext.util.Collection-event-itemchange" class="docClass">itemchange event</a> of the store's backing collection
   * /
  public native function get details():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractStore_record_operation_modifiedFieldNames_detailsEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            UPDATE: "onUpdate",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.AbstractStore_storeEvent", function(AbstractStore_storeEvent) {
    /*package ext.data.events {
import ext.data.Store;

import net.jangaroo.ext.FlExtEvent;

public class AbstractStore_storeEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractStore_storeEvent.__PARAMETER_SEQUENCE__ = ([
            "store",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after a store is sorted.
   *
   * <p>For <a href="#!/api/Ext.data.AbstractStore-cfg-remoteSort" rel="Ext.data.AbstractStore-cfg-remoteSort" class="docClass">remotely sorted</a> stores, this will be upon the success of a load operation triggered by
   * changing the store's sorters.</p>
   *
   * <p>For locally sorted stores, this will be just after the data items in the store's backing collection are sorted.</p>
   * @see ext.data.AbstractStore
   * @eventType onSort
   * /
  public static const SORT:String = "onSort";

  public*/
    function AbstractStore_storeEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The store being sorted
   * /
  public native function get store():Store;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractStore_storeEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SORT: "onSort",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.AbstractStore_store_records_indexEvent", function(AbstractStore_store_records_indexEvent) {
    /*package ext.data.events {
import ext.data.Store;

import net.jangaroo.ext.FlExtEvent;

public class AbstractStore_store_records_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractStore_store_records_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "store",
            "records",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when a Model instance has been added to this Store.
   * @since 1.1.0
   * @see ext.data.AbstractStore
   * @eventType onAdd
   * /
  public static const ADD:String = "onAdd";

  public*/
    function AbstractStore_store_records_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The store.
   * /
  public native function get store():Store;

  /**
   * The records that were added.
   * /
  public native function get records():Array;

  /**
   * The index at which the records were inserted.
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractStore_store_records_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ADD: "onAdd",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.AbstractStore_store_records_index_isMoveEvent", function(AbstractStore_store_records_index_isMoveEvent) {
    /*package ext.data.events {
import ext.data.Store;

import net.jangaroo.ext.FlExtEvent;

public class AbstractStore_store_records_index_isMoveEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractStore_store_records_index_isMoveEvent.__PARAMETER_SEQUENCE__ = ([
            "store",
            "records",
            "index",
            "isMove",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when one or more records have been removed from this Store.
   *
   * <p><strong>The signature for this event has changed in 5.0: </strong></p>
   * @since 5.0.0
   * @see ext.data.AbstractStore
   * @eventType onRemove
   * /
  public static const REMOVE:String = "onRemove";

  public*/
    function AbstractStore_store_records_index_isMoveEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The Store object
   * /
  public native function get store():Store;

  /**
   * The records that were removed. In previous
   * releases this was a single record, not an array.
   * /
  public native function get records():Array;

  /**
   * The index at which the records were removed.
   * /
  public native function get index():Number;

  /**
   * <code>true</code> if the child node is being removed so it can be
   * moved to another position in this Store.
   * /
  public native function get isMove():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractStore_store_records_index_isMoveEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            REMOVE: "onRemove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.AbstractStore_store_sortersEvent", function(AbstractStore_store_sortersEvent) {
    /*package ext.data.events {
import ext.data.Store;

import net.jangaroo.ext.FlExtEvent;

public class AbstractStore_store_sortersEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractStore_store_sortersEvent.__PARAMETER_SEQUENCE__ = ([
            "store",
            "sorters",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a store is sorted.
   *
   * <p>For <a href="#!/api/Ext.data.AbstractStore-cfg-remoteSort" rel="Ext.data.AbstractStore-cfg-remoteSort" class="docClass">remotely sorted</a> stores, this will be just before the load operation triggered by changing the
   * store's sorters.</p>
   *
   * <p>For locally sorted stores, this will be just before the data items in the store's backing collection are sorted.</p>
   * @see ext.data.AbstractStore
   * @eventType onBeforeSort
   * /
  public static const BEFORE_SORT:String = "onBeforeSort";

  public*/
    function AbstractStore_store_sortersEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The store being sorted
   * /
  public native function get store():Store;

  /**
   * Array of sorters applied to the store
   * /
  public native function get sorters():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractStore_store_sortersEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_SORT: "onBeforeSort",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.Batch_operationEvent", function(Batch_operationEvent) {
    /*package ext.data.events {
import ext.data.Batch;

import net.jangaroo.ext.FlExtEvent;

public class Batch_operationEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Batch_operationEvent.__PARAMETER_SEQUENCE__ = ([
            "batch",
            "operation",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when all operations of this batch have been completed
   * @see ext.data.Batch
   * @eventType onComplete
   * /
  public static const COMPLETE:String = "onComplete";
  /**
   * "Fired when a operation encountered an exception
   * @see ext.data.Batch
   * @eventType onException
   * /
  public static const EXCEPTION:String = "onException";
  /**
   * "Fired when each operation of the batch completes
   * @see ext.data.Batch
   * @eventType onOperationComplete
   * /
  public static const OPERATION_COMPLETE:String = "onOperationComplete";

  public*/
    function Batch_operationEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The batch object
   * /
  public native function get batch():Batch;

  /**
   * The last operation that was executed
   * /
  public native function get operation():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Batch_operationEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            COMPLETE: "onComplete",
            EXCEPTION: "onException",
            OPERATION_COMPLETE: "onOperationComplete",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.Connection_optionsEvent", function(Connection_optionsEvent) {
    /*package ext.data.events {
import ext.data.Connection;

import net.jangaroo.ext.FlExtEvent;

public class Connection_optionsEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Connection_optionsEvent.__PARAMETER_SEQUENCE__ = ([
            "conn",
            "options",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a network request is made to retrieve a data object.
   * @see ext.data.Connection
   * @eventType onBeforeRequest
   * /
  public static const BEFORE_REQUEST:String = "onBeforeRequest";

  public*/
    function Connection_optionsEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This Connection object.
   * /
  public native function get conn():Connection;

  /**
   * The options config object passed to the <a href="#!/api/Ext.data.Connection-method-request" rel="Ext.data.Connection-method-request" class="docClass">request</a> method.
   * /
  public native function get options():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Connection_optionsEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_REQUEST: "onBeforeRequest",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.Connection_response_optionsEvent", function(Connection_response_optionsEvent) {
    /*package ext.data.events {
import ext.data.Connection;

import net.jangaroo.ext.FlExtEvent;

public class Connection_response_optionsEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Connection_response_optionsEvent.__PARAMETER_SEQUENCE__ = ([
            "conn",
            "response",
            "options",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires if the request was successfully completed.
   * @see ext.data.Connection
   * @eventType onRequestComplete
   * /
  public static const REQUEST_COMPLETE:String = "onRequestComplete";
  /**
   * "Fires if an error HTTP status was returned from the server. This event may also
   * be listened to in the event that a request has timed out or has been aborted.
   * See <a href="http://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html">HTTP Status Code Definitions</a>
   * for details of HTTP status codes.
   * @see ext.data.Connection
   * @eventType onRequestException
   * /
  public static const REQUEST_EXCEPTION:String = "onRequestException";

  public*/
    function Connection_response_optionsEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This Connection object.
   * /
  public native function get conn():Connection;

  /**
   * The XHR object containing the response data.
   * See <a href="http://www.w3.org/TR/XMLHttpRequest/">The XMLHttpRequest Object</a> for details.
   * /
  public native function get response():Object;

  /**
   * The options config object passed to the <a href="#!/api/Ext.data.Connection-method-request" rel="Ext.data.Connection-method-request" class="docClass">request</a> method.
   * /
  public native function get options():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Connection_response_optionsEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            REQUEST_COMPLETE: "onRequestComplete",
            REQUEST_EXCEPTION: "onRequestException",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.NodeInterfaceEvent", function(NodeInterfaceEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class NodeInterfaceEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        NodeInterfaceEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before this node is collapsed.
   * @see ext.data.NodeInterface
   * @eventType onBeforeCollapse
   * /
  public static const BEFORE_COLLAPSE:String = "onBeforeCollapse";
  /**
   * "Fires before this node is expanded.
   * @see ext.data.NodeInterface
   * @eventType onBeforeExpand
   * /
  public static const BEFORE_EXPAND:String = "onBeforeExpand";
  /**
   * "Fires when this node is collapsed.
   * @see ext.data.NodeInterface
   * @eventType onCollapse
   * /
  public static const COLLAPSE:String = "onCollapse";
  /**
   * "Fires when this node is expanded.
   * @see ext.data.NodeInterface
   * @eventType onExpand
   * /
  public static const EXPAND:String = "onExpand";

  public*/
    function NodeInterfaceEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The collapsing node
   * /
  public native function get source():NodeInterface;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: NodeInterfaceEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_COLLAPSE: "onBeforeCollapse",
            BEFORE_EXPAND: "onBeforeExpand",
            COLLAPSE: "onCollapse",
            EXPAND: "onExpand",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.NodeInterface_childNodesEvent", function(NodeInterface_childNodesEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class NodeInterface_childNodesEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        NodeInterface_childNodesEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "childNodes",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when this node's childNodes are sorted.
   * @see ext.data.NodeInterface
   * @eventType onSort
   * /
  public static const SORT:String = "onSort";

  public*/
    function NodeInterface_childNodesEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node.
   * /
  public native function get source():NodeInterface;

  /**
   * The childNodes of this node.
   * /
  public native function get childNodes():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: NodeInterface_childNodesEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SORT: "onSort",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.NodeInterface_nodeEvent", function(NodeInterface_nodeEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class NodeInterface_nodeEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        NodeInterface_nodeEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a new child is appended, return false to cancel the append.
   * @see ext.data.NodeInterface
   * @eventType onBeforeAppend
   * /
  public static const BEFORE_APPEND:String = "onBeforeAppend";

  public*/
    function NodeInterface_nodeEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The child node to be appended
   * /
  public native function get node():NodeInterface;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: NodeInterface_nodeEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_APPEND: "onBeforeAppend",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.NodeInterface_node_indexEvent", function(NodeInterface_node_indexEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class NodeInterface_node_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        NodeInterface_node_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a new child node is appended
   * @see ext.data.NodeInterface
   * @eventType onAppend
   * /
  public static const APPEND:String = "onAppend";

  public*/
    function NodeInterface_node_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The newly appended node
   * /
  public native function get node():NodeInterface;

  /**
   * The index of the newly appended node
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: NodeInterface_node_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            APPEND: "onAppend",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.NodeInterface_node_isMoveEvent", function(NodeInterface_node_isMoveEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class NodeInterface_node_isMoveEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        NodeInterface_node_isMoveEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "isMove",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a child is removed, return false to cancel the remove.
   * @see ext.data.NodeInterface
   * @eventType onBeforeRemove
   * /
  public static const BEFORE_REMOVE:String = "onBeforeRemove";

  public*/
    function NodeInterface_node_isMoveEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The child node to be removed
   * /
  public native function get node():NodeInterface;

  /**
   * <code>true</code> if the child node is being removed so it can be moved to another position in the tree.
   * (a side effect of calling <a href="#!/api/Ext.data.NodeInterface-method-appendChild" rel="Ext.data.NodeInterface-method-appendChild" class="docClass">appendChild</a> or
   * <a href="#!/api/Ext.data.NodeInterface-method-insertBefore" rel="Ext.data.NodeInterface-method-insertBefore" class="docClass">insertBefore</a> with a node that already has a parentNode)
   * /
  public native function get isMove():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: NodeInterface_node_isMoveEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_REMOVE: "onBeforeRemove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.NodeInterface_node_isMove_contextEvent", function(NodeInterface_node_isMove_contextEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class NodeInterface_node_isMove_contextEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        NodeInterface_node_isMove_contextEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "isMove",
            "context",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a child node is removed
   * @see ext.data.NodeInterface
   * @eventType onRemove
   * /
  public static const REMOVE:String = "onRemove";

  public*/
    function NodeInterface_node_isMove_contextEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The removed node
   * /
  public native function get node():NodeInterface;

  /**
   * <code>true</code> if the child node is being removed so it can be moved to another position in the tree.
   * /
  public native function get isMove():Boolean;

  /**
   * An object providing information about where the removed node came from. It contains the following properties:
   * <ul>
   *   <li><code>parentNode</code> : ext.data.NodeInterface
   * The node from which the removed node was removed.
   *   </li>
   *   <li><code>previousSibling</code> : ext.data.NodeInterface
   * The removed node's former previous sibling.
   *   </li>
   *   <li><code>nextSibling</code> : ext.data.NodeInterface
   * The removed node's former next sibling.
   * (a side effect of calling <a href="#!/api/Ext.data.NodeInterface-method-appendChild" rel="Ext.data.NodeInterface-method-appendChild" class="docClass">appendChild</a> or
   * <a href="#!/api/Ext.data.NodeInterface-method-insertBefore" rel="Ext.data.NodeInterface-method-insertBefore" class="docClass">insertBefore</a> with a node that already has a parentNode)
   *   </li>
   * </ul>
   * /
  public native function get context():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: NodeInterface_node_isMove_contextEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            REMOVE: "onRemove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.NodeInterface_node_refNodeEvent", function(NodeInterface_node_refNodeEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class NodeInterface_node_refNodeEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        NodeInterface_node_refNodeEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "refNode",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a new child is inserted, return false to cancel the insert.
   * @see ext.data.NodeInterface
   * @eventType onBeforeInsert
   * /
  public static const BEFORE_INSERT:String = "onBeforeInsert";
  /**
   * "Fires when a new child node is inserted.
   * @see ext.data.NodeInterface
   * @eventType onInsert
   * /
  public static const INSERT:String = "onInsert";

  public*/
    function NodeInterface_node_refNodeEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The child node to be inserted
   * /
  public native function get node():NodeInterface;

  /**
   * The child node the node is being inserted before
   * /
  public native function get refNode():NodeInterface;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: NodeInterface_node_refNodeEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_INSERT: "onBeforeInsert",
            INSERT: "onInsert",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.NodeInterface_oldParent_newParent_indexEvent", function(NodeInterface_oldParent_newParent_indexEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class NodeInterface_oldParent_newParent_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        NodeInterface_oldParent_newParent_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "oldParent",
            "newParent",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before this node is moved to a new location in the tree. Return false to cancel the move.
   * @see ext.data.NodeInterface
   * @eventType onBeforeMove
   * /
  public static const BEFORE_MOVE:String = "onBeforeMove";
  /**
   * "Fires when this node is moved to a new location in the tree
   * @see ext.data.NodeInterface
   * @eventType onMove
   * /
  public static const MOVE:String = "onMove";

  public*/
    function NodeInterface_oldParent_newParent_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The parent of this node
   * /
  public native function get oldParent():NodeInterface;

  /**
   * The new parent this node is moving to
   * /
  public native function get newParent():NodeInterface;

  /**
   * The index it is being moved to
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: NodeInterface_oldParent_newParent_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_MOVE: "onBeforeMove",
            MOVE: "onMove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.ProxyStore_metaEvent", function(ProxyStore_metaEvent) {
    /*package ext.data.events {
import ext.data.Store;

import net.jangaroo.ext.FlExtEvent;

public class ProxyStore_metaEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ProxyStore_metaEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "meta",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when this store's underlying reader (available via the proxy) provides new metadata.
   * Metadata usually consists of new field definitions, but can include any configuration data
   * required by an application, and can be processed as needed in the event handler.
   * This event is currently only fired for JsonReaders.
   * @since 1.1.0
   * @see ext.data.ProxyStore
   * @eventType onMetaChange
   * /
  public static const META_CHANGE:String = "onMetaChange";

  public*/
    function ProxyStore_metaEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Store;

  /**
   * The JSON metadata
   * /
  public native function get meta():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ProxyStore_metaEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            META_CHANGE: "onMetaChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.ProxyStore_optionsEvent", function(ProxyStore_optionsEvent) {
    /*package ext.data.events {
import net.jangaroo.ext.FlExtEvent;

public class ProxyStore_optionsEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ProxyStore_optionsEvent.__PARAMETER_SEQUENCE__ = ([
            "options",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired before a call to <a href="#!/api/Ext.data.ProxyStore-method-sync" rel="Ext.data.ProxyStore-method-sync" class="docClass">sync</a> is executed. Return false from any listener to cancel the sync
   * @see ext.data.ProxyStore
   * @eventType onBeforeSync
   * /
  public static const BEFORE_SYNC:String = "onBeforeSync";

  public*/
    function ProxyStore_optionsEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * Hash of all records to be synchronized, broken down into create, update and destroy
   * /
  public native function get options():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ProxyStore_optionsEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_SYNC: "onBeforeSync",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.ProxyStore_records_successful_operationEvent", function(ProxyStore_records_successful_operationEvent) {
    /*package ext.data.events {
import ext.data.Store;
import ext.data.operation.ReadOperation;

import net.jangaroo.ext.FlExtEvent;

public class ProxyStore_records_successful_operationEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ProxyStore_records_successful_operationEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "records",
            "successful",
            "operation",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires whenever the store reads data from a remote data source.
   * @since 1.1.0
   * @see ext.data.ProxyStore
   * @eventType onLoad
   * /
  public static const LOAD:String = "onLoad";

  public*/
    function ProxyStore_records_successful_operationEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Store;

  /**
   * An array of records
   * /
  public native function get records():Array;

  /**
   * True if the operation was successful.
   * /
  public native function get successful():Boolean;

  /**
   * The
   * <a href="#!/api/Ext.data.operation.Read" rel="Ext.data.operation.Read" class="docClass">Operation</a> object that was used in the data
   * load call
   * /
  public native function get operation():ReadOperation;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ProxyStore_records_successful_operationEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            LOAD: "onLoad",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.ProxyStore_store_operationEvent", function(ProxyStore_store_operationEvent) {
    /*package ext.data.events {
import ext.data.Store;
import ext.data.operation.Operation;

import net.jangaroo.ext.FlExtEvent;

public class ProxyStore_store_operationEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ProxyStore_store_operationEvent.__PARAMETER_SEQUENCE__ = ([
            "store",
            "operation",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a request is made for a new data object. If the beforeload handler returns false the load
   * action will be canceled.
   * @since 1.1.0
   * @see ext.data.ProxyStore
   * @eventType onBeforeLoad
   * /
  public static const BEFORE_LOAD:String = "onBeforeLoad";
  /**
   * "Fires whenever a successful write has been made via the configured <a href="#!/api/Ext.data.ProxyStore-cfg-proxy" rel="Ext.data.ProxyStore-cfg-proxy" class="docClass">Proxy</a>
   * @since 3.4.0
   * @see ext.data.ProxyStore
   * @eventType onWrite
   * /
  public static const WRITE:String = "onWrite";

  public*/
    function ProxyStore_store_operationEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This Store
   * /
  public native function get store():Store;

  /**
   * The <a href="#!/api/Ext.data.operation.Operation" rel="Ext.data.operation.Operation" class="docClass">Ext.data.operation.Operation</a> object that will be passed to the Proxy to
   * load the Store
   * /
  public native function get operation():Operation;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ProxyStore_store_operationEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_LOAD: "onBeforeLoad",
            WRITE: "onWrite",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.Session_dirtyEvent", function(Session_dirtyEvent) {
    /*package ext.data.events {
import ext.Base;

import net.jangaroo.ext.FlExtEvent;

public class Session_dirtyEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Session_dirtyEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "dirty",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a change in the object's <a href="#!/api/Ext.mixin.Dirty-cfg-dirty" rel="Ext.mixin.Dirty-cfg-dirty" class="docClass">dirty</a> state is detected.
   *
   * <p><strong>Note:</strong> In order for this event to fire, the class that mixes in this mixin
   * must be <code><a href="#!/api/Ext.mixin.Observable" rel="Ext.mixin.Observable" class="docClass">Observable</a></code>.</p>
   * @see ext.data.Session
   * @eventType onDirtyChange
   * /
  public static const DIRTY_CHANGE:String = "onDirtyChange";

  public*/
    function Session_dirtyEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Base;

  /**
   * Whether or not the object is now dirty.
   * /
  public native function get dirty():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Session_dirtyEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DIRTY_CHANGE: "onDirtyChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.Store_filtersEvent", function(Store_filtersEvent) {
    /*package ext.data.events {
import ext.data.Store;

import net.jangaroo.ext.FlExtEvent;

public class Store_filtersEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Store_filtersEvent.__PARAMETER_SEQUENCE__ = ([
            "store",
            "filters",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired whenever the filter set changes.
   * @see ext.data.Store
   * @eventType onFilterChange
   * /
  public static const FILTER_CHANGE:String = "onFilterChange";

  public*/
    function Store_filtersEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The store.
   * /
  public native function get store():Store;

  /**
   * The array of Filter objects.
   * /
  public native function get filters():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Store_filtersEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            FILTER_CHANGE: "onFilterChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.Store_grouperEvent", function(Store_grouperEvent) {
    /*package ext.data.events {
import ext.data.Store;
import ext.util.Grouper;

import net.jangaroo.ext.FlExtEvent;

public class Store_grouperEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Store_grouperEvent.__PARAMETER_SEQUENCE__ = ([
            "store",
            "grouper",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired whenever the grouping in the grid changes.
   * @see ext.data.Store
   * @eventType onGroupChange
   * /
  public static const GROUP_CHANGE:String = "onGroupChange";

  public*/
    function Store_grouperEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The store.
   * /
  public native function get store():Store;

  /**
   * The grouper object.
   * /
  public native function get grouper():Grouper;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Store_grouperEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            GROUP_CHANGE: "onGroupChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.Store_operationEvent", function(Store_operationEvent) {
    /*package ext.data.events {
import ext.data.Store;
import ext.data.operation.Operation;

import net.jangaroo.ext.FlExtEvent;

public class Store_operationEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Store_operationEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "operation",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a prefetch occurs. Return <code>false</code> to cancel.
   * @see ext.data.Store
   * @eventType onBeforePrefetch
   * /
  public static const BEFORE_PREFETCH:String = "onBeforePrefetch";

  public*/
    function Store_operationEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Store;

  /**
   * The associated operation.
   * /
  public native function get operation():Operation;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Store_operationEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_PREFETCH: "onBeforePrefetch",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.Store_records_successful_operationEvent", function(Store_records_successful_operationEvent) {
    /*package ext.data.events {
import ext.data.Store;
import ext.data.operation.Operation;

import net.jangaroo.ext.FlExtEvent;

public class Store_records_successful_operationEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Store_records_successful_operationEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "records",
            "successful",
            "operation",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires whenever records have been prefetched.
   * @see ext.data.Store
   * @eventType onPrefetch
   * /
  public static const PREFETCH:String = "onPrefetch";

  public*/
    function Store_records_successful_operationEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Store;

  /**
   * An array of records.
   * /
  public native function get records():Array;

  /**
   * <code>true</code> if the operation was successful.
   * /
  public native function get successful():Boolean;

  /**
   * The associated operation.
   * /
  public native function get operation():Operation;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Store_records_successful_operationEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            PREFETCH: "onPrefetch",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.TreeStoreEvent", function(TreeStoreEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreeStoreEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreeStoreEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before this node is collapsed.
   * @see ext.data.TreeStore
   * @eventType onNodeBeforeCollapse
   * /
  public static const NODE_BEFORE_COLLAPSE:String = "onNodeBeforeCollapse";
  /**
   * "Fires before this node is expanded.
   * @see ext.data.TreeStore
   * @eventType onNodeBeforeExpand
   * /
  public static const NODE_BEFORE_EXPAND:String = "onNodeBeforeExpand";
  /**
   * "Fires when this node is collapsed.
   * @see ext.data.TreeStore
   * @eventType onNodeCollapse
   * /
  public static const NODE_COLLAPSE:String = "onNodeCollapse";
  /**
   * "Fires when this node is expanded.
   * @see ext.data.TreeStore
   * @eventType onNodeExpand
   * /
  public static const NODE_EXPAND:String = "onNodeExpand";

  public*/
    function TreeStoreEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The collapsing node
   * /
  public native function get source():NodeInterface;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreeStoreEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            NODE_BEFORE_COLLAPSE: "onNodeBeforeCollapse",
            NODE_BEFORE_EXPAND: "onNodeBeforeExpand",
            NODE_COLLAPSE: "onNodeCollapse",
            NODE_EXPAND: "onNodeExpand",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.TreeStore_childNodesEvent", function(TreeStore_childNodesEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreeStore_childNodesEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreeStore_childNodesEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "childNodes",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when this node's childNodes are sorted.
   * @see ext.data.TreeStore
   * @eventType onNodeSort
   * /
  public static const NODE_SORT:String = "onNodeSort";

  public*/
    function TreeStore_childNodesEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node.
   * /
  public native function get source():NodeInterface;

  /**
   * The childNodes of this node.
   * /
  public native function get childNodes():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreeStore_childNodesEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            NODE_SORT: "onNodeSort",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.TreeStore_newRoot_oldRootEvent", function(TreeStore_newRoot_oldRootEvent) {
    /*package ext.data.events {
import net.jangaroo.ext.FlExtEvent;

public class TreeStore_newRoot_oldRootEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreeStore_newRoot_oldRootEvent.__PARAMETER_SEQUENCE__ = ([
            "newRoot",
            "oldRoot",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires any time the tree's root node changes.
   * @see ext.data.TreeStore
   * @eventType onRootChange
   * /
  public static const ROOT_CHANGE:String = "onRootChange";

  public*/
    function TreeStore_newRoot_oldRootEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The new root
   * /
  public native function get newRoot():*;

  /**
   * The old root
   * /
  public native function get oldRoot():*;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreeStore_newRoot_oldRootEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ROOT_CHANGE: "onRootChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.TreeStore_nodeEvent", function(TreeStore_nodeEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreeStore_nodeEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreeStore_nodeEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a new child is appended, return false to cancel the append.
   * @see ext.data.TreeStore
   * @eventType onNodeBeforeAppend
   * /
  public static const NODE_BEFORE_APPEND:String = "onNodeBeforeAppend";

  public*/
    function TreeStore_nodeEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The child node to be appended
   * /
  public native function get node():NodeInterface;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreeStore_nodeEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            NODE_BEFORE_APPEND: "onNodeBeforeAppend",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.TreeStore_node_indexEvent", function(TreeStore_node_indexEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreeStore_node_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreeStore_node_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a new child node is appended
   * @see ext.data.TreeStore
   * @eventType onNodeAppend
   * /
  public static const NODE_APPEND:String = "onNodeAppend";

  public*/
    function TreeStore_node_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The newly appended node
   * /
  public native function get node():NodeInterface;

  /**
   * The index of the newly appended node
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreeStore_node_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            NODE_APPEND: "onNodeAppend",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.TreeStore_node_isMoveEvent", function(TreeStore_node_isMoveEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreeStore_node_isMoveEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreeStore_node_isMoveEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "isMove",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a child is removed, return false to cancel the remove.
   * @see ext.data.TreeStore
   * @eventType onNodeBeforeRemove
   * /
  public static const NODE_BEFORE_REMOVE:String = "onNodeBeforeRemove";

  public*/
    function TreeStore_node_isMoveEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The child node to be removed
   * /
  public native function get node():NodeInterface;

  /**
   * <code>true</code> if the child node is being removed so it can be moved to another position in the tree.
   * (a side effect of calling <a href="#!/api/Ext.data.NodeInterface-method-appendChild" rel="Ext.data.NodeInterface-method-appendChild" class="docClass">appendChild</a> or
   * <a href="#!/api/Ext.data.NodeInterface-method-insertBefore" rel="Ext.data.NodeInterface-method-insertBefore" class="docClass">insertBefore</a> with a node that already has a parentNode)
   * /
  public native function get isMove():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreeStore_node_isMoveEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            NODE_BEFORE_REMOVE: "onNodeBeforeRemove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.TreeStore_node_isMove_contextEvent", function(TreeStore_node_isMove_contextEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreeStore_node_isMove_contextEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreeStore_node_isMove_contextEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "isMove",
            "context",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a child node is removed
   * @see ext.data.TreeStore
   * @eventType onNodeRemove
   * /
  public static const NODE_REMOVE:String = "onNodeRemove";

  public*/
    function TreeStore_node_isMove_contextEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The removed node
   * /
  public native function get node():NodeInterface;

  /**
   * <code>true</code> if the child node is being removed so it can be moved to another position in the tree.
   * /
  public native function get isMove():Boolean;

  /**
   * An object providing information about where the removed node came from. It contains the following properties:
   * <ul>
   *   <li><code>parentNode</code> : ext.data.NodeInterface
   * The node from which the removed node was removed.
   *   </li>
   *   <li><code>previousSibling</code> : ext.data.NodeInterface
   * The removed node's former previous sibling.
   *   </li>
   *   <li><code>nextSibling</code> : ext.data.NodeInterface
   * The removed node's former next sibling.
   * (a side effect of calling <a href="#!/api/Ext.data.NodeInterface-method-appendChild" rel="Ext.data.NodeInterface-method-appendChild" class="docClass">appendChild</a> or
   * <a href="#!/api/Ext.data.NodeInterface-method-insertBefore" rel="Ext.data.NodeInterface-method-insertBefore" class="docClass">insertBefore</a> with a node that already has a parentNode)
   *   </li>
   * </ul>
   * /
  public native function get context():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreeStore_node_isMove_contextEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            NODE_REMOVE: "onNodeRemove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.TreeStore_node_refNodeEvent", function(TreeStore_node_refNodeEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreeStore_node_refNodeEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreeStore_node_refNodeEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "refNode",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a new child is inserted, return false to cancel the insert.
   * @see ext.data.TreeStore
   * @eventType onNodeBeforeInsert
   * /
  public static const NODE_BEFORE_INSERT:String = "onNodeBeforeInsert";
  /**
   * "Fires when a new child node is inserted.
   * @see ext.data.TreeStore
   * @eventType onNodeInsert
   * /
  public static const NODE_INSERT:String = "onNodeInsert";

  public*/
    function TreeStore_node_refNodeEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The child node to be inserted
   * /
  public native function get node():NodeInterface;

  /**
   * The child node the node is being inserted before
   * /
  public native function get refNode():NodeInterface;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreeStore_node_refNodeEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            NODE_BEFORE_INSERT: "onNodeBeforeInsert",
            NODE_INSERT: "onNodeInsert",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.TreeStore_oldParent_newParent_indexEvent", function(TreeStore_oldParent_newParent_indexEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreeStore_oldParent_newParent_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreeStore_oldParent_newParent_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "oldParent",
            "newParent",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before this node is moved to a new location in the tree. Return false to cancel the move.
   * @see ext.data.TreeStore
   * @eventType onNodeBeforeMove
   * /
  public static const NODE_BEFORE_MOVE:String = "onNodeBeforeMove";
  /**
   * "Fires when this node is moved to a new location in the tree
   * @see ext.data.TreeStore
   * @eventType onNodeMove
   * /
  public static const NODE_MOVE:String = "onNodeMove";

  public*/
    function TreeStore_oldParent_newParent_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The parent of this node
   * /
  public native function get oldParent():NodeInterface;

  /**
   * The new parent this node is moving to
   * /
  public native function get newParent():NodeInterface;

  /**
   * The index it is being moved to
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreeStore_oldParent_newParent_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            NODE_BEFORE_MOVE: "onNodeBeforeMove",
            NODE_MOVE: "onNodeMove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.events.TreeStore_records_successful_operation_nodeEvent", function(TreeStore_records_successful_operation_nodeEvent) {
    /*package ext.data.events {
import ext.data.NodeInterface;
import ext.data.TreeStore;
import ext.data.operation.Operation;

import net.jangaroo.ext.FlExtEvent;

public class TreeStore_records_successful_operation_nodeEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreeStore_records_successful_operation_nodeEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "records",
            "successful",
            "operation",
            "node",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires whenever the store reads data from a remote data source.
   * @see ext.data.TreeStore
   * @eventType onLoad
   * /
  public static const LOAD:String = "onLoad";

  public*/
    function TreeStore_records_successful_operation_nodeEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():TreeStore;

  /**
   * An array of records.
   * /
  public native function get records():Array;

  /**
   * True if the operation was successful.
   * /
  public native function get successful():Boolean;

  /**
   * The operation that triggered this load.
   * /
  public native function get operation():Operation;

  /**
   * The node that was loaded.
   * /
  public native function get node():NodeInterface;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreeStore_records_successful_operation_nodeEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            LOAD: "onLoad",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.proxy.events.DataProxy_metaEvent", function(DataProxy_metaEvent) {
    /*package ext.data.proxy.events {
import ext.data.proxy.DataProxy;

import net.jangaroo.ext.FlExtEvent;

public class DataProxy_metaEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DataProxy_metaEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "meta",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when this proxy's reader provides new metadata. Metadata usually consists
   * of new field definitions, but can include any configuration data required by an
   * application, and can be processed as needed in the event handler.
   * This event is currently only fired for JsonReaders. Note that this event is also
   * propagated by <a href="#!/api/Ext.data.Store" rel="Ext.data.Store" class="docClass">Ext.data.Store</a>, which is typically where it would be handled.
   * @see ext.data.proxy.DataProxy
   * @eventType onMetaChange
   * /
  public static const META_CHANGE:String = "onMetaChange";

  public*/
    function DataProxy_metaEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():DataProxy;

  /**
   * The JSON metadata
   * /
  public native function get meta():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DataProxy_metaEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            META_CHANGE: "onMetaChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.proxy.events.ServerProxy_request_operationEvent", function(ServerProxy_request_operationEvent) {
    /*package ext.data.proxy.events {
import ext.data.Request;
import ext.data.operation.Operation;
import ext.data.proxy.DataProxy;

import net.jangaroo.ext.FlExtEvent;

public class ServerProxy_request_operationEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ServerProxy_request_operationEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "request",
            "operation",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the server returns an exception. This event may also be listened
   * to in the event that a request has timed out or has been aborted.
   * @see ext.data.proxy.ServerProxy
   * @eventType onException
   * /
  public static const EXCEPTION:String = "onException";

  public*/
    function ServerProxy_request_operationEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():DataProxy;

  /**
   * The request that was sent
   * /
  public native function get request():Request;

  /**
   * The operation that triggered the request
   * /
  public native function get operation():Operation;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ServerProxy_request_operationEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            EXCEPTION: "onException",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.data.reader.events.DataReader_response_errorEvent", function(DataReader_response_errorEvent) {
    /*package ext.data.reader.events {
import ext.data.ResultSet;
import ext.data.reader.DataReader;

import js.XMLHttpRequest;

import net.jangaroo.ext.FlExtEvent;

public class DataReader_response_errorEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DataReader_response_errorEvent.__PARAMETER_SEQUENCE__ = ([
            "reader",
            "response",
            "error",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the reader receives improperly encoded data from the server
   * @see ext.data.reader.DataReader
   * @eventType onException
   * /
  public static const EXCEPTION:String = "onException";

  public*/
    function DataReader_response_errorEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * A reference to this reader
   * /
  public native function get reader():DataReader;

  /**
   * The XMLHttpRequest response object
   * /
  public native function get response():XMLHttpRequest;

  /**
   * The error object
   * /
  public native function get error():ResultSet;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DataReader_response_errorEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            EXCEPTION: "onException",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.dd.IDDScrollConfig", function(IDDScrollConfig) {
    /*package ext.dd {

/**
 * Scroll configuration of a DOM element, implemented and used by <code>ScrollManager</code>.
 *
 * @see ScrollManager
 * /
public interface IDDScrollConfig {
  /**
   * The frequency of scrolls in milliseconds (defaults to 500).
   *
   * @see http://docs.sencha.com/ext-js/3-4/#!/api/Ext.dd.ScrollManager-property-frequency Sencha Docs Ext JS 3.4
   * /
  function get frequency():Number;

  /**
   * @private
   * /
  function set frequency(value:Number):void;

  /**
   * The number of pixels from the right or left edge of a container the pointer needs to be to trigger scrolling (defaults to 25).
   *
   * @see http://docs.sencha.com/ext-js/3-4/#!/api/Ext.dd.ScrollManager-property-hthresh Sencha Docs Ext JS 3.4
   * /
  function get hthresh():Number;

  /**
   * @private
   * /
  function set hthresh(value:Number):void;

  /**
   * The number of pixels to scroll in each scroll increment (defaults to 100).
   *
   * @see http://docs.sencha.com/ext-js/3-4/#!/api/Ext.dd.ScrollManager-property-increment Sencha Docs Ext JS 3.4
   * /
  function get increment():Number;

  /**
   * @private
   * /
  function set increment(value:Number):void;

  /**
   * The number of pixels from the top or bottom edge of a container the pointer needs to be to trigger scrolling (defaults to 25).
   *
   * @see http://docs.sencha.com/ext-js/3-4/#!/api/Ext.dd.ScrollManager-property-vthresh Sencha Docs Ext JS 3.4
   * /
  function get vthresh():Number;

  /**
   * @private
   * /
  function set vthresh(value:Number):void;

  /**
   * The animation duration in seconds - MUST BE less than <a href="#!/api/Ext.dd.ScrollManager-property-frequency" rel="Ext.dd.ScrollManager-property-frequency" class="docClass">Ext.dd.ScrollManager.frequency</a>!
   * @default 0.4
   * /
  function get animDuration():Number;

  /**
   * @private
   * /
  function set animDuration(value:Number):void;

  /**
   * True to animate the scroll
   * @default true
   * /
  function get animated():Boolean;

  /**
   * @private
   * /
  function set animated(value:Boolean):void;

  /**
   * The named drag drop <a href="output/Ext.dd.DragSource.html#Ext.dd.DragSource-ddGroup">group</a> to which this container belongs (defaults to undefined). If a ddGroup is specified, then container scrolling will only occur when a dragged object is in the same ddGroup.
   *
   * @see http://docs.sencha.com/ext-js/3-4/#!/api/Ext.dd.ScrollManager-property-ddGroup Sencha Docs Ext JS 3.4
   * /
  function get ddGroup():String;

  /**
   * @private
   * /
  function set ddGroup(value:String):void;
}
}

============================================== Jangaroo part ==============================================*/
    return {};
});

Ext.define("ext.dd.events.DragTracker_eEvent", function(DragTracker_eEvent) {
    /*package ext.dd.events {
import net.jangaroo.ext.FlExtEvent;

public class DragTracker_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DragTracker_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @see ext.dd.DragTracker
   * @eventType onBeforeStart
   * /
  public static const BEFORE_START:String = "onBeforeStart";
  /**
   * "
   * @see ext.dd.DragTracker
   * @eventType onDrag
   * /
  public static const DRAG:String = "onDrag";
  /**
   * "
   * @see ext.dd.DragTracker
   * @eventType onDragEnd
   * /
  public static const DRAG_END:String = "onDragEnd";
  /**
   * "
   * @see ext.dd.DragTracker
   * @eventType onDragStart
   * /
  public static const DRAG_START:String = "onDragStart";
  /**
   * "Fires when the mouse button is pressed down, but before a drag operation begins. The
   * drag operation begins after either the mouse has been moved by <a href="#!/api/Ext.dd.DragTracker-cfg-tolerance" rel="Ext.dd.DragTracker-cfg-tolerance" class="docClass">tolerance</a> pixels,
   * or after the <a href="#!/api/Ext.dd.DragTracker-cfg-autoStart" rel="Ext.dd.DragTracker-cfg-autoStart" class="docClass">autoStart</a> timer fires.
   *
   * <p>Return <code>false</code> to veto the drag operation.</p>
   * @see ext.dd.DragTracker
   * @eventType onMouseDown
   * /
  public static const MOUSE_DOWN:String = "onMouseDown";
  /**
   * "Fired when the mouse is moved. Returning false cancels the drag operation.
   * @see ext.dd.DragTracker
   * @eventType onMouseMove
   * /
  public static const MOUSE_MOVE:String = "onMouseMove";
  /**
   * "Fires when the mouse exits the DragTracker's target element (or if <a href="#!/api/Ext.dd.DragTracker-cfg-delegate" rel="Ext.dd.DragTracker-cfg-delegate" class="docClass">delegate</a> is
   * used, when the mouse exits a delegate element).
   *
   * <p><strong>Only available when <a href="#!/api/Ext.dd.DragTracker-cfg-trackOver" rel="Ext.dd.DragTracker-cfg-trackOver" class="docClass">trackOver</a> is <code>true</code></strong></p>
   * @see ext.dd.DragTracker
   * @eventType onMouseOut
   * /
  public static const MOUSE_OUT:String = "onMouseOut";
  /**
   * "
   * @see ext.dd.DragTracker
   * @eventType onMouseUp
   * /
  public static const MOUSE_UP:String = "onMouseUp";

  public*/
    function DragTracker_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Object;

  /**
   * event object
   * /
  public native function get e():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DragTracker_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_START: "onBeforeStart",
            DRAG: "onDrag",
            DRAG_END: "onDragEnd",
            DRAG_START: "onDragStart",
            MOUSE_DOWN: "onMouseDown",
            MOUSE_MOVE: "onMouseMove",
            MOUSE_OUT: "onMouseOut",
            MOUSE_UP: "onMouseUp",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.dd.events.DragTracker_e_targetEvent", function(DragTracker_e_targetEvent) {
    /*package ext.dd.events {
import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class DragTracker_e_targetEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DragTracker_e_targetEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "e",
            "target",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the mouse enters the DragTracker's target element (or if <a href="#!/api/Ext.dd.DragTracker-cfg-delegate" rel="Ext.dd.DragTracker-cfg-delegate" class="docClass">delegate</a> is
   * used, when the mouse enters a delegate element).
   *
   * <p><strong>Only available when <a href="#!/api/Ext.dd.DragTracker-cfg-trackOver" rel="Ext.dd.DragTracker-cfg-trackOver" class="docClass">trackOver</a> is <code>true</code></strong></p>
   * @see ext.dd.DragTracker
   * @eventType onMouseOver
   * /
  public static const MOUSE_OVER:String = "onMouseOver";

  public*/
    function DragTracker_e_targetEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Object;

  /**
   * event object
   * /
  public native function get e():Object;

  /**
   * The element mouseovered.
   * /
  public native function get target():HTMLElement;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DragTracker_e_targetEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            MOUSE_OVER: "onMouseOver",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.direct.events.DirectManager_event_providerEvent", function(DirectManager_event_providerEvent) {
    /*package ext.direct.events {
import ext.direct.DirectEvent;
import ext.direct.Provider;

import net.jangaroo.ext.FlExtEvent;

public class DirectManager_event_providerEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DirectManager_event_providerEvent.__PARAMETER_SEQUENCE__ = ([
            "event",
            "provider",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after an event.
   * @see ext.direct.SDirectManager
   * @eventType onEvent
   * /
  public static const EVENT:String = "onEvent";
  /**
   * "Fires after an event exception.
   * @see ext.direct.SDirectManager
   * @eventType onException
   * /
  public static const EXCEPTION:String = "onException";

  public*/
    function DirectManager_event_providerEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The <a href="#!/api/Ext.direct.Event" rel="Ext.direct.Event" class="docClass">Event</a> that occurred.
   * /
  public native function get event():DirectEvent;

  /**
   * The <a href="#!/api/Ext.direct.Provider" rel="Ext.direct.Provider" class="docClass">Provider</a>
   * that provided the event.
   * /
  public native function get provider():Provider;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DirectManager_event_providerEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            EVENT: "onEvent",
            EXCEPTION: "onException",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.direct.events.DirectManager_url_errorEvent", function(DirectManager_url_errorEvent) {
    /*package ext.direct.events {
import net.jangaroo.ext.FlExtEvent;

public class DirectManager_url_errorEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DirectManager_url_errorEvent.__PARAMETER_SEQUENCE__ = ([
            "url",
            "error",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired by <a href="#!/api/Ext.direct.Manager-method-loadProvider" rel="Ext.direct.Manager-method-loadProvider" class="docClass">loadProvider</a> when remoting API could not be loaded, or
   * Provider instance could not be created.
   * @see ext.direct.SDirectManager
   * @eventType onProviderLoadError
   * /
  public static const PROVIDER_LOAD_ERROR:String = "onProviderLoadError";

  public*/
    function DirectManager_url_errorEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The URL used to retrieve remoting API.
   * /
  public native function get url():String;

  /**
   * The error that occured.
   * /
  public native function get error():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DirectManager_url_errorEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            PROVIDER_LOAD_ERROR: "onProviderLoadError",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.direct.events.DirectManager_url_providerEvent", function(DirectManager_url_providerEvent) {
    /*package ext.direct.events {
import ext.direct.Provider;

import net.jangaroo.ext.FlExtEvent;

public class DirectManager_url_providerEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DirectManager_url_providerEvent.__PARAMETER_SEQUENCE__ = ([
            "url",
            "provider",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired by <a href="#!/api/Ext.direct.Manager-method-loadProvider" rel="Ext.direct.Manager-method-loadProvider" class="docClass">loadProvider</a> after successfully loading RemotingProvider API
   * declaration and creating a new Provider instance.
   * @see ext.direct.SDirectManager
   * @eventType onProviderLoad
   * /
  public static const PROVIDER_LOAD:String = "onProviderLoad";

  public*/
    function DirectManager_url_providerEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The URL used to retrieve remoting API.
   * /
  public native function get url():String;

  /**
   * The <a href="#!/api/Ext.direct.Provider" rel="Ext.direct.Provider" class="docClass">Provider</a>
   * instance that was created.
   * /
  public native function get provider():Provider;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DirectManager_url_providerEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            PROVIDER_LOAD: "onProviderLoad",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.direct.events.PollingProviderEvent", function(PollingProviderEvent) {
    /*package ext.direct.events {
import ext.direct.PollingProvider;

import net.jangaroo.ext.FlExtEvent;

public class PollingProviderEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        PollingProviderEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired immediately before a poll takes place.
   * @see ext.direct.PollingProvider
   * @eventType onBeforePoll
   * /
  public static const BEFORE_POLL:String = "onBeforePoll";
  /**
   * "Fired immediately after a poll takes place.
   * @see ext.direct.PollingProvider
   * @eventType onPoll
   * /
  public static const POLL:String = "onPoll";

  public*/
    function PollingProviderEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():PollingProvider;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: PollingProviderEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_POLL: "onBeforePoll",
            POLL: "onPoll",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.direct.events.ProviderEvent", function(ProviderEvent) {
    /*package ext.direct.events {
import ext.direct.Provider;

import net.jangaroo.ext.FlExtEvent;

public class ProviderEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ProviderEvent.__PARAMETER_SEQUENCE__ = ([
            "provider",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the Provider connects to the server-side
   * @see ext.direct.Provider
   * @eventType onConnect
   * /
  public static const CONNECT:String = "onConnect";
  /**
   * "Fires when the Provider disconnects from the server-side
   * @see ext.direct.Provider
   * @eventType onDisconnect
   * /
  public static const DISCONNECT:String = "onDisconnect";

  public*/
    function ProviderEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The <a href="#!/api/Ext.direct.Provider" rel="Ext.direct.Provider" class="docClass">Provider</a>.
   * /
  public native function get provider():Provider;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ProviderEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CONNECT: "onConnect",
            DISCONNECT: "onDisconnect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.direct.events.Provider_eEvent", function(Provider_eEvent) {
    /*package ext.direct.events {
import ext.direct.DirectEvent;
import ext.direct.Provider;

import net.jangaroo.ext.FlExtEvent;

public class Provider_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Provider_eEvent.__PARAMETER_SEQUENCE__ = ([
            "provider",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the Provider receives data from the server-side. This event is fired
   * for valid responses as well as for exceptions.
   * @see ext.direct.Provider
   * @eventType onData
   * /
  public static const DATA:String = "onData";
  /**
   * "Fires when the Provider receives an exception from the server-side. This event is <em>not</em>
   * fired for valid responses.
   * @see ext.direct.Provider
   * @eventType onException
   * /
  public static const EXCEPTION:String = "onException";

  public*/
    function Provider_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The <a href="#!/api/Ext.direct.Provider" rel="Ext.direct.Provider" class="docClass">Provider</a> instance.
   * /
  public native function get provider():Provider;

  /**
   * The <a href="#!/api/Ext.direct.Event" rel="Ext.direct.Event" class="docClass">Ext.direct.Event</a> that occurred.
   * /
  public native function get e():DirectEvent;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Provider_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DATA: "onData",
            EXCEPTION: "onException",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.direct.events.RemotingProvider_event_transactionEvent", function(RemotingProvider_event_transactionEvent) {
    /*package ext.direct.events {
import ext.direct.DirectEvent;
import ext.direct.RemotingProvider;
import ext.direct.Transaction;

import net.jangaroo.ext.FlExtEvent;

public class RemotingProvider_event_transactionEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        RemotingProvider_event_transactionEvent.__PARAMETER_SEQUENCE__ = ([
            "provider",
            "event",
            "transaction",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before callback function is executed. By returning <code>false</code> from an event handler
   * you can prevent the callback from executing.
   * @see ext.direct.RemotingProvider
   * @eventType onBeforeCallback
   * /
  public static const BEFORE_CALLBACK:String = "onBeforeCallback";

  public*/
    function RemotingProvider_event_transactionEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The provider instance
   * /
  public native function get provider():RemotingProvider;

  /**
   * Event associated with the callback invocation
   * /
  public native function get event():DirectEvent;

  /**
   * Transaction for which the callback
   * is about to be fired
   * /
  public native function get transaction():Transaction;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: RemotingProvider_event_transactionEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_CALLBACK: "onBeforeCallback",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.direct.events.RemotingProvider_transaction_metaEvent", function(RemotingProvider_transaction_metaEvent) {
    /*package ext.direct.events {
import ext.direct.RemotingProvider;
import ext.direct.Transaction;

import net.jangaroo.ext.FlExtEvent;

public class RemotingProvider_transaction_metaEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        RemotingProvider_transaction_metaEvent.__PARAMETER_SEQUENCE__ = ([
            "provider",
            "transaction",
            "meta",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires immediately before the client-side sends off the RPC call. By returning
   * <code>false</code> from an event handler you can prevent the call from being made.
   * @see ext.direct.RemotingProvider
   * @eventType onBeforeCall
   * /
  public static const BEFORE_CALL:String = "onBeforeCall";
  /**
   * "Fires immediately after the request to the server-side is sent. This does
   * NOT fire after the response has come back from the call.
   * @see ext.direct.RemotingProvider
   * @eventType onCall
   * /
  public static const CALL:String = "onCall";

  public*/
    function RemotingProvider_transaction_metaEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get provider():RemotingProvider;

  public native function get transaction():Transaction;

  /**
   * The meta data
   * /
  public native function get meta():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: RemotingProvider_transaction_metaEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_CALL: "onBeforeCall",
            CALL: "onCall",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.dom.events.ElementEvent", function(ElementEvent) {
    /*package ext.dom.events {
import ext.dom.Element;

import net.jangaroo.ext.FlExtEvent;

public class ElementEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ElementEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires whenever this Element actually becomes visible (painted) on the screen. This is useful when you need to
   * perform 'read' operations on the DOM element, i.e: calculating natural sizes and positioning.
   *
   * <p><strong>Note:</strong> This event is not available to be used with event delegation. Instead <code>painted</code> only fires if you explicitly
   * add at least one listener to it, for performance reasons.</p>
   * @see ext.dom.Element
   * @eventType onPainted
   * /
  public static const PAINTED:String = "onPainted";
  /**
   * "Important note: For the best performance on mobile devices, use this only when you absolutely need to monitor
   * a Element's size.
   *
   * <p><strong>Note:</strong> This event is not available to be used with event delegation. Instead <code>resize</code> only fires if you explicitly
   * add at least one listener to it, for performance reasons.</p>
   * @see ext.dom.Element
   * @eventType onResize
   * /
  public static const RESIZE:String = "onResize";

  public*/
    function ElementEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The component instance.
   * /
  public native function get source():Element;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ElementEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            PAINTED: "onPainted",
            RESIZE: "onResize",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.dom.events.Element_e_tEvent", function(Element_e_tEvent) {
    /*package ext.dom.events {
import ext.event.Event;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class Element_e_tEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Element_e_tEvent.__PARAMETER_SEQUENCE__ = ([
            "e",
            "t",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Where supported. Fires when an element is activated, for instance, through a mouse click or a keypress.
   * @see ext.dom.Element
   * @eventType onDOMActivate
   * /
  public static const DOM_ACTIVATE:String = "onDOMActivate";
  /**
   * "Where supported. Fires when an attribute has been modified.
   * @see ext.dom.Element
   * @eventType onDOMAttrModified
   * /
  public static const DOM_ATTR_MODIFIED:String = "onDOMAttrModified";
  /**
   * "Where supported. Fires when the character data has been modified.
   * @see ext.dom.Element
   * @eventType onDOMCharacterDataModified
   * /
  public static const DOM_CHARACTER_DATA_MODIFIED:String = "onDOMCharacterDataModified";
  /**
   * "Where supported. Similar to HTML focus event, but can be applied to any focusable element.
   * @see ext.dom.Element
   * @eventType onDOMFocusIn
   * /
  public static const DOM_FOCUS_IN:String = "onDOMFocusIn";
  /**
   * "Where supported. Similar to HTML blur event, but can be applied to any focusable element.
   * @see ext.dom.Element
   * @eventType onDOMFocusOut
   * /
  public static const DOM_FOCUS_OUT:String = "onDOMFocusOut";
  /**
   * "Where supported. Fires when a node has been added as a child of another node.
   * @see ext.dom.Element
   * @eventType onDOMNodeInserted
   * /
  public static const DOM_NODE_INSERTED:String = "onDOMNodeInserted";
  /**
   * "Where supported. Fires when a node is being inserted into a document.
   * @see ext.dom.Element
   * @eventType onDOMNodeInsertedIntoDocument
   * /
  public static const DOM_NODE_INSERTED_INTO_DOCUMENT:String = "onDOMNodeInsertedIntoDocument";
  /**
   * "Where supported. Fires when a descendant node of the element is removed.
   * @see ext.dom.Element
   * @eventType onDOMNodeRemoved
   * /
  public static const DOM_NODE_REMOVED:String = "onDOMNodeRemoved";
  /**
   * "Where supported. Fires when a node is being removed from a document.
   * @see ext.dom.Element
   * @eventType onDOMNodeRemovedFromDocument
   * /
  public static const DOM_NODE_REMOVED_FROM_DOCUMENT:String = "onDOMNodeRemovedFromDocument";
  /**
   * "Where supported. Fires when the subtree is modified.
   * @see ext.dom.Element
   * @eventType onDOMSubtreeModified
   * /
  public static const DOM_SUBTREE_MODIFIED:String = "onDOMSubtreeModified";
  /**
   * "Fires when an object/image is stopped from loading before completely loaded.
   * @see ext.dom.Element
   * @eventType onAbort
   * /
  public static const ABORT:String = "onAbort";
  /**
   * "Fires when an element loses focus either via the pointing device or by tabbing navigation.
   * @see ext.dom.Element
   * @eventType onBlur
   * /
  public static const BLUR:String = "onBlur";
  /**
   * "Fires when a control loses the input focus and its value has been modified since gaining focus.
   * @see ext.dom.Element
   * @eventType onChange
   * /
  public static const CHANGE:String = "onChange";
  /**
   * "Fires when a mouse click is detected within the element.
   * @see ext.dom.Element
   * @eventType onClick
   * /
  public static const CLICK:String = "onClick";
  /**
   * "Fires when a right click is detected within the element.
   * @see ext.dom.Element
   * @eventType onContextMenu
   * /
  public static const CONTEXT_MENU:String = "onContextMenu";
  /**
   * "Fires when a mouse double click is detected within the element.
   * @see ext.dom.Element
   * @eventType onDblclick
   * /
  public static const DBLCLICK:String = "onDblclick";
  /**
   * "Fires when an object/image/frame cannot be loaded properly.
   * @see ext.dom.Element
   * @eventType onError
   * /
  public static const ERROR:String = "onError";
  /**
   * "Fires when an element receives focus either via the pointing device or by tab navigation.
   * @see ext.dom.Element
   * @eventType onFocus
   * /
  public static const FOCUS:String = "onFocus";
  /**
   * "Fires when focus is moved <em>within</em> an element.
   * @see ext.dom.Element
   * @eventType onFocusMove
   * /
  public static const FOCUS_MOVE:String = "onFocusMove";
  /**
   * "Fires when a keydown is detected within the element.
   * @see ext.dom.Element
   * @eventType onKeyDown
   * /
  public static const KEY_DOWN:String = "onKeyDown";
  /**
   * "Fires when a keypress is detected within the element.
   * @see ext.dom.Element
   * @eventType onKeypress
   * /
  public static const KEYPRESS:String = "onKeypress";
  /**
   * "Fires when a keyup is detected within the element.
   * @see ext.dom.Element
   * @eventType onKeyUp
   * /
  public static const KEY_UP:String = "onKeyUp";
  /**
   * "Fires when the user agent finishes loading all content within the element. Only supported by window, frames,
   * objects and images.
   * @see ext.dom.Element
   * @eventType onLoad
   * /
  public static const LOAD:String = "onLoad";
  /**
   * "Fires when a mousedown is detected within the element.
   * @see ext.dom.Element
   * @eventType onMouseDown
   * /
  public static const MOUSE_DOWN:String = "onMouseDown";
  /**
   * "Fires when the mouse enters the element.
   * @see ext.dom.Element
   * @eventType onMouseEnter
   * /
  public static const MOUSE_ENTER:String = "onMouseEnter";
  /**
   * "Fires when the mouse leaves the element.
   * @see ext.dom.Element
   * @eventType onMouseLeave
   * /
  public static const MOUSE_LEAVE:String = "onMouseLeave";
  /**
   * "Fires when a mousemove is detected with the element.
   * @see ext.dom.Element
   * @eventType onMouseMove
   * /
  public static const MOUSE_MOVE:String = "onMouseMove";
  /**
   * "Fires when a mouseout is detected with the element.
   * @see ext.dom.Element
   * @eventType onMouseOut
   * /
  public static const MOUSE_OUT:String = "onMouseOut";
  /**
   * "Fires when a mouseover is detected within the element.
   * @see ext.dom.Element
   * @eventType onMouseOver
   * /
  public static const MOUSE_OVER:String = "onMouseOver";
  /**
   * "Fires when a mouseup is detected within the element.
   * @see ext.dom.Element
   * @eventType onMouseUp
   * /
  public static const MOUSE_UP:String = "onMouseUp";
  /**
   * "Fires when a form is reset.
   * @see ext.dom.Element
   * @eventType onReset
   * /
  public static const RESET:String = "onReset";
  /**
   * "Fires when a document view is scrolled.
   * @see ext.dom.Element
   * @eventType onScroll
   * /
  public static const SCROLL:String = "onScroll";
  /**
   * "Fires when a user selects some text in a text field, including input and textarea.
   * @see ext.dom.Element
   * @eventType onSelect
   * /
  public static const SELECT:String = "onSelect";
  /**
   * "Fires when a form is submitted.
   * @see ext.dom.Element
   * @eventType onSubmit
   * /
  public static const SUBMIT:String = "onSubmit";
  /**
   * "Fires when the user agent removes all content from a window or frame. For elements, it fires when the target
   * element or any of its content has been removed.
   * @see ext.dom.Element
   * @eventType onUnload
   * /
  public static const UNLOAD:String = "onUnload";

  public*/
    function Element_e_tEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The <a href="#!/api/Ext.event.Event" rel="Ext.event.Event" class="docClass">Ext.event.Event</a> encapsulating the DOM event.
   * /
  public native function get e():Event;

  /**
   * The target of the event.
   * /
  public native function get t():HTMLElement;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Element_e_tEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DOM_ACTIVATE: "onDOMActivate",
            DOM_ATTR_MODIFIED: "onDOMAttrModified",
            DOM_CHARACTER_DATA_MODIFIED: "onDOMCharacterDataModified",
            DOM_FOCUS_IN: "onDOMFocusIn",
            DOM_FOCUS_OUT: "onDOMFocusOut",
            DOM_NODE_INSERTED: "onDOMNodeInserted",
            DOM_NODE_INSERTED_INTO_DOCUMENT: "onDOMNodeInsertedIntoDocument",
            DOM_NODE_REMOVED: "onDOMNodeRemoved",
            DOM_NODE_REMOVED_FROM_DOCUMENT: "onDOMNodeRemovedFromDocument",
            DOM_SUBTREE_MODIFIED: "onDOMSubtreeModified",
            ABORT: "onAbort",
            BLUR: "onBlur",
            CHANGE: "onChange",
            CLICK: "onClick",
            CONTEXT_MENU: "onContextMenu",
            DBLCLICK: "onDblclick",
            ERROR: "onError",
            FOCUS: "onFocus",
            FOCUS_MOVE: "onFocusMove",
            KEY_DOWN: "onKeyDown",
            KEYPRESS: "onKeypress",
            KEY_UP: "onKeyUp",
            LOAD: "onLoad",
            MOUSE_DOWN: "onMouseDown",
            MOUSE_ENTER: "onMouseEnter",
            MOUSE_LEAVE: "onMouseLeave",
            MOUSE_MOVE: "onMouseMove",
            MOUSE_OUT: "onMouseOut",
            MOUSE_OVER: "onMouseOver",
            MOUSE_UP: "onMouseUp",
            RESET: "onReset",
            SCROLL: "onScroll",
            SELECT: "onSelect",
            SUBMIT: "onSubmit",
            UNLOAD: "onUnload",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.dom.events.Element_event_node_optionsEvent", function(Element_event_node_optionsEvent) {
    /*package ext.dom.events {
import ext.event.Event;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class Element_event_node_optionsEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Element_event_node_optionsEvent.__PARAMETER_SEQUENCE__ = ([
            "event",
            "node",
            "options",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when there is a double tap.
   * @see ext.dom.Element
   * @eventType onDoubleTap
   * /
  public static const DOUBLE_TAP:String = "onDoubleTap";
  /**
   * "Fires when you touch and hold still for more than 1 second.
   * @see ext.dom.Element
   * @eventType onLongPress
   * /
  public static const LONG_PRESS:String = "onLongPress";
  /**
   * "Fires continuously when there is pinching (the touch must move for this to be fired).
   * @see ext.dom.Element
   * @eventType onPinch
   * /
  public static const PINCH:String = "onPinch";
  /**
   * "Fires when a pinch has ended.
   * @see ext.dom.Element
   * @eventType onPinchEnd
   * /
  public static const PINCH_END:String = "onPinchEnd";
  /**
   * "Fired once when a pinch has started.
   * @see ext.dom.Element
   * @eventType onPinchStart
   * /
  public static const PINCH_START:String = "onPinchStart";
  /**
   * "Fires continuously when there is rotation (the touch must move for this to be fired).
   * When listening to this, ensure you know about the <a href="#!/api/Ext.event.Event-property-angle" rel="Ext.event.Event-property-angle" class="docClass">Ext.event.Event.angle</a> and <a href="#!/api/Ext.event.Event-property-rotation" rel="Ext.event.Event-property-rotation" class="docClass">Ext.event.Event.rotation</a>
   * properties in the <code>event</code> object.
   * @see ext.dom.Element
   * @eventType onRotate
   * /
  public static const ROTATE:String = "onRotate";
  /**
   * "Fires when a rotation event has ended.
   * @see ext.dom.Element
   * @eventType onRotateEnd
   * /
  public static const ROTATE_END:String = "onRotateEnd";
  /**
   * "Fired once when a rotation has started.
   * @see ext.dom.Element
   * @eventType onRotateStart
   * /
  public static const ROTATE_START:String = "onRotateStart";
  /**
   * "Fires when there is a single tap.
   * @see ext.dom.Element
   * @eventType onSingleTap
   * /
  public static const SINGLE_TAP:String = "onSingleTap";
  /**
   * "Fires when there is a swipe
   * When listening to this, ensure you know about the <a href="#!/api/Ext.event.Event-property-direction" rel="Ext.event.Event-property-direction" class="docClass">Ext.event.Event.direction</a> property in the <code>event</code> object.
   * @see ext.dom.Element
   * @eventType onSwipe
   * /
  public static const SWIPE:String = "onSwipe";
  /**
   * "Fires when you touch and hold still for more than 1 second.
   * @see ext.dom.Element
   * @eventType onTapHold
   * /
  public static const TAP_HOLD:String = "onTapHold";

  public*/
    function Element_event_node_optionsEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The <a href="#!/api/Ext.event.Event" rel="Ext.event.Event" class="docClass">Ext.event.Event</a> event encapsulating the DOM event.
   * /
  public native function get event():Event;

  /**
   * The target of the event.
   * /
  public native function get node():HTMLElement;

  /**
   * The options object passed to <a href="#!/api/Ext.mixin.Observable-method-addListener" rel="Ext.mixin.Observable-method-addListener" class="docClass">Ext.mixin.Observable.addListener</a>.
   * /
  public native function get options():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Element_event_node_optionsEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DOUBLE_TAP: "onDoubleTap",
            LONG_PRESS: "onLongPress",
            PINCH: "onPinch",
            PINCH_END: "onPinchEnd",
            PINCH_START: "onPinchStart",
            ROTATE: "onRotate",
            ROTATE_END: "onRotateEnd",
            ROTATE_START: "onRotateStart",
            SINGLE_TAP: "onSingleTap",
            SWIPE: "onSwipe",
            TAP_HOLD: "onTapHold",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.ComponentEvent", function(ComponentEvent) {
    /*package ext.events {
import ext.Component;

import net.jangaroo.ext.FlExtEvent;

public class ComponentEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ComponentEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after a Component has been visually activated.
   *
   * <p><strong>Note</strong> This event is only fired if this Component is a child of a <a href="#!/api/Ext.container.Container" rel="Ext.container.Container" class="docClass">Ext.container.Container</a>
   * that uses <a href="#!/api/Ext.layout.container.Card" rel="Ext.layout.container.Card" class="docClass">Ext.layout.container.Card</a> as it's layout or this Component is a floating Component.</p>
   * @see ext.Component
   * @eventType onActivate
   * /
  public static const ACTIVATE:String = "onActivate";
  /**
   * "This event first after a component's layout has been updated by a layout that
   * included animation (e.g., a <a href="#!/api/Ext.panel.Panel" rel="Ext.panel.Panel" class="docClass">panel</a> in an
   * <a href="#!/api/Ext.layout.container.Accordion" rel="Ext.layout.container.Accordion" class="docClass">accordion</a> layout).
   * @since 6.0.0
   * @see ext.Component
   * @eventType onAfterLayoutAnimation
   * /
  public static const AFTER_LAYOUT_ANIMATION:String = "onAfterLayoutAnimation";
  /**
   * "Fires after the component rendering is finished.
   *
   * <p>The <code>afterrender</code> event is fired after this Component has been <a href="#!/api/Ext.Component-property-rendered" rel="Ext.Component-property-rendered" class="docClass">rendered</a>, been post-processed by any
   * <code>afterRender</code> method defined for the Component.</p>
   * @since 3.4.0
   * @see ext.Component
   * @eventType onAfterRender
   * /
  public static const AFTER_RENDER:String = "onAfterRender";
  /**
   * "Fires before a Component has been visually activated. Returning <code>false</code> from an event listener can prevent
   * the activate from occurring.
   *
   * <p><strong>Note</strong> This event is only fired if this Component is a child of a <a href="#!/api/Ext.container.Container" rel="Ext.container.Container" class="docClass">Ext.container.Container</a>
   * that uses <a href="#!/api/Ext.layout.container.Card" rel="Ext.layout.container.Card" class="docClass">Ext.layout.container.Card</a> as it's layout.</p>
   * @see ext.Component
   * @eventType onBeforeActivate
   * /
  public static const BEFORE_ACTIVATE:String = "onBeforeActivate";
  /**
   * "Fires before a Component has been visually deactivated. Returning <code>false</code> from an event listener can
   * prevent the deactivate from occurring.
   *
   * <p><strong>Note</strong> This event is only fired if this Component is a child of a <a href="#!/api/Ext.container.Container" rel="Ext.container.Container" class="docClass">Ext.container.Container</a>
   * that uses <a href="#!/api/Ext.layout.container.Card" rel="Ext.layout.container.Card" class="docClass">Ext.layout.container.Card</a> as it's layout.</p>
   * @see ext.Component
   * @eventType onBeforeDeactivate
   * /
  public static const BEFORE_DEACTIVATE:String = "onBeforeDeactivate";
  /**
   * "Fires before the component is <a href="#!/api/Ext.Component-method-destroy" rel="Ext.Component-method-destroy" class="docClass">destroy</a>ed. Return <code>false</code> from an event handler to stop the
   * <a href="#!/api/Ext.Component-method-destroy" rel="Ext.Component-method-destroy" class="docClass">destroy</a>.
   * @since 1.1.0
   * @see ext.Component
   * @eventType onBeforeDestroy
   * /
  public static const BEFORE_DESTROY:String = "onBeforeDestroy";
  /**
   * "Fires before the component is hidden when calling the <a href="#!/api/Ext.Component-method-hide" rel="Ext.Component-method-hide" class="docClass">hide</a> method. Return <code>false</code> from an event
   * handler to stop the hide.
   * @since 1.1.0
   * @see ext.Component
   * @eventType onBeforeHide
   * /
  public static const BEFORE_HIDE:String = "onBeforeHide";
  /**
   * "Fires before the component is <a href="#!/api/Ext.Component-property-rendered" rel="Ext.Component-property-rendered" class="docClass">rendered</a>. Return <code>false</code> from an event handler to stop the
   * <a href="#!/api/Ext.Component-method-render" rel="Ext.Component-method-render" class="docClass">render</a>.
   * @since 1.1.0
   * @see ext.Component
   * @eventType onBeforeRender
   * /
  public static const BEFORE_RENDER:String = "onBeforeRender";
  /**
   * "Fires before the component is shown when calling the <a href="#!/api/Ext.Component-method-show" rel="Ext.Component-method-show" class="docClass">show</a> method. Return <code>false</code> from an event
   * handler to stop the show.
   * @since 1.1.0
   * @see ext.Component
   * @eventType onBeforeShow
   * /
  public static const BEFORE_SHOW:String = "onBeforeShow";
  /**
   * "Fires after a Component has been visually deactivated.
   *
   * <p><strong>Note</strong> This event is only fired if this Component is a child of a <a href="#!/api/Ext.container.Container" rel="Ext.container.Container" class="docClass">Ext.container.Container</a>
   * that uses <a href="#!/api/Ext.layout.container.Card" rel="Ext.layout.container.Card" class="docClass">Ext.layout.container.Card</a> as it's layout or this Component is a floating Component.</p>
   * @see ext.Component
   * @eventType onDeactivate
   * /
  public static const DEACTIVATE:String = "onDeactivate";
  /**
   * "Fires after the component is <a href="#!/api/Ext.Component-method-destroy" rel="Ext.Component-method-destroy" class="docClass">destroy</a>ed.
   * @since 1.1.0
   * @see ext.Component
   * @eventType onDestroy
   * /
  public static const DESTROY:String = "onDestroy";
  /**
   * "Fires after the component is disabled.
   * @since 1.1.0
   * @see ext.Component
   * @eventType onDisable
   * /
  public static const DISABLE:String = "onDisable";
  /**
   * "Fires after the component is enabled.
   * @since 1.1.0
   * @see ext.Component
   * @eventType onEnable
   * /
  public static const ENABLE:String = "onEnable";
  /**
   * "Fires after the component is hidden. Fires after the component is hidden when calling the <a href="#!/api/Ext.Component-method-hide" rel="Ext.Component-method-hide" class="docClass">hide</a>
   * method.
   * @since 1.1.0
   * @see ext.Component
   * @eventType onHide
   * /
  public static const HIDE:String = "onHide";
  /**
   * "Fires after the component markup is <a href="#!/api/Ext.Component-property-rendered" rel="Ext.Component-property-rendered" class="docClass">rendered</a>.
   * @since 1.1.0
   * @see ext.Component
   * @eventType onRender
   * /
  public static const RENDER:String = "onRender";
  /**
   * "Fires after the component is shown when calling the <a href="#!/api/Ext.Component-method-show" rel="Ext.Component-method-show" class="docClass">show</a> method.
   * @since 1.1.0
   * @see ext.Component
   * @eventType onShow
   * /
  public static const SHOW:String = "onShow";

  public*/
    function ComponentEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Component;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ComponentEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ACTIVATE: "onActivate",
            AFTER_LAYOUT_ANIMATION: "onAfterLayoutAnimation",
            AFTER_RENDER: "onAfterRender",
            BEFORE_ACTIVATE: "onBeforeActivate",
            BEFORE_DEACTIVATE: "onBeforeDeactivate",
            BEFORE_DESTROY: "onBeforeDestroy",
            BEFORE_HIDE: "onBeforeHide",
            BEFORE_RENDER: "onBeforeRender",
            BEFORE_SHOW: "onBeforeShow",
            DEACTIVATE: "onDeactivate",
            DESTROY: "onDestroy",
            DISABLE: "onDisable",
            ENABLE: "onEnable",
            HIDE: "onHide",
            RENDER: "onRender",
            SHOW: "onShow",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.Component_container_posEvent", function(Component_container_posEvent) {
    /*package ext.events {
import ext.Component;
import ext.container.Container;

import net.jangaroo.ext.FlExtEvent;

public class Component_container_posEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Component_container_posEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "container",
            "pos",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after a Component had been added to a Container.
   * @since 3.4.0
   * @see ext.Component
   * @eventType onAdded
   * /
  public static const ADDED:String = "onAdded";

  public*/
    function Component_container_posEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Component;

  /**
   * Parent Container
   * /
  public native function get container():Container;

  /**
   * position of Component
   * /
  public native function get pos():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Component_container_posEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ADDED: "onAdded",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.Component_eventEvent", function(Component_eventEvent) {
    /*package ext.events {
import ext.Component;
import ext.event.Event;

import net.jangaroo.ext.FlExtEvent;

public class Component_eventEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Component_eventEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "event",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when this Component loses focus.
   * @see ext.Component
   * @eventType onBlur
   * /
  public static const BLUR:String = "onBlur";
  /**
   * "Fires when this Component receives focus.
   * @see ext.Component
   * @eventType onFocus
   * /
  public static const FOCUS:String = "onFocus";
  /**
   * "Fires when focus enters this Component's hierarchy.
   * @see ext.Component
   * @eventType onFocusEnter
   * /
  public static const FOCUS_ENTER:String = "onFocusEnter";
  /**
   * "Fires when focus leaves this Component's hierarchy.
   * @see ext.Component
   * @eventType onFocusLeave
   * /
  public static const FOCUS_LEAVE:String = "onFocusLeave";

  public*/
    function Component_eventEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Component;

  /**
   * The blur event.
   * /
  public native function get event():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Component_eventEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BLUR: "onBlur",
            FOCUS: "onFocus",
            FOCUS_ENTER: "onFocusEnter",
            FOCUS_LEAVE: "onFocusLeave",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.Component_ownerCtEvent", function(Component_ownerCtEvent) {
    /*package ext.events {
import ext.Component;
import ext.container.Container;

import net.jangaroo.ext.FlExtEvent;

public class Component_ownerCtEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Component_ownerCtEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "ownerCt",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a component is removed from an <a href="#!/api/Ext.container.Container" rel="Ext.container.Container" class="docClass">Ext.container.Container</a>
   * @since 3.4.0
   * @see ext.Component
   * @eventType onRemoved
   * /
  public static const REMOVED:String = "onRemoved";

  public*/
    function Component_ownerCtEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Component;

  /**
   * Container which holds the component
   * /
  public native function get ownerCt():Container;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Component_ownerCtEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            REMOVED: "onRemoved",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.Component_stateEvent", function(Component_stateEvent) {
    /*package ext.events {
import ext.state.Stateful;

import net.jangaroo.ext.FlExtEvent;

public class Component_stateEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Component_stateEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "state",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the state of the object is restored. Return false from an event handler to stop the restore.
   * @see ext.Component
   * @eventType onBeforeStateRestore
   * /
  public static const BEFORE_STATE_RESTORE:String = "onBeforeStateRestore";
  /**
   * "Fires before the state of the object is saved to the configured state provider. Return false to stop the save.
   * @see ext.Component
   * @eventType onBeforeStateSave
   * /
  public static const BEFORE_STATE_SAVE:String = "onBeforeStateSave";
  /**
   * "Fires after the state of the object is restored.
   * @see ext.Component
   * @eventType onStateRestore
   * /
  public static const STATE_RESTORE:String = "onStateRestore";
  /**
   * "Fires after the state of the object is saved to the configured state provider.
   * @see ext.Component
   * @eventType onStateSave
   * /
  public static const STATE_SAVE:String = "onStateSave";

  public*/
    function Component_stateEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Stateful;

  /**
   * The hash of state values returned from the StateProvider. If this
   * event is not vetoed, then the state object is passed to <em><code>applyState</code></em>. By default,
   * that simply copies property values into this object. The method maybe overriden to
   * provide custom state restoration.
   * /
  public native function get state():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Component_stateEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_STATE_RESTORE: "onBeforeStateRestore",
            BEFORE_STATE_SAVE: "onBeforeStateSave",
            STATE_RESTORE: "onStateRestore",
            STATE_SAVE: "onStateSave",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.Component_width_heightEvent", function(Component_width_heightEvent) {
    /*package ext.events {
import ext.Component;

import net.jangaroo.ext.FlExtEvent;

public class Component_width_heightEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Component_width_heightEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "width",
            "height",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires <em>one time</em> - after the component has been laid out for the first time at its initial size.
   *
   * <p>This event does not fire on components that use <a href="#!/api/Ext.Component-cfg-liquidLayout" rel="Ext.Component-cfg-liquidLayout" class="docClass">liquidLayout</a>, such as
   * <a href="#!/api/Ext.button.Button" rel="Ext.button.Button" class="docClass">Buttons</a> and <a href="#!/api/Ext.form.field.Base" rel="Ext.form.field.Base" class="docClass">Form Fields</a>.</p>
   * @see ext.Component
   * @eventType onBoxReady
   * /
  public static const BOX_READY:String = "onBoxReady";

  public*/
    function Component_width_heightEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Component;

  /**
   * The initial width.
   * /
  public native function get width():Number;

  /**
   * The initial height.
   * /
  public native function get height():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Component_width_heightEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BOX_READY: "onBoxReady",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.Component_width_height_oldWidth_oldHeightEvent", function(Component_width_height_oldWidth_oldHeightEvent) {
    /*package ext.events {
import ext.Component;

import net.jangaroo.ext.FlExtEvent;

public class Component_width_height_oldWidth_oldHeightEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Component_width_height_oldWidth_oldHeightEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "width",
            "height",
            "oldWidth",
            "oldHeight",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after the component is resized. Note that this does <em>not</em> fire when the component is first laid out at its initial
   * size. To hook that point in the life cycle, use the <a href="#!/api/Ext.Component-event-boxready" rel="Ext.Component-event-boxready" class="docClass">boxready</a> event.
   *
   * <p>This event does not fire on components that use <a href="#!/api/Ext.Component-cfg-liquidLayout" rel="Ext.Component-cfg-liquidLayout" class="docClass">liquidLayout</a>, such as
   * <a href="#!/api/Ext.button.Button" rel="Ext.button.Button" class="docClass">Buttons</a> and <a href="#!/api/Ext.form.field.Base" rel="Ext.form.field.Base" class="docClass">Form Fields</a>.</p>
   * @see ext.Component
   * @eventType onResize
   * /
  public static const RESIZE:String = "onResize";

  public*/
    function Component_width_height_oldWidth_oldHeightEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Component;

  /**
   * The new width that was set.
   * /
  public native function get width():Number;

  /**
   * The new height that was set.
   * /
  public native function get height():Number;

  /**
   * The previous width.
   * /
  public native function get oldWidth():Number;

  /**
   * The previous height.
   * /
  public native function get oldHeight():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Component_width_height_oldWidth_oldHeightEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            RESIZE: "onResize",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.Component_x_yEvent", function(Component_x_yEvent) {
    /*package ext.events {
import ext.Component;

import net.jangaroo.ext.FlExtEvent;

public class Component_x_yEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Component_x_yEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "x",
            "y",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after the component is moved.
   * @see ext.Component
   * @eventType onMove
   * /
  public static const MOVE:String = "onMove";

  public*/
    function Component_x_yEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Component;

  /**
   * The new x position.
   * /
  public native function get x():Number;

  /**
   * The new y position.
   * /
  public native function get y():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Component_x_yEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            MOVE: "onMove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.Editor_boundEl_valueEvent", function(Editor_boundEl_valueEvent) {
    /*package ext.events {
import ext.Editor;
import ext.dom.Element;

import net.jangaroo.ext.FlExtEvent;

public class Editor_boundEl_valueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Editor_boundEl_valueEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "boundEl",
            "value",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when editing is initiated, but before the value changes.  Editing can be canceled by returning
   * false from the handler of this event.
   * @see ext.Editor
   * @eventType onBeforeStartEdit
   * /
  public static const BEFORE_START_EDIT:String = "onBeforeStartEdit";
  /**
   * "Fires when this editor is displayed
   * @see ext.Editor
   * @eventType onStartEdit
   * /
  public static const START_EDIT:String = "onStartEdit";

  public*/
    function Editor_boundEl_valueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Editor;

  /**
   * The underlying element bound to this editor
   * /
  public native function get boundEl():Element;

  /**
   * The field value being set
   * /
  public native function get value():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Editor_boundEl_valueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_START_EDIT: "onBeforeStartEdit",
            START_EDIT: "onStartEdit",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.Editor_field_eventEvent", function(Editor_field_eventEvent) {
    /*package ext.events {
import ext.Editor;
import ext.event.Event;
import ext.form.field.Field;

import net.jangaroo.ext.FlExtEvent;

public class Editor_field_eventEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Editor_field_eventEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "field",
            "event",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when any key related to navigation (arrows, tab, enter, esc, etc.) is pressed.  You can check
   * <a href="#!/api/Ext.event.Event-method-getKey" rel="Ext.event.Event-method-getKey" class="docClass">Ext.event.Event.getKey</a> to determine which key was pressed.
   * @see ext.Editor
   * @eventType onSpecialKey
   * /
  public static const SPECIAL_KEY:String = "onSpecialKey";

  public*/
    function Editor_field_eventEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Editor;

  /**
   * The field attached to this editor
   * /
  public native function get field():Field;

  /**
   * The event object
   * /
  public native function get event():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Editor_field_eventEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SPECIAL_KEY: "onSpecialKey",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.Editor_value_startValueEvent", function(Editor_value_startValueEvent) {
    /*package ext.events {
import ext.Editor;

import net.jangaroo.ext.FlExtEvent;

public class Editor_value_startValueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Editor_value_startValueEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "value",
            "startValue",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after a change has been made to the field, but before the change is reflected in the underlying
   * field.  Saving the change to the field can be canceled by returning false from the handler of this event.
   * Note that if the value has not changed and ignoreNoChange = true, the editing will still end but this
   * event will not fire since no edit actually occurred.
   * @see ext.Editor
   * @eventType onBeforeComplete
   * /
  public static const BEFORE_COMPLETE:String = "onBeforeComplete";
  /**
   * "Fires after editing has been canceled and the editor's value has been reset.
   * @see ext.Editor
   * @eventType onCancelEdit
   * /
  public static const CANCEL_EDIT:String = "onCancelEdit";
  /**
   * "Fires after editing is complete and any changed value has been written to the underlying field.
   * @see ext.Editor
   * @eventType onComplete
   * /
  public static const COMPLETE:String = "onComplete";

  public*/
    function Editor_value_startValueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Editor;

  /**
   * The current field value
   * /
  public native function get value():Object;

  /**
   * The original field value
   * /
  public native function get startValue():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Editor_value_startValueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_COMPLETE: "onBeforeComplete",
            CANCEL_EDIT: "onCancelEdit",
            COMPLETE: "onComplete",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.ElementLoader_optionsEvent", function(ElementLoader_optionsEvent) {
    /*package ext.events {
import ext.ElementLoader;

import net.jangaroo.ext.FlExtEvent;

public class ElementLoader_optionsEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ElementLoader_optionsEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "options",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a load request is made to the server.
   * Returning false from an event listener can prevent the load
   * from occurring.
   * @see ext.ElementLoader
   * @eventType onBeforeLoad
   * /
  public static const BEFORE_LOAD:String = "onBeforeLoad";

  public*/
    function ElementLoader_optionsEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():ElementLoader;

  /**
   * The options passed to the request
   * /
  public native function get options():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ElementLoader_optionsEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_LOAD: "onBeforeLoad",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.ElementLoader_response_optionsEvent", function(ElementLoader_response_optionsEvent) {
    /*package ext.events {
import ext.ElementLoader;

import net.jangaroo.ext.FlExtEvent;

public class ElementLoader_response_optionsEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ElementLoader_response_optionsEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "response",
            "options",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after an unsuccessful load.
   * @see ext.ElementLoader
   * @eventType onException
   * /
  public static const EXCEPTION:String = "onException";
  /**
   * "Fires after a successful load.
   * @see ext.ElementLoader
   * @eventType onLoad
   * /
  public static const LOAD:String = "onLoad";

  public*/
    function ElementLoader_response_optionsEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():ElementLoader;

  /**
   * The response from the server
   * /
  public native function get response():Object;

  /**
   * The options passed to the request
   * /
  public native function get options():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ElementLoader_response_optionsEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            EXCEPTION: "onException",
            LOAD: "onLoad",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.GlobalEventsEvent", function(GlobalEventsEvent) {
    /*package ext.events {
import net.jangaroo.ext.FlExtEvent;

public class GlobalEventsEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        GlobalEventsEvent.__PARAMETER_SEQUENCE__ = ([
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when an event handler finishes its run, just before returning to
   * browser control.
   *
   * <p>This includes DOM event handlers, Ajax (including JSONP) event handlers,
   * and <a href="#!/api/Ext.util.TaskRunner" rel="Ext.util.TaskRunner" class="docClass">TaskRunners</a></p>
   *
   * <p>When called at the tail of a DOM event, the event object is passed as the
   * sole parameter.</p>
   *
   * <p>This can be useful for performing cleanup, or update tasks which need to
   * happen only after all code in an event handler has been run, but which
   * should not be executed in a timer due to the intervening browser
   * reflow/repaint which would take place.</p>
   * @see ext.SGlobalEvents
   * @eventType onIdle
   * /
  public static const IDLE:String = "onIdle";
  /**
   * "Fires after global layout processing has been resumed in <a href="#!/api/Ext.Component-method-resumeLayouts" rel="Ext.Component-method-resumeLayouts" class="docClass">Ext.Component.resumeLayouts</a>.
   * @see ext.SGlobalEvents
   * @eventType onResumeLayouts
   * /
  public static const RESUME_LAYOUTS:String = "onResumeLayouts";

  public*/
    function GlobalEventsEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: GlobalEventsEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            IDLE: "onIdle",
            RESUME_LAYOUTS: "onResumeLayouts",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.GlobalEvents_componentEvent", function(GlobalEvents_componentEvent) {
    /*package ext.events {
import ext.Component;

import net.jangaroo.ext.FlExtEvent;

public class GlobalEvents_componentEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        GlobalEvents_componentEvent.__PARAMETER_SEQUENCE__ = ([
            "component",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a Component is added to a Container.
   * @see ext.SGlobalEvents
   * @eventType onAdded
   * /
  public static const ADDED:String = "onAdded";
  /**
   * "Fires when a Component is collapsed (e.g., a panel).
   * @see ext.SGlobalEvents
   * @eventType onCollapse
   * /
  public static const COLLAPSE:String = "onCollapse";
  /**
   * "Fires when a Component is expanded (e.g., a panel).
   * @see ext.SGlobalEvents
   * @eventType onExpand
   * /
  public static const EXPAND:String = "onExpand";
  /**
   * "Fires when a Component is hidden.
   * @see ext.SGlobalEvents
   * @eventType onHide
   * /
  public static const HIDE:String = "onHide";
  /**
   * "Fires when a Component is removed from a Container.
   * @see ext.SGlobalEvents
   * @eventType onRemoved
   * /
  public static const REMOVED:String = "onRemoved";
  /**
   * "Fires when a Component is shown.
   * @see ext.SGlobalEvents
   * @eventType onShow
   * /
  public static const SHOW:String = "onShow";

  public*/
    function GlobalEvents_componentEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get component():Component;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: GlobalEvents_componentEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ADDED: "onAdded",
            COLLAPSE: "onCollapse",
            EXPAND: "onExpand",
            HIDE: "onHide",
            REMOVED: "onRemoved",
            SHOW: "onShow",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.GlobalEvents_contextEvent", function(GlobalEvents_contextEvent) {
    /*package ext.events {
import net.jangaroo.ext.FlExtEvent;

public class GlobalEvents_contextEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        GlobalEvents_contextEvent.__PARAMETER_SEQUENCE__ = ([
            "context",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before <a href="#!/api/Ext.mixin.Responsive" rel="Ext.mixin.Responsive" class="docClass">Ext.mixin.Responsive</a> perform any updates in response to
   * dynamic changes. This is prior to refreshing <code>responsiveFormulas</code>.
   * @since 5.0.1
   * @see ext.SGlobalEvents
   * @eventType onBeforeResponsiveUpdate
   * /
  public static const BEFORE_RESPONSIVE_UPDATE:String = "onBeforeResponsiveUpdate";
  /**
   * "Fires when <a href="#!/api/Ext.mixin.Responsive" rel="Ext.mixin.Responsive" class="docClass">Ext.mixin.Responsive</a> is about to perform updates in response to
   * dynamic changes. At this point all <code>responsiveFormulas</code> have been refreshed.
   * @since 5.0.1
   * @see ext.SGlobalEvents
   * @eventType onBeginResponsiveUpdate
   * /
  public static const BEGIN_RESPONSIVE_UPDATE:String = "onBeginResponsiveUpdate";
  /**
   * "Fires after <a href="#!/api/Ext.mixin.Responsive" rel="Ext.mixin.Responsive" class="docClass">Ext.mixin.Responsive</a> has performed updates in response to
   * dynamic changes.
   * @since 5.0.1
   * @see ext.SGlobalEvents
   * @eventType onResponsiveUpdate
   * /
  public static const RESPONSIVE_UPDATE:String = "onResponsiveUpdate";

  public*/
    function GlobalEvents_contextEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The context object used by <code>responsiveConfig</code> expressions.
   * /
  public native function get context():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: GlobalEvents_contextEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_RESPONSIVE_UPDATE: "onBeforeResponsiveUpdate",
            BEGIN_RESPONSIVE_UPDATE: "onBeginResponsiveUpdate",
            RESPONSIVE_UPDATE: "onResponsiveUpdate",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.GlobalEvents_eEvent", function(GlobalEvents_eEvent) {
    /*package ext.events {
import ext.event.Event;

import net.jangaroo.ext.FlExtEvent;

public class GlobalEvents_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        GlobalEvents_eEvent.__PARAMETER_SEQUENCE__ = ([
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "A mousedown listener on the document that is immune to stopPropagation()
   * used in cases where we need to know if a mousedown event occurred on the
   * document regardless of whether some other handler tried to stop it.  An
   * example where this is useful is a menu that needs to be hidden whenever
   * there is a mousedown event on the document.
   * @see ext.SGlobalEvents
   * @eventType onMouseDown
   * /
  public static const MOUSE_DOWN:String = "onMouseDown";

  public*/
    function GlobalEvents_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The event object
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: GlobalEvents_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            MOUSE_DOWN: "onMouseDown",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.GlobalEvents_width_heightEvent", function(GlobalEvents_width_heightEvent) {
    /*package ext.events {
import net.jangaroo.ext.FlExtEvent;

public class GlobalEvents_width_heightEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        GlobalEvents_width_heightEvent.__PARAMETER_SEQUENCE__ = ([
            "width",
            "height",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the browser window is resized.  To avoid running resize handlers
   * too often resulting in sluggish window resizing, resize events use a buffer
   * of 100 milliseconds.
   * @see ext.SGlobalEvents
   * @eventType onResize
   * /
  public static const RESIZE:String = "onResize";

  public*/
    function GlobalEvents_width_heightEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The new width
   * /
  public native function get width():Number;

  /**
   * The new height
   * /
  public native function get height():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: GlobalEvents_width_heightEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            RESIZE: "onResize",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.ProgressBar_value_textEvent", function(ProgressBar_value_textEvent) {
    /*package ext.events {
import ext.ProgressBar;

import net.jangaroo.ext.FlExtEvent;

public class ProgressBar_value_textEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ProgressBar_value_textEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "value",
            "text",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after each update interval
   * @see ext.ProgressBar
   * @eventType onUpdate
   * /
  public static const UPDATE:String = "onUpdate";

  public*/
    function ProgressBar_value_textEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():ProgressBar;

  /**
   * The current progress value
   * /
  public native function get value():Number;

  /**
   * The current progress text
   * /
  public native function get text():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ProgressBar_value_textEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            UPDATE: "onUpdate",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.events.Widget_value_oldValueEvent", function(Widget_value_oldValueEvent) {
    /*package ext.events {
import ext.Widget;

import net.jangaroo.ext.FlExtEvent;

public class Widget_value_oldValueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Widget_value_oldValueEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "value",
            "oldValue",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the <a href="#!/api/Ext.Widget-cfg-height" rel="Ext.Widget-cfg-height" class="docClass">height</a> configuration is changed by <a href="#!/api/Ext.Widget-method-setHeight" rel="Ext.Widget-method-setHeight" class="docClass">setHeight</a>.
   * @see ext.Widget
   * @eventType onHeightChange
   * /
  public static const HEIGHT_CHANGE:String = "onHeightChange";
  /**
   * "Fires when the <a href="#!/api/Ext.Widget-cfg-hidden" rel="Ext.Widget-cfg-hidden" class="docClass">hidden</a> configuration is changed by <a href="#!/api/Ext.Widget-method-setHidden" rel="Ext.Widget-method-setHidden" class="docClass">setHidden</a>.
   * @see ext.Widget
   * @eventType onHiddenChange
   * /
  public static const HIDDEN_CHANGE:String = "onHiddenChange";
  /**
   * "Fires when the <a href="#!/api/Ext.Widget-cfg-width" rel="Ext.Widget-cfg-width" class="docClass">width</a> configuration is changed by <a href="#!/api/Ext.Widget-method-setWidth" rel="Ext.Widget-method-setWidth" class="docClass">setWidth</a>.
   * @see ext.Widget
   * @eventType onWidthChange
   * /
  public static const WIDTH_CHANGE:String = "onWidthChange";

  public*/
    function Widget_value_oldValueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The <a href="#!/api/Ext.Widget" rel="Ext.Widget" class="docClass">Ext.Widget</a> instance.
   * /
  public native function get source():Widget;

  /**
   * The new value being set.
   * /
  public native function get value():*;

  /**
   * The existing value.
   * /
  public native function get oldValue():*;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Widget_value_oldValueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            HEIGHT_CHANGE: "onHeightChange",
            HIDDEN_CHANGE: "onHiddenChange",
            WIDTH_CHANGE: "onWidthChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.flash.events.FlashComponentEvent", function(FlashComponentEvent) {
    /*package ext.flash.events {
import ext.flash.FlashComponent;

import net.jangaroo.ext.FlExtEvent;

public class FlashComponentEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FlashComponentEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when the Flash movie embedding fails
   * @see ext.flash.FlashComponent
   * @eventType onFailure
   * /
  public static const FAILURE:String = "onFailure";
  /**
   * "Fired when the Flash movie has been successfully embedded
   * @see ext.flash.FlashComponent
   * @eventType onSuccess
   * /
  public static const SUCCESS:String = "onSuccess";

  public*/
    function FlashComponentEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():FlashComponent;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FlashComponentEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            FAILURE: "onFailure",
            SUCCESS: "onSuccess",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.IFieldMixin", function(IFieldMixin) {
    /*package ext.form {
import js.HTMLElement;

/**
 * This mixin provides a common interface for the logical behavior and state of form fields, including:
 *
 * <ul>
 * <li>Getter and setter methods for field values</li>
 * <li>Events and methods for tracking value and validity changes</li>
 * <li>Methods for triggering validation</li>
 * </ul>
 *
 *
 * <p><strong>NOTE</strong>: When implementing custom fields, it is most likely that you will want to extend the <a href="#!/api/Ext.form.field.Base" rel="Ext.form.field.Base" class="docClass">Ext.form.field.Base</a>
 * component class rather than using this mixin directly, as BaseField contains additional logic for generating an
 * actual DOM complete with <a href="#!/api/Ext.form.Labelable" rel="Ext.form.Labelable" class="docClass">label and error message</a> display and a form input field,
 * plus methods that bind the Field value getters and setters to the input field's value.</p>
 *
 * <p>If you do want to implement this mixin directly and don't want to extend <a href="#!/api/Ext.form.field.Base" rel="Ext.form.field.Base" class="docClass">Ext.form.field.Base</a>, then
 * you will most likely want to override the following methods with custom implementations: <a href="#!/api/Ext.form.field.Field-method-getValue" rel="Ext.form.field.Field-method-getValue" class="docClass">getValue</a>,
 * <a href="#!/api/Ext.form.field.Field-method-setValue" rel="Ext.form.field.Field-method-setValue" class="docClass">setValue</a>, and <a href="#!/api/Ext.form.field.Field-method-getErrors" rel="Ext.form.field.Field-method-getErrors" class="docClass">getErrors</a>. Other methods may be overridden as needed but their base
 * implementations should be sufficient for common cases. You will also need to make sure that <a href="#!/api/Ext.form.field.Field-method-initField" rel="Ext.form.field.Field-method-initField" class="docClass">initField</a>
 * is called during the component's initialization.</p>
 * /
public interface IFieldMixin {
  /**
   * Flag denoting that this component is a Field. Always true.
   * @default true
   * /
  function get isFormField():Boolean;

  /**
   * @private
   * /
  function set isFormField(value:Boolean):void;

  /**
   * The original value of the field as configured in the <a href="#!/api/Ext.form.field.Field-cfg-value" rel="Ext.form.field.Field-cfg-value" class="docClass">value</a> configuration, or as loaded by the last
   * form load operation if the form's <a href="#!/api/Ext.form.Basic-cfg-trackResetOnLoad" rel="Ext.form.Basic-cfg-trackResetOnLoad" class="docClass">trackResetOnLoad</a> setting is <code>true</code>.
   * /
  function get originalValue():Object;

  /**
   * @private
   * /
  function set originalValue(value:Object):void;

  /**
   * A utility for grouping a set of modifications which may trigger value changes into a single transaction, to
   * prevent excessive firing of <a href="#!/api/Ext.form.field.Field-event-change" rel="Ext.form.field.Field-event-change" class="docClass">change</a> events. This is useful for instance if the field has sub-fields which
   * are being updated as a group; you don't want the container field to check its own changed state for each subfield
   * change.
   * @param fn The function to call with change checks suspended.
   * /
  function batchChanges(fn:Function):void;

  /**
   * Checks whether the value of the field has changed since the last time it was checked.
   * If the value has changed, it:
   *
   * <ol>
   * <li>Fires the <a href="#!/api/Ext.form.field.Field-event-change" rel="Ext.form.field.Field-event-change" class="docClass">change event</a>,</li>
   * <li>Performs validation if the <a href="#!/api/Ext.form.field.Field-cfg-validateOnChange" rel="Ext.form.field.Field-cfg-validateOnChange" class="docClass">validateOnChange</a> config is enabled, firing the
   * <a href="#!/api/Ext.form.field.Field-event-validitychange" rel="Ext.form.field.Field-event-validitychange" class="docClass">validitychange event</a> if the validity has changed, and</li>
   * <li>Checks the <a href="#!/api/Ext.form.field.Field-method-isDirty" rel="Ext.form.field.Field-method-isDirty" class="docClass">dirty state</a> of the field and fires the <a href="#!/api/Ext.form.field.Field-event-dirtychange" rel="Ext.form.field.Field-event-dirtychange" class="docClass">dirtychange event</a>
   * if it has changed.</li>
   * </ol>
   * /
  function checkChange():void;

  /**
   * Checks the <a href="#!/api/Ext.form.field.Field-method-isDirty" rel="Ext.form.field.Field-method-isDirty" class="docClass">isDirty</a> state of the field and if it has changed since the last time it was checked,
   * fires the <a href="#!/api/Ext.form.field.Field-event-dirtychange" rel="Ext.form.field.Field-event-dirtychange" class="docClass">dirtychange</a> event.
   * /
  function checkDirty():void;

  /**
   * Clear any invalid styles/messages for this field. Components using this mixin should implement this method to
   * update the components rendering to clear any existing messages.
   *
   * <p><strong>Note</strong>: this method does not cause the Field's <a href="#!/api/Ext.form.field.Field-method-validate" rel="Ext.form.field.Field-method-validate" class="docClass">validate</a> or <a href="#!/api/Ext.form.field.Field-method-isValid" rel="Ext.form.field.Field-method-isValid" class="docClass">isValid</a> methods to return <code>true</code>
   * if the value does not <em>pass</em> validation. So simply clearing a field's errors will not necessarily allow
   * submission of forms submitted with the <a href="#!/api/Ext.form.action.Submit-cfg-clientValidation" rel="Ext.form.action.Submit-cfg-clientValidation" class="docClass">Ext.form.action.Submit.clientValidation</a> option set.</p>
   * /
  function clearInvalid():void;

  /**
   * Only relevant if the instance's <a href="#!/api/Ext.form.field.Field-method-isFileUpload" rel="Ext.form.field.Field-method-isFileUpload" class="docClass">isFileUpload</a> method returns true. Returns a reference to the file input
   * DOM element holding the user's selected file. The input will be appended into the submission form and will not be
   * returned, so this method should also create a replacement.
   * /
  function extractFileInput():HTMLElement;

  /**
   * Runs this field's validators and returns an array of error messages for any validation failures. This is called
   * internally during validation and would not usually need to be used manually.
   *
   * <p>Each subclass should override or augment the return value to provide their own errors.</p>
   * @param value The value to get errors for (defaults to the current field value)
   * @return All error messages for this field; an empty Array if none.
   * /
  function getErrors(value:*):Array;

  /**
   * Returns the value(s) that should be saved to the <a href="#!/api/Ext.data.Model" rel="Ext.data.Model" class="docClass">Ext.data.Model</a> instance for this field, when <a href="#!/api/Ext.form.Basic-method-updateRecord" rel="Ext.form.Basic-method-updateRecord" class="docClass">Ext.form.Basic.updateRecord</a> is called. Typically this will be an object with a single name-value pair, the name
   * being this field's <a href="#!/api/Ext.form.field.Field-method-getName" rel="Ext.form.field.Field-method-getName" class="docClass">name</a> and the value being its current data value. More advanced field
   * implementations may return more than one name-value pair. The returned values will be saved to the corresponding
   * field names in the Model.
   *
   * <p>Note that the values returned from this method are not guaranteed to have been successfully <a href="#!/api/Ext.form.field.Field-method-validate" rel="Ext.form.field.Field-method-validate" class="docClass">validated</a>.</p>
   * @return A mapping of submit parameter names to values; each value should be a string, or an array of
   * strings if that particular name has multiple values. It can also return null if there are no parameters to be
   * submitted.
   * /
  function getModelData(includeEmptyText:Object, isSubmitting:Object):Object;

  /**
   * Returns the <a href="#!/api/Ext.form.field.Field-cfg-name" rel="Ext.form.field.Field-cfg-name" class="docClass">name</a> attribute of the field. This is used as the parameter name
   * when including the field value in a <a href="#!/api/Ext.form.Basic-method-submit" rel="Ext.form.Basic-method-submit" class="docClass">form submit()</a>.
   * @return name The field <a href="#!/api/Ext.form.field.Field-cfg-name" rel="Ext.form.field.Field-cfg-name" class="docClass">name</a>
   * /
  function getName():String;

  /**
   * Returns the parameter(s) that would be included in a standard form submit for this field. Typically this will be
   * an object with a single name-value pair, the name being this field's <a href="#!/api/Ext.form.field.Field-method-getName" rel="Ext.form.field.Field-method-getName" class="docClass">name</a> and the value being
   * its current stringified value. More advanced field implementations may return more than one name-value pair.
   *
   * <p>Note that the values returned from this method are not guaranteed to have been successfully <a href="#!/api/Ext.form.field.Field-method-validate" rel="Ext.form.field.Field-method-validate" class="docClass">validated</a>.</p>
   * @return A mapping of submit parameter names to values; each value should be a string, or an array of
   * strings if that particular name has multiple values. It can also return null if there are no parameters to be
   * submitted.
   * /
  function getSubmitData():Object;

  /**
   * Returns the value of <a href="#!/api/Ext.form.field.Field-cfg-validation" rel="Ext.form.field.Field-cfg-validation" class="docClass">validation</a>.
   * /
  function getValidation():*;

  /**
   * Returns the current data value of the field. The type of value returned is particular to the type of the
   * particular field (e.g. a Date object for <a href="#!/api/Ext.form.field.Date" rel="Ext.form.field.Date" class="docClass">Ext.form.field.Date</a>).
   * @return value The field value
   * /
  function getValue():Object;

  /**
   * Initializes this Field mixin on the current instance. Components using this mixin should call this method during
   * their own initialization process.
   * /
  function initField():void;

  /**
   * Initializes the field's value based on the initial config.
   * /
  function initValue():void;

  /**
   * Returns true if the value of this Field has been changed from its <a href="#!/api/Ext.form.field.Field-property-originalValue" rel="Ext.form.field.Field-property-originalValue" class="docClass">originalValue</a>.
   * Will always return false if the field is disabled.
   *
   * <p>Note that if the owning <a href="#!/api/Ext.form.Basic" rel="Ext.form.Basic" class="docClass">form</a> was configured with
   * <a href="#!/api/Ext.form.Basic-cfg-trackResetOnLoad" rel="Ext.form.Basic-cfg-trackResetOnLoad" class="docClass">trackResetOnLoad</a> then the <a href="#!/api/Ext.form.field.Field-property-originalValue" rel="Ext.form.field.Field-property-originalValue" class="docClass">originalValue</a> is updated when
   * the values are loaded by <a href="#!/api/Ext.form.Basic" rel="Ext.form.Basic" class="docClass">Ext.form.Basic</a>.<a href="#!/api/Ext.form.Basic-method-setValues" rel="Ext.form.Basic-method-setValues" class="docClass">setValues</a>.</p>
   * @return True if this field has been changed from its original value (and is not disabled),
   * false otherwise.
   * /
  function isDirty():Boolean;

  /**
   * Returns whether two field <a href="#!/api/Ext.form.field.Field-method-getValue" rel="Ext.form.field.Field-method-getValue" class="docClass">values</a> are logically equal. Field implementations may override this
   * to provide custom comparison logic appropriate for the particular field's data type.
   * @param value1 The first value to compare
   * @param value2 The second value to compare
   * @return True if the values are equal, false if inequal.
   * /
  function isEqual(value1:Object, value2:Object):Boolean;

  /**
   * Returns whether this Field is a file upload field; if it returns true, forms will use special techniques for
   * <a href="#!/api/Ext.form.Basic-method-submit" rel="Ext.form.Basic-method-submit" class="docClass">submitting the form</a> via AJAX. See <a href="#!/api/Ext.form.Basic-method-hasUpload" rel="Ext.form.Basic-method-hasUpload" class="docClass">Ext.form.Basic.hasUpload</a> for details. If
   * this returns true, the <a href="#!/api/Ext.form.field.Field-method-extractFileInput" rel="Ext.form.field.Field-method-extractFileInput" class="docClass">extractFileInput</a> method must also be implemented to return the corresponding file
   * input element.
   * /
  function isFileUpload():Boolean;

  /**
   * Returns whether or not the field value is currently valid by <a href="#!/api/Ext.form.field.Field-method-getErrors" rel="Ext.form.field.Field-method-getErrors" class="docClass">validating</a> the field's current
   * value. The <a href="#!/api/Ext.form.field.Field-event-validitychange" rel="Ext.form.field.Field-event-validitychange" class="docClass">validitychange</a> event will not be fired; use <a href="#!/api/Ext.form.field.Field-method-validate" rel="Ext.form.field.Field-method-validate" class="docClass">validate</a> instead if you want the event
   * to fire. <strong>Note</strong>: <a href="#!/api/Ext.form.field.Field-cfg-disabled" rel="Ext.form.field.Field-cfg-disabled" class="docClass">disabled</a> fields are always treated as valid.
   *
   * <p>Implementations are encouraged to ensure that this method does not have side-effects such as triggering error
   * message display.</p>
   * @return True if the value is valid, else false
   * /
  function isValid():Boolean;

  /**
   * Display one or more error messages associated with this field, using
   * <a href="#!/api/Ext.form.Labelable-cfg-msgTarget" rel="Ext.form.Labelable-cfg-msgTarget" class="docClass">Ext.form.Labelable.msgTarget</a> to determine how to display the messages and
   * applying <a href="#!/api/Ext.form.Labelable-cfg-invalidCls" rel="Ext.form.Labelable-cfg-invalidCls" class="docClass">Ext.form.Labelable.invalidCls</a> to the field's UI element.
   *
   * <pre><code>var formPanel = <a href="#!/api/Ext-method-create" rel="Ext-method-create" class="docClass">Ext.create</a>('<a href="#!/api/Ext.form.Panel" rel="Ext.form.Panel" class="docClass">Ext.form.Panel</a>', {
   *     title: 'Contact Info',
   *     width: 300,
   *     bodyPadding: 10,
   *     renderTo: <a href="#!/api/Ext-method-getBody" rel="Ext-method-getBody" class="docClass">Ext.getBody</a>(),
   *     items: [{
   *         xtype: 'textfield',
   *         name: 'name',
   *         id: 'nameId',
   *         fieldLabel: 'Name'
   *     }],
   *     bbar: [{
   *         text: 'Mark both fields invalid',
   *         handler: function() {
   *             var nameField = formPanel.getForm().findField('name');
   *             nameField.markInvalid('Name invalid message');
   *
   *             // multiple error string syntax
   *             // nameField.markInvalid(['First message', 'Second message']);
   *         }
   *     }]
   * });
   * </code></pre>
   *
   * <p><strong>Note</strong>: this method does not cause the Field's <a href="#!/api/Ext.form.field.Field-method-validate" rel="Ext.form.field.Field-method-validate" class="docClass">validate</a> or
   * <a href="#!/api/Ext.form.field.Field-method-isValid" rel="Ext.form.field.Field-method-isValid" class="docClass">isValid</a> methods to return <code>false</code> if the value does <em>pass</em> validation.
   * So simply marking a Field as invalid will not prevent submission of forms
   * submitted with the <a href="#!/api/Ext.form.action.Submit-cfg-clientValidation" rel="Ext.form.action.Submit-cfg-clientValidation" class="docClass">Ext.form.action.Submit.clientValidation</a> option set.</p>
   * @param errors The validation message(s) to display.
   * /
  function markInvalid(errors:String):void;

  /**
   * Resets the current field value to the originally loaded value and clears any validation messages. See <a href="#!/api/Ext.form.Basic" rel="Ext.form.Basic" class="docClass">Ext.form.Basic</a>.<a href="#!/api/Ext.form.Basic-cfg-trackResetOnLoad" rel="Ext.form.Basic-cfg-trackResetOnLoad" class="docClass">trackResetOnLoad</a>
   * /
  function reset():void;

  /**
   * Resets the field's <a href="#!/api/Ext.form.field.Field-property-originalValue" rel="Ext.form.field.Field-property-originalValue" class="docClass">originalValue</a> property so it matches the current <a href="#!/api/Ext.form.field.Field-method-getValue" rel="Ext.form.field.Field-method-getValue" class="docClass">value</a>. This is
   * called by <a href="#!/api/Ext.form.Basic" rel="Ext.form.Basic" class="docClass">Ext.form.Basic</a>.<a href="#!/api/Ext.form.Basic-method-setValues" rel="Ext.form.Basic-method-setValues" class="docClass">setValues</a> if the form's
   * <a href="#!/api/Ext.form.Basic-cfg-trackResetOnLoad" rel="Ext.form.Basic-cfg-trackResetOnLoad" class="docClass">trackResetOnLoad</a> property is set to true.
   * /
  function resetOriginalValue():void;

  /**
   * Sets the value of <a href="#!/api/Ext.form.field.Field-cfg-validation" rel="Ext.form.field.Field-cfg-validation" class="docClass">validation</a>.
   * @param validation The new value.
   * /
  function setValidation(validation:*):void;

  /**
   * Sets a data value into the field and runs the change detection and validation.
   * @param value The value to set
   * @return this
   * /
  function setValue(value:Object):FieldMixin;

  /**
   * Returns whether or not the field value is currently valid by <a href="#!/api/Ext.form.field.Field-method-getErrors" rel="Ext.form.field.Field-method-getErrors" class="docClass">validating</a> the field's current
   * value, and fires the <a href="#!/api/Ext.form.field.Field-event-validitychange" rel="Ext.form.field.Field-event-validitychange" class="docClass">validitychange</a> event if the field's validity has changed since the last validation.
   * <strong>Note</strong>: <a href="#!/api/Ext.form.field.Field-cfg-disabled" rel="Ext.form.field.Field-cfg-disabled" class="docClass">disabled</a> fields are always treated as valid.
   *
   * <p>Custom implementations of this method are allowed to have side-effects such as triggering error message display.
   * To validate without side-effects, use <a href="#!/api/Ext.form.field.Field-method-isValid" rel="Ext.form.field.Field-method-isValid" class="docClass">isValid</a>.</p>
   * @return True if the value is valid, else false
   * /
  function validate():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {};
});

Ext.define("ext.form.events.BasicForm_actionEvent", function(BasicForm_actionEvent) {
    /*package ext.form.events {
import ext.form.BasicForm;
import ext.form.action.Action;

import net.jangaroo.ext.FlExtEvent;

public class BasicForm_actionEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        BasicForm_actionEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "action",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when an action is completed.
   * @see ext.form.BasicForm
   * @eventType onActionComplete
   * /
  public static const ACTION_COMPLETE:String = "onActionComplete";
  /**
   * "Fires when an action fails.
   * @see ext.form.BasicForm
   * @eventType onActionFailed
   * /
  public static const ACTION_FAILED:String = "onActionFailed";
  /**
   * "Fires before any action is performed. Return false to cancel the action.
   * @see ext.form.BasicForm
   * @eventType onBeforeAction
   * /
  public static const BEFORE_ACTION:String = "onBeforeAction";

  public*/
    function BasicForm_actionEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():BasicForm;

  /**
   * The <a href="#!/api/Ext.form.action.Action" rel="Ext.form.action.Action" class="docClass">Ext.form.action.Action</a> that completed
   * /
  public native function get action():Action;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: BasicForm_actionEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ACTION_COMPLETE: "onActionComplete",
            ACTION_FAILED: "onActionFailed",
            BEFORE_ACTION: "onBeforeAction",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.BasicForm_dirtyEvent", function(BasicForm_dirtyEvent) {
    /*package ext.form.events {
import ext.form.BasicForm;

import net.jangaroo.ext.FlExtEvent;

public class BasicForm_dirtyEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        BasicForm_dirtyEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "dirty",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the dirty state of the entire form changes.
   * @see ext.form.BasicForm
   * @eventType onDirtyChange
   * /
  public static const DIRTY_CHANGE:String = "onDirtyChange";

  public*/
    function BasicForm_dirtyEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():BasicForm;

  /**
   * <code>true</code> if the form is now dirty, <code>false</code> if it is no longer dirty.
   * /
  public native function get dirty():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: BasicForm_dirtyEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DIRTY_CHANGE: "onDirtyChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.BasicForm_validEvent", function(BasicForm_validEvent) {
    /*package ext.form.events {
import ext.form.BasicForm;

import net.jangaroo.ext.FlExtEvent;

public class BasicForm_validEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        BasicForm_validEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "valid",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the validity of the entire form changes.
   * @see ext.form.BasicForm
   * @eventType onValidityChange
   * /
  public static const VALIDITY_CHANGE:String = "onValidityChange";

  public*/
    function BasicForm_validEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():BasicForm;

  /**
   * <code>true</code> if the form is now valid, <code>false</code> if it is now invalid.
   * /
  public native function get valid():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: BasicForm_validEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            VALIDITY_CHANGE: "onValidityChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.CheckboxGroup_isDirtyEvent", function(CheckboxGroup_isDirtyEvent) {
    /*package ext.form.events {
import ext.form.field.Field;

import net.jangaroo.ext.FlExtEvent;

public class CheckboxGroup_isDirtyEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        CheckboxGroup_isDirtyEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "isDirty",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a change in the field's <a href="#!/api/Ext.form.field.Field-method-isDirty" rel="Ext.form.field.Field-method-isDirty" class="docClass">isDirty</a> state is detected.
   * @see ext.form.CheckboxGroup
   * @eventType onDirtyChange
   * /
  public static const DIRTY_CHANGE:String = "onDirtyChange";

  public*/
    function CheckboxGroup_isDirtyEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Field;

  /**
   * Whether or not the field is now dirty
   * /
  public native function get isDirty():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: CheckboxGroup_isDirtyEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DIRTY_CHANGE: "onDirtyChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.CheckboxGroup_isValidEvent", function(CheckboxGroup_isValidEvent) {
    /*package ext.form.events {
import ext.form.field.Field;

import net.jangaroo.ext.FlExtEvent;

public class CheckboxGroup_isValidEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        CheckboxGroup_isValidEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "isValid",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a change in the field's validity is detected.
   * @see ext.form.CheckboxGroup
   * @eventType onValidityChange
   * /
  public static const VALIDITY_CHANGE:String = "onValidityChange";

  public*/
    function CheckboxGroup_isValidEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Field;

  /**
   * Whether or not the field is now valid
   * /
  public native function get isValid():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: CheckboxGroup_isValidEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            VALIDITY_CHANGE: "onValidityChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.CheckboxGroup_newValue_oldValueEvent", function(CheckboxGroup_newValue_oldValueEvent) {
    /*package ext.form.events {
import ext.form.field.Field;

import net.jangaroo.ext.FlExtEvent;

public class CheckboxGroup_newValue_oldValueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        CheckboxGroup_newValue_oldValueEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "newValue",
            "oldValue",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the value of a field is changed. The value of a field is
   * checked for changes when the field's <a href="#!/api/Ext.form.field.Field-method-setValue" rel="Ext.form.field.Field-method-setValue" class="docClass">setValue</a> method
   * is called and when any of the events listed in
   * <a href="#!/api/Ext.form.field.Base-cfg-checkChangeEvents" rel="Ext.form.field.Base-cfg-checkChangeEvents" class="docClass">checkChangeEvents</a> are fired.
   * @see ext.form.CheckboxGroup
   * @eventType onChange
   * /
  public static const CHANGE:String = "onChange";

  public*/
    function CheckboxGroup_newValue_oldValueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Field;

  /**
   * The new value
   * /
  public native function get newValue():Object;

  /**
   * The original value
   * /
  public native function get oldValue():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: CheckboxGroup_newValue_oldValueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CHANGE: "onChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.FieldAncestor_field_errorEvent", function(FieldAncestor_field_errorEvent) {
    /*package ext.form.events {
import ext.form.FieldAncestor;
import ext.form.Labelable;

import net.jangaroo.ext.FlExtEvent;

public class FieldAncestor_field_errorEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FieldAncestor_field_errorEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "field",
            "error",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the active error message is changed for any one of the <a href="#!/api/Ext.form.Labelable" rel="Ext.form.Labelable" class="docClass">Ext.form.Labelable</a> instances
   * within this container.
   * @see ext.form.FieldAncestor
   * @eventType onFieldErrorChange
   * /
  public static const FIELD_ERROR_CHANGE:String = "onFieldErrorChange";

  public*/
    function FieldAncestor_field_errorEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():FieldAncestor;

  /**
   * The Labelable instance whose active error was changed
   * /
  public native function get field():Labelable;

  /**
   * The active error message
   * /
  public native function get error():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FieldAncestor_field_errorEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            FIELD_ERROR_CHANGE: "onFieldErrorChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.FieldAncestor_field_isValidEvent", function(FieldAncestor_field_isValidEvent) {
    /*package ext.form.events {
import ext.form.FieldAncestor;
import ext.form.Labelable;

import net.jangaroo.ext.FlExtEvent;

public class FieldAncestor_field_isValidEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FieldAncestor_field_isValidEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "field",
            "isValid",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the validity state of any one of the <a href="#!/api/Ext.form.field.Field" rel="Ext.form.field.Field" class="docClass">Ext.form.field.Field</a> instances within this
   * container changes.
   * @see ext.form.FieldAncestor
   * @eventType onFieldValidityChange
   * /
  public static const FIELD_VALIDITY_CHANGE:String = "onFieldValidityChange";

  public*/
    function FieldAncestor_field_isValidEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():FieldAncestor;

  /**
   * The Field instance whose validity changed
   * /
  public native function get field():Labelable;

  /**
   * The field's new validity state
   * /
  public native function get isValid():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FieldAncestor_field_isValidEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            FIELD_VALIDITY_CHANGE: "onFieldValidityChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.FieldContainer_errorEvent", function(FieldContainer_errorEvent) {
    /*package ext.form.events {
import ext.form.Labelable;

import net.jangaroo.ext.FlExtEvent;

public class FieldContainer_errorEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FieldContainer_errorEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "error",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the active error message is changed via <a href="#!/api/Ext.form.Labelable-method-setActiveError" rel="Ext.form.Labelable-method-setActiveError" class="docClass">setActiveError</a>.
   * @see ext.form.FieldContainer
   * @eventType onErrorChange
   * /
  public static const ERROR_CHANGE:String = "onErrorChange";

  public*/
    function FieldContainer_errorEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Labelable;

  /**
   * The active error message
   * /
  public native function get error():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FieldContainer_errorEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ERROR_CHANGE: "onErrorChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.FieldContainer_field_errorEvent", function(FieldContainer_field_errorEvent) {
    /*package ext.form.events {
import ext.form.FieldAncestor;
import ext.form.Labelable;

import net.jangaroo.ext.FlExtEvent;

public class FieldContainer_field_errorEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FieldContainer_field_errorEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "field",
            "error",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the active error message is changed for any one of the <a href="#!/api/Ext.form.Labelable" rel="Ext.form.Labelable" class="docClass">Ext.form.Labelable</a> instances
   * within this container.
   * @see ext.form.FieldContainer
   * @eventType onFieldErrorChange
   * /
  public static const FIELD_ERROR_CHANGE:String = "onFieldErrorChange";

  public*/
    function FieldContainer_field_errorEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():FieldAncestor;

  /**
   * The Labelable instance whose active error was changed
   * /
  public native function get field():Labelable;

  /**
   * The active error message
   * /
  public native function get error():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FieldContainer_field_errorEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            FIELD_ERROR_CHANGE: "onFieldErrorChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.FieldContainer_field_isValidEvent", function(FieldContainer_field_isValidEvent) {
    /*package ext.form.events {
import ext.form.FieldAncestor;
import ext.form.Labelable;

import net.jangaroo.ext.FlExtEvent;

public class FieldContainer_field_isValidEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FieldContainer_field_isValidEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "field",
            "isValid",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the validity state of any one of the <a href="#!/api/Ext.form.field.Field" rel="Ext.form.field.Field" class="docClass">Ext.form.field.Field</a> instances within this
   * container changes.
   * @see ext.form.FieldContainer
   * @eventType onFieldValidityChange
   * /
  public static const FIELD_VALIDITY_CHANGE:String = "onFieldValidityChange";

  public*/
    function FieldContainer_field_isValidEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():FieldAncestor;

  /**
   * The Field instance whose validity changed
   * /
  public native function get field():Labelable;

  /**
   * The field's new validity state
   * /
  public native function get isValid():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FieldContainer_field_isValidEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            FIELD_VALIDITY_CHANGE: "onFieldValidityChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.FieldSetEvent", function(FieldSetEvent) {
    /*package ext.form.events {
import ext.form.FieldSet;

import net.jangaroo.ext.FlExtEvent;

public class FieldSetEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FieldSetEvent.__PARAMETER_SEQUENCE__ = ([
            "fieldset",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before this FieldSet is collapsed. Return false to prevent the collapse.
   * @see ext.form.FieldSet
   * @eventType onBeforeCollapse
   * /
  public static const BEFORE_COLLAPSE:String = "onBeforeCollapse";
  /**
   * "Fires before this FieldSet is expanded. Return false to prevent the expand.
   * @see ext.form.FieldSet
   * @eventType onBeforeExpand
   * /
  public static const BEFORE_EXPAND:String = "onBeforeExpand";
  /**
   * "Fires after this FieldSet has collapsed.
   * @see ext.form.FieldSet
   * @eventType onCollapse
   * /
  public static const COLLAPSE:String = "onCollapse";
  /**
   * "Fires after this FieldSet has expanded.
   * @see ext.form.FieldSet
   * @eventType onExpand
   * /
  public static const EXPAND:String = "onExpand";

  public*/
    function FieldSetEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The FieldSet being collapsed.
   * /
  public native function get fieldset():FieldSet;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FieldSetEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_COLLAPSE: "onBeforeCollapse",
            BEFORE_EXPAND: "onBeforeExpand",
            COLLAPSE: "onCollapse",
            EXPAND: "onExpand",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.FieldSet_field_errorEvent", function(FieldSet_field_errorEvent) {
    /*package ext.form.events {
import ext.form.FieldAncestor;
import ext.form.Labelable;

import net.jangaroo.ext.FlExtEvent;

public class FieldSet_field_errorEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FieldSet_field_errorEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "field",
            "error",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the active error message is changed for any one of the <a href="#!/api/Ext.form.Labelable" rel="Ext.form.Labelable" class="docClass">Ext.form.Labelable</a> instances
   * within this container.
   * @see ext.form.FieldSet
   * @eventType onFieldErrorChange
   * /
  public static const FIELD_ERROR_CHANGE:String = "onFieldErrorChange";

  public*/
    function FieldSet_field_errorEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():FieldAncestor;

  /**
   * The Labelable instance whose active error was changed
   * /
  public native function get field():Labelable;

  /**
   * The active error message
   * /
  public native function get error():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FieldSet_field_errorEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            FIELD_ERROR_CHANGE: "onFieldErrorChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.FieldSet_field_isValidEvent", function(FieldSet_field_isValidEvent) {
    /*package ext.form.events {
import ext.form.FieldAncestor;
import ext.form.Labelable;

import net.jangaroo.ext.FlExtEvent;

public class FieldSet_field_isValidEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FieldSet_field_isValidEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "field",
            "isValid",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the validity state of any one of the <a href="#!/api/Ext.form.field.Field" rel="Ext.form.field.Field" class="docClass">Ext.form.field.Field</a> instances within this
   * container changes.
   * @see ext.form.FieldSet
   * @eventType onFieldValidityChange
   * /
  public static const FIELD_VALIDITY_CHANGE:String = "onFieldValidityChange";

  public*/
    function FieldSet_field_isValidEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():FieldAncestor;

  /**
   * The Field instance whose validity changed
   * /
  public native function get field():Labelable;

  /**
   * The field's new validity state
   * /
  public native function get isValid():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FieldSet_field_isValidEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            FIELD_VALIDITY_CHANGE: "onFieldValidityChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.FormPanel_actionEvent", function(FormPanel_actionEvent) {
    /*package ext.form.events {
import ext.form.BasicForm;
import ext.form.action.Action;

import net.jangaroo.ext.FlExtEvent;

public class FormPanel_actionEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FormPanel_actionEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "action",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when an action is completed.
   * @see ext.form.FormPanel
   * @eventType onActionComplete
   * /
  public static const ACTION_COMPLETE:String = "onActionComplete";
  /**
   * "Fires when an action fails.
   * @see ext.form.FormPanel
   * @eventType onActionFailed
   * /
  public static const ACTION_FAILED:String = "onActionFailed";
  /**
   * "Fires before any action is performed. Return false to cancel the action.
   * @see ext.form.FormPanel
   * @eventType onBeforeAction
   * /
  public static const BEFORE_ACTION:String = "onBeforeAction";

  public*/
    function FormPanel_actionEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():BasicForm;

  /**
   * The <a href="#!/api/Ext.form.action.Action" rel="Ext.form.action.Action" class="docClass">Ext.form.action.Action</a> that completed
   * /
  public native function get action():Action;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FormPanel_actionEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ACTION_COMPLETE: "onActionComplete",
            ACTION_FAILED: "onActionFailed",
            BEFORE_ACTION: "onBeforeAction",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.FormPanel_dirtyEvent", function(FormPanel_dirtyEvent) {
    /*package ext.form.events {
import ext.form.BasicForm;

import net.jangaroo.ext.FlExtEvent;

public class FormPanel_dirtyEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FormPanel_dirtyEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "dirty",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the dirty state of the entire form changes.
   * @see ext.form.FormPanel
   * @eventType onDirtyChange
   * /
  public static const DIRTY_CHANGE:String = "onDirtyChange";

  public*/
    function FormPanel_dirtyEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():BasicForm;

  /**
   * <code>true</code> if the form is now dirty, <code>false</code> if it is no longer dirty.
   * /
  public native function get dirty():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FormPanel_dirtyEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DIRTY_CHANGE: "onDirtyChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.FormPanel_field_errorEvent", function(FormPanel_field_errorEvent) {
    /*package ext.form.events {
import ext.form.FieldAncestor;
import ext.form.Labelable;

import net.jangaroo.ext.FlExtEvent;

public class FormPanel_field_errorEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FormPanel_field_errorEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "field",
            "error",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the active error message is changed for any one of the <a href="#!/api/Ext.form.Labelable" rel="Ext.form.Labelable" class="docClass">Ext.form.Labelable</a> instances
   * within this container.
   * @see ext.form.FormPanel
   * @eventType onFieldErrorChange
   * /
  public static const FIELD_ERROR_CHANGE:String = "onFieldErrorChange";

  public*/
    function FormPanel_field_errorEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():FieldAncestor;

  /**
   * The Labelable instance whose active error was changed
   * /
  public native function get field():Labelable;

  /**
   * The active error message
   * /
  public native function get error():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FormPanel_field_errorEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            FIELD_ERROR_CHANGE: "onFieldErrorChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.FormPanel_field_isValidEvent", function(FormPanel_field_isValidEvent) {
    /*package ext.form.events {
import ext.form.FieldAncestor;
import ext.form.Labelable;

import net.jangaroo.ext.FlExtEvent;

public class FormPanel_field_isValidEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FormPanel_field_isValidEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "field",
            "isValid",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the validity state of any one of the <a href="#!/api/Ext.form.field.Field" rel="Ext.form.field.Field" class="docClass">Ext.form.field.Field</a> instances within this
   * container changes.
   * @see ext.form.FormPanel
   * @eventType onFieldValidityChange
   * /
  public static const FIELD_VALIDITY_CHANGE:String = "onFieldValidityChange";

  public*/
    function FormPanel_field_isValidEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():FieldAncestor;

  /**
   * The Field instance whose validity changed
   * /
  public native function get field():Labelable;

  /**
   * The field's new validity state
   * /
  public native function get isValid():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FormPanel_field_isValidEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            FIELD_VALIDITY_CHANGE: "onFieldValidityChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.FormPanel_validEvent", function(FormPanel_validEvent) {
    /*package ext.form.events {
import ext.form.BasicForm;

import net.jangaroo.ext.FlExtEvent;

public class FormPanel_validEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FormPanel_validEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "valid",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the validity of the entire form changes.
   * @see ext.form.FormPanel
   * @eventType onValidityChange
   * /
  public static const VALIDITY_CHANGE:String = "onValidityChange";

  public*/
    function FormPanel_validEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():BasicForm;

  /**
   * <code>true</code> if the form is now valid, <code>false</code> if it is now invalid.
   * /
  public native function get valid():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FormPanel_validEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            VALIDITY_CHANGE: "onValidityChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.events.Labelable_errorEvent", function(Labelable_errorEvent) {
    /*package ext.form.events {
import ext.form.Labelable;

import net.jangaroo.ext.FlExtEvent;

public class Labelable_errorEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Labelable_errorEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "error",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the active error message is changed via <a href="#!/api/Ext.form.Labelable-method-setActiveError" rel="Ext.form.Labelable-method-setActiveError" class="docClass">setActiveError</a>.
   * @see ext.form.Labelable
   * @eventType onErrorChange
   * /
  public static const ERROR_CHANGE:String = "onErrorChange";

  public*/
    function Labelable_errorEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Labelable;

  /**
   * The active error message
   * /
  public native function get error():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Labelable_errorEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ERROR_CHANGE: "onErrorChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.BaseField_ReadEvent", function(BaseField_ReadEvent) {
    /*package ext.form.field.events {
import ext.form.field.BaseField;

import net.jangaroo.ext.FlExtEvent;

public class BaseField_ReadEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        BaseField_ReadEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "Read",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when this field changes its read-only status.
   * @see ext.form.field.BaseField
   * @eventType onWriteableChange
   * /
  public static const WRITEABLE_CHANGE:String = "onWriteableChange";

  public*/
    function BaseField_ReadEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():BaseField;

  /**
   * only flag
   * /
  public native function get Read():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: BaseField_ReadEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            WRITEABLE_CHANGE: "onWriteableChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.BaseField_eEvent", function(BaseField_eEvent) {
    /*package ext.form.field.events {
import ext.event.Event;
import ext.form.field.BaseField;

import net.jangaroo.ext.FlExtEvent;

public class BaseField_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        BaseField_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when any key related to navigation (arrows, tab, enter, esc, etc.) is pressed. To handle other keys
   * see <a href="#!/api/Ext.util.KeyMap" rel="Ext.util.KeyMap" class="docClass">Ext.util.KeyMap</a>. You can check <a href="#!/api/Ext.event.Event-method-getKey" rel="Ext.event.Event-method-getKey" class="docClass">Ext.event.Event.getKey</a> to determine which key was
   * pressed. For example:
   *
   * <pre><code>var form = new <a href="#!/api/Ext.form.Panel" rel="Ext.form.Panel" class="docClass">Ext.form.Panel</a>({
   *     ...
   *     items: [{
   *             fieldLabel: 'Field 1',
   *             name: 'field1',
   *             allowBlank: false
   *         },{
   *             fieldLabel: 'Field 2',
   *             name: 'field2',
   *             listeners: {
   *                 specialkey: function(field, e){
   *                     // e.HOME, e.END, e.PAGE_UP, e.PAGE_DOWN,
   *                     // e.TAB, e.ESC, arrow keys: e.LEFT, e.RIGHT, e.UP, e.DOWN
   *                     if (e.getKey() == e.ENTER) {
   *                         var form = field.up('form').getForm();
   *                         form.submit();
   *                     }
   *                 }
   *             }
   *         }
   *     ],
   *     ...
   * });
   * </code></pre>
   * @see ext.form.field.BaseField
   * @eventType onSpecialKey
   * /
  public static const SPECIAL_KEY:String = "onSpecialKey";

  public*/
    function BaseField_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():BaseField;

  /**
   * The event object
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: BaseField_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SPECIAL_KEY: "onSpecialKey",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.BaseField_errorEvent", function(BaseField_errorEvent) {
    /*package ext.form.field.events {
import ext.form.Labelable;

import net.jangaroo.ext.FlExtEvent;

public class BaseField_errorEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        BaseField_errorEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "error",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the active error message is changed via <a href="#!/api/Ext.form.Labelable-method-setActiveError" rel="Ext.form.Labelable-method-setActiveError" class="docClass">setActiveError</a>.
   * @see ext.form.field.BaseField
   * @eventType onErrorChange
   * /
  public static const ERROR_CHANGE:String = "onErrorChange";

  public*/
    function BaseField_errorEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Labelable;

  /**
   * The active error message
   * /
  public native function get error():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: BaseField_errorEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ERROR_CHANGE: "onErrorChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.BaseField_isDirtyEvent", function(BaseField_isDirtyEvent) {
    /*package ext.form.field.events {
import ext.form.field.Field;

import net.jangaroo.ext.FlExtEvent;

public class BaseField_isDirtyEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        BaseField_isDirtyEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "isDirty",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a change in the field's <a href="#!/api/Ext.form.field.Field-method-isDirty" rel="Ext.form.field.Field-method-isDirty" class="docClass">isDirty</a> state is detected.
   * @see ext.form.field.BaseField
   * @eventType onDirtyChange
   * /
  public static const DIRTY_CHANGE:String = "onDirtyChange";

  public*/
    function BaseField_isDirtyEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Field;

  /**
   * Whether or not the field is now dirty
   * /
  public native function get isDirty():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: BaseField_isDirtyEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DIRTY_CHANGE: "onDirtyChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.BaseField_isValidEvent", function(BaseField_isValidEvent) {
    /*package ext.form.field.events {
import ext.form.field.Field;

import net.jangaroo.ext.FlExtEvent;

public class BaseField_isValidEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        BaseField_isValidEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "isValid",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a change in the field's validity is detected.
   * @see ext.form.field.BaseField
   * @eventType onValidityChange
   * /
  public static const VALIDITY_CHANGE:String = "onValidityChange";

  public*/
    function BaseField_isValidEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Field;

  /**
   * Whether or not the field is now valid
   * /
  public native function get isValid():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: BaseField_isValidEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            VALIDITY_CHANGE: "onValidityChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.BaseField_newValue_oldValueEvent", function(BaseField_newValue_oldValueEvent) {
    /*package ext.form.field.events {
import ext.form.field.Field;

import net.jangaroo.ext.FlExtEvent;

public class BaseField_newValue_oldValueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        BaseField_newValue_oldValueEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "newValue",
            "oldValue",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the value of a field is changed. The value of a field is
   * checked for changes when the field's <a href="#!/api/Ext.form.field.Field-method-setValue" rel="Ext.form.field.Field-method-setValue" class="docClass">setValue</a> method
   * is called and when any of the events listed in
   * <a href="#!/api/Ext.form.field.Base-cfg-checkChangeEvents" rel="Ext.form.field.Base-cfg-checkChangeEvents" class="docClass">checkChangeEvents</a> are fired.
   * @see ext.form.field.BaseField
   * @eventType onChange
   * /
  public static const CHANGE:String = "onChange";

  public*/
    function BaseField_newValue_oldValueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Field;

  /**
   * The new value
   * /
  public native function get newValue():Object;

  /**
   * The original value
   * /
  public native function get oldValue():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: BaseField_newValue_oldValueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CHANGE: "onChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.ComboBox_queryPlanEvent", function(ComboBox_queryPlanEvent) {
    /*package ext.form.field.events {
import net.jangaroo.ext.FlExtEvent;

public class ComboBox_queryPlanEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ComboBox_queryPlanEvent.__PARAMETER_SEQUENCE__ = ([
            "queryPlan",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before all queries are processed. Return false to cancel the query or set the queryPlan's cancel
   * property to true.
   * @see ext.form.field.ComboBox
   * @eventType onBeforeQuery
   * /
  public static const BEFORE_QUERY:String = "onBeforeQuery";

  public*/
    function ComboBox_queryPlanEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * An object containing details about the query to be executed.
   * <ul>
   *   <li><code>combo</code> : ext.form.field.ComboBox
   * A reference to this ComboBox.
   *   </li>
   *   <li><code>query</code> : String
   * The query value to be used to match against the ComboBox's <a href="#!/api/Ext.form.field.ComboBox-cfg-valueField" rel="Ext.form.field.ComboBox-cfg-valueField" class="docClass">valueField</a>.
   *   </li>
   *   <li><code>forceAll</code> : Boolean
   * If <code>true</code>, causes the query to be executed even if the minChars threshold is not met.
   *   </li>
   *   <li><code>cancel</code> : Boolean
   * A boolean value which, if set to <code>true</code> upon return, causes the query not to be executed.
   *   </li>
   *   <li><code>rawQuery</code> : Boolean
   * If <code>true</code> indicates that the raw input field value is being used, and upon store load,
   *   </li>
   * </ul>
   * /
  public native function get queryPlan():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ComboBox_queryPlanEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_QUERY: "onBeforeQuery",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.ComboBox_recordEvent", function(ComboBox_recordEvent) {
    /*package ext.form.field.events {
import ext.form.field.ComboBox;

import net.jangaroo.ext.FlExtEvent;

public class ComboBox_recordEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ComboBox_recordEvent.__PARAMETER_SEQUENCE__ = ([
            "combo",
            "record",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when at least one list item is selected.
   * @see ext.form.field.ComboBox
   * @eventType onSelect
   * /
  public static const SELECT:String = "onSelect";

  public*/
    function ComboBox_recordEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This combo box
   * /
  public native function get combo():ComboBox;

  /**
   * With <a href="#!/api/Ext.form.field.ComboBox-cfg-multiSelect" rel="Ext.form.field.ComboBox-cfg-multiSelect" class="docClass">multiSelect</a>
   * <code>false</code>, the value will be a single record. With <a href="#!/api/Ext.form.field.ComboBox-cfg-multiSelect" rel="Ext.form.field.ComboBox-cfg-multiSelect" class="docClass">multiSelect</a> <code>true</code>, the
   * value will be an array of records.
   * /
  public native function get record():*;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ComboBox_recordEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SELECT: "onSelect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.ComboBox_record_indexEvent", function(ComboBox_record_indexEvent) {
    /*package ext.form.field.events {
import ext.data.Model;
import ext.form.field.ComboBox;

import net.jangaroo.ext.FlExtEvent;

public class ComboBox_record_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ComboBox_record_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "combo",
            "record",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the deselected item is removed from the collection
   * @see ext.form.field.ComboBox
   * @eventType onBeforeDeselect
   * /
  public static const BEFORE_DESELECT:String = "onBeforeDeselect";
  /**
   * "Fires before the selected item is added to the collection
   * @see ext.form.field.ComboBox
   * @eventType onBeforeSelect
   * /
  public static const BEFORE_SELECT:String = "onBeforeSelect";

  public*/
    function ComboBox_record_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This combo box
   * /
  public native function get combo():ComboBox;

  /**
   * The deselected record
   * /
  public native function get record():Model;

  /**
   * The index of the deselected record
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ComboBox_record_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_DESELECT: "onBeforeDeselect",
            BEFORE_SELECT: "onBeforeSelect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.Field_isDirtyEvent", function(Field_isDirtyEvent) {
    /*package ext.form.field.events {
import ext.form.field.Field;

import net.jangaroo.ext.FlExtEvent;

public class Field_isDirtyEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Field_isDirtyEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "isDirty",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a change in the field's <a href="#!/api/Ext.form.field.Field-method-isDirty" rel="Ext.form.field.Field-method-isDirty" class="docClass">isDirty</a> state is detected.
   * @see ext.form.field.Field
   * @eventType onDirtyChange
   * /
  public static const DIRTY_CHANGE:String = "onDirtyChange";

  public*/
    function Field_isDirtyEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Field;

  /**
   * Whether or not the field is now dirty
   * /
  public native function get isDirty():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Field_isDirtyEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DIRTY_CHANGE: "onDirtyChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.Field_isValidEvent", function(Field_isValidEvent) {
    /*package ext.form.field.events {
import ext.form.field.Field;

import net.jangaroo.ext.FlExtEvent;

public class Field_isValidEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Field_isValidEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "isValid",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a change in the field's validity is detected.
   * @see ext.form.field.Field
   * @eventType onValidityChange
   * /
  public static const VALIDITY_CHANGE:String = "onValidityChange";

  public*/
    function Field_isValidEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Field;

  /**
   * Whether or not the field is now valid
   * /
  public native function get isValid():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Field_isValidEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            VALIDITY_CHANGE: "onValidityChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.Field_newValue_oldValueEvent", function(Field_newValue_oldValueEvent) {
    /*package ext.form.field.events {
import ext.form.field.Field;

import net.jangaroo.ext.FlExtEvent;

public class Field_newValue_oldValueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Field_newValue_oldValueEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "newValue",
            "oldValue",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the value of a field is changed. The value of a field is
   * checked for changes when the field's <a href="#!/api/Ext.form.field.Field-method-setValue" rel="Ext.form.field.Field-method-setValue" class="docClass">setValue</a> method
   * is called and when any of the events listed in
   * <a href="#!/api/Ext.form.field.Base-cfg-checkChangeEvents" rel="Ext.form.field.Base-cfg-checkChangeEvents" class="docClass">checkChangeEvents</a> are fired.
   * @see ext.form.field.Field
   * @eventType onChange
   * /
  public static const CHANGE:String = "onChange";

  public*/
    function Field_newValue_oldValueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Field;

  /**
   * The new value
   * /
  public native function get newValue():Object;

  /**
   * The original value
   * /
  public native function get oldValue():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Field_newValue_oldValueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CHANGE: "onChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.FileUploadField_valueEvent", function(FileUploadField_valueEvent) {
    /*package ext.form.field.events {
import ext.form.field.FileUploadField;

import net.jangaroo.ext.FlExtEvent;

public class FileUploadField_valueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        FileUploadField_valueEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "value",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the underlying file input field's value has changed from the user selecting a new file from the system
   * file selection dialog.
   * @see ext.form.field.FileUploadField
   * @eventType onChange
   * /
  public static const CHANGE:String = "onChange";

  public*/
    function FileUploadField_valueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():FileUploadField;

  /**
   * The file value returned by the underlying file input field
   * /
  public native function get value():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: FileUploadField_valueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CHANGE: "onChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.HtmlEditorEvent", function(HtmlEditorEvent) {
    /*package ext.form.field.events {
import ext.form.field.HtmlEditor;

import net.jangaroo.ext.FlExtEvent;

public class HtmlEditorEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HtmlEditorEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the editor is first receives the focus. Any insertion must wait until after this event.
   * @see ext.form.field.HtmlEditor
   * @eventType onActivate
   * /
  public static const ACTIVATE:String = "onActivate";
  /**
   * "Fires when the editor is fully initialized (including the iframe)
   * @see ext.form.field.HtmlEditor
   * @eventType onInitialize
   * /
  public static const INITIALIZE:String = "onInitialize";

  public*/
    function HtmlEditorEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():HtmlEditor;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HtmlEditorEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ACTIVATE: "onActivate",
            INITIALIZE: "onInitialize",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.HtmlEditor_htmlEvent", function(HtmlEditor_htmlEvent) {
    /*package ext.form.field.events {
import ext.form.field.HtmlEditor;

import net.jangaroo.ext.FlExtEvent;

public class HtmlEditor_htmlEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HtmlEditor_htmlEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "html",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the iframe editor is updated with content from the textarea. Return false to cancel the
   * push.
   * @see ext.form.field.HtmlEditor
   * @eventType onBeforePush
   * /
  public static const BEFORE_PUSH:String = "onBeforePush";
  /**
   * "Fires before the textarea is updated with content from the editor iframe. Return false to cancel the
   * sync.
   * @see ext.form.field.HtmlEditor
   * @eventType onBeforeSync
   * /
  public static const BEFORE_SYNC:String = "onBeforeSync";
  /**
   * "Fires when the iframe editor is updated with content from the textarea.
   * @see ext.form.field.HtmlEditor
   * @eventType onPush
   * /
  public static const PUSH:String = "onPush";
  /**
   * "Fires when the textarea is updated with content from the editor iframe.
   * @see ext.form.field.HtmlEditor
   * @eventType onSync
   * /
  public static const SYNC:String = "onSync";

  public*/
    function HtmlEditor_htmlEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():HtmlEditor;

  public native function get html():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HtmlEditor_htmlEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_PUSH: "onBeforePush",
            BEFORE_SYNC: "onBeforeSync",
            PUSH: "onPush",
            SYNC: "onSync",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.HtmlEditor_isDirtyEvent", function(HtmlEditor_isDirtyEvent) {
    /*package ext.form.field.events {
import ext.form.field.Field;

import net.jangaroo.ext.FlExtEvent;

public class HtmlEditor_isDirtyEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HtmlEditor_isDirtyEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "isDirty",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a change in the field's <a href="#!/api/Ext.form.field.Field-method-isDirty" rel="Ext.form.field.Field-method-isDirty" class="docClass">isDirty</a> state is detected.
   * @see ext.form.field.HtmlEditor
   * @eventType onDirtyChange
   * /
  public static const DIRTY_CHANGE:String = "onDirtyChange";

  public*/
    function HtmlEditor_isDirtyEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Field;

  /**
   * Whether or not the field is now dirty
   * /
  public native function get isDirty():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HtmlEditor_isDirtyEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DIRTY_CHANGE: "onDirtyChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.HtmlEditor_isValidEvent", function(HtmlEditor_isValidEvent) {
    /*package ext.form.field.events {
import ext.form.field.Field;

import net.jangaroo.ext.FlExtEvent;

public class HtmlEditor_isValidEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HtmlEditor_isValidEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "isValid",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a change in the field's validity is detected.
   * @see ext.form.field.HtmlEditor
   * @eventType onValidityChange
   * /
  public static const VALIDITY_CHANGE:String = "onValidityChange";

  public*/
    function HtmlEditor_isValidEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Field;

  /**
   * Whether or not the field is now valid
   * /
  public native function get isValid():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HtmlEditor_isValidEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            VALIDITY_CHANGE: "onValidityChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.HtmlEditor_newValue_oldValueEvent", function(HtmlEditor_newValue_oldValueEvent) {
    /*package ext.form.field.events {
import ext.form.field.Field;

import net.jangaroo.ext.FlExtEvent;

public class HtmlEditor_newValue_oldValueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HtmlEditor_newValue_oldValueEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "newValue",
            "oldValue",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the value of a field is changed. The value of a field is
   * checked for changes when the field's <a href="#!/api/Ext.form.field.Field-method-setValue" rel="Ext.form.field.Field-method-setValue" class="docClass">setValue</a> method
   * is called and when any of the events listed in
   * <a href="#!/api/Ext.form.field.Base-cfg-checkChangeEvents" rel="Ext.form.field.Base-cfg-checkChangeEvents" class="docClass">checkChangeEvents</a> are fired.
   * @see ext.form.field.HtmlEditor
   * @eventType onChange
   * /
  public static const CHANGE:String = "onChange";

  public*/
    function HtmlEditor_newValue_oldValueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Field;

  /**
   * The new value
   * /
  public native function get newValue():Object;

  /**
   * The original value
   * /
  public native function get oldValue():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HtmlEditor_newValue_oldValueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CHANGE: "onChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.HtmlEditor_sourceEditEvent", function(HtmlEditor_sourceEditEvent) {
    /*package ext.form.field.events {
import ext.form.field.HtmlEditor;

import net.jangaroo.ext.FlExtEvent;

public class HtmlEditor_sourceEditEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HtmlEditor_sourceEditEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "sourceEdit",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the editor switches edit modes
   * @see ext.form.field.HtmlEditor
   * @eventType onEditModeChange
   * /
  public static const EDIT_MODE_CHANGE:String = "onEditModeChange";

  public*/
    function HtmlEditor_sourceEditEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():HtmlEditor;

  /**
   * True if source edit, false if standard editing.
   * /
  public native function get sourceEdit():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HtmlEditor_sourceEditEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            EDIT_MODE_CHANGE: "onEditModeChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.PickerEvent", function(PickerEvent) {
    /*package ext.form.field.events {
import ext.form.field.Picker;

import net.jangaroo.ext.FlExtEvent;

public class PickerEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        PickerEvent.__PARAMETER_SEQUENCE__ = ([
            "field",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the field's picker is collapsed.
   * @see ext.form.field.Picker
   * @eventType onCollapse
   * /
  public static const COLLAPSE:String = "onCollapse";
  /**
   * "Fires when the field's picker is expanded.
   * @see ext.form.field.Picker
   * @eventType onExpand
   * /
  public static const EXPAND:String = "onExpand";

  public*/
    function PickerEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This field instance
   * /
  public native function get field():Picker;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: PickerEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            COLLAPSE: "onCollapse",
            EXPAND: "onExpand",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.Picker_valueEvent", function(Picker_valueEvent) {
    /*package ext.form.field.events {
import ext.form.field.Picker;

import net.jangaroo.ext.FlExtEvent;

public class Picker_valueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Picker_valueEvent.__PARAMETER_SEQUENCE__ = ([
            "field",
            "value",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a value is selected via the picker.
   * @see ext.form.field.Picker
   * @eventType onSelect
   * /
  public static const SELECT:String = "onSelect";

  public*/
    function Picker_valueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This field instance
   * /
  public native function get field():Picker;

  /**
   * The value that was selected. The exact type of this value is dependent on
   * the individual field and picker implementations.
   * /
  public native function get value():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Picker_valueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SELECT: "onSelect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.SpinnerFieldEvent", function(SpinnerFieldEvent) {
    /*package ext.form.field.events {
import ext.form.field.SpinnerField;

import net.jangaroo.ext.FlExtEvent;

public class SpinnerFieldEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        SpinnerFieldEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the spinner is made to spin down.
   * @see ext.form.field.SpinnerField
   * @eventType onSpinDown
   * /
  public static const SPIN_DOWN:String = "onSpinDown";
  /**
   * "Fires when a spin command has been finished. For example on mouseup
   * on the spin buttons, when an <code>UP</code> or <code>DOWN</code> arrow key is released
   * of when a mousewheel stops spinning.
   *
   * <p>When this event fires, the field's value has stabilized.</p>
   * @since 6.2.0
   * @see ext.form.field.SpinnerField
   * @eventType onSpinEnd
   * /
  public static const SPIN_END:String = "onSpinEnd";
  /**
   * "Fires when the spinner is made to spin up.
   * @see ext.form.field.SpinnerField
   * @eventType onSpinUp
   * /
  public static const SPIN_UP:String = "onSpinUp";

  public*/
    function SpinnerFieldEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():SpinnerField;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: SpinnerFieldEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SPIN_DOWN: "onSpinDown",
            SPIN_END: "onSpinEnd",
            SPIN_UP: "onSpinUp",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.SpinnerField_directionEvent", function(SpinnerField_directionEvent) {
    /*package ext.form.field.events {
import ext.form.field.SpinnerField;

import net.jangaroo.ext.FlExtEvent;

public class SpinnerField_directionEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        SpinnerField_directionEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "direction",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the spinner is made to spin up or down.
   * @see ext.form.field.SpinnerField
   * @eventType onSpin
   * /
  public static const SPIN:String = "onSpin";

  public*/
    function SpinnerField_directionEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():SpinnerField;

  /**
   * Either 'up' if spinning up, or 'down' if spinning down.
   * /
  public native function get direction():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: SpinnerField_directionEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SPIN: "onSpin",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.Tag_heightEvent", function(Tag_heightEvent) {
    /*package ext.form.field.events {
import ext.form.field.Tag;

import net.jangaroo.ext.FlExtEvent;

public class Tag_heightEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Tag_heightEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "height",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the <strong><a href="#!/api/Ext.form.field.Tag-method-autoSize" rel="Ext.form.field.Tag-method-autoSize" class="docClass">autoSize</a></strong> function is triggered and the field is resized according to the
   * <a href="#!/api/Ext.form.field.Tag-cfg-grow" rel="Ext.form.field.Tag-cfg-grow" class="docClass">grow</a>/<a href="#!/api/Ext.form.field.Tag-cfg-growMin" rel="Ext.form.field.Tag-cfg-growMin" class="docClass">growMin</a>/<a href="#!/api/Ext.form.field.Tag-cfg-growMax" rel="Ext.form.field.Tag-cfg-growMax" class="docClass">growMax</a> configs as a result. This event provides a hook for the
   * developer to apply additional logic at runtime to resize the field if needed.
   * @see ext.form.field.Tag
   * @eventType onAutoSize
   * /
  public static const AUTO_SIZE:String = "onAutoSize";

  public*/
    function Tag_heightEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This field
   * /
  public native function get source():Tag;

  /**
   * The new field height
   * /
  public native function get height():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Tag_heightEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            AUTO_SIZE: "onAutoSize",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.TextField_eEvent", function(TextField_eEvent) {
    /*package ext.form.field.events {
import ext.event.Event;
import ext.form.field.TextField;

import net.jangaroo.ext.FlExtEvent;

public class TextField_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TextField_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Keydown input field event. This event only fires if <strong><a href="#!/api/Ext.form.field.Text-cfg-enableKeyEvents" rel="Ext.form.field.Text-cfg-enableKeyEvents" class="docClass">enableKeyEvents</a></strong> is set to true.
   * @see ext.form.field.TextField
   * @eventType onKeyDown
   * /
  public static const KEY_DOWN:String = "onKeyDown";
  /**
   * "Keypress input field event. This event only fires if <strong><a href="#!/api/Ext.form.field.Text-cfg-enableKeyEvents" rel="Ext.form.field.Text-cfg-enableKeyEvents" class="docClass">enableKeyEvents</a></strong> is set to true.
   * @see ext.form.field.TextField
   * @eventType onKeypress
   * /
  public static const KEYPRESS:String = "onKeypress";
  /**
   * "Keyup input field event. This event only fires if <strong><a href="#!/api/Ext.form.field.Text-cfg-enableKeyEvents" rel="Ext.form.field.Text-cfg-enableKeyEvents" class="docClass">enableKeyEvents</a></strong> is set to true.
   * @see ext.form.field.TextField
   * @eventType onKeyUp
   * /
  public static const KEY_UP:String = "onKeyUp";

  public*/
    function TextField_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This text field
   * /
  public native function get source():TextField;

  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TextField_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            KEY_DOWN: "onKeyDown",
            KEYPRESS: "onKeypress",
            KEY_UP: "onKeyUp",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.form.field.events.TextField_widthEvent", function(TextField_widthEvent) {
    /*package ext.form.field.events {
import ext.form.field.TextField;

import net.jangaroo.ext.FlExtEvent;

public class TextField_widthEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TextField_widthEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "width",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the <strong><a href="#!/api/Ext.form.field.Text-method-autoSize" rel="Ext.form.field.Text-method-autoSize" class="docClass">autoSize</a></strong> function is triggered and the field is resized according to the
   * <a href="#!/api/Ext.form.field.Text-cfg-grow" rel="Ext.form.field.Text-cfg-grow" class="docClass">grow</a>/<a href="#!/api/Ext.form.field.Text-cfg-growMin" rel="Ext.form.field.Text-cfg-growMin" class="docClass">growMin</a>/<a href="#!/api/Ext.form.field.Text-cfg-growMax" rel="Ext.form.field.Text-cfg-growMax" class="docClass">growMax</a> configs as a result. This event provides a hook for the
   * developer to apply additional logic at runtime to resize the field if needed.
   * @see ext.form.field.TextField
   * @eventType onAutoSize
   * /
  public static const AUTO_SIZE:String = "onAutoSize";

  public*/
    function TextField_widthEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This text field
   * /
  public native function get source():TextField;

  /**
   * The new field width
   * /
  public native function get width():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TextField_widthEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            AUTO_SIZE: "onAutoSize",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.fx.events.AnimEvent", function(AnimEvent) {
    /*package ext.fx.events {
import ext.fx.Anim;

import net.jangaroo.ext.FlExtEvent;

public class AnimEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AnimEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the animation starts. A handler can return false to cancel the animation.
   * @see ext.fx.Anim
   * @eventType onBeforeAnimate
   * /
  public static const BEFORE_ANIMATE:String = "onBeforeAnimate";

  public*/
    function AnimEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Anim;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AnimEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_ANIMATE: "onBeforeAnimate",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.fx.events.Anim_startTimeEvent", function(Anim_startTimeEvent) {
    /*package ext.fx.events {
import ext.fx.Anim;

import net.jangaroo.ext.FlExtEvent;

public class Anim_startTimeEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Anim_startTimeEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "startTime",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the animation is complete.
   * @see ext.fx.Anim
   * @eventType onAfterAnimate
   * /
  public static const AFTER_ANIMATE:String = "onAfterAnimate";
  /**
   * "Fires when the animation's last frame has been set.
   * @see ext.fx.Anim
   * @eventType onLastFrame
   * /
  public static const LAST_FRAME:String = "onLastFrame";

  public*/
    function Anim_startTimeEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Anim;

  public native function get startTime():Date;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Anim_startTimeEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            AFTER_ANIMATE: "onAfterAnimate",
            LAST_FRAME: "onLastFrame",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.fx.events.AnimatorEvent", function(AnimatorEvent) {
    /*package ext.fx.events {
import ext.fx.Animator;

import net.jangaroo.ext.FlExtEvent;

public class AnimatorEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AnimatorEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the animation starts. A handler can return false to cancel the animation.
   * @see ext.fx.Animator
   * @eventType onBeforeAnimate
   * /
  public static const BEFORE_ANIMATE:String = "onBeforeAnimate";

  public*/
    function AnimatorEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Animator;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AnimatorEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_ANIMATE: "onBeforeAnimate",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.fx.events.Animator_keyframeEvent", function(Animator_keyframeEvent) {
    /*package ext.fx.events {
import ext.fx.Animator;

import net.jangaroo.ext.FlExtEvent;

public class Animator_keyframeEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Animator_keyframeEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "keyframe",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires at each keyframe.
   * @see ext.fx.Animator
   * @eventType onKeyframe
   * /
  public static const KEYFRAME:String = "onKeyframe";

  public*/
    function Animator_keyframeEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Animator;

  /**
   * step number
   * /
  public native function get keyframe():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Animator_keyframeEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            KEYFRAME: "onKeyframe",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.fx.events.Animator_startTimeEvent", function(Animator_startTimeEvent) {
    /*package ext.fx.events {
import ext.fx.Animator;

import net.jangaroo.ext.FlExtEvent;

public class Animator_startTimeEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Animator_startTimeEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "startTime",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the animation is complete.
   * @see ext.fx.Animator
   * @eventType onAfterAnimate
   * /
  public static const AFTER_ANIMATE:String = "onAfterAnimate";

  public*/
    function Animator_startTimeEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Animator;

  public native function get startTime():Date;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Animator_startTimeEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            AFTER_ANIMATE: "onAfterAnimate",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.column.events.CheckColumn_checked_eEvent", function(CheckColumn_checked_eEvent) {
    /*package ext.grid.column.events {
import ext.event.Event;
import ext.grid.column.CheckColumn;

import net.jangaroo.ext.FlExtEvent;

public class CheckColumn_checked_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        CheckColumn_checked_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "checked",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the header is clicked and before the mass check/uncheck takes place.
   * The change may be vetoed by returning <code>false</code> from a listener.
   * @see ext.grid.column.CheckColumn
   * @eventType onBeforeHeaderCheckChange
   * /
  public static const BEFORE_HEADER_CHECK_CHANGE:String = "onBeforeHeaderCheckChange";
  /**
   * "Fires after the header is clicked and a mass check/uncheck operation has been completed.
   * @see ext.grid.column.CheckColumn
   * @eventType onHeaderCheckChange
   * /
  public static const HEADER_CHECK_CHANGE:String = "onHeaderCheckChange";

  public*/
    function CheckColumn_checked_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * CheckColumn.
   * /
  public native function get source():CheckColumn;

  /**
   * <code>true</code> if all boxes are to be checked.
   * /
  public native function get checked():Boolean;

  /**
   * The underlying event which caused the check change.
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: CheckColumn_checked_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_HEADER_CHECK_CHANGE: "onBeforeHeaderCheckChange",
            HEADER_CHECK_CHANGE: "onHeaderCheckChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.column.events.CheckColumn_rowIndex_checked_record_eEvent", function(CheckColumn_rowIndex_checked_record_eEvent) {
    /*package ext.grid.column.events {
import ext.data.Model;
import ext.event.Event;
import ext.grid.column.CheckColumn;

import net.jangaroo.ext.FlExtEvent;

public class CheckColumn_rowIndex_checked_record_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        CheckColumn_rowIndex_checked_record_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "rowIndex",
            "checked",
            "record",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the UI requests a change of check status.
   * The change may be vetoed by returning <code>false</code> from a listener.
   * @see ext.grid.column.CheckColumn
   * @eventType onBeforeCheckChange
   * /
  public static const BEFORE_CHECK_CHANGE:String = "onBeforeCheckChange";
  /**
   * "Fires when the UI has successfully changed the checked state of a row.
   * @see ext.grid.column.CheckColumn
   * @eventType onCheckChange
   * /
  public static const CHECK_CHANGE:String = "onCheckChange";

  public*/
    function CheckColumn_rowIndex_checked_record_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * CheckColumn.
   * /
  public native function get source():CheckColumn;

  /**
   * The row index.
   * /
  public native function get rowIndex():Number;

  /**
   * <code>true</code> if the box is to be checked.
   * /
  public native function get checked():Boolean;

  /**
   * The record to be updated.
   * /
  public native function get record():Model;

  /**
   * The underlying event which caused the check change.
   * <ul>
   *   <li><code>position</code> : ext.grid.CellContext
   * A <a href="#!/api/Ext.grid.CellContext" rel="Ext.grid.CellContext" class="docClass">CellContext</a> object
   * containing all contextual information about where the event was triggered.
   *   </li>
   * </ul>
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: CheckColumn_rowIndex_checked_record_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_CHECK_CHANGE: "onBeforeCheckChange",
            CHECK_CHANGE: "onCheckChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.events.GridPanel_store_columns_oldStore_oldColumnsEvent", function(GridPanel_store_columns_oldStore_oldColumnsEvent) {
    /*package ext.grid.events {
import ext.data.Store;
import ext.grid.GridPanel;

import net.jangaroo.ext.FlExtEvent;

public class GridPanel_store_columns_oldStore_oldColumnsEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        GridPanel_store_columns_oldStore_oldColumnsEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "store",
            "columns",
            "oldStore",
            "oldColumns",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a reconfigure to enable modification of incoming Store and columns.
   * @see ext.grid.GridPanel
   * @eventType onBeforeReconfigure
   * /
  public static const BEFORE_RECONFIGURE:String = "onBeforeReconfigure";
  /**
   * "Fires after a reconfigure.
   * @see ext.grid.GridPanel
   * @eventType onReconfigure
   * /
  public static const RECONFIGURE:String = "onReconfigure";

  public*/
    function GridPanel_store_columns_oldStore_oldColumnsEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():GridPanel;

  /**
   * The store that was passed to the <a href="#!/api/Ext.grid.Panel-method-reconfigure" rel="Ext.grid.Panel-method-reconfigure" class="docClass">reconfigure</a> method
   * /
  public native function get store():Store;

  /**
   * The column configs that were passed to the <a href="#!/api/Ext.grid.Panel-method-reconfigure" rel="Ext.grid.Panel-method-reconfigure" class="docClass">reconfigure</a> method
   * /
  public native function get columns():Array;

  /**
   * The store that will be replaced
   * /
  public native function get oldStore():Store;

  /**
   * The column headers that will be replaced.
   * /
  public native function get oldColumns():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: GridPanel_store_columns_oldStore_oldColumnsEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_RECONFIGURE: "onBeforeReconfigure",
            RECONFIGURE: "onReconfigure",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.feature.events.Grouping_view_node_groupEvent", function(Grouping_view_node_groupEvent) {
    /*package ext.grid.feature.events {
import ext.view.TableView;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class Grouping_view_node_groupEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Grouping_view_node_groupEvent.__PARAMETER_SEQUENCE__ = ([
            "view",
            "node",
            "group",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @see ext.grid.feature.Grouping
   * @eventType onGroupCollapse
   * /
  public static const GROUP_COLLAPSE:String = "onGroupCollapse";
  /**
   * "
   * @see ext.grid.feature.Grouping
   * @eventType onGroupExpand
   * /
  public static const GROUP_EXPAND:String = "onGroupExpand";

  public*/
    function Grouping_view_node_groupEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get view():TableView;

  public native function get node():HTMLElement;

  /**
   * The name of the group
   * /
  public native function get group():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Grouping_view_node_groupEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            GROUP_COLLAPSE: "onGroupCollapse",
            GROUP_EXPAND: "onGroupExpand",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.feature.events.Grouping_view_node_group_eEvent", function(Grouping_view_node_group_eEvent) {
    /*package ext.grid.feature.events {
import ext.event.Event;
import ext.view.TableView;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class Grouping_view_node_group_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Grouping_view_node_group_eEvent.__PARAMETER_SEQUENCE__ = ([
            "view",
            "node",
            "group",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @see ext.grid.feature.Grouping
   * @eventType onGroupClick
   * /
  public static const GROUP_CLICK:String = "onGroupClick";
  /**
   * "
   * @see ext.grid.feature.Grouping
   * @eventType onGroupContextMenu
   * /
  public static const GROUP_CONTEXT_MENU:String = "onGroupContextMenu";
  /**
   * "
   * @see ext.grid.feature.Grouping
   * @eventType onGroupDblclick
   * /
  public static const GROUP_DBLCLICK:String = "onGroupDblclick";

  public*/
    function Grouping_view_node_group_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get view():TableView;

  public native function get node():HTMLElement;

  /**
   * The name of the group
   * /
  public native function get group():String;

  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Grouping_view_node_group_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            GROUP_CLICK: "onGroupClick",
            GROUP_CONTEXT_MENU: "onGroupContextMenu",
            GROUP_DBLCLICK: "onGroupDblclick",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.filters.filter.events.BaseFilterEvent", function(BaseFilterEvent) {
    /*package ext.grid.filters.filter.events {
import ext.grid.filters.Filters;

import net.jangaroo.ext.FlExtEvent;

public class BaseFilterEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        BaseFilterEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when an inactive filter becomes active
   * @see ext.grid.filters.filter.BaseFilter
   * @eventType onActivate
   * /
  public static const ACTIVATE:String = "onActivate";
  /**
   * "Fires when an active filter becomes inactive
   * @see ext.grid.filters.filter.BaseFilter
   * @eventType onDeactivate
   * /
  public static const DEACTIVATE:String = "onDeactivate";
  /**
   * "Fires when a filter configuration has changed
   * @see ext.grid.filters.filter.BaseFilter
   * @eventType onUpdate
   * /
  public static const UPDATE:String = "onUpdate";

  public*/
    function BaseFilterEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Filters;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: BaseFilterEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ACTIVATE: "onActivate",
            DEACTIVATE: "onDeactivate",
            UPDATE: "onUpdate",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.header.events.HeaderContainerEvent", function(HeaderContainerEvent) {
    /*package ext.grid.header.events {
import ext.grid.header.HeaderContainer;

import net.jangaroo.ext.FlExtEvent;

public class HeaderContainerEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HeaderContainerEvent.__PARAMETER_SEQUENCE__ = ([
            "ct",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired after the columns change in any way, when a column has been hidden or shown, or when a column
   * is added to or removed from this header container.
   * @see ext.grid.header.HeaderContainer
   * @eventType onColumnsChanged
   * /
  public static const COLUMNS_CHANGED:String = "onColumnsChanged";

  public*/
    function HeaderContainerEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The grid's header Container which encapsulates all column headers.
   * /
  public native function get ct():HeaderContainer;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HeaderContainerEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            COLUMNS_CHANGED: "onColumnsChanged",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.header.events.HeaderContainer_columnEvent", function(HeaderContainer_columnEvent) {
    /*package ext.grid.header.events {
import ext.grid.column.Column;
import ext.grid.header.HeaderContainer;

import net.jangaroo.ext.FlExtEvent;

public class HeaderContainer_columnEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HeaderContainer_columnEvent.__PARAMETER_SEQUENCE__ = ([
            "ct",
            "column",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @see ext.grid.header.HeaderContainer
   * @eventType onColumnHide
   * /
  public static const COLUMN_HIDE:String = "onColumnHide";
  /**
   * "
   * @see ext.grid.header.HeaderContainer
   * @eventType onColumnsHow
   * /
  public static const COLUMNS_HOW:String = "onColumnsHow";

  public*/
    function HeaderContainer_columnEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The grid's header Container which encapsulates all column headers.
   * /
  public native function get ct():HeaderContainer;

  /**
   * The Column header Component which provides the column definition
   * /
  public native function get column():Column;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HeaderContainer_columnEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            COLUMN_HIDE: "onColumnHide",
            COLUMNS_HOW: "onColumnsHow",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.header.events.HeaderContainer_column_directionEvent", function(HeaderContainer_column_directionEvent) {
    /*package ext.grid.header.events {
import ext.grid.column.Column;
import ext.grid.header.HeaderContainer;

import net.jangaroo.ext.FlExtEvent;

public class HeaderContainer_column_directionEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HeaderContainer_column_directionEvent.__PARAMETER_SEQUENCE__ = ([
            "ct",
            "column",
            "direction",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @see ext.grid.header.HeaderContainer
   * @eventType onSortChange
   * /
  public static const SORT_CHANGE:String = "onSortChange";

  public*/
    function HeaderContainer_column_directionEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The grid's header Container which encapsulates all column headers.
   * /
  public native function get ct():HeaderContainer;

  /**
   * The Column header Component which provides the column definition
   * /
  public native function get column():Column;

  public native function get direction():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HeaderContainer_column_directionEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SORT_CHANGE: "onSortChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.header.events.HeaderContainer_column_e_tEvent", function(HeaderContainer_column_e_tEvent) {
    /*package ext.grid.header.events {
import ext.event.Event;
import ext.grid.column.Column;
import ext.grid.header.HeaderContainer;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class HeaderContainer_column_e_tEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HeaderContainer_column_e_tEvent.__PARAMETER_SEQUENCE__ = ([
            "ct",
            "column",
            "e",
            "t",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @see ext.grid.header.HeaderContainer
   * @eventType onHeaderClick
   * /
  public static const HEADER_CLICK:String = "onHeaderClick";
  /**
   * "
   * @see ext.grid.header.HeaderContainer
   * @eventType onHeaderContextMenu
   * /
  public static const HEADER_CONTEXT_MENU:String = "onHeaderContextMenu";
  /**
   * "
   * @see ext.grid.header.HeaderContainer
   * @eventType onHeaderTriggerClick
   * /
  public static const HEADER_TRIGGER_CLICK:String = "onHeaderTriggerClick";

  public*/
    function HeaderContainer_column_e_tEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The grid's header Container which encapsulates all column headers.
   * /
  public native function get ct():HeaderContainer;

  /**
   * The Column header Component which provides the column definition
   * /
  public native function get column():Column;

  public native function get e():Event;

  public native function get t():HTMLElement;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HeaderContainer_column_e_tEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            HEADER_CLICK: "onHeaderClick",
            HEADER_CONTEXT_MENU: "onHeaderContextMenu",
            HEADER_TRIGGER_CLICK: "onHeaderTriggerClick",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.header.events.HeaderContainer_column_fromIdx_toIdxEvent", function(HeaderContainer_column_fromIdx_toIdxEvent) {
    /*package ext.grid.header.events {
import ext.grid.column.Column;
import ext.grid.header.HeaderContainer;

import net.jangaroo.ext.FlExtEvent;

public class HeaderContainer_column_fromIdx_toIdxEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HeaderContainer_column_fromIdx_toIdxEvent.__PARAMETER_SEQUENCE__ = ([
            "ct",
            "column",
            "fromIdx",
            "toIdx",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @see ext.grid.header.HeaderContainer
   * @eventType onColumnMove
   * /
  public static const COLUMN_MOVE:String = "onColumnMove";

  public*/
    function HeaderContainer_column_fromIdx_toIdxEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The grid's header Container which encapsulates all column headers.
   * /
  public native function get ct():HeaderContainer;

  /**
   * The Column header Component which provides the column definition
   * /
  public native function get column():Column;

  public native function get fromIdx():Number;

  public native function get toIdx():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HeaderContainer_column_fromIdx_toIdxEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            COLUMN_MOVE: "onColumnMove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.header.events.HeaderContainer_column_widthEvent", function(HeaderContainer_column_widthEvent) {
    /*package ext.grid.header.events {
import ext.grid.column.Column;
import ext.grid.header.HeaderContainer;

import net.jangaroo.ext.FlExtEvent;

public class HeaderContainer_column_widthEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HeaderContainer_column_widthEvent.__PARAMETER_SEQUENCE__ = ([
            "ct",
            "column",
            "width",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @see ext.grid.header.HeaderContainer
   * @eventType onColumnResize
   * /
  public static const COLUMN_RESIZE:String = "onColumnResize";

  public*/
    function HeaderContainer_column_widthEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The grid's header Container which encapsulates all column headers.
   * /
  public native function get ct():HeaderContainer;

  /**
   * The Column header Component which provides the column definition
   * /
  public native function get column():Column;

  public native function get width():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HeaderContainer_column_widthEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            COLUMN_RESIZE: "onColumnResize",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.header.events.HeaderContainer_menuEvent", function(HeaderContainer_menuEvent) {
    /*package ext.grid.header.events {
import ext.grid.header.HeaderContainer;
import ext.menu.Menu;

import net.jangaroo.ext.FlExtEvent;

public class HeaderContainer_menuEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HeaderContainer_menuEvent.__PARAMETER_SEQUENCE__ = ([
            "ct",
            "menu",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired immediately after the column header menu is created.
   * @see ext.grid.header.HeaderContainer
   * @eventType onMenuCreate
   * /
  public static const MENU_CREATE:String = "onMenuCreate";

  public*/
    function HeaderContainer_menuEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This instance
   * /
  public native function get ct():HeaderContainer;

  /**
   * The Menu that was created
   * /
  public native function get menu():Menu;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HeaderContainer_menuEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            MENU_CREATE: "onMenuCreate",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.locking.events.LockableEvent", function(LockableEvent) {
    /*package ext.grid.locking.events {
import ext.panel.TablePanel;

import net.jangaroo.ext.FlExtEvent;

public class LockableEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        LockableEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the grid view is available (use this for selecting a default row).
   * @see ext.grid.locking.Lockable
   * @eventType onViewReady
   * /
  public static const VIEW_READY:String = "onViewReady";

  public*/
    function LockableEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():TablePanel;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: LockableEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            VIEW_READY: "onViewReady",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.locking.events.Lockable_columnEvent", function(Lockable_columnEvent) {
    /*package ext.grid.locking.events {
import ext.grid.GridPanel;
import ext.grid.column.Column;

import net.jangaroo.ext.FlExtEvent;

public class Lockable_columnEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Lockable_columnEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "column",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a column is locked.
   * @see ext.grid.locking.Lockable
   * @eventType onLockColumn
   * /
  public static const LOCK_COLUMN:String = "onLockColumn";
  /**
   * "Fires when a column is unlocked.
   * @see ext.grid.locking.Lockable
   * @eventType onUnlockColumn
   * /
  public static const UNLOCK_COLUMN:String = "onUnlockColumn";

  public*/
    function Lockable_columnEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The gridpanel.
   * /
  public native function get source():GridPanel;

  /**
   * The column being locked.
   * /
  public native function get column():Column;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Lockable_columnEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            LOCK_COLUMN: "onLockColumn",
            UNLOCK_COLUMN: "onUnlockColumn",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.locking.events.Lockable_lockedColumns_normalColumnsEvent", function(Lockable_lockedColumns_normalColumnsEvent) {
    /*package ext.grid.locking.events {
import net.jangaroo.ext.FlExtEvent;

public class Lockable_lockedColumns_normalColumnsEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Lockable_lockedColumns_normalColumnsEvent.__PARAMETER_SEQUENCE__ = ([
            "lockedColumns",
            "normalColumns",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the configured (or <strong>reconfigured</strong>) column set is split into two depending on the <a href="#!/api/Ext.grid.column.Column-cfg-locked" rel="Ext.grid.column.Column-cfg-locked" class="docClass">locked</a> flag.
   * @see ext.grid.locking.Lockable
   * @eventType onProcessColumns
   * /
  public static const PROCESS_COLUMNS:String = "onProcessColumns";

  public*/
    function Lockable_lockedColumns_normalColumnsEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The locked columns.
   * /
  public native function get lockedColumns():Array;

  /**
   * The normal columns.
   * /
  public native function get normalColumns():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Lockable_lockedColumns_normalColumnsEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            PROCESS_COLUMNS: "onProcessColumns",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.locking.events.Lockable_records_successful_operationEvent", function(Lockable_records_successful_operationEvent) {
    /*package ext.grid.locking.events {
import ext.data.Store;
import ext.data.operation.ReadOperation;

import net.jangaroo.ext.FlExtEvent;

public class Lockable_records_successful_operationEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Lockable_records_successful_operationEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "records",
            "successful",
            "operation",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires whenever the store reads data from a remote data source.
   * @see ext.grid.locking.Lockable
   * @eventType onLoad
   * /
  public static const LOAD:String = "onLoad";

  public*/
    function Lockable_records_successful_operationEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Store;

  /**
   * An array of records
   * /
  public native function get records():Array;

  /**
   * True if the operation was successful.
   * /
  public native function get successful():Boolean;

  /**
   * The
   * <a href="#!/api/Ext.data.operation.Read" rel="Ext.data.operation.Read" class="docClass">Operation</a> object that was used in the data
   * load call
   * /
  public native function get operation():ReadOperation;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Lockable_records_successful_operationEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            LOAD: "onLoad",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.locking.events.Lockable_store_filtersEvent", function(Lockable_store_filtersEvent) {
    /*package ext.grid.locking.events {
import ext.data.Store;

import net.jangaroo.ext.FlExtEvent;

public class Lockable_store_filtersEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Lockable_store_filtersEvent.__PARAMETER_SEQUENCE__ = ([
            "store",
            "filters",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired whenever the filter set changes.
   * @see ext.grid.locking.Lockable
   * @eventType onFilterChange
   * /
  public static const FILTER_CHANGE:String = "onFilterChange";

  public*/
    function Lockable_store_filtersEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The store.
   * /
  public native function get store():Store;

  /**
   * The array of Filter objects.
   * /
  public native function get filters():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Lockable_store_filtersEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            FILTER_CHANGE: "onFilterChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.locking.events.Lockable_store_grouperEvent", function(Lockable_store_grouperEvent) {
    /*package ext.grid.locking.events {
import ext.data.Store;
import ext.util.Grouper;

import net.jangaroo.ext.FlExtEvent;

public class Lockable_store_grouperEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Lockable_store_grouperEvent.__PARAMETER_SEQUENCE__ = ([
            "store",
            "grouper",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired whenever the grouping in the grid changes.
   * @see ext.grid.locking.Lockable
   * @eventType onGroupChange
   * /
  public static const GROUP_CHANGE:String = "onGroupChange";

  public*/
    function Lockable_store_grouperEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The store.
   * /
  public native function get store():Store;

  /**
   * The grouper object.
   * /
  public native function get grouper():Grouper;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Lockable_store_grouperEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            GROUP_CHANGE: "onGroupChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.locking.events.Lockable_store_operationEvent", function(Lockable_store_operationEvent) {
    /*package ext.grid.locking.events {
import ext.data.Store;
import ext.data.operation.Operation;

import net.jangaroo.ext.FlExtEvent;

public class Lockable_store_operationEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Lockable_store_operationEvent.__PARAMETER_SEQUENCE__ = ([
            "store",
            "operation",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a request is made for a new data object. If the beforeload handler returns false the load
   * action will be canceled.
   * @see ext.grid.locking.Lockable
   * @eventType onBeforeLoad
   * /
  public static const BEFORE_LOAD:String = "onBeforeLoad";

  public*/
    function Lockable_store_operationEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This Store
   * /
  public native function get store():Store;

  /**
   * The <a href="#!/api/Ext.data.operation.Operation" rel="Ext.data.operation.Operation" class="docClass">Ext.data.operation.Operation</a> object that will be passed to the Proxy to
   * load the Store
   * /
  public native function get operation():Operation;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Lockable_store_operationEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_LOAD: "onBeforeLoad",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.plugin.events.CellEditingPlugin_contextEvent", function(CellEditingPlugin_contextEvent) {
    /*package ext.grid.plugin.events {
import ext.grid.plugin.CellEditingPlugin;

import net.jangaroo.ext.FlExtEvent;

public class CellEditingPlugin_contextEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        CellEditingPlugin_contextEvent.__PARAMETER_SEQUENCE__ = ([
            "editor",
            "context",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before cell editing is triggered. Return false from event handler to stop the editing.
   * @see ext.grid.plugin.CellEditingPlugin
   * @eventType onBeforeEdit
   * /
  public static const BEFORE_EDIT:String = "onBeforeEdit";
  /**
   * "Fires when the user started editing a cell but then cancelled the edit.
   * @see ext.grid.plugin.CellEditingPlugin
   * @eventType onCancelEdit
   * /
  public static const CANCEL_EDIT:String = "onCancelEdit";
  /**
   * "Fires after a cell is edited. Usage example:
   *
   * <pre><code>grid.on('edit', function(editor, e) {
   *     // commit the changes right after editing finished
   *     e.record.commit();
   * });
   * </code></pre>
   * @see ext.grid.plugin.CellEditingPlugin
   * @eventType onEdit
   * /
  public static const EDIT:String = "onEdit";
  /**
   * "Fires after a cell is edited, but before the value is set in the record.
   * There are three possible outcomes when handling the validateedit event:
   *
   * <ul>
   * <li>Return <code>true</code> - Return true to commit the change to the underlying record and
   * hide the editor</li>
   * <li>Return 'false' - Return false to prevent 1) the edit from being committed to
   * the underlying record and 2) the editor from hiding / blurring.</li>
   * <li>Set context.cancel: true and return <code>false</code> - Set the context param's cancel property
   * to true and returning false will 1) prevent the edit from being committed to
   * the underlying record but <em>will</em> allow the edit to hide once blurred.</li>
   * </ul>
   *
   *
   * <p>In the following example, entering 10 in the editor field and tabbing out /
   * blurring the editor field will result in the the editor remaining focused as the
   * required validation criteria has not been met.</p>
   *
   * <pre><code>grid.on('validateedit', function(editor, context) {
   *     if (context.value &lt; 10) {
   *         return false;
   *     }
   * });
   * </code></pre>
   *
   * <p>If we modify the previous example by setting context.cancel to true then changing
   * the editor value from 2 to 10 and tabbing out of the field will result in the
   * editor hiding and the grid cell retaining the initial value of 2.</p>
   *
   * <pre><code>grid.on('validateedit', function(editor, context) {
   *     if (context.value &lt; 10) {
   *         context.cancel = true;
   *         return false;
   *     }
   * });
   * </code></pre>
   *
   * <p>Below is a usage example showing how to remove the red triangle (dirty-record
   * indicator) from some records (not all). By observing the grid's validateedit
   * event, it can be cancelled if the edit occurs on a targeted row (for example) and
   * then setting the field's new value in the Record directly:</p>
   *
   * <pre><code>grid.on('validateedit', function(editor, e) {
   *   var myTargetRow = 6;
   *
   *   if (e.row == myTargetRow) {
   *     e.cancel = true;
   *     e.record.data[e.field] = e.value;
   *   }
   * });
   * </code></pre>
   * @see ext.grid.plugin.CellEditingPlugin
   * @eventType onValidateEdit
   * /
  public static const VALIDATE_EDIT:String = "onValidateEdit";

  public*/
    function CellEditingPlugin_contextEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get editor():CellEditingPlugin;

  /**
   * An editing context event with the following properties:
   * <ul>
   *   <li><code>grid</code> : ext.grid.GridPanel
   * The owning grid Panel.
   *   </li>
   *   <li><code>record</code> : ext.data.Model
   * The record being edited.
   *   </li>
   *   <li><code>field</code> : String
   * The name of the field being edited.
   *   </li>
   *   <li><code>value</code>
   * The field's current value.
   *   </li>
   *   <li><code>row</code> : js.HTMLElement
   * The grid row element.
   *   </li>
   *   <li><code>column</code> : ext.grid.column.Column
   * The <a href="#!/api/Ext.grid.column.Column" rel="Ext.grid.column.Column" class="docClass">Ext.grid.column.Column</a> Column} being edited.
   *   </li>
   *   <li><code>rowIdx</code> : Number
   * The index of the row being edited.
   *   </li>
   *   <li><code>colIdx</code> : Number
   * The index of the column being edited.
   *   </li>
   *   <li><code>cancel</code> : Boolean
   * Set this to <code>true</code> to cancel the edit or return false from your handler.
   *   </li>
   * </ul>
   * /
  public native function get context():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: CellEditingPlugin_contextEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_EDIT: "onBeforeEdit",
            CANCEL_EDIT: "onCancelEdit",
            EDIT: "onEdit",
            VALIDATE_EDIT: "onValidateEdit",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.plugin.events.GridEditingPlugin_contextEvent", function(GridEditingPlugin_contextEvent) {
    /*package ext.grid.plugin.events {
import ext.grid.plugin.GridEditingPlugin;

import net.jangaroo.ext.FlExtEvent;

public class GridEditingPlugin_contextEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        GridEditingPlugin_contextEvent.__PARAMETER_SEQUENCE__ = ([
            "editor",
            "context",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before editing is triggered. Return false from event handler to stop the editing.
   * @see ext.grid.plugin.GridEditingPlugin
   * @eventType onBeforeEdit
   * /
  public static const BEFORE_EDIT:String = "onBeforeEdit";
  /**
   * "Fires when the user started editing but then cancelled the edit.
   * @see ext.grid.plugin.GridEditingPlugin
   * @eventType onCancelEdit
   * /
  public static const CANCEL_EDIT:String = "onCancelEdit";
  /**
   * "Fires after editing. Usage example:
   *
   * <pre><code>grid.on('edit', function(editor, e) {
   *     // commit the changes right after editing finished
   *     e.record.commit();
   * });
   * </code></pre>
   * @see ext.grid.plugin.GridEditingPlugin
   * @eventType onEdit
   * /
  public static const EDIT:String = "onEdit";
  /**
   * "Fires after editing, but before the value is set in the record. Return false from event handler to
   * cancel the change.
   *
   * <p>Usage example showing how to remove the red triangle (dirty record indicator) from some records (not all). By
   * observing the grid's validateedit event, it can be cancelled if the edit occurs on a targeted row (for example)
   * and then setting the field's new value in the Record directly:</p>
   *
   * <pre><code>grid.on('validateedit', function (editor, context) {
   *     var myTargetRow = 6;
   *
   *     if (context.rowIdx === myTargetRow) {
   *         context.record.data[context.field] = context.value;
   *     }
   * });
   * </code></pre>
   * @see ext.grid.plugin.GridEditingPlugin
   * @eventType onValidateEdit
   * /
  public static const VALIDATE_EDIT:String = "onValidateEdit";

  public*/
    function GridEditingPlugin_contextEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get editor():GridEditingPlugin;

  /**
   * The editing context with the following properties:
   * <ul>
   *   <li><code>grid</code> : ext.grid.GridPanel
   * The owning grid Panel.
   *   </li>
   *   <li><code>record</code> : ext.data.Model
   * The record being edited.
   *   </li>
   *   <li><code>field</code> : String
   * The name of the field being edited.
   *   </li>
   *   <li><code>value</code>
   * The field's current value.
   *   </li>
   *   <li><code>row</code> : js.HTMLElement
   * The grid row element.
   *   </li>
   *   <li><code>column</code> : ext.grid.column.Column
   * The Column being edited.
   *   </li>
   *   <li><code>rowIdx</code> : Number
   * The index of the row being edited.
   *   </li>
   *   <li><code>colIdx</code> : Number
   * The index of the column being edited.
   *   </li>
   *   <li><code>cancel</code> : Boolean
   * Set this to <code>true</code> to cancel the edit or return false from your handler.
   *   </li>
   *   <li><code>originalValue</code>
   * Alias for value (only when using <a href="#!/api/Ext.grid.plugin.CellEditing" rel="Ext.grid.plugin.CellEditing" class="docClass">CellEditing</a>).
   *   </li>
   * </ul>
   * /
  public native function get context():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: GridEditingPlugin_contextEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_EDIT: "onBeforeEdit",
            CANCEL_EDIT: "onCancelEdit",
            EDIT: "onEdit",
            VALIDATE_EDIT: "onValidateEdit",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.plugin.events.GridViewDragDropPlugin_node_data_overModel_dropPositionEvent", function(GridViewDragDropPlugin_node_data_overModel_dropPositionEvent) {
    /*package ext.grid.plugin.events {
import ext.data.Model;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class GridViewDragDropPlugin_node_data_overModel_dropPositionEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        GridViewDragDropPlugin_node_data_overModel_dropPositionEvent.__PARAMETER_SEQUENCE__ = ([
            "node",
            "data",
            "overModel",
            "dropPosition",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "<strong>This event is fired through the <a href="#!/api/Ext.view.Table" rel="Ext.view.Table" class="docClass">GridView</a> and its owning
   * <a href="#!/api/Ext.grid.Panel" rel="Ext.grid.Panel" class="docClass">Grid</a>. You can add listeners to the grid or grid <a href="#!/api/Ext.grid.Panel-cfg-viewConfig" rel="Ext.grid.Panel-cfg-viewConfig" class="docClass">view config</a> object</strong>
   *
   * <p>Fired when a drop operation has been completed and the data has been moved or
   * copied.</p>
   * @see ext.grid.plugin.GridViewDragDropPlugin
   * @eventType onDrop
   * /
  public static const DROP:String = "onDrop";

  public*/
    function GridViewDragDropPlugin_node_data_overModel_dropPositionEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The <a href="#!/api/Ext.view.Table" rel="Ext.view.Table" class="docClass">GridView</a> node <strong>if any</strong> over
   * which the cursor was positioned.
   * /
  public native function get node():HTMLElement;

  /**
   * The data object gathered at mousedown time by the
   * cooperating <a href="#!/api/Ext.dd.DragZone" rel="Ext.dd.DragZone" class="docClass">DragZone</a>'s <a href="#!/api/Ext.dd.DragZone-method-getDragData" rel="Ext.dd.DragZone-method-getDragData" class="docClass">getDragData</a> method.  It contains the following properties:
   * <ul>
   *   <li><code>copy</code> : Boolean
   * The value of <a href="#!/api/Ext.grid.plugin.DragDrop-cfg-copy" rel="Ext.grid.plugin.DragDrop-cfg-copy" class="docClass">copy</a>.  Or <code>true</code> if
   * <a href="#!/api/Ext.grid.plugin.DragDrop-cfg-allowCopy" rel="Ext.grid.plugin.DragDrop-cfg-allowCopy" class="docClass">allowCopy</a> is true <strong>and</strong> the control key was pressed as the drag
   * operation began.
   *   </li>
   *   <li><code>view</code> : ext.view.TableView
   * The source grid view from which the drag
   * originated
   *   </li>
   *   <li><code>ddel</code> : js.HTMLElement
   * The drag proxy element which moves with the cursor
   *   </li>
   *   <li><code>item</code> : js.HTMLElement
   * The grid view node upon which the mousedown event
   * was registered
   *   </li>
   *   <li><code>records</code> : Array
   * An Array of Models representing the
   * selected data being dragged from the source grid view
   *   </li>
   * </ul>
   * /
  public native function get data():Object;

  /**
   * The Model over which the drop gesture took
   * place.
   * /
  public native function get overModel():Model;

  /**
   * <code>"before"</code> or <code>"after"</code> depending on whether the
   * cursor is above or below the mid-line of the node.
   * /
  public native function get dropPosition():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: GridViewDragDropPlugin_node_data_overModel_dropPositionEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DROP: "onDrop",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.plugin.events.GridViewDragDropPlugin_node_data_overModel_dropPosition_dropHandlersEvent", function(GridViewDragDropPlugin_node_data_overModel_dropPosition_dropHandlersEvent) {
    /*package ext.grid.plugin.events {
import ext.data.Model;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class GridViewDragDropPlugin_node_data_overModel_dropPosition_dropHandlersEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        GridViewDragDropPlugin_node_data_overModel_dropPosition_dropHandlersEvent.__PARAMETER_SEQUENCE__ = ([
            "node",
            "data",
            "overModel",
            "dropPosition",
            "dropHandlers",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "<strong>This event is fired through the <a href="#!/api/Ext.view.Table" rel="Ext.view.Table" class="docClass">GridView</a> and its owning
   * <a href="#!/api/Ext.grid.Panel" rel="Ext.grid.Panel" class="docClass">Grid</a>. You can add listeners to the grid or grid <a href="#!/api/Ext.grid.Panel-cfg-viewConfig" rel="Ext.grid.Panel-cfg-viewConfig" class="docClass">view config</a> object</strong>
   *
   * <p>Fired when a drop gesture has been triggered by a mouseup event in a valid drop
   * position in the grid view.</p>
   *
   * <p>Returning <code>false</code> to this event signals that the drop gesture was invalid and
   * animates the drag proxy back to the point from which the drag began.</p>
   *
   * <p>The dropHandlers parameter can be used to defer the processing of this event. For
   * example, you can force the handler to wait for the result of a message box
   * confirmation or an asynchronous server call (<em>see the details of the dropHandlers
   * property for more information</em>).</p>
   *
   * <pre><code>grid.on('beforedrop', function(node, data, overModel, dropPosition, dropHandlers) {
   *     // Defer the handling
   *     dropHandlers.wait = true;
   *     <a href="#!/api/Ext.MessageBox-method-confirm" rel="Ext.MessageBox-method-confirm" class="docClass">Ext.MessageBox.confirm</a>('Drop', 'Are you sure', function(btn){
   *         if (btn === 'yes') {
   *             dropHandlers.processDrop();
   *         } else {
   *             dropHandlers.cancelDrop();
   *         }
   *     });
   * });
   * </code></pre>
   *
   * <p>Any other return value continues with the data transfer operation unless the wait
   * property is set.</p>
   * @see ext.grid.plugin.GridViewDragDropPlugin
   * @eventType onBeforeDrop
   * /
  public static const BEFORE_DROP:String = "onBeforeDrop";

  public*/
    function GridViewDragDropPlugin_node_data_overModel_dropPosition_dropHandlersEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The <a href="#!/api/Ext.view.Table" rel="Ext.view.Table" class="docClass">grid view</a> node <strong>if any</strong> over
   * which the cursor was positioned.
   * /
  public native function get node():HTMLElement;

  /**
   * The data object gathered at mousedown time by the
   * cooperating <a href="#!/api/Ext.dd.DragZone" rel="Ext.dd.DragZone" class="docClass">DragZone</a>'s <a href="#!/api/Ext.dd.DragZone-method-getDragData" rel="Ext.dd.DragZone-method-getDragData" class="docClass">getDragData</a> method.  It contains the following properties:
   * <ul>
   *   <li><code>copy</code> : Boolean
   * The value of <a href="#!/api/Ext.grid.plugin.DragDrop-cfg-copy" rel="Ext.grid.plugin.DragDrop-cfg-copy" class="docClass">copy</a>.  Or <code>true</code> if
   * <a href="#!/api/Ext.grid.plugin.DragDrop-cfg-allowCopy" rel="Ext.grid.plugin.DragDrop-cfg-allowCopy" class="docClass">allowCopy</a> is true <strong>and</strong> the control key was pressed as the drag
   * operation began.
   *   </li>
   *   <li><code>view</code> : ext.view.TableView
   * The source grid view from which the drag
   * originated
   *   </li>
   *   <li><code>ddel</code> : js.HTMLElement
   * The drag proxy element which moves with the cursor
   *   </li>
   *   <li><code>item</code> : js.HTMLElement
   * The grid view node upon which the mousedown event
   * was registered
   *   </li>
   *   <li><code>records</code> : Array
   * An Array of Models representing the
   * selected data being dragged from the source grid view
   *   </li>
   * </ul>
   * /
  public native function get data():Object;

  /**
   * The Model over which the drop gesture took place
   * /
  public native function get overModel():Model;

  /**
   * <code>"before"</code> or <code>"after"</code> depending on whether the
   * cursor is above or below the mid-line of the node.
   * /
  public native function get dropPosition():String;

  /**
   * This parameter allows the developer to control when the drop action takes place.
   * It is useful if any asynchronous processing needs to be completed before
   * performing the drop. This object has the following properties:
   * <ul>
   *   <li><code>wait</code> : Boolean
   * Indicates whether the drop should be deferred.
   * Set this property to true to defer the drop.
   *   </li>
   *   <li><code>processDrop</code> : Function
   * A function to be called to complete
   * the drop operation.
   *   </li>
   *   <li><code>cancelDrop</code> : Function
   * A function to be called to cancel the
   * drop operation.
   *   </li>
   * </ul>
   * /
  public native function get dropHandlers():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: GridViewDragDropPlugin_node_data_overModel_dropPosition_dropHandlersEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_DROP: "onBeforeDrop",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.plugin.events.RowExpanderPlugin_rowNode_record_expandRowEvent", function(RowExpanderPlugin_rowNode_record_expandRowEvent) {
    /*package ext.grid.plugin.events {
import ext.data.Model;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class RowExpanderPlugin_rowNode_record_expandRowEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        RowExpanderPlugin_rowNode_record_expandRowEvent.__PARAMETER_SEQUENCE__ = ([
            "rowNode",
            "record",
            "expandRow",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "<strong>Fired through the grid's View.</strong>
   * @see ext.grid.plugin.RowExpanderPlugin
   * @eventType onCollapseBody
   * /
  public static const COLLAPSE_BODY:String = "onCollapseBody";
  /**
   * "<strong>Fired through the grid's View</strong>
   * @see ext.grid.plugin.RowExpanderPlugin
   * @eventType onExpandBody
   * /
  public static const EXPAND_BODY:String = "onExpandBody";

  public*/
    function RowExpanderPlugin_rowNode_record_expandRowEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The &lt;tr> element which owns the expanded row.
   * /
  public native function get rowNode():HTMLElement;

  /**
   * The record providing the data.
   * /
  public native function get record():Model;

  /**
   * The &lt;tr> element containing the expanded data.
   * /
  public native function get expandRow():HTMLElement;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: RowExpanderPlugin_rowNode_record_expandRowEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            COLLAPSE_BODY: "onCollapseBody",
            EXPAND_BODY: "onExpandBody",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.property.events.PropertyGrid_source_recordId_value_oldValueEvent", function(PropertyGrid_source_recordId_value_oldValueEvent) {
    /*package ext.grid.property.events {
import net.jangaroo.ext.FlExtEvent;

public class PropertyGrid_source_recordId_value_oldValueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        PropertyGrid_source_recordId_value_oldValueEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "recordId",
            "value",
            "oldValue",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a property value changes.  Handlers can return false to cancel the property change
   * (this will internally call <a href="#!/api/Ext.data.Model-method-reject" rel="Ext.data.Model-method-reject" class="docClass">Ext.data.Model.reject</a> on the property's record).
   * @see ext.grid.property.PropertyGrid
   * @eventType onBeforePropertyChange
   * /
  public static const BEFORE_PROPERTY_CHANGE:String = "onBeforePropertyChange";
  /**
   * "Fires after a property value has changed.
   * @see ext.grid.property.PropertyGrid
   * @eventType onPropertyChange
   * /
  public static const PROPERTY_CHANGE:String = "onPropertyChange";

  public*/
    function PropertyGrid_source_recordId_value_oldValueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The source data object for the grid (corresponds to the same object passed in
   * as the <a href="#!/api/Ext.grid.property.Grid-cfg-source" rel="Ext.grid.property.Grid-cfg-source" class="docClass">source</a> config property).
   * /
  public native function get source():Object;

  /**
   * The record's id in the data store
   * /
  public native function get recordId():String;

  /**
   * The current edited property value
   * /
  public native function get value():Object;

  /**
   * The original property value prior to editing
   * /
  public native function get oldValue():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: PropertyGrid_source_recordId_value_oldValueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_PROPERTY_CHANGE: "onBeforePropertyChange",
            PROPERTY_CHANGE: "onPropertyChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.grid.selection.events.SpreadsheetModelSelection_grid_selectionEvent", function(SpreadsheetModelSelection_grid_selectionEvent) {
    /*package ext.grid.selection.events {
import ext.grid.GridPanel;
import ext.grid.selection.Selection;

import net.jangaroo.ext.FlExtEvent;

public class SpreadsheetModelSelection_grid_selectionEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        SpreadsheetModelSelection_grid_selectionEvent.__PARAMETER_SEQUENCE__ = ([
            "grid",
            "selection",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired <em>by the grid</em> after the selection changes. Return <code>false</code> to veto the selection extension.
   *
   * <p>Note that the behavior of selectionchange is different in Ext 6.x vs. Ext 5.  In Ext 6.x, if rows
   * are being selected, a block of records is passed as the second parameter.  In Ext 5, the selection
   * object was passed.</p>
   * @see ext.grid.selection.SpreadsheetModelSelection
   * @eventType onSelectionChange
   * /
  public static const SELECTION_CHANGE:String = "onSelectionChange";

  public*/
    function SpreadsheetModelSelection_grid_selectionEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The grid whose selection has changed.
   * /
  public native function get grid():GridPanel;

  /**
   * A subclass of
   * <a href="#!/api/Ext.grid.selection.Selection" rel="Ext.grid.selection.Selection" class="docClass">Ext.grid.selection.Selection</a> describing the new selection.
   * /
  public native function get selection():Selection;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: SpreadsheetModelSelection_grid_selectionEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SELECTION_CHANGE: "onSelectionChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.list.events.AbstractTreeItem_sender_infoEvent", function(AbstractTreeItem_sender_infoEvent) {
    /*package ext.list.events {
import ext.list.Tree;

import net.jangaroo.ext.FlExtEvent;

public class AbstractTreeItem_sender_infoEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractTreeItem_sender_infoEvent.__PARAMETER_SEQUENCE__ = ([
            "sender",
            "info",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @since 6.0.1
   * @see ext.list.AbstractTreeItem
   * @eventType onItemClick
   * /
  public static const ITEM_CLICK:String = "onItemClick";

  public*/
    function AbstractTreeItem_sender_infoEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The <code>treelist</code> that fired this event.
   * /
  public native function get sender():Tree;

  /**
   *
   * <ul>
   *   <li><code>event</code> : ext.event.Event
   * The DOM event that precipitated this
   * event.
   *   </li>
   *   <li><code>item</code> : ext.list.AbstractTreeItem
   * The tree node that was clicked.
   *   </li>
   *   <li><code>tree</code> : ext.list.Tree
   * The <code>treelist</code> that fired this event.
   *   </li>
   *   <li><code>select</code> : Boolean
   * On input this is value is the result of the
   *   <a href="#!/api/Ext.list.AbstractTreeItem-method-isSelectionEvent" rel="Ext.list.AbstractTreeItem-method-isSelectionEvent" class="docClass">isSelectionEvent</a> method. On return from event handlers (assuming a
   *   <code>false</code> return does not cancel things) this property is used to determine
   *   if the clicked node should be selected.
   *   </li>
   *   <li><code>toggle</code> : Boolean
   * On input this is value is the result of the
   *   <a href="#!/api/Ext.list.AbstractTreeItem-method-isToggleEvent" rel="Ext.list.AbstractTreeItem-method-isToggleEvent" class="docClass">isToggleEvent</a> method. On return from event handlers (assuming a
   *   <code>false</code> return does not cancel things) this property is used to determine
   *   if the clicked node's expand/collapse state should be toggled.
   *   </li>
   * </ul>
   * /
  public native function get info():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractTreeItem_sender_infoEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ITEM_CLICK: "onItemClick",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.menu.events.CheckItem_checkedEvent", function(CheckItem_checkedEvent) {
    /*package ext.menu.events {
import ext.menu.CheckItem;

import net.jangaroo.ext.FlExtEvent;

public class CheckItem_checkedEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        CheckItem_checkedEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "checked",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a change event. Return false to cancel.
   * @see ext.menu.CheckItem
   * @eventType onBeforeCheckChange
   * /
  public static const BEFORE_CHECK_CHANGE:String = "onBeforeCheckChange";
  /**
   * "Fires after a change event.
   * @see ext.menu.CheckItem
   * @eventType onCheckChange
   * /
  public static const CHECK_CHANGE:String = "onCheckChange";

  public*/
    function CheckItem_checkedEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():CheckItem;

  public native function get checked():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: CheckItem_checkedEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_CHECK_CHANGE: "onBeforeCheckChange",
            CHECK_CHANGE: "onCheckChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.menu.events.ColorPickerMenu_colorEvent", function(ColorPickerMenu_colorEvent) {
    /*package ext.menu.events {
import ext.picker.ColorPicker;

import net.jangaroo.ext.FlExtEvent;

public class ColorPickerMenu_colorEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ColorPickerMenu_colorEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "color",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a color is selected
   * @see ext.menu.ColorPickerMenu
   * @eventType onSelect
   * /
  public static const SELECT:String = "onSelect";

  public*/
    function ColorPickerMenu_colorEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():ColorPicker;

  /**
   * The 6-digit color hex code (without the # symbol)
   * /
  public native function get color():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ColorPickerMenu_colorEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SELECT: "onSelect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.menu.events.DatePickerMenu_dateEvent", function(DatePickerMenu_dateEvent) {
    /*package ext.menu.events {
import ext.picker.DatePicker;

import net.jangaroo.ext.FlExtEvent;

public class DatePickerMenu_dateEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DatePickerMenu_dateEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "date",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a date is selected
   * @see ext.menu.DatePickerMenu
   * @eventType onSelect
   * /
  public static const SELECT:String = "onSelect";

  public*/
    function DatePickerMenu_dateEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * DatePicker
   * /
  public native function get source():DatePicker;

  /**
   * The selected date
   * /
  public native function get date():Date;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DatePickerMenu_dateEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SELECT: "onSelect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.menu.events.ItemEvent", function(ItemEvent) {
    /*package ext.menu.events {
import ext.menu.Item;

import net.jangaroo.ext.FlExtEvent;

public class ItemEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ItemEvent.__PARAMETER_SEQUENCE__ = ([
            "item",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when this item is activated
   * @see ext.menu.Item
   * @eventType onActivate
   * /
  public static const ACTIVATE:String = "onActivate";
  /**
   * "Fires when this item is deactivated
   * @see ext.menu.Item
   * @eventType onDeactivate
   * /
  public static const DEACTIVATE:String = "onDeactivate";

  public*/
    function ItemEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The activated item
   * /
  public native function get item():Item;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ItemEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ACTIVATE: "onActivate",
            DEACTIVATE: "onDeactivate",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.menu.events.Item_eEvent", function(Item_eEvent) {
    /*package ext.menu.events {
import ext.event.Event;
import ext.menu.Item;

import net.jangaroo.ext.FlExtEvent;

public class Item_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Item_eEvent.__PARAMETER_SEQUENCE__ = ([
            "item",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when this item is clicked
   * @see ext.menu.Item
   * @eventType onClick
   * /
  public static const CLICK:String = "onClick";

  public*/
    function Item_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The item that was clicked
   * /
  public native function get item():Item;

  /**
   * The underlying <a href="#!/api/Ext.event.Event" rel="Ext.event.Event" class="docClass">Ext.event.Event</a>.
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Item_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CLICK: "onClick",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.menu.events.Item_oldIcon_newIconEvent", function(Item_oldIcon_newIconEvent) {
    /*package ext.menu.events {
import ext.menu.Item;

import net.jangaroo.ext.FlExtEvent;

public class Item_oldIcon_newIconEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Item_oldIcon_newIconEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "oldIcon",
            "newIcon",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when the item's icon is changed by the <a href="#!/api/Ext.menu.Item-method-setIcon" rel="Ext.menu.Item-method-setIcon" class="docClass">setIcon</a> or <a href="#!/api/Ext.menu.Item-method-setIconCls" rel="Ext.menu.Item-method-setIconCls" class="docClass">setIconCls</a> methods.
   * @see ext.menu.Item
   * @eventType onIconChange
   * /
  public static const ICON_CHANGE:String = "onIconChange";

  public*/
    function Item_oldIcon_newIconEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Item;

  public native function get oldIcon():String;

  public native function get newIcon():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Item_oldIcon_newIconEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ICON_CHANGE: "onIconChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.menu.events.Item_oldText_newTextEvent", function(Item_oldText_newTextEvent) {
    /*package ext.menu.events {
import ext.menu.Item;

import net.jangaroo.ext.FlExtEvent;

public class Item_oldText_newTextEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Item_oldText_newTextEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "oldText",
            "newText",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when the item's text is changed by the <a href="#!/api/Ext.menu.Item-method-setText" rel="Ext.menu.Item-method-setText" class="docClass">setText</a> method.
   * @see ext.menu.Item
   * @eventType onTextChange
   * /
  public static const TEXT_CHANGE:String = "onTextChange";

  public*/
    function Item_oldText_newTextEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Item;

  public native function get oldText():String;

  public native function get newText():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Item_oldText_newTextEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            TEXT_CHANGE: "onTextChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.menu.events.Menu_eEvent", function(Menu_eEvent) {
    /*package ext.menu.events {
import ext.event.Event;
import ext.menu.Menu;

import net.jangaroo.ext.FlExtEvent;

public class Menu_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Menu_eEvent.__PARAMETER_SEQUENCE__ = ([
            "menu",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the mouse enters this menu
   * @see ext.menu.Menu
   * @eventType onMouseEnter
   * /
  public static const MOUSE_ENTER:String = "onMouseEnter";
  /**
   * "Fires when the mouse leaves this menu
   * @see ext.menu.Menu
   * @eventType onMouseLeave
   * /
  public static const MOUSE_LEAVE:String = "onMouseLeave";

  public*/
    function Menu_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The menu
   * /
  public native function get menu():Menu;

  /**
   * The underlying <a href="#!/api/Ext.event.Event" rel="Ext.event.Event" class="docClass">Ext.event.Event</a>
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Menu_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            MOUSE_ENTER: "onMouseEnter",
            MOUSE_LEAVE: "onMouseLeave",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.menu.events.Menu_item_eEvent", function(Menu_item_eEvent) {
    /*package ext.menu.events {
import ext.Component;
import ext.event.Event;
import ext.menu.Menu;

import net.jangaroo.ext.FlExtEvent;

public class Menu_item_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Menu_item_eEvent.__PARAMETER_SEQUENCE__ = ([
            "menu",
            "item",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when this menu is clicked
   * @see ext.menu.Menu
   * @eventType onClick
   * /
  public static const CLICK:String = "onClick";
  /**
   * "Fires when the mouse is hovering over this menu
   * @see ext.menu.Menu
   * @eventType onMouseOver
   * /
  public static const MOUSE_OVER:String = "onMouseOver";

  public*/
    function Menu_item_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The menu which has been clicked
   * /
  public native function get menu():Menu;

  /**
   * The menu item that was clicked. <code>undefined</code> if not applicable.
   * /
  public native function get item():Component;

  /**
   * The underlying <a href="#!/api/Ext.event.Event" rel="Ext.event.Event" class="docClass">Ext.event.Event</a>.
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Menu_item_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CLICK: "onClick",
            MOUSE_OVER: "onMouseOver",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.PanelEvent", function(PanelEvent) {
    /*package ext.panel.events {
import ext.panel.Panel;

import net.jangaroo.ext.FlExtEvent;

public class PanelEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        PanelEvent.__PARAMETER_SEQUENCE__ = ([
            "panel",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the user closes the panel. Return false from any listener to stop the close event being
   * fired
   * @see ext.panel.Panel
   * @eventType onBeforeClose
   * /
  public static const BEFORE_CLOSE:String = "onBeforeClose";
  /**
   * "Fires when the user closes the panel.
   * @see ext.panel.Panel
   * @eventType onClose
   * /
  public static const CLOSE:String = "onClose";
  /**
   * "Fires after this Panel has collapsed.
   * @see ext.panel.Panel
   * @eventType onCollapse
   * /
  public static const COLLAPSE:String = "onCollapse";
  /**
   * "Fires after this Panel has expanded.
   * @see ext.panel.Panel
   * @eventType onExpand
   * /
  public static const EXPAND:String = "onExpand";
  /**
   * "Fires after a collapsed Panel has been "floated" by clicking on
   * it's header. Only applicable when the Panel is an item in a
   * <a href="#!/api/Ext.layout.container.Border" rel="Ext.layout.container.Border" class="docClass">Border Layout</a>.
   * @see ext.panel.Panel
   * @eventType onFloat
   * /
  public static const FLOAT:String = "onFloat";
  /**
   * "Fires after a "floated" Panel has returned to it's collapsed state
   * as a result of the mouse leaving the Panel. Only applicable when
   * the Panel is an item in a
   * <a href="#!/api/Ext.layout.container.Border" rel="Ext.layout.container.Border" class="docClass">Border Layout</a>.
   * @see ext.panel.Panel
   * @eventType onUnfloat
   * /
  public static const UNFLOAT:String = "onUnfloat";

  public*/
    function PanelEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The Panel object
   * /
  public native function get panel():Panel;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: PanelEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_CLOSE: "onBeforeClose",
            CLOSE: "onClose",
            COLLAPSE: "onCollapse",
            EXPAND: "onExpand",
            FLOAT: "onFloat",
            UNFLOAT: "onUnfloat",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.PanelHeader_eEvent", function(PanelHeader_eEvent) {
    /*package ext.panel.events {
import ext.event.Event;
import ext.panel.PanelHeader;

import net.jangaroo.ext.FlExtEvent;

public class PanelHeader_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        PanelHeader_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the header is clicked. This event will not be fired
   * if the click was on a <a href="#!/api/Ext.panel.Tool" rel="Ext.panel.Tool" class="docClass">Ext.panel.Tool</a>
   * @see ext.panel.PanelHeader
   * @eventType onClick
   * /
  public static const CLICK:String = "onClick";
  /**
   * "Fires when the header is double clicked. This event will not
   * be fired if the click was on a <a href="#!/api/Ext.panel.Tool" rel="Ext.panel.Tool" class="docClass">Ext.panel.Tool</a>
   * @see ext.panel.PanelHeader
   * @eventType onDblclick
   * /
  public static const DBLCLICK:String = "onDblclick";

  public*/
    function PanelHeader_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():PanelHeader;

  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: PanelHeader_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CLICK: "onClick",
            DBLCLICK: "onDblclick",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.Panel_animateEvent", function(Panel_animateEvent) {
    /*package ext.panel.events {
import ext.panel.Panel;

import net.jangaroo.ext.FlExtEvent;

public class Panel_animateEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Panel_animateEvent.__PARAMETER_SEQUENCE__ = ([
            "p",
            "animate",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before this panel is expanded. Return false to prevent the expand.
   * @see ext.panel.Panel
   * @eventType onBeforeExpand
   * /
  public static const BEFORE_EXPAND:String = "onBeforeExpand";

  public*/
    function Panel_animateEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The Panel being expanded.
   * /
  public native function get p():Panel;

  /**
   * True if the expand is animated, else false.
   * /
  public native function get animate():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Panel_animateEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_EXPAND: "onBeforeExpand",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.Panel_componentEvent", function(Panel_componentEvent) {
    /*package ext.panel.events {
import ext.Component;
import ext.panel.Panel;

import net.jangaroo.ext.FlExtEvent;

public class Panel_componentEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Panel_componentEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "component",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when any <a href="#!/api/Ext.Component" rel="Ext.Component" class="docClass">Ext.Component</a> is removed from the docked items.
   * @see ext.panel.Panel
   * @eventType onDockedRemove
   * /
  public static const DOCKED_REMOVE:String = "onDockedRemove";

  public*/
    function Panel_componentEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Panel;

  /**
   * The component being removed
   * /
  public native function get component():Component;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Panel_componentEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DOCKED_REMOVE: "onDockedRemove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.Panel_component_indexEvent", function(Panel_component_indexEvent) {
    /*package ext.panel.events {
import ext.Component;
import ext.panel.Panel;

import net.jangaroo.ext.FlExtEvent;

public class Panel_component_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Panel_component_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "component",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when any <a href="#!/api/Ext.Component" rel="Ext.Component" class="docClass">Ext.Component</a> is added or inserted as a docked item.
   * @see ext.panel.Panel
   * @eventType onDockedAdd
   * /
  public static const DOCKED_ADD:String = "onDockedAdd";

  public*/
    function Panel_component_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Panel;

  /**
   * The component being added
   * /
  public native function get component():Component;

  /**
   * The index at which the component will be added docked items collection
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Panel_component_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DOCKED_ADD: "onDockedAdd",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.Panel_direction_animateEvent", function(Panel_direction_animateEvent) {
    /*package ext.panel.events {
import ext.panel.Panel;

import net.jangaroo.ext.FlExtEvent;

public class Panel_direction_animateEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Panel_direction_animateEvent.__PARAMETER_SEQUENCE__ = ([
            "p",
            "direction",
            "animate",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before this panel is collapsed. Return false to prevent the collapse.
   * @see ext.panel.Panel
   * @eventType onBeforeCollapse
   * /
  public static const BEFORE_COLLAPSE:String = "onBeforeCollapse";

  public*/
    function Panel_direction_animateEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The Panel being collapsed.
   * /
  public native function get p():Panel;

  /**
   * . The direction of the collapse. One of
   * <ul>
   * <li><a href="#!/api/Ext.Component-static-property-DIRECTION_TOP" rel="Ext.Component-static-property-DIRECTION_TOP" class="docClass">Ext.Component.DIRECTION_TOP</a></li>
   * <li><a href="#!/api/Ext.Component-static-property-DIRECTION_RIGHT" rel="Ext.Component-static-property-DIRECTION_RIGHT" class="docClass">Ext.Component.DIRECTION_RIGHT</a></li>
   * <li><a href="#!/api/Ext.Component-static-property-DIRECTION_BOTTOM" rel="Ext.Component-static-property-DIRECTION_BOTTOM" class="docClass">Ext.Component.DIRECTION_BOTTOM</a></li>
   * <li><a href="#!/api/Ext.Component-static-property-DIRECTION_LEFT" rel="Ext.Component-static-property-DIRECTION_LEFT" class="docClass">Ext.Component.DIRECTION_LEFT</a></li>
   * </ul>
   * /
  public native function get direction():String;

  /**
   * True if the collapse is animated, else false.
   * /
  public native function get animate():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Panel_direction_animateEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_COLLAPSE: "onBeforeCollapse",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.Panel_newGlyph_oldGlyphEvent", function(Panel_newGlyph_oldGlyphEvent) {
    /*package ext.panel.events {
import ext.panel.Panel;

import net.jangaroo.ext.FlExtEvent;

public class Panel_newGlyph_oldGlyphEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Panel_newGlyph_oldGlyphEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "newGlyph",
            "oldGlyph",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when the Panel glyph has been changed by the <a href="#!/api/Ext.panel.Panel-method-setGlyph" rel="Ext.panel.Panel-method-setGlyph" class="docClass">setGlyph</a> method.
   * @see ext.panel.Panel
   * @eventType onGlyphChange
   * /
  public static const GLYPH_CHANGE:String = "onGlyphChange";

  public*/
    function Panel_newGlyph_oldGlyphEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Panel;

  public native function get newGlyph():*;

  public native function get oldGlyph():*;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Panel_newGlyph_oldGlyphEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            GLYPH_CHANGE: "onGlyphChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.Panel_newIconCls_oldIconClsEvent", function(Panel_newIconCls_oldIconClsEvent) {
    /*package ext.panel.events {
import ext.panel.Panel;

import net.jangaroo.ext.FlExtEvent;

public class Panel_newIconCls_oldIconClsEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Panel_newIconCls_oldIconClsEvent.__PARAMETER_SEQUENCE__ = ([
            "p",
            "newIconCls",
            "oldIconCls",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after the Panel iconCls has been set or changed.
   * @see ext.panel.Panel
   * @eventType onIconClsChange
   * /
  public static const ICON_CLS_CHANGE:String = "onIconClsChange";

  public*/
    function Panel_newIconCls_oldIconClsEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The Panel which has the iconCls changed.
   * /
  public native function get p():Panel;

  /**
   * The new iconCls.
   * /
  public native function get newIconCls():String;

  /**
   * The previous panel iconCls.
   * /
  public native function get oldIconCls():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Panel_newIconCls_oldIconClsEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ICON_CLS_CHANGE: "onIconClsChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.Panel_newIcon_oldIconEvent", function(Panel_newIcon_oldIconEvent) {
    /*package ext.panel.events {
import ext.panel.Panel;

import net.jangaroo.ext.FlExtEvent;

public class Panel_newIcon_oldIconEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Panel_newIcon_oldIconEvent.__PARAMETER_SEQUENCE__ = ([
            "p",
            "newIcon",
            "oldIcon",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after the Panel icon has been set or changed.
   * @see ext.panel.Panel
   * @eventType onIconChange
   * /
  public static const ICON_CHANGE:String = "onIconChange";

  public*/
    function Panel_newIcon_oldIconEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The Panel which has the icon changed.
   * /
  public native function get p():Panel;

  /**
   * The path to the new icon image.
   * /
  public native function get newIcon():String;

  /**
   * The path to the previous panel icon image.
   * /
  public native function get oldIcon():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Panel_newIcon_oldIconEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ICON_CHANGE: "onIconChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.Panel_newTitle_oldTitleEvent", function(Panel_newTitle_oldTitleEvent) {
    /*package ext.panel.events {
import ext.panel.Panel;

import net.jangaroo.ext.FlExtEvent;

public class Panel_newTitle_oldTitleEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Panel_newTitle_oldTitleEvent.__PARAMETER_SEQUENCE__ = ([
            "p",
            "newTitle",
            "oldTitle",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after the Panel title has been set or changed.
   * @see ext.panel.Panel
   * @eventType onTitleChange
   * /
  public static const TITLE_CHANGE:String = "onTitleChange";

  public*/
    function Panel_newTitle_oldTitleEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * the Panel which has been resized.
   * /
  public native function get p():Panel;

  /**
   * The new title.
   * /
  public native function get newTitle():String;

  /**
   * The previous panel title.
   * /
  public native function get oldTitle():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Panel_newTitle_oldTitleEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            TITLE_CHANGE: "onTitleChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanelEvent", function(TablePanelEvent) {
    /*package ext.panel.events {
import ext.panel.TablePanel;

import net.jangaroo.ext.FlExtEvent;

public class TablePanelEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanelEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the grid view is available (use this for selecting a default row).
   * @see ext.panel.TablePanel
   * @eventType onViewReady
   * /
  public static const VIEW_READY:String = "onViewReady";

  public*/
    function TablePanelEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():TablePanel;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanelEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            VIEW_READY: "onViewReady",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_An_extensionEvent", function(TablePanel_An_extensionEvent) {
    /*package ext.panel.events {
import ext.grid.selection.Selection;
import ext.panel.TablePanel;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_An_extensionEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_An_extensionEvent.__PARAMETER_SEQUENCE__ = ([
            "grid",
            "An",
            "extension",
            "eOpts"
        ]);
    }
    /*;
  /**
   * ".
   * An event fired when an extension block is extended
   * using a drag gesture.  Only fired when the SpreadsheetSelectionModel is used and
   * configured with the
   * <a href="#!/api/Ext.grid.selection.SpreadsheetModel-cfg-extensible" rel="Ext.grid.selection.SpreadsheetModel-cfg-extensible" class="docClass">extensible</a> config.
   * @see ext.panel.TablePanel
   * @eventType onBeforeSelectionExtend
   * /
  public static const BEFORE_SELECTION_EXTEND:String = "onBeforeSelectionExtend";
  /**
   * ".
   * An event fired when an extension block is dragged to
   * encompass a new range.  Only fired when the SpreadsheetSelectionModel is used and
   * configured with the
   * <a href="#!/api/Ext.grid.selection.SpreadsheetModel-cfg-extensible" rel="Ext.grid.selection.SpreadsheetModel-cfg-extensible" class="docClass">extensible</a> config.
   * @see ext.panel.TablePanel
   * @eventType onSelectionExtenderDrag
   * /
  public static const SELECTION_EXTENDER_DRAG:String = "onSelectionExtenderDrag";

  public*/
    function TablePanel_An_extensionEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The owning grid.
   * /
  public native function get grid():TablePanel;

  /**
   * object which encapsulates a contiguous selection block.
   * /
  public native function get An():Selection;

  /**
   * An object describing the type and size of extension.
   * <ul>
   *   <li><code>type</code> : String
   * <code>"rows"</code> or <code>"columns"</code>
   *   </li>
   *   <li><code>start</code> : ext.grid.CellContext
   * The start (top left) cell of the extension area.
   *   </li>
   *   <li><code>end</code> : ext.grid.CellContext
   * The end (bottom right) cell of the extension area.
   *   </li>
   *   <li><code>columns</code> : Number (optional)
   * The number of columns extended (-ve means on the left side).
   *   </li>
   *   <li><code>rows</code> : Number (optional)
   * The number of rows extended (-ve means on the top side).
   *   </li>
   * </ul>
   * /
  public native function get extension():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_An_extensionEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_SELECTION_EXTEND: "onBeforeSelectionExtend",
            SELECTION_EXTENDER_DRAG: "onSelectionExtenderDrag",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_columnEvent", function(TablePanel_columnEvent) {
    /*package ext.panel.events {
import ext.grid.GridPanel;
import ext.grid.column.Column;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_columnEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_columnEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "column",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a column is locked.
   * @see ext.panel.TablePanel
   * @eventType onLockColumn
   * /
  public static const LOCK_COLUMN:String = "onLockColumn";
  /**
   * "Fires when a column is unlocked.
   * @see ext.panel.TablePanel
   * @eventType onUnlockColumn
   * /
  public static const UNLOCK_COLUMN:String = "onUnlockColumn";

  public*/
    function TablePanel_columnEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The gridpanel.
   * /
  public native function get source():GridPanel;

  /**
   * The column being locked.
   * /
  public native function get column():Column;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_columnEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            LOCK_COLUMN: "onLockColumn",
            UNLOCK_COLUMN: "onUnlockColumn",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_ctEvent", function(TablePanel_ctEvent) {
    /*package ext.panel.events {
import ext.grid.header.HeaderContainer;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_ctEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_ctEvent.__PARAMETER_SEQUENCE__ = ([
            "ct",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired after the columns change in any way, when a column has been hidden or shown, or when a column
   * is added to or removed from this header container.
   * @see ext.panel.TablePanel
   * @eventType onColumnsChanged
   * /
  public static const COLUMNS_CHANGED:String = "onColumnsChanged";

  public*/
    function TablePanel_ctEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The grid's header Container which encapsulates all column headers.
   * /
  public native function get ct():HeaderContainer;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_ctEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            COLUMNS_CHANGED: "onColumnsChanged",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_ct_columnEvent", function(TablePanel_ct_columnEvent) {
    /*package ext.panel.events {
import ext.grid.column.Column;
import ext.grid.header.HeaderContainer;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_ct_columnEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_ct_columnEvent.__PARAMETER_SEQUENCE__ = ([
            "ct",
            "column",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @see ext.panel.TablePanel
   * @eventType onColumnHide
   * /
  public static const COLUMN_HIDE:String = "onColumnHide";
  /**
   * "
   * @see ext.panel.TablePanel
   * @eventType onColumnsHow
   * /
  public static const COLUMNS_HOW:String = "onColumnsHow";

  public*/
    function TablePanel_ct_columnEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The grid's header Container which encapsulates all column headers.
   * /
  public native function get ct():HeaderContainer;

  /**
   * The Column header Component which provides the column definition
   * /
  public native function get column():Column;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_ct_columnEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            COLUMN_HIDE: "onColumnHide",
            COLUMNS_HOW: "onColumnsHow",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_ct_column_directionEvent", function(TablePanel_ct_column_directionEvent) {
    /*package ext.panel.events {
import ext.grid.column.Column;
import ext.grid.header.HeaderContainer;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_ct_column_directionEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_ct_column_directionEvent.__PARAMETER_SEQUENCE__ = ([
            "ct",
            "column",
            "direction",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @see ext.panel.TablePanel
   * @eventType onSortChange
   * /
  public static const SORT_CHANGE:String = "onSortChange";

  public*/
    function TablePanel_ct_column_directionEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The grid's header Container which encapsulates all column headers.
   * /
  public native function get ct():HeaderContainer;

  /**
   * The Column header Component which provides the column definition
   * /
  public native function get column():Column;

  public native function get direction():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_ct_column_directionEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SORT_CHANGE: "onSortChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_ct_column_e_tEvent", function(TablePanel_ct_column_e_tEvent) {
    /*package ext.panel.events {
import ext.event.Event;
import ext.grid.column.Column;
import ext.grid.header.HeaderContainer;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_ct_column_e_tEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_ct_column_e_tEvent.__PARAMETER_SEQUENCE__ = ([
            "ct",
            "column",
            "e",
            "t",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @see ext.panel.TablePanel
   * @eventType onHeaderClick
   * /
  public static const HEADER_CLICK:String = "onHeaderClick";
  /**
   * "
   * @see ext.panel.TablePanel
   * @eventType onHeaderContextMenu
   * /
  public static const HEADER_CONTEXT_MENU:String = "onHeaderContextMenu";
  /**
   * "
   * @see ext.panel.TablePanel
   * @eventType onHeaderTriggerClick
   * /
  public static const HEADER_TRIGGER_CLICK:String = "onHeaderTriggerClick";

  public*/
    function TablePanel_ct_column_e_tEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The grid's header Container which encapsulates all column headers.
   * /
  public native function get ct():HeaderContainer;

  /**
   * The Column header Component which provides the column definition
   * /
  public native function get column():Column;

  public native function get e():Event;

  public native function get t():HTMLElement;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_ct_column_e_tEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            HEADER_CLICK: "onHeaderClick",
            HEADER_CONTEXT_MENU: "onHeaderContextMenu",
            HEADER_TRIGGER_CLICK: "onHeaderTriggerClick",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_ct_column_fromIdx_toIdxEvent", function(TablePanel_ct_column_fromIdx_toIdxEvent) {
    /*package ext.panel.events {
import ext.grid.column.Column;
import ext.grid.header.HeaderContainer;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_ct_column_fromIdx_toIdxEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_ct_column_fromIdx_toIdxEvent.__PARAMETER_SEQUENCE__ = ([
            "ct",
            "column",
            "fromIdx",
            "toIdx",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @see ext.panel.TablePanel
   * @eventType onColumnMove
   * /
  public static const COLUMN_MOVE:String = "onColumnMove";

  public*/
    function TablePanel_ct_column_fromIdx_toIdxEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The grid's header Container which encapsulates all column headers.
   * /
  public native function get ct():HeaderContainer;

  /**
   * The Column header Component which provides the column definition
   * /
  public native function get column():Column;

  public native function get fromIdx():Number;

  public native function get toIdx():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_ct_column_fromIdx_toIdxEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            COLUMN_MOVE: "onColumnMove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_ct_column_widthEvent", function(TablePanel_ct_column_widthEvent) {
    /*package ext.panel.events {
import ext.grid.column.Column;
import ext.grid.header.HeaderContainer;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_ct_column_widthEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_ct_column_widthEvent.__PARAMETER_SEQUENCE__ = ([
            "ct",
            "column",
            "width",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "
   * @see ext.panel.TablePanel
   * @eventType onColumnResize
   * /
  public static const COLUMN_RESIZE:String = "onColumnResize";

  public*/
    function TablePanel_ct_column_widthEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The grid's header Container which encapsulates all column headers.
   * /
  public native function get ct():HeaderContainer;

  /**
   * The Column header Component which provides the column definition
   * /
  public native function get column():Column;

  public native function get width():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_ct_column_widthEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            COLUMN_RESIZE: "onColumnResize",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_eEvent", function(TablePanel_eEvent) {
    /*package ext.panel.events {
import ext.event.Event;
import ext.view.DataView;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the click event on the container is processed. Returns false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeContainerClick
   * /
  public static const BEFORE_CONTAINER_CLICK:String = "onBeforeContainerClick";
  /**
   * "Fires before the contextmenu event on the container is processed. Returns false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeContainerContextMenu
   * /
  public static const BEFORE_CONTAINER_CONTEXT_MENU:String = "onBeforeContainerContextMenu";
  /**
   * "Fires before the dblclick event on the container is processed. Returns false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeContainerDblclick
   * /
  public static const BEFORE_CONTAINER_DBLCLICK:String = "onBeforeContainerDblclick";
  /**
   * "Fires before the keydown event on the container is processed. Returns false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeContainerKeyDown
   * /
  public static const BEFORE_CONTAINER_KEY_DOWN:String = "onBeforeContainerKeyDown";
  /**
   * "Fires before the keypress event on the container is processed. Returns false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeContainerKeypress
   * /
  public static const BEFORE_CONTAINER_KEYPRESS:String = "onBeforeContainerKeypress";
  /**
   * "Fires before the keyup event on the container is processed. Returns false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeContainerKeyUp
   * /
  public static const BEFORE_CONTAINER_KEY_UP:String = "onBeforeContainerKeyUp";
  /**
   * "Fires before the mousedown event on the container is processed. Returns false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeContainerMouseDown
   * /
  public static const BEFORE_CONTAINER_MOUSE_DOWN:String = "onBeforeContainerMouseDown";
  /**
   * "Fires before the mouseout event on the container is processed. Returns false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeContainerMouseOut
   * /
  public static const BEFORE_CONTAINER_MOUSE_OUT:String = "onBeforeContainerMouseOut";
  /**
   * "Fires before the mouseover event on the container is processed. Returns false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeContainerMouseOver
   * /
  public static const BEFORE_CONTAINER_MOUSE_OVER:String = "onBeforeContainerMouseOver";
  /**
   * "Fires before the mouseup event on the container is processed. Returns false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeContainerMouseUp
   * /
  public static const BEFORE_CONTAINER_MOUSE_UP:String = "onBeforeContainerMouseUp";
  /**
   * "Fires when the container is clicked.
   * @see ext.panel.TablePanel
   * @eventType onContainerClick
   * /
  public static const CONTAINER_CLICK:String = "onContainerClick";
  /**
   * "Fires when the container is right clicked.
   * @see ext.panel.TablePanel
   * @eventType onContainerContextMenu
   * /
  public static const CONTAINER_CONTEXT_MENU:String = "onContainerContextMenu";
  /**
   * "Fires when the container is double clicked.
   * @see ext.panel.TablePanel
   * @eventType onContainerDblclick
   * /
  public static const CONTAINER_DBLCLICK:String = "onContainerDblclick";
  /**
   * "Fires when a key is pressed down while the container is focused, and no item is currently selected.
   * @see ext.panel.TablePanel
   * @eventType onContainerKeyDown
   * /
  public static const CONTAINER_KEY_DOWN:String = "onContainerKeyDown";
  /**
   * "Fires when a key is pressed while the container is focused, and no item is currently selected.
   * @see ext.panel.TablePanel
   * @eventType onContainerKeypress
   * /
  public static const CONTAINER_KEYPRESS:String = "onContainerKeypress";
  /**
   * "Fires when a key is released while the container is focused, and no item is currently selected.
   * @see ext.panel.TablePanel
   * @eventType onContainerKeyUp
   * /
  public static const CONTAINER_KEY_UP:String = "onContainerKeyUp";
  /**
   * "Fires when there is a mousedown on the container
   * @see ext.panel.TablePanel
   * @eventType onContainerMouseDown
   * /
  public static const CONTAINER_MOUSE_DOWN:String = "onContainerMouseDown";
  /**
   * "Fires when you move the mouse out of the container.
   * @see ext.panel.TablePanel
   * @eventType onContainerMouseOut
   * /
  public static const CONTAINER_MOUSE_OUT:String = "onContainerMouseOut";
  /**
   * "Fires when you move the mouse over the container.
   * @see ext.panel.TablePanel
   * @eventType onContainerMouseOver
   * /
  public static const CONTAINER_MOUSE_OVER:String = "onContainerMouseOver";
  /**
   * "Fires when there is a mouseup on the container
   * @see ext.panel.TablePanel
   * @eventType onContainerMouseUp
   * /
  public static const CONTAINER_MOUSE_UP:String = "onContainerMouseUp";

  public*/
    function TablePanel_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():DataView;

  /**
   * The raw event object
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_CONTAINER_CLICK: "onBeforeContainerClick",
            BEFORE_CONTAINER_CONTEXT_MENU: "onBeforeContainerContextMenu",
            BEFORE_CONTAINER_DBLCLICK: "onBeforeContainerDblclick",
            BEFORE_CONTAINER_KEY_DOWN: "onBeforeContainerKeyDown",
            BEFORE_CONTAINER_KEYPRESS: "onBeforeContainerKeypress",
            BEFORE_CONTAINER_KEY_UP: "onBeforeContainerKeyUp",
            BEFORE_CONTAINER_MOUSE_DOWN: "onBeforeContainerMouseDown",
            BEFORE_CONTAINER_MOUSE_OUT: "onBeforeContainerMouseOut",
            BEFORE_CONTAINER_MOUSE_OVER: "onBeforeContainerMouseOver",
            BEFORE_CONTAINER_MOUSE_UP: "onBeforeContainerMouseUp",
            CONTAINER_CLICK: "onContainerClick",
            CONTAINER_CONTEXT_MENU: "onContainerContextMenu",
            CONTAINER_DBLCLICK: "onContainerDblclick",
            CONTAINER_KEY_DOWN: "onContainerKeyDown",
            CONTAINER_KEYPRESS: "onContainerKeypress",
            CONTAINER_KEY_UP: "onContainerKeyUp",
            CONTAINER_MOUSE_DOWN: "onContainerMouseDown",
            CONTAINER_MOUSE_OUT: "onContainerMouseOut",
            CONTAINER_MOUSE_OVER: "onContainerMouseOver",
            CONTAINER_MOUSE_UP: "onContainerMouseUp",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_keyEvent_prevRow_nextRow_forwardEvent", function(TablePanel_keyEvent_prevRow_nextRow_forwardEvent) {
    /*package ext.panel.events {
import ext.event.Event;
import ext.view.TableView;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_keyEvent_prevRow_nextRow_forwardEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_keyEvent_prevRow_nextRow_forwardEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "keyEvent",
            "prevRow",
            "nextRow",
            "forward",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when View is asked to exit Actionable mode in the current row,
   * and proceed to the previous/next row. If the handler returns <code>false</code>,
   * View processing is aborted.
   * @see ext.panel.TablePanel
   * @eventType onBeforeRowExit
   * /
  public static const BEFORE_ROW_EXIT:String = "onBeforeRowExit";

  public*/
    function TablePanel_keyEvent_prevRow_nextRow_forwardEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():TableView;

  /**
   * The key event that caused navigation.
   * /
  public native function get keyEvent():Event;

  /**
   * Currently active table row.
   * /
  public native function get prevRow():HTMLElement;

  /**
   * Table row that is going to be focused and activated.
   * /
  public native function get nextRow():HTMLElement;

  /**
   * <code>true</code> if we're navigating forward (Tab), <code>false</code> if
   * navigating backward (Shift-Tab).
   * @cancelable
   * /
  public native function get forward():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_keyEvent_prevRow_nextRow_forwardEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_ROW_EXIT: "onBeforeRowExit",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_lockedColumns_normalColumnsEvent", function(TablePanel_lockedColumns_normalColumnsEvent) {
    /*package ext.panel.events {
import net.jangaroo.ext.FlExtEvent;

public class TablePanel_lockedColumns_normalColumnsEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_lockedColumns_normalColumnsEvent.__PARAMETER_SEQUENCE__ = ([
            "lockedColumns",
            "normalColumns",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the configured (or <strong>reconfigured</strong>) column set is split into two depending on the <a href="#!/api/Ext.grid.column.Column-cfg-locked" rel="Ext.grid.column.Column-cfg-locked" class="docClass">locked</a> flag.
   * @see ext.panel.TablePanel
   * @eventType onProcessColumns
   * /
  public static const PROCESS_COLUMNS:String = "onProcessColumns";

  public*/
    function TablePanel_lockedColumns_normalColumnsEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The locked columns.
   * /
  public native function get lockedColumns():Array;

  /**
   * The normal columns.
   * /
  public native function get normalColumns():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_lockedColumns_normalColumnsEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            PROCESS_COLUMNS: "onProcessColumns",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_menu_headerCtEvent", function(TablePanel_menu_headerCtEvent) {
    /*package ext.panel.events {
import ext.grid.header.HeaderContainer;
import ext.menu.Menu;
import ext.panel.TablePanel;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_menu_headerCtEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_menu_headerCtEvent.__PARAMETER_SEQUENCE__ = ([
            "grid",
            "menu",
            "headerCt",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired immediately after the column header menu is created.
   * @see ext.panel.TablePanel
   * @eventType onHeaderMenuCreate
   * /
  public static const HEADER_MENU_CREATE:String = "onHeaderMenuCreate";

  public*/
    function TablePanel_menu_headerCtEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This grid instance
   * /
  public native function get grid():TablePanel;

  /**
   * The Menu that was created
   * /
  public native function get menu():Menu;

  /**
   * This header container
   * /
  public native function get headerCt():HeaderContainer;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_menu_headerCtEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            HEADER_MENU_CREATE: "onHeaderMenuCreate",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_record_indexEvent", function(TablePanel_record_indexEvent) {
    /*package ext.panel.events {
import ext.data.Model;
import ext.selection.RowSelectionModel;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_record_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_record_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "record",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired before a record is deselected. If any listener returns false, the
   * deselection is cancelled.
   * @see ext.panel.TablePanel
   * @eventType onBeforeDeselect
   * /
  public static const BEFORE_DESELECT:String = "onBeforeDeselect";
  /**
   * "Fired before a record is selected. If any listener returns false, the
   * selection is cancelled.
   * @see ext.panel.TablePanel
   * @eventType onBeforeSelect
   * /
  public static const BEFORE_SELECT:String = "onBeforeSelect";
  /**
   * "Fired after a record is deselected
   * @see ext.panel.TablePanel
   * @eventType onDeselect
   * /
  public static const DESELECT:String = "onDeselect";
  /**
   * "Fired after a record is selected
   * @see ext.panel.TablePanel
   * @eventType onSelect
   * /
  public static const SELECT:String = "onSelect";

  public*/
    function TablePanel_record_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():RowSelectionModel;

  /**
   * The deselected record
   * /
  public native function get record():Model;

  /**
   * The row index deselected
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_record_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_DESELECT: "onBeforeDeselect",
            BEFORE_SELECT: "onBeforeSelect",
            DESELECT: "onDeselect",
            SELECT: "onSelect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_record_item_index_eEvent", function(TablePanel_record_item_index_eEvent) {
    /*package ext.panel.events {
import ext.data.Model;
import ext.event.Event;
import ext.view.DataView;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_record_item_index_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_record_item_index_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "record",
            "item",
            "index",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the click event on an item is processed. Return false to cancel the
   * default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeItemClick
   * /
  public static const BEFORE_ITEM_CLICK:String = "onBeforeItemClick";
  /**
   * "Fires before the contextmenu event on an item is processed. Return false to
   * cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeItemContextMenu
   * /
  public static const BEFORE_ITEM_CONTEXT_MENU:String = "onBeforeItemContextMenu";
  /**
   * "Fires before the dblclick event on an item is processed. Return false to cancel
   * the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeItemDblclick
   * /
  public static const BEFORE_ITEM_DBLCLICK:String = "onBeforeItemDblclick";
  /**
   * "Fires before the keydown event on an item is processed. Return false to cancel
   * the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeItemKeyDown
   * /
  public static const BEFORE_ITEM_KEY_DOWN:String = "onBeforeItemKeyDown";
  /**
   * "Fires before the keypress event on an item is processed. Return false to cancel
   * the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeItemKeypress
   * /
  public static const BEFORE_ITEM_KEYPRESS:String = "onBeforeItemKeypress";
  /**
   * "Fires before the keyup event on an item is processed. Return false to cancel the
   * default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeItemKeyUp
   * /
  public static const BEFORE_ITEM_KEY_UP:String = "onBeforeItemKeyUp";
  /**
   * "Fires before the longpress event on an item is processed. Return false to
   * cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeItemLongPress
   * /
  public static const BEFORE_ITEM_LONG_PRESS:String = "onBeforeItemLongPress";
  /**
   * "Fires before the mousedown event on an item is processed. Return false to cancel
   * the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeItemMouseDown
   * /
  public static const BEFORE_ITEM_MOUSE_DOWN:String = "onBeforeItemMouseDown";
  /**
   * "Fires before the mouseenter event on an item is processed. Return false to cancel
   * the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeItemMouseEnter
   * /
  public static const BEFORE_ITEM_MOUSE_ENTER:String = "onBeforeItemMouseEnter";
  /**
   * "Fires before the mouseleave event on an item is processed. Return false to cancel
   * the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeItemMouseLeave
   * /
  public static const BEFORE_ITEM_MOUSE_LEAVE:String = "onBeforeItemMouseLeave";
  /**
   * "Fires before the mouseup event on an item is processed. Return false to cancel
   * the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeItemMouseUp
   * /
  public static const BEFORE_ITEM_MOUSE_UP:String = "onBeforeItemMouseUp";
  /**
   * "Fires when an item is clicked.
   * @see ext.panel.TablePanel
   * @eventType onItemClick
   * /
  public static const ITEM_CLICK:String = "onItemClick";
  /**
   * "Fires when an item is right clicked.
   * @see ext.panel.TablePanel
   * @eventType onItemContextMenu
   * /
  public static const ITEM_CONTEXT_MENU:String = "onItemContextMenu";
  /**
   * "Fires when an item is double clicked.
   * @see ext.panel.TablePanel
   * @eventType onItemDblclick
   * /
  public static const ITEM_DBLCLICK:String = "onItemDblclick";
  /**
   * "Fires when a key is pressed down while an item is currently selected.
   * @see ext.panel.TablePanel
   * @eventType onItemKeyDown
   * /
  public static const ITEM_KEY_DOWN:String = "onItemKeyDown";
  /**
   * "Fires when a key is pressed while an item is currently selected.
   * @see ext.panel.TablePanel
   * @eventType onItemKeypress
   * /
  public static const ITEM_KEYPRESS:String = "onItemKeypress";
  /**
   * "Fires when a key is released while an item is currently selected.
   * @see ext.panel.TablePanel
   * @eventType onItemKeyUp
   * /
  public static const ITEM_KEY_UP:String = "onItemKeyUp";
  /**
   * "Fires on a longpress event on an item.
   * @see ext.panel.TablePanel
   * @eventType onItemLongPress
   * /
  public static const ITEM_LONG_PRESS:String = "onItemLongPress";
  /**
   * "Fires when there is a mouse down on an item
   * @see ext.panel.TablePanel
   * @eventType onItemMouseDown
   * /
  public static const ITEM_MOUSE_DOWN:String = "onItemMouseDown";
  /**
   * "Fires when the mouse enters an item.
   * @see ext.panel.TablePanel
   * @eventType onItemMouseEnter
   * /
  public static const ITEM_MOUSE_ENTER:String = "onItemMouseEnter";
  /**
   * "Fires when the mouse leaves an item.
   * @see ext.panel.TablePanel
   * @eventType onItemMouseLeave
   * /
  public static const ITEM_MOUSE_LEAVE:String = "onItemMouseLeave";
  /**
   * "Fires when there is a mouse up on an item
   * @see ext.panel.TablePanel
   * @eventType onItemMouseUp
   * /
  public static const ITEM_MOUSE_UP:String = "onItemMouseUp";

  public*/
    function TablePanel_record_item_index_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():DataView;

  /**
   * The record that belongs to the item
   * /
  public native function get record():Model;

  /**
   * The item's element
   * /
  public native function get item():HTMLElement;

  /**
   * The item's index
   * /
  public native function get index():Number;

  /**
   * The raw event object
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_record_item_index_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_ITEM_CLICK: "onBeforeItemClick",
            BEFORE_ITEM_CONTEXT_MENU: "onBeforeItemContextMenu",
            BEFORE_ITEM_DBLCLICK: "onBeforeItemDblclick",
            BEFORE_ITEM_KEY_DOWN: "onBeforeItemKeyDown",
            BEFORE_ITEM_KEYPRESS: "onBeforeItemKeypress",
            BEFORE_ITEM_KEY_UP: "onBeforeItemKeyUp",
            BEFORE_ITEM_LONG_PRESS: "onBeforeItemLongPress",
            BEFORE_ITEM_MOUSE_DOWN: "onBeforeItemMouseDown",
            BEFORE_ITEM_MOUSE_ENTER: "onBeforeItemMouseEnter",
            BEFORE_ITEM_MOUSE_LEAVE: "onBeforeItemMouseLeave",
            BEFORE_ITEM_MOUSE_UP: "onBeforeItemMouseUp",
            ITEM_CLICK: "onItemClick",
            ITEM_CONTEXT_MENU: "onItemContextMenu",
            ITEM_DBLCLICK: "onItemDblclick",
            ITEM_KEY_DOWN: "onItemKeyDown",
            ITEM_KEYPRESS: "onItemKeypress",
            ITEM_KEY_UP: "onItemKeyUp",
            ITEM_LONG_PRESS: "onItemLongPress",
            ITEM_MOUSE_DOWN: "onItemMouseDown",
            ITEM_MOUSE_ENTER: "onItemMouseEnter",
            ITEM_MOUSE_LEAVE: "onItemMouseLeave",
            ITEM_MOUSE_UP: "onItemMouseUp",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_record_tr_rowIndex_eEvent", function(TablePanel_record_tr_rowIndex_eEvent) {
    /*package ext.panel.events {
import ext.data.Model;
import ext.event.Event;
import ext.view.TableView;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_record_tr_rowIndex_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_record_tr_rowIndex_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "record",
            "tr",
            "rowIndex",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when table cell is clicked.
   * @see ext.panel.TablePanel
   * @eventType onRowClick
   * /
  public static const ROW_CLICK:String = "onRowClick";
  /**
   * "Fired when table cell is right clicked.
   * @see ext.panel.TablePanel
   * @eventType onRowContextMenu
   * /
  public static const ROW_CONTEXT_MENU:String = "onRowContextMenu";
  /**
   * "Fired when table cell is double clicked.
   * @see ext.panel.TablePanel
   * @eventType onRowDblclick
   * /
  public static const ROW_DBLCLICK:String = "onRowDblclick";
  /**
   * "Fired when the keydown event is captured on the cell.
   * @see ext.panel.TablePanel
   * @eventType onRowKeyDown
   * /
  public static const ROW_KEY_DOWN:String = "onRowKeyDown";
  /**
   * "Fired when the mousedown event is captured on the cell.
   * @see ext.panel.TablePanel
   * @eventType onRowMouseDown
   * /
  public static const ROW_MOUSE_DOWN:String = "onRowMouseDown";
  /**
   * "Fired when the mouseup event is captured on the cell.
   * @see ext.panel.TablePanel
   * @eventType onRowMouseUp
   * /
  public static const ROW_MOUSE_UP:String = "onRowMouseUp";

  public*/
    function TablePanel_record_tr_rowIndex_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():TableView;

  public native function get record():Model;

  /**
   * The TR element for the cell.
   * /
  public native function get tr():HTMLElement;

  public native function get rowIndex():Number;

  /**
   *
   * <ul>
   *   <li><code>position</code> : ext.grid.CellContext
   * A CellContext object which defines the target cell.
   *   </li>
   * </ul>
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_record_tr_rowIndex_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ROW_CLICK: "onRowClick",
            ROW_CONTEXT_MENU: "onRowContextMenu",
            ROW_DBLCLICK: "onRowDblclick",
            ROW_KEY_DOWN: "onRowKeyDown",
            ROW_MOUSE_DOWN: "onRowMouseDown",
            ROW_MOUSE_UP: "onRowMouseUp",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_records_successful_operationEvent", function(TablePanel_records_successful_operationEvent) {
    /*package ext.panel.events {
import ext.data.Store;
import ext.data.operation.ReadOperation;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_records_successful_operationEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_records_successful_operationEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "records",
            "successful",
            "operation",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires whenever the store reads data from a remote data source.
   * @see ext.panel.TablePanel
   * @eventType onLoad
   * /
  public static const LOAD:String = "onLoad";

  public*/
    function TablePanel_records_successful_operationEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Store;

  /**
   * An array of records
   * /
  public native function get records():Array;

  /**
   * True if the operation was successful.
   * /
  public native function get successful():Boolean;

  /**
   * The
   * <a href="#!/api/Ext.data.operation.Read" rel="Ext.data.operation.Read" class="docClass">Operation</a> object that was used in the data
   * load call
   * /
  public native function get operation():ReadOperation;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_records_successful_operationEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            LOAD: "onLoad",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_selectedEvent", function(TablePanel_selectedEvent) {
    /*package ext.panel.events {
import ext.selection.SelectionModel;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_selectedEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_selectedEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "selected",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired after a selection change has occurred
   * @see ext.panel.TablePanel
   * @eventType onSelectionChange
   * /
  public static const SELECTION_CHANGE:String = "onSelectionChange";

  public*/
    function TablePanel_selectedEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():SelectionModel;

  /**
   * The selected records
   * /
  public native function get selected():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_selectedEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SELECTION_CHANGE: "onSelectionChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_store_filtersEvent", function(TablePanel_store_filtersEvent) {
    /*package ext.panel.events {
import ext.data.Store;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_store_filtersEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_store_filtersEvent.__PARAMETER_SEQUENCE__ = ([
            "store",
            "filters",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired whenever the filter set changes.
   * @see ext.panel.TablePanel
   * @eventType onFilterChange
   * /
  public static const FILTER_CHANGE:String = "onFilterChange";

  public*/
    function TablePanel_store_filtersEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The store.
   * /
  public native function get store():Store;

  /**
   * The array of Filter objects.
   * /
  public native function get filters():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_store_filtersEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            FILTER_CHANGE: "onFilterChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_store_grouperEvent", function(TablePanel_store_grouperEvent) {
    /*package ext.panel.events {
import ext.data.Store;
import ext.util.Grouper;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_store_grouperEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_store_grouperEvent.__PARAMETER_SEQUENCE__ = ([
            "store",
            "grouper",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired whenever the grouping in the grid changes.
   * @see ext.panel.TablePanel
   * @eventType onGroupChange
   * /
  public static const GROUP_CHANGE:String = "onGroupChange";

  public*/
    function TablePanel_store_grouperEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The store.
   * /
  public native function get store():Store;

  /**
   * The grouper object.
   * /
  public native function get grouper():Grouper;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_store_grouperEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            GROUP_CHANGE: "onGroupChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_store_operationEvent", function(TablePanel_store_operationEvent) {
    /*package ext.panel.events {
import ext.data.Store;
import ext.data.operation.Operation;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_store_operationEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_store_operationEvent.__PARAMETER_SEQUENCE__ = ([
            "store",
            "operation",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a request is made for a new data object. If the beforeload handler returns false the load
   * action will be canceled.
   * @see ext.panel.TablePanel
   * @eventType onBeforeLoad
   * /
  public static const BEFORE_LOAD:String = "onBeforeLoad";

  public*/
    function TablePanel_store_operationEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This Store
   * /
  public native function get store():Store;

  /**
   * The <a href="#!/api/Ext.data.operation.Operation" rel="Ext.data.operation.Operation" class="docClass">Ext.data.operation.Operation</a> object that will be passed to the Proxy to
   * load the Store
   * /
  public native function get operation():Operation;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_store_operationEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_LOAD: "onBeforeLoad",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_td_cellIndex_record_tr_rowIndex_eEvent", function(TablePanel_td_cellIndex_record_tr_rowIndex_eEvent) {
    /*package ext.panel.events {
import ext.data.Model;
import ext.event.Event;
import ext.view.TableView;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_td_cellIndex_record_tr_rowIndex_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_td_cellIndex_record_tr_rowIndex_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "td",
            "cellIndex",
            "record",
            "tr",
            "rowIndex",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired before the cell click is processed. Return false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeCellClick
   * /
  public static const BEFORE_CELL_CLICK:String = "onBeforeCellClick";
  /**
   * "Fired before the cell right click is processed. Return false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeCellContextMenu
   * /
  public static const BEFORE_CELL_CONTEXT_MENU:String = "onBeforeCellContextMenu";
  /**
   * "Fired before the cell double click is processed. Return false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeCellDblclick
   * /
  public static const BEFORE_CELL_DBLCLICK:String = "onBeforeCellDblclick";
  /**
   * "Fired before the cell key down is processed. Return false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeCellKeyDown
   * /
  public static const BEFORE_CELL_KEY_DOWN:String = "onBeforeCellKeyDown";
  /**
   * "Fired before the cell mouse down is processed. Return false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeCellMouseDown
   * /
  public static const BEFORE_CELL_MOUSE_DOWN:String = "onBeforeCellMouseDown";
  /**
   * "Fired before the cell mouse up is processed. Return false to cancel the default action.
   * @see ext.panel.TablePanel
   * @eventType onBeforeCellMouseUp
   * /
  public static const BEFORE_CELL_MOUSE_UP:String = "onBeforeCellMouseUp";
  /**
   * "Fired when table cell is clicked.
   * @see ext.panel.TablePanel
   * @eventType onCellClick
   * /
  public static const CELL_CLICK:String = "onCellClick";
  /**
   * "Fired when table cell is right clicked.
   * @see ext.panel.TablePanel
   * @eventType onCellContextMenu
   * /
  public static const CELL_CONTEXT_MENU:String = "onCellContextMenu";
  /**
   * "Fired when table cell is double clicked.
   * @see ext.panel.TablePanel
   * @eventType onCellDblclick
   * /
  public static const CELL_DBLCLICK:String = "onCellDblclick";
  /**
   * "Fired when the keydown event is captured on the cell.
   * @see ext.panel.TablePanel
   * @eventType onCellKeyDown
   * /
  public static const CELL_KEY_DOWN:String = "onCellKeyDown";
  /**
   * "Fired when the mousedown event is captured on the cell.
   * @see ext.panel.TablePanel
   * @eventType onCellMouseDown
   * /
  public static const CELL_MOUSE_DOWN:String = "onCellMouseDown";
  /**
   * "Fired when the mouseup event is captured on the cell.
   * @see ext.panel.TablePanel
   * @eventType onCellMouseUp
   * /
  public static const CELL_MOUSE_UP:String = "onCellMouseUp";

  public*/
    function TablePanel_td_cellIndex_record_tr_rowIndex_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():TableView;

  /**
   * The TD element for the cell.
   * /
  public native function get td():HTMLElement;

  public native function get cellIndex():Number;

  public native function get record():Model;

  /**
   * The TR element for the cell.
   * /
  public native function get tr():HTMLElement;

  public native function get rowIndex():Number;

  /**
   *
   * <ul>
   *   <li><code>position</code> : ext.grid.CellContext
   * A CellContext object which defines the target cell.
   *   </li>
   * </ul>
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_td_cellIndex_record_tr_rowIndex_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_CELL_CLICK: "onBeforeCellClick",
            BEFORE_CELL_CONTEXT_MENU: "onBeforeCellContextMenu",
            BEFORE_CELL_DBLCLICK: "onBeforeCellDblclick",
            BEFORE_CELL_KEY_DOWN: "onBeforeCellKeyDown",
            BEFORE_CELL_MOUSE_DOWN: "onBeforeCellMouseDown",
            BEFORE_CELL_MOUSE_UP: "onBeforeCellMouseUp",
            CELL_CLICK: "onCellClick",
            CELL_CONTEXT_MENU: "onCellContextMenu",
            CELL_DBLCLICK: "onCellDblclick",
            CELL_KEY_DOWN: "onCellKeyDown",
            CELL_MOUSE_DOWN: "onCellMouseDown",
            CELL_MOUSE_UP: "onCellMouseUp",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.TablePanel_view_rowBodyEl_eEvent", function(TablePanel_view_rowBodyEl_eEvent) {
    /*package ext.panel.events {
import ext.event.Event;
import ext.view.DataView;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class TablePanel_view_rowBodyEl_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TablePanel_view_rowBodyEl_eEvent.__PARAMETER_SEQUENCE__ = ([
            "view",
            "rowBodyEl",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the click event on a row body element is processed. Return false to
   * cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onBeforeRowBodyClick
   * /
  public static const BEFORE_ROW_BODY_CLICK:String = "onBeforeRowBodyClick";
  /**
   * "Fires before the contextmenu event on a row body element is processed. Return
   * false to cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onBeforeRowBodyContextMenu
   * /
  public static const BEFORE_ROW_BODY_CONTEXT_MENU:String = "onBeforeRowBodyContextMenu";
  /**
   * "Fires before the dblclick event on a row body element is processed. Return false
   * to cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onBeforeRowBodyDblclick
   * /
  public static const BEFORE_ROW_BODY_DBLCLICK:String = "onBeforeRowBodyDblclick";
  /**
   * "Fires before the keydown event on a row body element is processed. Return false
   * to cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onBeforeRowBodyKeyDown
   * /
  public static const BEFORE_ROW_BODY_KEY_DOWN:String = "onBeforeRowBodyKeyDown";
  /**
   * "Fires before the keypress event on a row body element is processed. Return false
   * to cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onBeforeRowBodyKeypress
   * /
  public static const BEFORE_ROW_BODY_KEYPRESS:String = "onBeforeRowBodyKeypress";
  /**
   * "Fires before the keyup event on a row body element is processed. Return false to
   * cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onBeforeRowBodyKeyUp
   * /
  public static const BEFORE_ROW_BODY_KEY_UP:String = "onBeforeRowBodyKeyUp";
  /**
   * "Fires before the longpress event on a row body element is processed. Return
   * false to cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onBeforeRowBodyLongPress
   * /
  public static const BEFORE_ROW_BODY_LONG_PRESS:String = "onBeforeRowBodyLongPress";
  /**
   * "Fires before the mousedown event on a row body element is processed. Return false
   * to cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onBeforeRowBodyMouseDown
   * /
  public static const BEFORE_ROW_BODY_MOUSE_DOWN:String = "onBeforeRowBodyMouseDown";
  /**
   * "Fires before the mouseup event on a row body element is processed. Return false
   * to cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onBeforeRowBodyMouseUp
   * /
  public static const BEFORE_ROW_BODY_MOUSE_UP:String = "onBeforeRowBodyMouseUp";
  /**
   * "Fires when a row body element is clicked
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onRowBodyClick
   * /
  public static const ROW_BODY_CLICK:String = "onRowBodyClick";
  /**
   * "Fires when a row body element is right clicked
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onRowBodyContextMenu
   * /
  public static const ROW_BODY_CONTEXT_MENU:String = "onRowBodyContextMenu";
  /**
   * "Fires when a row body element is double clicked
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onRowBodyDblclick
   * /
  public static const ROW_BODY_DBLCLICK:String = "onRowBodyDblclick";
  /**
   * "Fires when a key is pressed down while a row body element is currently selected
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onRowBodyKeyDown
   * /
  public static const ROW_BODY_KEY_DOWN:String = "onRowBodyKeyDown";
  /**
   * "Fires when a key is pressed while a row body element is currently selected.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onRowBodyKeypress
   * /
  public static const ROW_BODY_KEYPRESS:String = "onRowBodyKeypress";
  /**
   * "Fires when a key is released while a row body element is currently selected
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onRowBodyKeyUp
   * /
  public static const ROW_BODY_KEY_UP:String = "onRowBodyKeyUp";
  /**
   * "Fires on a row body element longpress event
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onRowBodyLongPress
   * /
  public static const ROW_BODY_LONG_PRESS:String = "onRowBodyLongPress";
  /**
   * "Fires when there is a mouse down on a row body element
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onRowBodyMouseDown
   * /
  public static const ROW_BODY_MOUSE_DOWN:String = "onRowBodyMouseDown";
  /**
   * "Fires when there is a mouse up on a row body element
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.panel.TablePanel
   * @eventType onRowBodyMouseUp
   * /
  public static const ROW_BODY_MOUSE_UP:String = "onRowBodyMouseUp";

  public*/
    function TablePanel_view_rowBodyEl_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The rowbody's owning View
   * /
  public native function get view():DataView;

  /**
   * The row body's element
   * /
  public native function get rowBodyEl():HTMLElement;

  /**
   * The raw event object
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TablePanel_view_rowBodyEl_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_ROW_BODY_CLICK: "onBeforeRowBodyClick",
            BEFORE_ROW_BODY_CONTEXT_MENU: "onBeforeRowBodyContextMenu",
            BEFORE_ROW_BODY_DBLCLICK: "onBeforeRowBodyDblclick",
            BEFORE_ROW_BODY_KEY_DOWN: "onBeforeRowBodyKeyDown",
            BEFORE_ROW_BODY_KEYPRESS: "onBeforeRowBodyKeypress",
            BEFORE_ROW_BODY_KEY_UP: "onBeforeRowBodyKeyUp",
            BEFORE_ROW_BODY_LONG_PRESS: "onBeforeRowBodyLongPress",
            BEFORE_ROW_BODY_MOUSE_DOWN: "onBeforeRowBodyMouseDown",
            BEFORE_ROW_BODY_MOUSE_UP: "onBeforeRowBodyMouseUp",
            ROW_BODY_CLICK: "onRowBodyClick",
            ROW_BODY_CONTEXT_MENU: "onRowBodyContextMenu",
            ROW_BODY_DBLCLICK: "onRowBodyDblclick",
            ROW_BODY_KEY_DOWN: "onRowBodyKeyDown",
            ROW_BODY_KEYPRESS: "onRowBodyKeypress",
            ROW_BODY_KEY_UP: "onRowBodyKeyUp",
            ROW_BODY_LONG_PRESS: "onRowBodyLongPress",
            ROW_BODY_MOUSE_DOWN: "onRowBodyMouseDown",
            ROW_BODY_MOUSE_UP: "onRowBodyMouseUp",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.panel.events.Tool_e_ownerEvent", function(Tool_e_ownerEvent) {
    /*package ext.panel.events {
import ext.Component;
import ext.event.Event;
import ext.panel.Tool;

import net.jangaroo.ext.FlExtEvent;

public class Tool_e_ownerEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Tool_e_ownerEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "e",
            "owner",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the tool is clicked
   * @since 5.0.0
   * @see ext.panel.Tool
   * @eventType onClick
   * /
  public static const CLICK:String = "onClick";

  public*/
    function Tool_e_ownerEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Tool;

  /**
   * The event object
   * /
  public native function get e():Event;

  /**
   * The logical owner of the tool. In a typical
   * <code><a href="#!/api/Ext.panel.Panel" rel="Ext.panel.Panel" class="docClass">Ext.panel.Panel</a></code>, this is set to the owning panel. This value comes from the
   * <code>toolOwner</code> config.
   * Note that if the tool handler destroys the tool and/or its owner, the event
   * will not fire.
   * /
  public native function get owner():Component;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Tool_e_ownerEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CLICK: "onClick",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.picker.events.ColorPicker_colorEvent", function(ColorPicker_colorEvent) {
    /*package ext.picker.events {
import ext.picker.ColorPicker;

import net.jangaroo.ext.FlExtEvent;

public class ColorPicker_colorEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ColorPicker_colorEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "color",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a color is selected
   * @see ext.picker.ColorPicker
   * @eventType onSelect
   * /
  public static const SELECT:String = "onSelect";

  public*/
    function ColorPicker_colorEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():ColorPicker;

  /**
   * The 6-digit color hex code (without the # symbol)
   * /
  public native function get color():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ColorPicker_colorEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SELECT: "onSelect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.picker.events.DatePicker_dateEvent", function(DatePicker_dateEvent) {
    /*package ext.picker.events {
import ext.picker.DatePicker;

import net.jangaroo.ext.FlExtEvent;

public class DatePicker_dateEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DatePicker_dateEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "date",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a date is selected
   * @see ext.picker.DatePicker
   * @eventType onSelect
   * /
  public static const SELECT:String = "onSelect";

  public*/
    function DatePicker_dateEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * DatePicker
   * /
  public native function get source():DatePicker;

  /**
   * The selected date
   * /
  public native function get date():Date;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DatePicker_dateEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SELECT: "onSelect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.picker.events.MonthPickerEvent", function(MonthPickerEvent) {
    /*package ext.picker.events {
import ext.picker.MonthPicker;

import net.jangaroo.ext.FlExtEvent;

public class MonthPickerEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        MonthPickerEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the cancel button is pressed.
   * @see ext.picker.MonthPicker
   * @eventType onCancelClick
   * /
  public static const CANCEL_CLICK:String = "onCancelClick";

  public*/
    function MonthPickerEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():MonthPicker;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: MonthPickerEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CANCEL_CLICK: "onCancelClick",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.picker.events.MonthPicker_valueEvent", function(MonthPicker_valueEvent) {
    /*package ext.picker.events {
import ext.picker.MonthPicker;

import net.jangaroo.ext.FlExtEvent;

public class MonthPicker_valueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        MonthPicker_valueEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "value",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a month is clicked.
   * @see ext.picker.MonthPicker
   * @eventType onMonthClick
   * /
  public static const MONTH_CLICK:String = "onMonthClick";
  /**
   * "Fires when a month is clicked.
   * @see ext.picker.MonthPicker
   * @eventType onMonthDblclick
   * /
  public static const MONTH_DBLCLICK:String = "onMonthDblclick";
  /**
   * "Fires when the ok button is pressed.
   * @see ext.picker.MonthPicker
   * @eventType onOkClick
   * /
  public static const OK_CLICK:String = "onOkClick";
  /**
   * "Fires when a month/year is selected.
   * @see ext.picker.MonthPicker
   * @eventType onSelect
   * /
  public static const SELECT:String = "onSelect";
  /**
   * "Fires when a year is clicked.
   * @see ext.picker.MonthPicker
   * @eventType onYearClick
   * /
  public static const YEAR_CLICK:String = "onYearClick";
  /**
   * "Fires when a year is clicked.
   * @see ext.picker.MonthPicker
   * @eventType onYearDblclick
   * /
  public static const YEAR_DBLCLICK:String = "onYearDblclick";

  public*/
    function MonthPicker_valueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():MonthPicker;

  /**
   * The current value
   * /
  public native function get value():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: MonthPicker_valueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            MONTH_CLICK: "onMonthClick",
            MONTH_DBLCLICK: "onMonthDblclick",
            OK_CLICK: "onOkClick",
            SELECT: "onSelect",
            YEAR_CLICK: "onYearClick",
            YEAR_DBLCLICK: "onYearDblclick",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.resizer.events.Resizer_width_height_eEvent", function(Resizer_width_height_eEvent) {
    /*package ext.resizer.events {
import ext.event.Event;
import ext.resizer.Resizer;

import net.jangaroo.ext.FlExtEvent;

public class Resizer_width_height_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Resizer_width_height_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "width",
            "height",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired before resize is allowed. Return false to cancel resize.
   * @see ext.resizer.Resizer
   * @eventType onBeforeResize
   * /
  public static const BEFORE_RESIZE:String = "onBeforeResize";
  /**
   * "Fired after a resize.
   * @see ext.resizer.Resizer
   * @eventType onResize
   * /
  public static const RESIZE:String = "onResize";
  /**
   * "Fires during resizing.
   * @see ext.resizer.Resizer
   * @eventType onResizeDrag
   * /
  public static const RESIZE_DRAG:String = "onResizeDrag";

  public*/
    function Resizer_width_height_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Resizer;

  /**
   * The start width
   * /
  public native function get width():Number;

  /**
   * The start height
   * /
  public native function get height():Number;

  /**
   * The mousedown event
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Resizer_width_height_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_RESIZE: "onBeforeResize",
            RESIZE: "onResize",
            RESIZE_DRAG: "onResizeDrag",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.scroll.events.ScrollerEvent", function(ScrollerEvent) {
    /*package ext.scroll.events {
import ext.scroll.Scroller;

import net.jangaroo.ext.FlExtEvent;

public class ScrollerEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ScrollerEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires whenever the Scroller is refreshed.
   * @see ext.scroll.Scroller
   * @eventType onRefresh
   * /
  public static const REFRESH:String = "onRefresh";

  public*/
    function ScrollerEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Scroller;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ScrollerEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            REFRESH: "onRefresh",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.scroll.events.Scroller_x_yEvent", function(Scroller_x_yEvent) {
    /*package ext.scroll.events {
import ext.scroll.Scroller;

import net.jangaroo.ext.FlExtEvent;

public class Scroller_x_yEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Scroller_x_yEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "x",
            "y",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires whenever the Scroller is scrolled.
   * @see ext.scroll.Scroller
   * @eventType onScroll
   * /
  public static const SCROLL:String = "onScroll";
  /**
   * "Fires whenever the scrolling is ended.
   * @see ext.scroll.Scroller
   * @eventType onScrollEnd
   * /
  public static const SCROLL_END:String = "onScrollEnd";
  /**
   * "Fires whenever the scrolling is started.
   * @see ext.scroll.Scroller
   * @eventType onScrollStart
   * /
  public static const SCROLL_START:String = "onScrollStart";

  public*/
    function Scroller_x_yEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Scroller;

  /**
   * The new x position.
   * /
  public native function get x():Number;

  /**
   * The new y position.
   * /
  public native function get y():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Scroller_x_yEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SCROLL: "onScroll",
            SCROLL_END: "onScrollEnd",
            SCROLL_START: "onScrollStart",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.selection.events.CellSelectionModel_record_row_columnEvent", function(CellSelectionModel_record_row_columnEvent) {
    /*package ext.selection.events {
import ext.data.Model;
import ext.selection.CellSelectionModel;

import net.jangaroo.ext.FlExtEvent;

public class CellSelectionModel_record_row_columnEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        CellSelectionModel_record_row_columnEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "record",
            "row",
            "column",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired after a cell is deselected
   * @see ext.selection.CellSelectionModel
   * @eventType onDeselect
   * /
  public static const DESELECT:String = "onDeselect";
  /**
   * "Fired after a cell is selected
   * @see ext.selection.CellSelectionModel
   * @eventType onSelect
   * /
  public static const SELECT:String = "onSelect";

  public*/
    function CellSelectionModel_record_row_columnEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():CellSelectionModel;

  /**
   * The record of the deselected cell
   * /
  public native function get record():Model;

  /**
   * The row index deselected
   * /
  public native function get row():Number;

  /**
   * The column index deselected
   * /
  public native function get column():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: CellSelectionModel_record_row_columnEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DESELECT: "onDeselect",
            SELECT: "onSelect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.selection.events.DataViewSelectionModel_recordEvent", function(DataViewSelectionModel_recordEvent) {
    /*package ext.selection.events {
import ext.data.Model;
import ext.selection.DataViewSelectionModel;

import net.jangaroo.ext.FlExtEvent;

public class DataViewSelectionModel_recordEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DataViewSelectionModel_recordEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "record",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired after a record is deselected
   * @see ext.selection.DataViewSelectionModel
   * @eventType onDeselect
   * /
  public static const DESELECT:String = "onDeselect";

  public*/
    function DataViewSelectionModel_recordEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():DataViewSelectionModel;

  /**
   * The deselected record
   * /
  public native function get record():Model;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DataViewSelectionModel_recordEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DESELECT: "onDeselect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.selection.events.DataViewSelectionModel_record_indexEvent", function(DataViewSelectionModel_record_indexEvent) {
    /*package ext.selection.events {
import ext.data.Model;
import ext.selection.DataViewSelectionModel;

import net.jangaroo.ext.FlExtEvent;

public class DataViewSelectionModel_record_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DataViewSelectionModel_record_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "record",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired before a record is deselected. If any listener returns false, the
   * deselection is cancelled.
   * @see ext.selection.DataViewSelectionModel
   * @eventType onBeforeDeselect
   * /
  public static const BEFORE_DESELECT:String = "onBeforeDeselect";
  /**
   * "Fired before a record is selected. If any listener returns false, the
   * selection is cancelled.
   * @see ext.selection.DataViewSelectionModel
   * @eventType onBeforeSelect
   * /
  public static const BEFORE_SELECT:String = "onBeforeSelect";
  /**
   * "Fired after a record is selected
   * @see ext.selection.DataViewSelectionModel
   * @eventType onSelect
   * /
  public static const SELECT:String = "onSelect";

  public*/
    function DataViewSelectionModel_record_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():DataViewSelectionModel;

  /**
   * The deselected record.
   * /
  public native function get record():Model;

  /**
   * The index within the store of the deselected record.
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DataViewSelectionModel_record_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_DESELECT: "onBeforeDeselect",
            BEFORE_SELECT: "onBeforeSelect",
            SELECT: "onSelect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.selection.events.RowSelectionModel_record_indexEvent", function(RowSelectionModel_record_indexEvent) {
    /*package ext.selection.events {
import ext.data.Model;
import ext.selection.RowSelectionModel;

import net.jangaroo.ext.FlExtEvent;

public class RowSelectionModel_record_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        RowSelectionModel_record_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "record",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired before a record is deselected. If any listener returns false, the
   * deselection is cancelled.
   * @see ext.selection.RowSelectionModel
   * @eventType onBeforeDeselect
   * /
  public static const BEFORE_DESELECT:String = "onBeforeDeselect";
  /**
   * "Fired before a record is selected. If any listener returns false, the
   * selection is cancelled.
   * @see ext.selection.RowSelectionModel
   * @eventType onBeforeSelect
   * /
  public static const BEFORE_SELECT:String = "onBeforeSelect";
  /**
   * "Fired after a record is deselected
   * @see ext.selection.RowSelectionModel
   * @eventType onDeselect
   * /
  public static const DESELECT:String = "onDeselect";
  /**
   * "Fired after a record is selected
   * @see ext.selection.RowSelectionModel
   * @eventType onSelect
   * /
  public static const SELECT:String = "onSelect";

  public*/
    function RowSelectionModel_record_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():RowSelectionModel;

  /**
   * The deselected record
   * /
  public native function get record():Model;

  /**
   * The row index deselected
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: RowSelectionModel_record_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_DESELECT: "onBeforeDeselect",
            BEFORE_SELECT: "onBeforeSelect",
            DESELECT: "onDeselect",
            SELECT: "onSelect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.selection.events.SelectionModel_oldFocused_newFocusedEvent", function(SelectionModel_oldFocused_newFocusedEvent) {
    /*package ext.selection.events {
import ext.data.Model;
import ext.selection.SelectionModel;

import net.jangaroo.ext.FlExtEvent;

public class SelectionModel_oldFocused_newFocusedEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        SelectionModel_oldFocused_newFocusedEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "oldFocused",
            "newFocused",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when a row is focused
   * @see ext.selection.SelectionModel
   * @eventType onFocusChange
   * /
  public static const FOCUS_CHANGE:String = "onFocusChange";

  public*/
    function SelectionModel_oldFocused_newFocusedEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():SelectionModel;

  /**
   * The previously focused record
   * /
  public native function get oldFocused():Model;

  /**
   * The newly focused record
   * /
  public native function get newFocused():Model;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: SelectionModel_oldFocused_newFocusedEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            FOCUS_CHANGE: "onFocusChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.selection.events.SelectionModel_selectedEvent", function(SelectionModel_selectedEvent) {
    /*package ext.selection.events {
import ext.selection.SelectionModel;

import net.jangaroo.ext.FlExtEvent;

public class SelectionModel_selectedEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        SelectionModel_selectedEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "selected",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired after a selection change has occurred
   * @see ext.selection.SelectionModel
   * @eventType onSelectionChange
   * /
  public static const SELECTION_CHANGE:String = "onSelectionChange";

  public*/
    function SelectionModel_selectedEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():SelectionModel;

  /**
   * The selected records
   * /
  public native function get selected():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: SelectionModel_selectedEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SELECTION_CHANGE: "onSelectionChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.slider.events.MultiSlider_eEvent", function(MultiSlider_eEvent) {
    /*package ext.slider.events {
import ext.event.Event;
import ext.slider.MultiSlider;

import net.jangaroo.ext.FlExtEvent;

public class MultiSlider_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        MultiSlider_eEvent.__PARAMETER_SEQUENCE__ = ([
            "slider",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires continuously during the drag operation while the mouse is moving.
   * @see ext.slider.MultiSlider
   * @eventType onDrag
   * /
  public static const DRAG:String = "onDrag";
  /**
   * "Fires after the drag operation has completed.
   * @see ext.slider.MultiSlider
   * @eventType onDragEnd
   * /
  public static const DRAG_END:String = "onDragEnd";
  /**
   * "Fires after a drag operation has started.
   * @see ext.slider.MultiSlider
   * @eventType onDragStart
   * /
  public static const DRAG_START:String = "onDragStart";

  public*/
    function MultiSlider_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The slider
   * /
  public native function get slider():MultiSlider;

  /**
   * The event fired from <a href="#!/api/Ext.dd.DragTracker" rel="Ext.dd.DragTracker" class="docClass">Ext.dd.DragTracker</a>
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: MultiSlider_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DRAG: "onDrag",
            DRAG_END: "onDragEnd",
            DRAG_START: "onDragStart",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.slider.events.MultiSlider_newValue_oldValueEvent", function(MultiSlider_newValue_oldValueEvent) {
    /*package ext.slider.events {
import ext.slider.MultiSlider;

import net.jangaroo.ext.FlExtEvent;

public class MultiSlider_newValue_oldValueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        MultiSlider_newValue_oldValueEvent.__PARAMETER_SEQUENCE__ = ([
            "slider",
            "newValue",
            "oldValue",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the slider value is changed. By returning false from an event handler, you can cancel the
   * event and prevent the slider from changing.
   * @see ext.slider.MultiSlider
   * @eventType onBeforeChange
   * /
  public static const BEFORE_CHANGE:String = "onBeforeChange";

  public*/
    function MultiSlider_newValue_oldValueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The slider
   * /
  public native function get slider():MultiSlider;

  /**
   * The new value which the slider is being changed to.
   * /
  public native function get newValue():Number;

  /**
   * The old value which the slider was previously.
   * /
  public native function get oldValue():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: MultiSlider_newValue_oldValueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_CHANGE: "onBeforeChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.slider.events.MultiSlider_newValue_thumbEvent", function(MultiSlider_newValue_thumbEvent) {
    /*package ext.slider.events {
import ext.Base;
import ext.slider.MultiSlider;

import net.jangaroo.ext.FlExtEvent;

public class MultiSlider_newValue_thumbEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        MultiSlider_newValue_thumbEvent.__PARAMETER_SEQUENCE__ = ([
            "slider",
            "newValue",
            "thumb",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the slider value is changed.
   * @see ext.slider.MultiSlider
   * @eventType onChange
   * /
  public static const CHANGE:String = "onChange";
  /**
   * "Fires when the slider value is changed by the user and any drag operations have completed.
   * @see ext.slider.MultiSlider
   * @eventType onChangeComplete
   * /
  public static const CHANGE_COMPLETE:String = "onChangeComplete";

  public*/
    function MultiSlider_newValue_thumbEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The slider
   * /
  public native function get slider():MultiSlider;

  /**
   * The new value which the slider has been changed to.
   * /
  public native function get newValue():Number;

  /**
   * The thumb that was changed
   * /
  public native function get thumb():Base;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: MultiSlider_newValue_thumbEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CHANGE: "onChange",
            CHANGE_COMPLETE: "onChangeComplete",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.state.events.Provider_key_valueEvent", function(Provider_key_valueEvent) {
    /*package ext.state.events {
import ext.state.Provider;

import net.jangaroo.ext.FlExtEvent;

public class Provider_key_valueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Provider_key_valueEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "key",
            "value",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a state change occurs.
   * @see ext.state.Provider
   * @eventType onStateChange
   * /
  public static const STATE_CHANGE:String = "onStateChange";

  public*/
    function Provider_key_valueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This state provider
   * /
  public native function get source():Provider;

  /**
   * The state key which was changed
   * /
  public native function get key():String;

  /**
   * The encoded value for the state
   * /
  public native function get value():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Provider_key_valueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            STATE_CHANGE: "onStateChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.state.events.Stateful_stateEvent", function(Stateful_stateEvent) {
    /*package ext.state.events {
import ext.state.Stateful;

import net.jangaroo.ext.FlExtEvent;

public class Stateful_stateEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Stateful_stateEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "state",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the state of the object is restored. Return false from an event handler to stop the restore.
   * @see ext.state.Stateful
   * @eventType onBeforeStateRestore
   * /
  public static const BEFORE_STATE_RESTORE:String = "onBeforeStateRestore";
  /**
   * "Fires before the state of the object is saved to the configured state provider. Return false to stop the save.
   * @see ext.state.Stateful
   * @eventType onBeforeStateSave
   * /
  public static const BEFORE_STATE_SAVE:String = "onBeforeStateSave";
  /**
   * "Fires after the state of the object is restored.
   * @see ext.state.Stateful
   * @eventType onStateRestore
   * /
  public static const STATE_RESTORE:String = "onStateRestore";
  /**
   * "Fires after the state of the object is saved to the configured state provider.
   * @see ext.state.Stateful
   * @eventType onStateSave
   * /
  public static const STATE_SAVE:String = "onStateSave";

  public*/
    function Stateful_stateEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Stateful;

  /**
   * The hash of state values returned from the StateProvider. If this
   * event is not vetoed, then the state object is passed to <em><code>applyState</code></em>. By default,
   * that simply copies property values into this object. The method maybe overriden to
   * provide custom state restoration.
   * /
  public native function get state():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Stateful_stateEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_STATE_RESTORE: "onBeforeStateRestore",
            BEFORE_STATE_SAVE: "onBeforeStateSave",
            STATE_RESTORE: "onStateRestore",
            STATE_SAVE: "onStateSave",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tab.events.TabBar_tab_cardEvent", function(TabBar_tab_cardEvent) {
    /*package ext.tab.events {
import ext.Component;
import ext.tab.Tab;
import ext.tab.TabBar;

import net.jangaroo.ext.FlExtEvent;

public class TabBar_tab_cardEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TabBar_tab_cardEvent.__PARAMETER_SEQUENCE__ = ([
            "tabBar",
            "tab",
            "card",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when the currently-active tab has changed
   * @see ext.tab.TabBar
   * @eventType onChange
   * /
  public static const CHANGE:String = "onChange";

  public*/
    function TabBar_tab_cardEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The TabBar
   * /
  public native function get tabBar():TabBar;

  /**
   * The new Tab
   * /
  public native function get tab():Tab;

  /**
   * The card that was just shown in the TabPanel
   * /
  public native function get card():Component;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TabBar_tab_cardEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CHANGE: "onChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tab.events.TabEvent", function(TabEvent) {
    /*package ext.tab.events {
import ext.tab.Tab;

import net.jangaroo.ext.FlExtEvent;

public class TabEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TabEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when the tab is activated.
   * @see ext.tab.Tab
   * @eventType onActivate
   * /
  public static const ACTIVATE:String = "onActivate";
  /**
   * "Fires if the user clicks on the Tab's close button, but before the <a href="#!/api/Ext.tab.Tab-event-close" rel="Ext.tab.Tab-event-close" class="docClass">close</a> event is fired. Return
   * false from any listener to stop the close event being fired
   * @see ext.tab.Tab
   * @eventType onBeforeClose
   * /
  public static const BEFORE_CLOSE:String = "onBeforeClose";
  /**
   * "Fires to indicate that the tab is to be closed, usually because the user has clicked the close button.
   * @see ext.tab.Tab
   * @eventType onClose
   * /
  public static const CLOSE:String = "onClose";
  /**
   * "Fired when the tab is deactivated.
   * @see ext.tab.Tab
   * @eventType onDeactivate
   * /
  public static const DEACTIVATE:String = "onDeactivate";

  public*/
    function TabEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Tab;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TabEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ACTIVATE: "onActivate",
            BEFORE_CLOSE: "onBeforeClose",
            CLOSE: "onClose",
            DEACTIVATE: "onDeactivate",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tab.events.TabPanel_newCard_oldCardEvent", function(TabPanel_newCard_oldCardEvent) {
    /*package ext.tab.events {
import ext.Component;
import ext.tab.TabPanel;

import net.jangaroo.ext.FlExtEvent;

public class TabPanel_newCard_oldCardEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TabPanel_newCard_oldCardEvent.__PARAMETER_SEQUENCE__ = ([
            "tabPanel",
            "newCard",
            "oldCard",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a tab change (activated by <a href="#!/api/Ext.tab.Panel-method-setActiveTab" rel="Ext.tab.Panel-method-setActiveTab" class="docClass">setActiveTab</a>). Return false in any listener to cancel
   * the tabchange
   * @see ext.tab.TabPanel
   * @eventType onBeforeTabChange
   * /
  public static const BEFORE_TAB_CHANGE:String = "onBeforeTabChange";
  /**
   * "Fires when a new tab has been activated (activated by <a href="#!/api/Ext.tab.Panel-method-setActiveTab" rel="Ext.tab.Panel-method-setActiveTab" class="docClass">setActiveTab</a>).
   * @see ext.tab.TabPanel
   * @eventType onTabChange
   * /
  public static const TAB_CHANGE:String = "onTabChange";

  public*/
    function TabPanel_newCard_oldCardEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The TabPanel
   * /
  public native function get tabPanel():TabPanel;

  /**
   * The card that is about to be activated
   * /
  public native function get newCard():Component;

  /**
   * The card that is currently active
   * /
  public native function get oldCard():Component;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TabPanel_newCard_oldCardEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_TAB_CHANGE: "onBeforeTabChange",
            TAB_CHANGE: "onTabChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.toolbar.events.Breadcrumb_node_prevNodeEvent", function(Breadcrumb_node_prevNodeEvent) {
    /*package ext.toolbar.events {
import ext.data.TreeModel;
import ext.toolbar.Breadcrumb;

import net.jangaroo.ext.FlExtEvent;

public class Breadcrumb_node_prevNodeEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Breadcrumb_node_prevNodeEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "prevNode",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the user changes the selected record. In contrast to the <a href="#!/api/Ext.toolbar.Breadcrumb-event-selectionchange" rel="Ext.toolbar.Breadcrumb-event-selectionchange" class="docClass">selectionchange</a> event, this does
   * <em>not</em> fire at render time, only in response to user activity.
   * @see ext.toolbar.Breadcrumb
   * @eventType onChange
   * /
  public static const CHANGE:String = "onChange";
  /**
   * "Fires when the selected node changes. At render time, this event will fire
   * indicating that the configured <a href="#!/api/Ext.toolbar.Breadcrumb-cfg-selection" rel="Ext.toolbar.Breadcrumb-cfg-selection" class="docClass">selection</a> has been selected.
   * @see ext.toolbar.Breadcrumb
   * @eventType onSelectionChange
   * /
  public static const SELECTION_CHANGE:String = "onSelectionChange";

  public*/
    function Breadcrumb_node_prevNodeEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Breadcrumb;

  /**
   * The selected node.
   * /
  public native function get node():TreeModel;

  /**
   * The previously selected node.
   * /
  public native function get prevNode():TreeModel;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Breadcrumb_node_prevNodeEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CHANGE: "onChange",
            SELECTION_CHANGE: "onSelectionChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.toolbar.events.PagingToolbar_pageDataEvent", function(PagingToolbar_pageDataEvent) {
    /*package ext.toolbar.events {
import ext.toolbar.PagingToolbar;

import net.jangaroo.ext.FlExtEvent;

public class PagingToolbar_pageDataEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        PagingToolbar_pageDataEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "pageData",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after the active page has been changed.
   * @see ext.toolbar.PagingToolbar
   * @eventType onChange
   * /
  public static const CHANGE:String = "onChange";

  public*/
    function PagingToolbar_pageDataEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():PagingToolbar;

  /**
   * An object that has these properties:
   * <ul>
   * <li><p><code>total</code> : Number</p>
   * <p>The total number of records in the dataset as returned by the server</p></li>
   * <li><p><code>currentPage</code> : Number</p>
   * <p>The current page number</p></li>
   * <li><p><code>pageCount</code> : Number</p>
   * <p>The total number of pages (calculated from the total number of records in the dataset as returned by the
   * server and the current <a href="#!/api/Ext.data.Store-cfg-pageSize" rel="Ext.data.Store-cfg-pageSize" class="docClass">pageSize</a>)</p></li>
   * <li><p><code>toRecord</code> : Number</p>
   * <p>The starting record index for the current page</p></li>
   * <li><p><code>fromRecord</code> : Number</p>
   * <p>The ending record index for the current page</p></li>
   * </ul>
   * /
  public native function get pageData():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: PagingToolbar_pageDataEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CHANGE: "onChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.toolbar.events.PagingToolbar_pageEvent", function(PagingToolbar_pageEvent) {
    /*package ext.toolbar.events {
import ext.toolbar.PagingToolbar;

import net.jangaroo.ext.FlExtEvent;

public class PagingToolbar_pageEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        PagingToolbar_pageEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "page",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires just before the active page is changed. Return false to prevent the active page from being changed.
   * @see ext.toolbar.PagingToolbar
   * @eventType onBeforeChange
   * /
  public static const BEFORE_CHANGE:String = "onBeforeChange";

  public*/
    function PagingToolbar_pageEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():PagingToolbar;

  /**
   * The page number that will be loaded on change
   * /
  public native function get page():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: PagingToolbar_pageEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_CHANGE: "onBeforeChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.toolbar.events.Toolbar_lastHiddenCount_hiddenCount_hiddenItemsEvent", function(Toolbar_lastHiddenCount_hiddenCount_hiddenItemsEvent) {
    /*package ext.toolbar.events {
import net.jangaroo.ext.FlExtEvent;

public class Toolbar_lastHiddenCount_hiddenCount_hiddenItemsEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Toolbar_lastHiddenCount_hiddenCount_hiddenItemsEvent.__PARAMETER_SEQUENCE__ = ([
            "lastHiddenCount",
            "hiddenCount",
            "hiddenItems",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after the overflow state has changed if this toolbar has been configured with
   * an <code><a href="#!/api/Ext.toolbar.Toolbar-cfg-overflowHandler" rel="Ext.toolbar.Toolbar-cfg-overflowHandler" class="docClass">overflowHandler</a></code>.
   * @see ext.toolbar.Toolbar
   * @eventType onOverflowChange
   * /
  public static const OVERFLOW_CHANGE:String = "onOverflowChange";

  public*/
    function Toolbar_lastHiddenCount_hiddenCount_hiddenItemsEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The number of overflowing items that used to be hidden.
   * /
  public native function get lastHiddenCount():Number;

  /**
   * The number of overflowing items that are hidden now.
   * /
  public native function get hiddenCount():Number;

  /**
   * The hidden items
   * /
  public native function get hiddenItems():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Toolbar_lastHiddenCount_hiddenCount_hiddenItemsEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            OVERFLOW_CHANGE: "onOverflowChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.events.TreePanelEvent", function(TreePanelEvent) {
    /*package ext.tree.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreePanelEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreePanelEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before this node is collapsed.
   * @see ext.tree.TreePanel
   * @eventType onBeforeItemCollapse
   * /
  public static const BEFORE_ITEM_COLLAPSE:String = "onBeforeItemCollapse";
  /**
   * "Fires before this node is expanded.
   * @see ext.tree.TreePanel
   * @eventType onBeforeItemExpand
   * /
  public static const BEFORE_ITEM_EXPAND:String = "onBeforeItemExpand";
  /**
   * "Fires when this node is collapsed.
   * @see ext.tree.TreePanel
   * @eventType onItemCollapse
   * /
  public static const ITEM_COLLAPSE:String = "onItemCollapse";
  /**
   * "Fires when this node is expanded.
   * @see ext.tree.TreePanel
   * @eventType onItemExpand
   * /
  public static const ITEM_EXPAND:String = "onItemExpand";

  public*/
    function TreePanelEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The collapsing node
   * /
  public native function get source():NodeInterface;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreePanelEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_ITEM_COLLAPSE: "onBeforeItemCollapse",
            BEFORE_ITEM_EXPAND: "onBeforeItemExpand",
            ITEM_COLLAPSE: "onItemCollapse",
            ITEM_EXPAND: "onItemExpand",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.events.TreePanel_nodeEvent", function(TreePanel_nodeEvent) {
    /*package ext.tree.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreePanel_nodeEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreePanel_nodeEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a new child is appended, return false to cancel the append.
   * @see ext.tree.TreePanel
   * @eventType onBeforeItemAppend
   * /
  public static const BEFORE_ITEM_APPEND:String = "onBeforeItemAppend";

  public*/
    function TreePanel_nodeEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The child node to be appended
   * /
  public native function get node():NodeInterface;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreePanel_nodeEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_ITEM_APPEND: "onBeforeItemAppend",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.events.TreePanel_node_checked_eEvent", function(TreePanel_node_checked_eEvent) {
    /*package ext.tree.events {
import ext.data.TreeModel;
import ext.event.Event;

import net.jangaroo.ext.FlExtEvent;

public class TreePanel_node_checked_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreePanel_node_checked_eEvent.__PARAMETER_SEQUENCE__ = ([
            "node",
            "checked",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a node with a checkbox's checked property changes.
   * @see ext.tree.TreePanel
   * @eventType onBeforeCheckChange
   * /
  public static const BEFORE_CHECK_CHANGE:String = "onBeforeCheckChange";
  /**
   * "Fires when a node with a checkbox's checked property changes.
   * @see ext.tree.TreePanel
   * @eventType onCheckChange
   * /
  public static const CHECK_CHANGE:String = "onCheckChange";

  public*/
    function TreePanel_node_checked_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The node who's checked property is to be changed.
   * /
  public native function get node():TreeModel;

  /**
   * The node's current checked state.
   * /
  public native function get checked():Boolean;

  /**
   * The click event.
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreePanel_node_checked_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_CHECK_CHANGE: "onBeforeCheckChange",
            CHECK_CHANGE: "onCheckChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.events.TreePanel_node_indexEvent", function(TreePanel_node_indexEvent) {
    /*package ext.tree.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreePanel_node_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreePanel_node_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a new child node is appended
   * @see ext.tree.TreePanel
   * @eventType onItemAppend
   * /
  public static const ITEM_APPEND:String = "onItemAppend";

  public*/
    function TreePanel_node_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The newly appended node
   * /
  public native function get node():NodeInterface;

  /**
   * The index of the newly appended node
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreePanel_node_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ITEM_APPEND: "onItemAppend",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.events.TreePanel_node_index_itemEvent", function(TreePanel_node_index_itemEvent) {
    /*package ext.tree.events {
import ext.data.NodeInterface;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class TreePanel_node_index_itemEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreePanel_node_index_itemEvent.__PARAMETER_SEQUENCE__ = ([
            "node",
            "index",
            "item",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after an item has been visually collapsed and is no longer visible in the tree.
   * @see ext.tree.TreePanel
   * @eventType onAfterItemCollapse
   * /
  public static const AFTER_ITEM_COLLAPSE:String = "onAfterItemCollapse";
  /**
   * "Fires after an item has been visually expanded and is visible in the tree.
   * @see ext.tree.TreePanel
   * @eventType onAfterItemExpand
   * /
  public static const AFTER_ITEM_EXPAND:String = "onAfterItemExpand";

  public*/
    function TreePanel_node_index_itemEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The node that was collapsed
   * /
  public native function get node():NodeInterface;

  /**
   * The index of the node
   * /
  public native function get index():Number;

  /**
   * The HTML element for the node that was collapsed
   * /
  public native function get item():HTMLElement;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreePanel_node_index_itemEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            AFTER_ITEM_COLLAPSE: "onAfterItemCollapse",
            AFTER_ITEM_EXPAND: "onAfterItemExpand",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.events.TreePanel_node_isMoveEvent", function(TreePanel_node_isMoveEvent) {
    /*package ext.tree.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreePanel_node_isMoveEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreePanel_node_isMoveEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "isMove",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a child is removed, return false to cancel the remove.
   * @see ext.tree.TreePanel
   * @eventType onBeforeItemRemove
   * /
  public static const BEFORE_ITEM_REMOVE:String = "onBeforeItemRemove";

  public*/
    function TreePanel_node_isMoveEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The child node to be removed
   * /
  public native function get node():NodeInterface;

  /**
   * <code>true</code> if the child node is being removed so it can be moved to another position in the tree.
   * (a side effect of calling <a href="#!/api/Ext.data.NodeInterface-method-appendChild" rel="Ext.data.NodeInterface-method-appendChild" class="docClass">appendChild</a> or
   * <a href="#!/api/Ext.data.NodeInterface-method-insertBefore" rel="Ext.data.NodeInterface-method-insertBefore" class="docClass">insertBefore</a> with a node that already has a parentNode)
   * /
  public native function get isMove():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreePanel_node_isMoveEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_ITEM_REMOVE: "onBeforeItemRemove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.events.TreePanel_node_isMove_contextEvent", function(TreePanel_node_isMove_contextEvent) {
    /*package ext.tree.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreePanel_node_isMove_contextEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreePanel_node_isMove_contextEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "isMove",
            "context",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a child node is removed
   * @see ext.tree.TreePanel
   * @eventType onItemRemove
   * /
  public static const ITEM_REMOVE:String = "onItemRemove";

  public*/
    function TreePanel_node_isMove_contextEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The removed node
   * /
  public native function get node():NodeInterface;

  /**
   * <code>true</code> if the child node is being removed so it can be moved to another position in the tree.
   * /
  public native function get isMove():Boolean;

  /**
   * An object providing information about where the removed node came from. It contains the following properties:
   * <ul>
   *   <li><code>parentNode</code> : ext.data.NodeInterface
   * The node from which the removed node was removed.
   *   </li>
   *   <li><code>previousSibling</code> : ext.data.NodeInterface
   * The removed node's former previous sibling.
   *   </li>
   *   <li><code>nextSibling</code> : ext.data.NodeInterface
   * The removed node's former next sibling.
   * (a side effect of calling <a href="#!/api/Ext.data.NodeInterface-method-appendChild" rel="Ext.data.NodeInterface-method-appendChild" class="docClass">appendChild</a> or
   * <a href="#!/api/Ext.data.NodeInterface-method-insertBefore" rel="Ext.data.NodeInterface-method-insertBefore" class="docClass">insertBefore</a> with a node that already has a parentNode)
   *   </li>
   * </ul>
   * /
  public native function get context():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreePanel_node_isMove_contextEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ITEM_REMOVE: "onItemRemove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.events.TreePanel_node_refNodeEvent", function(TreePanel_node_refNodeEvent) {
    /*package ext.tree.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreePanel_node_refNodeEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreePanel_node_refNodeEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "node",
            "refNode",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a new child is inserted, return false to cancel the insert.
   * @see ext.tree.TreePanel
   * @eventType onBeforeItemInsert
   * /
  public static const BEFORE_ITEM_INSERT:String = "onBeforeItemInsert";
  /**
   * "Fires when a new child node is inserted.
   * @see ext.tree.TreePanel
   * @eventType onItemInsert
   * /
  public static const ITEM_INSERT:String = "onItemInsert";

  public*/
    function TreePanel_node_refNodeEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The child node to be inserted
   * /
  public native function get node():NodeInterface;

  /**
   * The child node the node is being inserted before
   * /
  public native function get refNode():NodeInterface;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreePanel_node_refNodeEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_ITEM_INSERT: "onBeforeItemInsert",
            ITEM_INSERT: "onItemInsert",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.events.TreePanel_oldParent_newParent_indexEvent", function(TreePanel_oldParent_newParent_indexEvent) {
    /*package ext.tree.events {
import ext.data.NodeInterface;

import net.jangaroo.ext.FlExtEvent;

public class TreePanel_oldParent_newParent_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreePanel_oldParent_newParent_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "oldParent",
            "newParent",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before this node is moved to a new location in the tree. Return false to cancel the move.
   * @see ext.tree.TreePanel
   * @eventType onBeforeItemMove
   * /
  public static const BEFORE_ITEM_MOVE:String = "onBeforeItemMove";
  /**
   * "Fires when this node is moved to a new location in the tree
   * @see ext.tree.TreePanel
   * @eventType onItemMove
   * /
  public static const ITEM_MOVE:String = "onItemMove";

  public*/
    function TreePanel_oldParent_newParent_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This node
   * /
  public native function get source():NodeInterface;

  /**
   * The parent of this node
   * /
  public native function get oldParent():NodeInterface;

  /**
   * The new parent this node is moving to
   * /
  public native function get newParent():NodeInterface;

  /**
   * The index it is being moved to
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreePanel_oldParent_newParent_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_ITEM_MOVE: "onBeforeItemMove",
            ITEM_MOVE: "onItemMove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.events.TreePanel_records_successful_operation_nodeEvent", function(TreePanel_records_successful_operation_nodeEvent) {
    /*package ext.tree.events {
import ext.data.NodeInterface;
import ext.data.TreeStore;
import ext.data.operation.Operation;

import net.jangaroo.ext.FlExtEvent;

public class TreePanel_records_successful_operation_nodeEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreePanel_records_successful_operation_nodeEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "records",
            "successful",
            "operation",
            "node",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires whenever the store reads data from a remote data source.
   * @see ext.tree.TreePanel
   * @eventType onLoad
   * /
  public static const LOAD:String = "onLoad";

  public*/
    function TreePanel_records_successful_operation_nodeEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():TreeStore;

  /**
   * An array of records.
   * /
  public native function get records():Array;

  /**
   * True if the operation was successful.
   * /
  public native function get successful():Boolean;

  /**
   * The operation that triggered this load.
   * /
  public native function get operation():Operation;

  /**
   * The node that was loaded.
   * /
  public native function get node():NodeInterface;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreePanel_records_successful_operation_nodeEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            LOAD: "onLoad",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.events.TreePanel_store_operationEvent", function(TreePanel_store_operationEvent) {
    /*package ext.tree.events {
import ext.data.Store;
import ext.data.operation.Operation;

import net.jangaroo.ext.FlExtEvent;

public class TreePanel_store_operationEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreePanel_store_operationEvent.__PARAMETER_SEQUENCE__ = ([
            "store",
            "operation",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a request is made for a new data object. If the beforeload handler returns false the load
   * action will be canceled.
   * @see ext.tree.TreePanel
   * @eventType onBeforeLoad
   * /
  public static const BEFORE_LOAD:String = "onBeforeLoad";

  public*/
    function TreePanel_store_operationEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This Store
   * /
  public native function get store():Store;

  /**
   * The <a href="#!/api/Ext.data.operation.Operation" rel="Ext.data.operation.Operation" class="docClass">Ext.data.operation.Operation</a> object that will be passed to the Proxy to
   * load the Store
   * /
  public native function get operation():Operation;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreePanel_store_operationEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_LOAD: "onBeforeLoad",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.events.TreeView_node_index_itemEvent", function(TreeView_node_index_itemEvent) {
    /*package ext.tree.events {
import ext.data.NodeInterface;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class TreeView_node_index_itemEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreeView_node_index_itemEvent.__PARAMETER_SEQUENCE__ = ([
            "node",
            "index",
            "item",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after an item has been visually collapsed and is no longer visible in the tree.
   * @see ext.tree.TreeView
   * @eventType onAfterItemCollapse
   * /
  public static const AFTER_ITEM_COLLAPSE:String = "onAfterItemCollapse";
  /**
   * "Fires after an item has been visually expanded and is visible in the tree.
   * @see ext.tree.TreeView
   * @eventType onAfterItemExpand
   * /
  public static const AFTER_ITEM_EXPAND:String = "onAfterItemExpand";

  public*/
    function TreeView_node_index_itemEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The node that was collapsed
   * /
  public native function get node():NodeInterface;

  /**
   * The index of the node
   * /
  public native function get index():Number;

  /**
   * The HTML element for the node that was collapsed
   * /
  public native function get item():HTMLElement;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreeView_node_index_itemEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            AFTER_ITEM_COLLAPSE: "onAfterItemCollapse",
            AFTER_ITEM_EXPAND: "onAfterItemExpand",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.events.TreeView_targetNode_position_dragData_eEvent", function(TreeView_targetNode_position_dragData_eEvent) {
    /*package ext.tree.events {
import ext.data.NodeInterface;
import ext.event.Event;

import net.jangaroo.ext.FlExtEvent;

public class TreeView_targetNode_position_dragData_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreeView_targetNode_position_dragData_eEvent.__PARAMETER_SEQUENCE__ = ([
            "targetNode",
            "position",
            "dragData",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a tree node is being targeted for a drag drop, return false to signal drop not allowed.
   * @see ext.tree.TreeView
   * @eventType onNodeDragOver
   * /
  public static const NODE_DRAG_OVER:String = "onNodeDragOver";

  public*/
    function TreeView_targetNode_position_dragData_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The target node
   * /
  public native function get targetNode():NodeInterface;

  /**
   * The drop position, "before", "after" or "append",
   * /
  public native function get position():String;

  /**
   * Data relating to the drag operation
   * /
  public native function get dragData():Object;

  /**
   * The event object for the drag
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreeView_targetNode_position_dragData_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            NODE_DRAG_OVER: "onNodeDragOver",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.plugin.events.TreeViewDragDropPlugin_node_data_overModel_dropPositionEvent", function(TreeViewDragDropPlugin_node_data_overModel_dropPositionEvent) {
    /*package ext.tree.plugin.events {
import ext.data.TreeModel;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class TreeViewDragDropPlugin_node_data_overModel_dropPositionEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreeViewDragDropPlugin_node_data_overModel_dropPositionEvent.__PARAMETER_SEQUENCE__ = ([
            "node",
            "data",
            "overModel",
            "dropPosition",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "<strong>This event is fired through the <a href="#!/api/Ext.tree.View" rel="Ext.tree.View" class="docClass">TreeView</a> and its owning
   * <a href="#!/api/Ext.tree.Panel" rel="Ext.tree.Panel" class="docClass">Tree</a>. You can add listeners to the tree or tree <a href="#!/api/Ext.tree.Panel-cfg-viewConfig" rel="Ext.tree.Panel-cfg-viewConfig" class="docClass">view config</a> object</strong>
   *
   * <p>Fired when a drop operation has been completed and the data has been moved or
   * copied.</p>
   * @see ext.tree.plugin.TreeViewDragDropPlugin
   * @eventType onDrop
   * /
  public static const DROP:String = "onDrop";

  public*/
    function TreeViewDragDropPlugin_node_data_overModel_dropPositionEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The <a href="#!/api/Ext.tree.View" rel="Ext.tree.View" class="docClass">tree view</a> node <strong>if any</strong> over
   * which the cursor was positioned.
   * /
  public native function get node():HTMLElement;

  /**
   * The data object gathered at mousedown time by the
   * cooperating <a href="#!/api/Ext.dd.DragZone" rel="Ext.dd.DragZone" class="docClass">DragZone</a>'s <a href="#!/api/Ext.dd.DragZone-method-getDragData" rel="Ext.dd.DragZone-method-getDragData" class="docClass">getDragData</a> method.  It contains the following properties:
   * <ul>
   *   <li><code>copy</code> : Boolean
   * The value of <a href="#!/api/Ext.tree.plugin.TreeViewDragDrop-cfg-copy" rel="Ext.tree.plugin.TreeViewDragDrop-cfg-copy" class="docClass">copy</a>.  Or <code>true</code> if
   * <a href="#!/api/Ext.tree.plugin.TreeViewDragDrop-cfg-allowCopy" rel="Ext.tree.plugin.TreeViewDragDrop-cfg-allowCopy" class="docClass">allowCopy</a> is true <strong>and</strong> the control key was pressed as the drag
   * operation began.
   *   </li>
   *   <li><code>view</code> : ext.tree.TreeView
   * The source tree view from which the drag
   * originated
   *   </li>
   *   <li><code>ddel</code> : js.HTMLElement
   * The drag proxy element which moves with the cursor
   *   </li>
   *   <li><code>item</code> : js.HTMLElement
   * The tree view node upon which the mousedown event
   * was registered
   *   </li>
   *   <li><code>records</code> : Array
   * An Array of Models representing the
   * selected data being dragged from the source tree view
   *   </li>
   * </ul>
   * /
  public native function get data():Object;

  /**
   * The Model over which the drop gesture took
   * place.
   * /
  public native function get overModel():TreeModel;

  /**
   * <code>"before"</code> or <code>"after"</code> depending on whether the
   * cursor is above or below the mid-line of the node.
   * /
  public native function get dropPosition():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreeViewDragDropPlugin_node_data_overModel_dropPositionEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DROP: "onDrop",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.tree.plugin.events.TreeViewDragDropPlugin_node_data_overModel_dropPosition_dropHandlersEvent", function(TreeViewDragDropPlugin_node_data_overModel_dropPosition_dropHandlersEvent) {
    /*package ext.tree.plugin.events {
import ext.data.TreeModel;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class TreeViewDragDropPlugin_node_data_overModel_dropPosition_dropHandlersEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TreeViewDragDropPlugin_node_data_overModel_dropPosition_dropHandlersEvent.__PARAMETER_SEQUENCE__ = ([
            "node",
            "data",
            "overModel",
            "dropPosition",
            "dropHandlers",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "<strong>This event is fired through the <a href="#!/api/Ext.tree.View" rel="Ext.tree.View" class="docClass">TreeView</a> and its owning
   * <a href="#!/api/Ext.tree.Panel" rel="Ext.tree.Panel" class="docClass">Tree</a>. You can add listeners to the tree or tree <a href="#!/api/Ext.tree.Panel-cfg-viewConfig" rel="Ext.tree.Panel-cfg-viewConfig" class="docClass">view config</a> object</strong>
   *
   * <p>Fired when a drop gesture has been triggered by a mouseup event in a valid drop
   * position in the tree view.</p>
   *
   * <p>Returning <code>false</code> to this event signals that the drop gesture was invalid and
   * animates the drag proxy back to the point from which the drag began.</p>
   *
   * <p>The dropHandlers parameter can be used to defer the processing of this event. For
   * example, you can force the handler to wait for the result of a message box
   * confirmation or an asynchronous server call (<em>see the details of the dropHandlers
   * property for more information</em>).</p>
   *
   * <pre><code>tree.on('beforedrop', function(node, data, overModel, dropPosition, dropHandlers) {
   *     // Defer the handling
   *     dropHandlers.wait = true;
   *     <a href="#!/api/Ext.MessageBox-method-confirm" rel="Ext.MessageBox-method-confirm" class="docClass">Ext.MessageBox.confirm</a>('Drop', 'Are you sure', function(btn){
   *         if (btn === 'yes') {
   *             dropHandlers.processDrop();
   *         } else {
   *             dropHandlers.cancelDrop();
   *         }
   *     });
   * });
   * </code></pre>
   *
   * <p>Any other return value continues with the data transfer operation unless the wait
   * property is set.</p>
   * @see ext.tree.plugin.TreeViewDragDropPlugin
   * @eventType onBeforeDrop
   * /
  public static const BEFORE_DROP:String = "onBeforeDrop";

  public*/
    function TreeViewDragDropPlugin_node_data_overModel_dropPosition_dropHandlersEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The <a href="#!/api/Ext.tree.View" rel="Ext.tree.View" class="docClass">tree view</a> node <strong>if any</strong> over
   * which the cursor was positioned.
   * /
  public native function get node():HTMLElement;

  /**
   * The data object gathered at mousedown time by the
   * cooperating <a href="#!/api/Ext.dd.DragZone" rel="Ext.dd.DragZone" class="docClass">DragZone</a>'s <a href="#!/api/Ext.dd.DragZone-method-getDragData" rel="Ext.dd.DragZone-method-getDragData" class="docClass">getDragData</a> method.  It contains the following properties:
   * <ul>
   *   <li><code>copy</code> : Boolean
   * The value of <a href="#!/api/Ext.tree.plugin.TreeViewDragDrop-cfg-copy" rel="Ext.tree.plugin.TreeViewDragDrop-cfg-copy" class="docClass">copy</a>.  Or <code>true</code> if
   * <a href="#!/api/Ext.tree.plugin.TreeViewDragDrop-cfg-allowCopy" rel="Ext.tree.plugin.TreeViewDragDrop-cfg-allowCopy" class="docClass">allowCopy</a> is true <strong>and</strong> the control key was pressed as the drag
   * operation began.
   *   </li>
   *   <li><code>view</code> : ext.tree.TreeView
   * The source tree view from which the drag
   * originated
   *   </li>
   *   <li><code>ddel</code> : js.HTMLElement
   * The drag proxy element which moves with the cursor
   *   </li>
   *   <li><code>item</code> : js.HTMLElement
   * The tree view node upon which the mousedown event
   * was registered
   *   </li>
   *   <li><code>records</code> : Array
   * An Array of Models representing the
   * selected data being dragged from the source tree view
   *   </li>
   * </ul>
   * /
  public native function get data():Object;

  /**
   * The Model over which the drop gesture took place
   * /
  public native function get overModel():TreeModel;

  /**
   * <code>"before"</code> or <code>"after"</code> depending on whether the
   * cursor is above or below the mid-line of the node.
   * /
  public native function get dropPosition():String;

  /**
   * This parameter allows the developer to control when the drop action takes place.
   * It is useful if any asynchronous processing needs to be completed before
   * performing the drop. This object has the following properties:
   * <ul>
   *   <li><code>wait</code> : Boolean
   * Indicates whether the drop should be deferred.
   * Set this property to true to defer the drop.
   *   </li>
   *   <li><code>processDrop</code> : Function
   * A function to be called to complete
   * the drop operation.
   *   </li>
   *   <li><code>cancelDrop</code> : Function
   * A function to be called to cancel the
   * drop operation.
   *   </li>
   * </ul>
   * /
  public native function get dropHandlers():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TreeViewDragDropPlugin_node_data_overModel_dropPosition_dropHandlersEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_DROP: "onBeforeDrop",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.AbstractMixedCollectionEvent", function(AbstractMixedCollectionEvent) {
    /*package ext.util.events {
import net.jangaroo.ext.FlExtEvent;

public class AbstractMixedCollectionEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractMixedCollectionEvent.__PARAMETER_SEQUENCE__ = ([
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the collection is cleared.
   * @since 1.1.0
   * @see ext.util.AbstractMixedCollection
   * @eventType onClear
   * /
  public static const CLEAR:String = "onClear";

  public*/
    function AbstractMixedCollectionEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractMixedCollectionEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CLEAR: "onClear",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.AbstractMixedCollection_index_o_keyEvent", function(AbstractMixedCollection_index_o_keyEvent) {
    /*package ext.util.events {
import net.jangaroo.ext.FlExtEvent;

public class AbstractMixedCollection_index_o_keyEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractMixedCollection_index_o_keyEvent.__PARAMETER_SEQUENCE__ = ([
            "index",
            "o",
            "key",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when an item is added to the collection.
   * @since 1.1.0
   * @see ext.util.AbstractMixedCollection
   * @eventType onAdd
   * /
  public static const ADD:String = "onAdd";

  public*/
    function AbstractMixedCollection_index_o_keyEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The index at which the item was added.
   * /
  public native function get index():Number;

  /**
   * The item added.
   * /
  public native function get o():Object;

  /**
   * The key associated with the added item.
   * /
  public native function get key():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractMixedCollection_index_o_keyEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ADD: "onAdd",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.AbstractMixedCollection_key_old_newEvent", function(AbstractMixedCollection_key_old_newEvent) {
    /*package ext.util.events {
import net.jangaroo.ext.FlExtEvent;

public class AbstractMixedCollection_key_old_newEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractMixedCollection_key_old_newEvent.__PARAMETER_SEQUENCE__ = ([
            "key",
            "old",
            "new_",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when an item is replaced in the collection.
   * @since 1.1.0
   * @see ext.util.AbstractMixedCollection
   * @eventType onReplace
   * /
  public static const REPLACE:String = "onReplace";

  public*/
    function AbstractMixedCollection_key_old_newEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * he key associated with the new added.
   * /
  public native function get key():String;

  /**
   * The item being replaced.
   * /
  public native function get old():Object;

  /**
   * The new item.
   * /
  public native function get new_():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractMixedCollection_key_old_newEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            REPLACE: "onReplace",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.AbstractMixedCollection_o_keyEvent", function(AbstractMixedCollection_o_keyEvent) {
    /*package ext.util.events {
import net.jangaroo.ext.FlExtEvent;

public class AbstractMixedCollection_o_keyEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractMixedCollection_o_keyEvent.__PARAMETER_SEQUENCE__ = ([
            "o",
            "key",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when an item is removed from the collection.
   * @since 1.1.0
   * @see ext.util.AbstractMixedCollection
   * @eventType onRemove
   * /
  public static const REMOVE:String = "onRemove";

  public*/
    function AbstractMixedCollection_o_keyEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The item being removed.
   * /
  public native function get o():Object;

  /**
   * The key associated with the removed item.
   * /
  public native function get key():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractMixedCollection_o_keyEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            REMOVE: "onRemove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.ClickRepeater_eEvent", function(ClickRepeater_eEvent) {
    /*package ext.util.events {
import ext.event.Event;
import ext.util.ClickRepeater;

import net.jangaroo.ext.FlExtEvent;

public class ClickRepeater_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        ClickRepeater_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires on a specified interval during the time the element is pressed.
   * @see ext.util.ClickRepeater
   * @eventType onClick
   * /
  public static const CLICK:String = "onClick";
  /**
   * "Fires when the mouse button is depressed.
   * @see ext.util.ClickRepeater
   * @eventType onMouseDown
   * /
  public static const MOUSE_DOWN:String = "onMouseDown";
  /**
   * "Fires when the mouse key is released.
   * @see ext.util.ClickRepeater
   * @eventType onMouseUp
   * /
  public static const MOUSE_UP:String = "onMouseUp";

  public*/
    function ClickRepeater_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():ClickRepeater;

  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: ClickRepeater_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CLICK: "onClick",
            MOUSE_DOWN: "onMouseDown",
            MOUSE_UP: "onMouseUp",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.CollectionEvent", function(CollectionEvent) {
    /*package ext.util.events {
import ext.util.Collection;

import net.jangaroo.ext.FlExtEvent;

public class CollectionEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        CollectionEvent.__PARAMETER_SEQUENCE__ = ([
            "collection",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired before changes are made to the collection. This event fires when the
   * <code>beginUpdate</code> method is called and the counter it manages transitions from 0 to 1.
   *
   * <p>All <code><a href="#!/api/Ext.util.Collection-event-add" rel="Ext.util.Collection-event-add" class="docClass">add</a></code> and <code><a href="#!/api/Ext.util.Collection-event-remove" rel="Ext.util.Collection-event-remove" class="docClass">remove</a></code> events occur between
   * <code><a href="#!/api/Ext.util.Collection-event-beginupdate" rel="Ext.util.Collection-event-beginupdate" class="docClass">beginupdate</a></code> and <code><a href="#!/api/Ext.util.Collection-event-endupdate" rel="Ext.util.Collection-event-endupdate" class="docClass">endupdate</a></code>
   * events so it is best to do only the minimal amount of work in response to these
   * events and move the more expensive side-effects to an <code>endupdate</code> listener.</p>
   * @since 5.0.0
   * @see ext.util.Collection
   * @eventType onBeginUpdate
   * /
  public static const BEGIN_UPDATE:String = "onBeginUpdate";
  /**
   * "Fired after changes are made to the collection. This event fires when the <code>endUpdate</code>
   * method is called and the counter it manages transitions from 1 to 0.
   *
   * <p>All <code><a href="#!/api/Ext.util.Collection-event-add" rel="Ext.util.Collection-event-add" class="docClass">add</a></code> and <code><a href="#!/api/Ext.util.Collection-event-remove" rel="Ext.util.Collection-event-remove" class="docClass">remove</a></code> events occur between
   * <code><a href="#!/api/Ext.util.Collection-event-beginupdate" rel="Ext.util.Collection-event-beginupdate" class="docClass">beginupdate</a></code> and <code><a href="#!/api/Ext.util.Collection-event-endupdate" rel="Ext.util.Collection-event-endupdate" class="docClass">endupdate</a></code>
   * events so it is best to do only the minimal amount of work in response to these
   * events and move the more expensive side-effects to an <code>endupdate</code> listener.</p>
   * @since 5.0.0
   * @see ext.util.Collection
   * @eventType onEndUpdate
   * /
  public static const END_UPDATE:String = "onEndUpdate";
  /**
   * "This event fires when the collection has changed entirely. This event is fired in
   * cases where the collection's filter is updated or the items are sorted. While the
   * items previously in the collection may remain the same, the order at a minimum has
   * changed in ways that cannot be simply translated to other events.
   * @see ext.util.Collection
   * @eventType onRefresh
   * /
  public static const REFRESH:String = "onRefresh";
  /**
   * "This event fires after the contents of the collection have been sorted.
   * @see ext.util.Collection
   * @eventType onSort
   * /
  public static const SORT:String = "onSort";

  public*/
    function CollectionEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The collection being modified.
   * /
  public native function get collection():Collection;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: CollectionEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEGIN_UPDATE: "onBeginUpdate",
            END_UPDATE: "onEndUpdate",
            REFRESH: "onRefresh",
            SORT: "onSort",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.Collection_detailsEvent", function(Collection_detailsEvent) {
    /*package ext.util.events {
import ext.util.Collection;

import net.jangaroo.ext.FlExtEvent;

public class Collection_detailsEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Collection_detailsEvent.__PARAMETER_SEQUENCE__ = ([
            "collection",
            "details",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after items have been added to the collection.
   *
   * <p>All <code><a href="#!/api/Ext.util.Collection-event-add" rel="Ext.util.Collection-event-add" class="docClass">add</a></code> and <code><a href="#!/api/Ext.util.Collection-event-remove" rel="Ext.util.Collection-event-remove" class="docClass">remove</a></code> events occur between
   * <code><a href="#!/api/Ext.util.Collection-event-beginupdate" rel="Ext.util.Collection-event-beginupdate" class="docClass">beginupdate</a></code> and <code><a href="#!/api/Ext.util.Collection-event-endupdate" rel="Ext.util.Collection-event-endupdate" class="docClass">endupdate</a></code>
   * events so it is best to do only the minimal amount of work in response to these
   * events and move the more expensive side-effects to an <code>endupdate</code> listener.</p>
   * @since 5.0.0
   * @see ext.util.Collection
   * @eventType onAdd
   * /
  public static const ADD:String = "onAdd";
  /**
   * "This event fires before an item change is reflected in the collection. This event
   * is always followed by an <code>itemchange</code> event and, depending on the change, possibly
   * an <code>add</code>, <code>remove</code> and/or <code>updatekey</code> event.
   * @since 5.0.0
   * @see ext.util.Collection
   * @eventType onBeforeItemChange
   * /
  public static const BEFORE_ITEM_CHANGE:String = "onBeforeItemChange";
  /**
   * "This event fires after an item change is reflected in the collection. This event
   * always follows a <code>beforeitemchange</code> event and its corresponding <code>add</code>, <code>remove</code>
   * and/or <code>updatekey</code> events.
   * @since 5.0.0
   * @see ext.util.Collection
   * @eventType onItemChange
   * /
  public static const ITEM_CHANGE:String = "onItemChange";
  /**
   * "Fires after items have been removed from the collection. Some properties of this
   * object may not be present if calculating them is deemed too expensive. These are
   * marked as "optional".
   *
   * <p>All <code><a href="#!/api/Ext.util.Collection-event-add" rel="Ext.util.Collection-event-add" class="docClass">add</a></code> and <code><a href="#!/api/Ext.util.Collection-event-remove" rel="Ext.util.Collection-event-remove" class="docClass">remove</a></code> events occur between
   * <code><a href="#!/api/Ext.util.Collection-event-beginupdate" rel="Ext.util.Collection-event-beginupdate" class="docClass">beginupdate</a></code> and <code><a href="#!/api/Ext.util.Collection-event-endupdate" rel="Ext.util.Collection-event-endupdate" class="docClass">endupdate</a></code>
   * events so it is best to do only the minimal amount of work in response to these
   * events and move the more expensive side-effects to an <code>endupdate</code> listener.</p>
   * @since 5.0.0
   * @see ext.util.Collection
   * @eventType onRemove
   * /
  public static const REMOVE:String = "onRemove";
  /**
   * "Fires after the key for an item has changed.
   * @since 5.0.0
   * @see ext.util.Collection
   * @eventType onUpdateKey
   * /
  public static const UPDATE_KEY:String = "onUpdateKey";

  public*/
    function Collection_detailsEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The collection being modified.
   * /
  public native function get collection():Collection;

  /**
   * An object describing the addition.
   * <ul>
   *   <li><code>at</code> : Number
   * The index in the collection where the add occurred.
   *   </li>
   *   <li><code>atItem</code> : Object
   * The item after which the new items were inserted or
   * <code>null</code> if at the beginning of the collection.
   *   </li>
   *   <li><code>items</code> : Array
   * The items that are now added to the collection.
   *   </li>
   *   <li><code>keys</code> : Array (optional)
   * If available this array holds the keys (extracted by
   * <code>getKey</code>) for each item in the <code>items</code> array.
   *   </li>
   *   <li><code>next</code> : Object (optional)
   * If more <code><a href="#!/api/Ext.util.Collection-event-add" rel="Ext.util.Collection-event-add" class="docClass">add</a></code> events are in queue
   * to be delivered this is a reference to the <code>details</code> instance for the next
   * <code><a href="#!/api/Ext.util.Collection-event-add" rel="Ext.util.Collection-event-add" class="docClass">add</a></code> event. This will only be the case when the collection is
   * sorted as the new items often need to be inserted at multiple locations to maintain
   * the sort. In this case, all of the new items have already been added not just those
   * described by the first <code><a href="#!/api/Ext.util.Collection-event-add" rel="Ext.util.Collection-event-add" class="docClass">add</a></code> event.
   *   </li>
   *   <li><code>replaced</code> : Object (optional)
   * If this addition has a corresponding set of
   * <code><a href="#!/api/Ext.util.Collection-event-remove" rel="Ext.util.Collection-event-remove" class="docClass">remove</a></code> events this reference holds the <code>details</code> object for
   * the first <code>remove</code> event. That <code>details</code> object may have a <code>next</code> property if there
   * are multiple associated <code>remove</code> events.
   *   </li>
   * </ul>
   * /
  public native function get details():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Collection_detailsEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ADD: "onAdd",
            BEFORE_ITEM_CHANGE: "onBeforeItemChange",
            ITEM_CHANGE: "onItemChange",
            REMOVE: "onRemove",
            UPDATE_KEY: "onUpdateKey",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.Focusable_eventEvent", function(Focusable_eventEvent) {
    /*package ext.util.events {
import ext.Component;
import ext.event.Event;

import net.jangaroo.ext.FlExtEvent;

public class Focusable_eventEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Focusable_eventEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "event",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when this Component loses focus.
   * @see ext.util.Focusable
   * @eventType onBlur
   * /
  public static const BLUR:String = "onBlur";
  /**
   * "Fires when this Component receives focus.
   * @see ext.util.Focusable
   * @eventType onFocus
   * /
  public static const FOCUS:String = "onFocus";
  /**
   * "Fires when focus enters this Component's hierarchy.
   * @see ext.util.Focusable
   * @eventType onFocusEnter
   * /
  public static const FOCUS_ENTER:String = "onFocusEnter";
  /**
   * "Fires when focus leaves this Component's hierarchy.
   * @see ext.util.Focusable
   * @eventType onFocusLeave
   * /
  public static const FOCUS_LEAVE:String = "onFocusLeave";

  public*/
    function Focusable_eventEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Component;

  /**
   * The blur event.
   * /
  public native function get event():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Focusable_eventEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BLUR: "onBlur",
            FOCUS: "onFocus",
            FOCUS_ENTER: "onFocusEnter",
            FOCUS_LEAVE: "onFocusLeave",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.HashMapEvent", function(HashMapEvent) {
    /*package ext.util.events {
import ext.util.HashMap;

import net.jangaroo.ext.FlExtEvent;

public class HashMapEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HashMapEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the hash is cleared.
   * @see ext.util.HashMap
   * @eventType onClear
   * /
  public static const CLEAR:String = "onClear";

  public*/
    function HashMapEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():HashMap;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HashMapEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CLEAR: "onClear",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.HashMap_key_valueEvent", function(HashMap_key_valueEvent) {
    /*package ext.util.events {
import ext.util.HashMap;

import net.jangaroo.ext.FlExtEvent;

public class HashMap_key_valueEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HashMap_key_valueEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "key",
            "value",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a new item is added to the hash.
   * @see ext.util.HashMap
   * @eventType onAdd
   * /
  public static const ADD:String = "onAdd";
  /**
   * "Fires when an item is removed from the hash.
   * @see ext.util.HashMap
   * @eventType onRemove
   * /
  public static const REMOVE:String = "onRemove";

  public*/
    function HashMap_key_valueEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():HashMap;

  /**
   * The key of the added item.
   * /
  public native function get key():String;

  /**
   * The value of the added item.
   * /
  public native function get value():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HashMap_key_valueEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ADD: "onAdd",
            REMOVE: "onRemove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.HashMap_key_value_oldEvent", function(HashMap_key_value_oldEvent) {
    /*package ext.util.events {
import ext.util.HashMap;

import net.jangaroo.ext.FlExtEvent;

public class HashMap_key_value_oldEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HashMap_key_value_oldEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "key",
            "value",
            "old",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when an item is replaced in the hash.
   * @see ext.util.HashMap
   * @eventType onReplace
   * /
  public static const REPLACE:String = "onReplace";

  public*/
    function HashMap_key_value_oldEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():HashMap;

  /**
   * The key of the replaced item.
   * /
  public native function get key():String;

  /**
   * The new value for the item.
   * /
  public native function get value():Object;

  /**
   * The old value for the item.
   * /
  public native function get old():Object;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HashMap_key_value_oldEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            REPLACE: "onReplace",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.HistoryEvent", function(HistoryEvent) {
    /*package ext.util.events {
import ext.util.SHistory;

import net.jangaroo.ext.FlExtEvent;

public class HistoryEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        HistoryEvent.__PARAMETER_SEQUENCE__ = ([
            "history",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the <a href="#!/api/Ext.util.History" rel="Ext.util.History" class="docClass">Ext.util.History</a> singleton has been initialized and is ready for use.
   * @see ext.util.SHistory
   * @eventType onReady
   * /
  public static const READY:String = "onReady";

  public*/
    function HistoryEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The <a href="#!/api/Ext.util.History" rel="Ext.util.History" class="docClass">Ext.util.History</a> singleton.
   * /
  public native function get history():SHistory;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: HistoryEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            READY: "onReady",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.History_tokenEvent", function(History_tokenEvent) {
    /*package ext.util.events {
import net.jangaroo.ext.FlExtEvent;

public class History_tokenEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        History_tokenEvent.__PARAMETER_SEQUENCE__ = ([
            "token",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when navigation back or forwards within the local page's history occurs.
   * @see ext.util.SHistory
   * @eventType onChange
   * /
  public static const CHANGE:String = "onChange";

  public*/
    function History_tokenEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * An identifier associated with the page state at that point in its history.
   * /
  public native function get token():String;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: History_tokenEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            CHANGE: "onChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.MixedCollection_me_sortersEvent", function(MixedCollection_me_sortersEvent) {
    /*package ext.util.events {
import ext.util.Sortable;

import net.jangaroo.ext.FlExtEvent;

public class MixedCollection_me_sortersEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        MixedCollection_me_sortersEvent.__PARAMETER_SEQUENCE__ = ([
            "me",
            "sorters",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a sort occurs.
   * @see ext.util.MixedCollection
   * @eventType onBeforeSort
   * /
  public static const BEFORE_SORT:String = "onBeforeSort";

  public*/
    function MixedCollection_me_sortersEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This object.
   * /
  public native function get me():Sortable;

  /**
   * The collection of Sorters being used to generate the comparator function.
   * /
  public native function get sorters():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: MixedCollection_me_sortersEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_SORT: "onBeforeSort",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.util.events.Sortable_sortersEvent", function(Sortable_sortersEvent) {
    /*package ext.util.events {
import ext.util.Sortable;

import net.jangaroo.ext.FlExtEvent;

public class Sortable_sortersEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Sortable_sortersEvent.__PARAMETER_SEQUENCE__ = ([
            "me",
            "sorters",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before a sort occurs.
   * @see ext.util.Sortable
   * @eventType onBeforeSort
   * /
  public static const BEFORE_SORT:String = "onBeforeSort";

  public*/
    function Sortable_sortersEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This object.
   * /
  public native function get me():Sortable;

  /**
   * The collection of Sorters being used to generate the comparator function.
   * /
  public native function get sorters():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Sortable_sortersEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_SORT: "onBeforeSort",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.AbstractViewEvent", function(AbstractViewEvent) {
    /*package ext.view.events {
import ext.view.DataView;

import net.jangaroo.ext.FlExtEvent;

public class AbstractViewEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractViewEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the view is refreshed
   * @see ext.view.AbstractView
   * @eventType onBeforeRefresh
   * /
  public static const BEFORE_REFRESH:String = "onBeforeRefresh";
  /**
   * "Fires when the view is refreshed
   * @see ext.view.AbstractView
   * @eventType onRefresh
   * /
  public static const REFRESH:String = "onRefresh";
  /**
   * "Fires when the View's item elements representing Store items has been rendered. No items will be available
   * for selection until this event fires.
   * @see ext.view.AbstractView
   * @eventType onViewReady
   * /
  public static const VIEW_READY:String = "onViewReady";

  public*/
    function AbstractViewEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The DataView object
   * /
  public native function get source():DataView;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractViewEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_REFRESH: "onBeforeRefresh",
            REFRESH: "onRefresh",
            VIEW_READY: "onViewReady",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.AbstractView_record_index_node_viewEvent", function(AbstractView_record_index_node_viewEvent) {
    /*package ext.view.events {
import ext.data.Model;
import ext.view.DataView;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class AbstractView_record_index_node_viewEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractView_record_index_node_viewEvent.__PARAMETER_SEQUENCE__ = ([
            "record",
            "index",
            "node",
            "view",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the node associated with an individual record is updated
   * @see ext.view.AbstractView
   * @eventType onItemUpdate
   * /
  public static const ITEM_UPDATE:String = "onItemUpdate";

  public*/
    function AbstractView_record_index_node_viewEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The model instance
   * /
  public native function get record():Model;

  /**
   * The index of the record
   * /
  public native function get index():Number;

  /**
   * The node that has just been updated
   * /
  public native function get node():HTMLElement;

  /**
   * The view containing the item
   * /
  public native function get view():DataView;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractView_record_index_node_viewEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ITEM_UPDATE: "onItemUpdate",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.AbstractView_records_index_item_viewEvent", function(AbstractView_records_index_item_viewEvent) {
    /*package ext.view.events {
import ext.view.DataView;

import net.jangaroo.ext.FlExtEvent;

public class AbstractView_records_index_item_viewEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractView_records_index_item_viewEvent.__PARAMETER_SEQUENCE__ = ([
            "records",
            "index",
            "item",
            "view",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the node associated with an individual record is removed
   * @see ext.view.AbstractView
   * @eventType onItemRemove
   * /
  public static const ITEM_REMOVE:String = "onItemRemove";

  public*/
    function AbstractView_records_index_item_viewEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The model instances removed
   * /
  public native function get records():Array;

  /**
   * The index from which the records wer removed
   * /
  public native function get index():Number;

  /**
   * The view items removed
   * /
  public native function get item():Array;

  /**
   * The view removing the item
   * /
  public native function get view():DataView;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractView_records_index_item_viewEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ITEM_REMOVE: "onItemRemove",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.AbstractView_records_index_node_viewEvent", function(AbstractView_records_index_node_viewEvent) {
    /*package ext.view.events {
import ext.view.DataView;

import net.jangaroo.ext.FlExtEvent;

public class AbstractView_records_index_node_viewEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        AbstractView_records_index_node_viewEvent.__PARAMETER_SEQUENCE__ = ([
            "records",
            "index",
            "node",
            "view",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when the nodes associated with an recordset have been added to the underlying store
   * @see ext.view.AbstractView
   * @eventType onItemAdd
   * /
  public static const ITEM_ADD:String = "onItemAdd";

  public*/
    function AbstractView_records_index_node_viewEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The model instance
   * /
  public native function get records():Array;

  /**
   * The index at which the set of records was inserted
   * /
  public native function get index():Number;

  /**
   * The node that has just been updated
   * /
  public native function get node():Array;

  /**
   * The view adding the item
   * /
  public native function get view():DataView;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: AbstractView_records_index_node_viewEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ITEM_ADD: "onItemAdd",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.DataView_eEvent", function(DataView_eEvent) {
    /*package ext.view.events {
import ext.event.Event;
import ext.view.DataView;

import net.jangaroo.ext.FlExtEvent;

public class DataView_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DataView_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the click event on the container is processed. Returns false to cancel the default action.
   * @see ext.view.DataView
   * @eventType onBeforeContainerClick
   * /
  public static const BEFORE_CONTAINER_CLICK:String = "onBeforeContainerClick";
  /**
   * "Fires before the contextmenu event on the container is processed. Returns false to cancel the default action.
   * @see ext.view.DataView
   * @eventType onBeforeContainerContextMenu
   * /
  public static const BEFORE_CONTAINER_CONTEXT_MENU:String = "onBeforeContainerContextMenu";
  /**
   * "Fires before the dblclick event on the container is processed. Returns false to cancel the default action.
   * @see ext.view.DataView
   * @eventType onBeforeContainerDblclick
   * /
  public static const BEFORE_CONTAINER_DBLCLICK:String = "onBeforeContainerDblclick";
  /**
   * "Fires before the keydown event on the container is processed. Returns false to cancel the default action.
   * @see ext.view.DataView
   * @eventType onBeforeContainerKeyDown
   * /
  public static const BEFORE_CONTAINER_KEY_DOWN:String = "onBeforeContainerKeyDown";
  /**
   * "Fires before the keypress event on the container is processed. Returns false to cancel the default action.
   * @see ext.view.DataView
   * @eventType onBeforeContainerKeypress
   * /
  public static const BEFORE_CONTAINER_KEYPRESS:String = "onBeforeContainerKeypress";
  /**
   * "Fires before the keyup event on the container is processed. Returns false to cancel the default action.
   * @see ext.view.DataView
   * @eventType onBeforeContainerKeyUp
   * /
  public static const BEFORE_CONTAINER_KEY_UP:String = "onBeforeContainerKeyUp";
  /**
   * "Fires before the mousedown event on the container is processed. Returns false to cancel the default action.
   * @see ext.view.DataView
   * @eventType onBeforeContainerMouseDown
   * /
  public static const BEFORE_CONTAINER_MOUSE_DOWN:String = "onBeforeContainerMouseDown";
  /**
   * "Fires before the mouseout event on the container is processed. Returns false to cancel the default action.
   * @see ext.view.DataView
   * @eventType onBeforeContainerMouseOut
   * /
  public static const BEFORE_CONTAINER_MOUSE_OUT:String = "onBeforeContainerMouseOut";
  /**
   * "Fires before the mouseover event on the container is processed. Returns false to cancel the default action.
   * @see ext.view.DataView
   * @eventType onBeforeContainerMouseOver
   * /
  public static const BEFORE_CONTAINER_MOUSE_OVER:String = "onBeforeContainerMouseOver";
  /**
   * "Fires before the mouseup event on the container is processed. Returns false to cancel the default action.
   * @see ext.view.DataView
   * @eventType onBeforeContainerMouseUp
   * /
  public static const BEFORE_CONTAINER_MOUSE_UP:String = "onBeforeContainerMouseUp";
  /**
   * "Fires when the container is clicked.
   * @see ext.view.DataView
   * @eventType onContainerClick
   * /
  public static const CONTAINER_CLICK:String = "onContainerClick";
  /**
   * "Fires when the container is right clicked.
   * @see ext.view.DataView
   * @eventType onContainerContextMenu
   * /
  public static const CONTAINER_CONTEXT_MENU:String = "onContainerContextMenu";
  /**
   * "Fires when the container is double clicked.
   * @see ext.view.DataView
   * @eventType onContainerDblclick
   * /
  public static const CONTAINER_DBLCLICK:String = "onContainerDblclick";
  /**
   * "Fires when a key is pressed down while the container is focused, and no item is currently selected.
   * @see ext.view.DataView
   * @eventType onContainerKeyDown
   * /
  public static const CONTAINER_KEY_DOWN:String = "onContainerKeyDown";
  /**
   * "Fires when a key is pressed while the container is focused, and no item is currently selected.
   * @see ext.view.DataView
   * @eventType onContainerKeypress
   * /
  public static const CONTAINER_KEYPRESS:String = "onContainerKeypress";
  /**
   * "Fires when a key is released while the container is focused, and no item is currently selected.
   * @see ext.view.DataView
   * @eventType onContainerKeyUp
   * /
  public static const CONTAINER_KEY_UP:String = "onContainerKeyUp";
  /**
   * "Fires when there is a mousedown on the container
   * @see ext.view.DataView
   * @eventType onContainerMouseDown
   * /
  public static const CONTAINER_MOUSE_DOWN:String = "onContainerMouseDown";
  /**
   * "Fires when you move the mouse out of the container.
   * @see ext.view.DataView
   * @eventType onContainerMouseOut
   * /
  public static const CONTAINER_MOUSE_OUT:String = "onContainerMouseOut";
  /**
   * "Fires when you move the mouse over the container.
   * @see ext.view.DataView
   * @eventType onContainerMouseOver
   * /
  public static const CONTAINER_MOUSE_OVER:String = "onContainerMouseOver";
  /**
   * "Fires when there is a mouseup on the container
   * @see ext.view.DataView
   * @eventType onContainerMouseUp
   * /
  public static const CONTAINER_MOUSE_UP:String = "onContainerMouseUp";

  public*/
    function DataView_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():DataView;

  /**
   * The raw event object
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DataView_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_CONTAINER_CLICK: "onBeforeContainerClick",
            BEFORE_CONTAINER_CONTEXT_MENU: "onBeforeContainerContextMenu",
            BEFORE_CONTAINER_DBLCLICK: "onBeforeContainerDblclick",
            BEFORE_CONTAINER_KEY_DOWN: "onBeforeContainerKeyDown",
            BEFORE_CONTAINER_KEYPRESS: "onBeforeContainerKeypress",
            BEFORE_CONTAINER_KEY_UP: "onBeforeContainerKeyUp",
            BEFORE_CONTAINER_MOUSE_DOWN: "onBeforeContainerMouseDown",
            BEFORE_CONTAINER_MOUSE_OUT: "onBeforeContainerMouseOut",
            BEFORE_CONTAINER_MOUSE_OVER: "onBeforeContainerMouseOver",
            BEFORE_CONTAINER_MOUSE_UP: "onBeforeContainerMouseUp",
            CONTAINER_CLICK: "onContainerClick",
            CONTAINER_CONTEXT_MENU: "onContainerContextMenu",
            CONTAINER_DBLCLICK: "onContainerDblclick",
            CONTAINER_KEY_DOWN: "onContainerKeyDown",
            CONTAINER_KEYPRESS: "onContainerKeypress",
            CONTAINER_KEY_UP: "onContainerKeyUp",
            CONTAINER_MOUSE_DOWN: "onContainerMouseDown",
            CONTAINER_MOUSE_OUT: "onContainerMouseOut",
            CONTAINER_MOUSE_OVER: "onContainerMouseOver",
            CONTAINER_MOUSE_UP: "onContainerMouseUp",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.DataView_nodeEvent", function(DataView_nodeEvent) {
    /*package ext.view.events {
import ext.dom.Element;
import ext.view.DataView;

import net.jangaroo.ext.FlExtEvent;

public class DataView_nodeEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DataView_nodeEvent.__PARAMETER_SEQUENCE__ = ([
            "view",
            "node",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires when a node is highlighted using keyboard navigation, or mouseover.
   * @see ext.view.DataView
   * @eventType onHighlightItem
   * /
  public static const HIGHLIGHT_ITEM:String = "onHighlightItem";
  /**
   * "Fires when a node is unhighlighted using keyboard navigation, or mouseout.
   * @see ext.view.DataView
   * @eventType onUnhighlightItem
   * /
  public static const UNHIGHLIGHT_ITEM:String = "onUnhighlightItem";

  public*/
    function DataView_nodeEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * This View Component.
   * /
  public native function get view():DataView;

  /**
   * The highlighted node.
   * /
  public native function get node():Element;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DataView_nodeEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            HIGHLIGHT_ITEM: "onHighlightItem",
            UNHIGHLIGHT_ITEM: "onUnhighlightItem",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.DataView_oldFocused_newFocusedEvent", function(DataView_oldFocused_newFocusedEvent) {
    /*package ext.view.events {
import ext.data.Model;
import ext.selection.SelectionModel;

import net.jangaroo.ext.FlExtEvent;

public class DataView_oldFocused_newFocusedEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DataView_oldFocused_newFocusedEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "oldFocused",
            "newFocused",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when a row is focused
   * @see ext.view.DataView
   * @eventType onFocusChange
   * /
  public static const FOCUS_CHANGE:String = "onFocusChange";

  public*/
    function DataView_oldFocused_newFocusedEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():SelectionModel;

  /**
   * The previously focused record
   * /
  public native function get oldFocused():Model;

  /**
   * The newly focused record
   * /
  public native function get newFocused():Model;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DataView_oldFocused_newFocusedEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            FOCUS_CHANGE: "onFocusChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.DataView_recordEvent", function(DataView_recordEvent) {
    /*package ext.view.events {
import ext.data.Model;
import ext.selection.DataViewSelectionModel;

import net.jangaroo.ext.FlExtEvent;

public class DataView_recordEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DataView_recordEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "record",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired after a record is deselected
   * @see ext.view.DataView
   * @eventType onDeselect
   * /
  public static const DESELECT:String = "onDeselect";

  public*/
    function DataView_recordEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():DataViewSelectionModel;

  /**
   * The deselected record
   * /
  public native function get record():Model;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DataView_recordEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            DESELECT: "onDeselect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.DataView_record_indexEvent", function(DataView_record_indexEvent) {
    /*package ext.view.events {
import ext.data.Model;
import ext.selection.DataViewSelectionModel;

import net.jangaroo.ext.FlExtEvent;

public class DataView_record_indexEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DataView_record_indexEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "record",
            "index",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired before a record is deselected. If any listener returns false, the
   * deselection is cancelled.
   * @see ext.view.DataView
   * @eventType onBeforeDeselect
   * /
  public static const BEFORE_DESELECT:String = "onBeforeDeselect";
  /**
   * "Fired before a record is selected. If any listener returns false, the
   * selection is cancelled.
   * @see ext.view.DataView
   * @eventType onBeforeSelect
   * /
  public static const BEFORE_SELECT:String = "onBeforeSelect";
  /**
   * "Fired after a record is selected
   * @see ext.view.DataView
   * @eventType onSelect
   * /
  public static const SELECT:String = "onSelect";

  public*/
    function DataView_record_indexEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():DataViewSelectionModel;

  /**
   * The deselected record.
   * /
  public native function get record():Model;

  /**
   * The index within the store of the deselected record.
   * /
  public native function get index():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DataView_record_indexEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_DESELECT: "onBeforeDeselect",
            BEFORE_SELECT: "onBeforeSelect",
            SELECT: "onSelect",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.DataView_record_item_index_eEvent", function(DataView_record_item_index_eEvent) {
    /*package ext.view.events {
import ext.data.Model;
import ext.event.Event;
import ext.view.DataView;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class DataView_record_item_index_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DataView_record_item_index_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "record",
            "item",
            "index",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the click event on an item is processed. Return false to cancel the
   * default action.
   * @see ext.view.DataView
   * @eventType onBeforeItemClick
   * /
  public static const BEFORE_ITEM_CLICK:String = "onBeforeItemClick";
  /**
   * "Fires before the contextmenu event on an item is processed. Return false to
   * cancel the default action.
   * @see ext.view.DataView
   * @eventType onBeforeItemContextMenu
   * /
  public static const BEFORE_ITEM_CONTEXT_MENU:String = "onBeforeItemContextMenu";
  /**
   * "Fires before the dblclick event on an item is processed. Return false to cancel
   * the default action.
   * @see ext.view.DataView
   * @eventType onBeforeItemDblclick
   * /
  public static const BEFORE_ITEM_DBLCLICK:String = "onBeforeItemDblclick";
  /**
   * "Fires before the keydown event on an item is processed. Return false to cancel
   * the default action.
   * @see ext.view.DataView
   * @eventType onBeforeItemKeyDown
   * /
  public static const BEFORE_ITEM_KEY_DOWN:String = "onBeforeItemKeyDown";
  /**
   * "Fires before the keypress event on an item is processed. Return false to cancel
   * the default action.
   * @see ext.view.DataView
   * @eventType onBeforeItemKeypress
   * /
  public static const BEFORE_ITEM_KEYPRESS:String = "onBeforeItemKeypress";
  /**
   * "Fires before the keyup event on an item is processed. Return false to cancel the
   * default action.
   * @see ext.view.DataView
   * @eventType onBeforeItemKeyUp
   * /
  public static const BEFORE_ITEM_KEY_UP:String = "onBeforeItemKeyUp";
  /**
   * "Fires before the longpress event on an item is processed. Return false to
   * cancel the default action.
   * @see ext.view.DataView
   * @eventType onBeforeItemLongPress
   * /
  public static const BEFORE_ITEM_LONG_PRESS:String = "onBeforeItemLongPress";
  /**
   * "Fires before the mousedown event on an item is processed. Return false to cancel
   * the default action.
   * @see ext.view.DataView
   * @eventType onBeforeItemMouseDown
   * /
  public static const BEFORE_ITEM_MOUSE_DOWN:String = "onBeforeItemMouseDown";
  /**
   * "Fires before the mouseenter event on an item is processed. Return false to cancel
   * the default action.
   * @see ext.view.DataView
   * @eventType onBeforeItemMouseEnter
   * /
  public static const BEFORE_ITEM_MOUSE_ENTER:String = "onBeforeItemMouseEnter";
  /**
   * "Fires before the mouseleave event on an item is processed. Return false to cancel
   * the default action.
   * @see ext.view.DataView
   * @eventType onBeforeItemMouseLeave
   * /
  public static const BEFORE_ITEM_MOUSE_LEAVE:String = "onBeforeItemMouseLeave";
  /**
   * "Fires before the mouseup event on an item is processed. Return false to cancel
   * the default action.
   * @see ext.view.DataView
   * @eventType onBeforeItemMouseUp
   * /
  public static const BEFORE_ITEM_MOUSE_UP:String = "onBeforeItemMouseUp";
  /**
   * "Fires when an item is clicked.
   * @see ext.view.DataView
   * @eventType onItemClick
   * /
  public static const ITEM_CLICK:String = "onItemClick";
  /**
   * "Fires when an item is right clicked.
   * @see ext.view.DataView
   * @eventType onItemContextMenu
   * /
  public static const ITEM_CONTEXT_MENU:String = "onItemContextMenu";
  /**
   * "Fires when an item is double clicked.
   * @see ext.view.DataView
   * @eventType onItemDblclick
   * /
  public static const ITEM_DBLCLICK:String = "onItemDblclick";
  /**
   * "Fires when a key is pressed down while an item is currently selected.
   * @see ext.view.DataView
   * @eventType onItemKeyDown
   * /
  public static const ITEM_KEY_DOWN:String = "onItemKeyDown";
  /**
   * "Fires when a key is pressed while an item is currently selected.
   * @see ext.view.DataView
   * @eventType onItemKeypress
   * /
  public static const ITEM_KEYPRESS:String = "onItemKeypress";
  /**
   * "Fires when a key is released while an item is currently selected.
   * @see ext.view.DataView
   * @eventType onItemKeyUp
   * /
  public static const ITEM_KEY_UP:String = "onItemKeyUp";
  /**
   * "Fires on a longpress event on an item.
   * @see ext.view.DataView
   * @eventType onItemLongPress
   * /
  public static const ITEM_LONG_PRESS:String = "onItemLongPress";
  /**
   * "Fires when there is a mouse down on an item
   * @see ext.view.DataView
   * @eventType onItemMouseDown
   * /
  public static const ITEM_MOUSE_DOWN:String = "onItemMouseDown";
  /**
   * "Fires when the mouse enters an item.
   * @see ext.view.DataView
   * @eventType onItemMouseEnter
   * /
  public static const ITEM_MOUSE_ENTER:String = "onItemMouseEnter";
  /**
   * "Fires when the mouse leaves an item.
   * @see ext.view.DataView
   * @eventType onItemMouseLeave
   * /
  public static const ITEM_MOUSE_LEAVE:String = "onItemMouseLeave";
  /**
   * "Fires when there is a mouse up on an item
   * @see ext.view.DataView
   * @eventType onItemMouseUp
   * /
  public static const ITEM_MOUSE_UP:String = "onItemMouseUp";

  public*/
    function DataView_record_item_index_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():DataView;

  /**
   * The record that belongs to the item
   * /
  public native function get record():Model;

  /**
   * The item's element
   * /
  public native function get item():HTMLElement;

  /**
   * The item's index
   * /
  public native function get index():Number;

  /**
   * The raw event object
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DataView_record_item_index_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_ITEM_CLICK: "onBeforeItemClick",
            BEFORE_ITEM_CONTEXT_MENU: "onBeforeItemContextMenu",
            BEFORE_ITEM_DBLCLICK: "onBeforeItemDblclick",
            BEFORE_ITEM_KEY_DOWN: "onBeforeItemKeyDown",
            BEFORE_ITEM_KEYPRESS: "onBeforeItemKeypress",
            BEFORE_ITEM_KEY_UP: "onBeforeItemKeyUp",
            BEFORE_ITEM_LONG_PRESS: "onBeforeItemLongPress",
            BEFORE_ITEM_MOUSE_DOWN: "onBeforeItemMouseDown",
            BEFORE_ITEM_MOUSE_ENTER: "onBeforeItemMouseEnter",
            BEFORE_ITEM_MOUSE_LEAVE: "onBeforeItemMouseLeave",
            BEFORE_ITEM_MOUSE_UP: "onBeforeItemMouseUp",
            ITEM_CLICK: "onItemClick",
            ITEM_CONTEXT_MENU: "onItemContextMenu",
            ITEM_DBLCLICK: "onItemDblclick",
            ITEM_KEY_DOWN: "onItemKeyDown",
            ITEM_KEYPRESS: "onItemKeypress",
            ITEM_KEY_UP: "onItemKeyUp",
            ITEM_LONG_PRESS: "onItemLongPress",
            ITEM_MOUSE_DOWN: "onItemMouseDown",
            ITEM_MOUSE_ENTER: "onItemMouseEnter",
            ITEM_MOUSE_LEAVE: "onItemMouseLeave",
            ITEM_MOUSE_UP: "onItemMouseUp",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.DataView_selectedEvent", function(DataView_selectedEvent) {
    /*package ext.view.events {
import ext.selection.SelectionModel;

import net.jangaroo.ext.FlExtEvent;

public class DataView_selectedEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        DataView_selectedEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "selected",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired after a selection change has occurred
   * @see ext.view.DataView
   * @eventType onSelectionChange
   * /
  public static const SELECTION_CHANGE:String = "onSelectionChange";

  public*/
    function DataView_selectedEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():SelectionModel;

  /**
   * The selected records
   * /
  public native function get selected():Array;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: DataView_selectedEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            SELECTION_CHANGE: "onSelectionChange",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.NavigationModelView_event_keyEventEvent", function(NavigationModelView_event_keyEventEvent) {
    /*package ext.view.events {
import ext.event.Event;

import net.jangaroo.ext.FlExtEvent;

public class NavigationModelView_event_keyEventEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        NavigationModelView_event_keyEventEvent.__PARAMETER_SEQUENCE__ = ([
            "event",
            "keyEvent",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when a key has been used to navigate around the view.
   * @see ext.view.NavigationModelView
   * @eventType onNavigate
   * /
  public static const NAVIGATE:String = "onNavigate";

  public*/
    function NavigationModelView_event_keyEventEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   *
   * <ul>
   *   <li><code>previousRecordIndex</code> : Number
   * The previously focused record index.
   *   </li>
   *   <li><code>previousRecord</code> : ext.data.Model
   * The previously focused record.
   *   </li>
   *   <li><code>previousItem</code> : js.HTMLElement
   * The previously focused view item.
   *   </li>
   *   <li><code>recordIndex</code> : Number
   * The newly focused record index.
   *   </li>
   *   <li><code>record</code> : ext.data.Model
   * the newly focused record.
   *   </li>
   *   <li><code>item</code> : js.HTMLElement
   * the newly focused view item.
   *   </li>
   * </ul>
   * /
  public native function get event():Object;

  /**
   * The key event which caused the navigation.
   * /
  public native function get keyEvent():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: NavigationModelView_event_keyEventEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            NAVIGATE: "onNavigate",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.TableView_keyEvent_prevRow_nextRow_forwardEvent", function(TableView_keyEvent_prevRow_nextRow_forwardEvent) {
    /*package ext.view.events {
import ext.event.Event;
import ext.view.TableView;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class TableView_keyEvent_prevRow_nextRow_forwardEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TableView_keyEvent_prevRow_nextRow_forwardEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "keyEvent",
            "prevRow",
            "nextRow",
            "forward",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when View is asked to exit Actionable mode in the current row,
   * and proceed to the previous/next row. If the handler returns <code>false</code>,
   * View processing is aborted.
   * @see ext.view.TableView
   * @eventType onBeforeRowExit
   * /
  public static const BEFORE_ROW_EXIT:String = "onBeforeRowExit";

  public*/
    function TableView_keyEvent_prevRow_nextRow_forwardEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():TableView;

  /**
   * The key event that caused navigation.
   * /
  public native function get keyEvent():Event;

  /**
   * Currently active table row.
   * /
  public native function get prevRow():HTMLElement;

  /**
   * Table row that is going to be focused and activated.
   * /
  public native function get nextRow():HTMLElement;

  /**
   * <code>true</code> if we're navigating forward (Tab), <code>false</code> if
   * navigating backward (Shift-Tab).
   * @cancelable
   * /
  public native function get forward():Boolean;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TableView_keyEvent_prevRow_nextRow_forwardEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_ROW_EXIT: "onBeforeRowExit",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.TableView_record_tr_rowIndex_eEvent", function(TableView_record_tr_rowIndex_eEvent) {
    /*package ext.view.events {
import ext.data.Model;
import ext.event.Event;
import ext.view.TableView;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class TableView_record_tr_rowIndex_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TableView_record_tr_rowIndex_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "record",
            "tr",
            "rowIndex",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired when table cell is clicked.
   * @see ext.view.TableView
   * @eventType onRowClick
   * /
  public static const ROW_CLICK:String = "onRowClick";
  /**
   * "Fired when table cell is right clicked.
   * @see ext.view.TableView
   * @eventType onRowContextMenu
   * /
  public static const ROW_CONTEXT_MENU:String = "onRowContextMenu";
  /**
   * "Fired when table cell is double clicked.
   * @see ext.view.TableView
   * @eventType onRowDblclick
   * /
  public static const ROW_DBLCLICK:String = "onRowDblclick";
  /**
   * "Fired when the keydown event is captured on the cell.
   * @see ext.view.TableView
   * @eventType onRowKeyDown
   * /
  public static const ROW_KEY_DOWN:String = "onRowKeyDown";
  /**
   * "Fired when the mousedown event is captured on the cell.
   * @see ext.view.TableView
   * @eventType onRowMouseDown
   * /
  public static const ROW_MOUSE_DOWN:String = "onRowMouseDown";
  /**
   * "Fired when the mouseup event is captured on the cell.
   * @see ext.view.TableView
   * @eventType onRowMouseUp
   * /
  public static const ROW_MOUSE_UP:String = "onRowMouseUp";

  public*/
    function TableView_record_tr_rowIndex_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():TableView;

  public native function get record():Model;

  /**
   * The TR element for the cell.
   * /
  public native function get tr():HTMLElement;

  public native function get rowIndex():Number;

  /**
   *
   * <ul>
   *   <li><code>position</code> : ext.grid.CellContext
   * A CellContext object which defines the target cell.
   *   </li>
   * </ul>
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TableView_record_tr_rowIndex_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ROW_CLICK: "onRowClick",
            ROW_CONTEXT_MENU: "onRowContextMenu",
            ROW_DBLCLICK: "onRowDblclick",
            ROW_KEY_DOWN: "onRowKeyDown",
            ROW_MOUSE_DOWN: "onRowMouseDown",
            ROW_MOUSE_UP: "onRowMouseUp",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.TableView_td_cellIndex_record_tr_rowIndex_eEvent", function(TableView_td_cellIndex_record_tr_rowIndex_eEvent) {
    /*package ext.view.events {
import ext.data.Model;
import ext.event.Event;
import ext.view.TableView;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class TableView_td_cellIndex_record_tr_rowIndex_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TableView_td_cellIndex_record_tr_rowIndex_eEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "td",
            "cellIndex",
            "record",
            "tr",
            "rowIndex",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fired before the cell click is processed. Return false to cancel the default action.
   * @see ext.view.TableView
   * @eventType onBeforeCellClick
   * /
  public static const BEFORE_CELL_CLICK:String = "onBeforeCellClick";
  /**
   * "Fired before the cell right click is processed. Return false to cancel the default action.
   * @see ext.view.TableView
   * @eventType onBeforeCellContextMenu
   * /
  public static const BEFORE_CELL_CONTEXT_MENU:String = "onBeforeCellContextMenu";
  /**
   * "Fired before the cell double click is processed. Return false to cancel the default action.
   * @see ext.view.TableView
   * @eventType onBeforeCellDblclick
   * /
  public static const BEFORE_CELL_DBLCLICK:String = "onBeforeCellDblclick";
  /**
   * "Fired before the cell key down is processed. Return false to cancel the default action.
   * @see ext.view.TableView
   * @eventType onBeforeCellKeyDown
   * /
  public static const BEFORE_CELL_KEY_DOWN:String = "onBeforeCellKeyDown";
  /**
   * "Fired before the cell mouse down is processed. Return false to cancel the default action.
   * @see ext.view.TableView
   * @eventType onBeforeCellMouseDown
   * /
  public static const BEFORE_CELL_MOUSE_DOWN:String = "onBeforeCellMouseDown";
  /**
   * "Fired before the cell mouse up is processed. Return false to cancel the default action.
   * @see ext.view.TableView
   * @eventType onBeforeCellMouseUp
   * /
  public static const BEFORE_CELL_MOUSE_UP:String = "onBeforeCellMouseUp";
  /**
   * "Fired when table cell is clicked.
   * @see ext.view.TableView
   * @eventType onCellClick
   * /
  public static const CELL_CLICK:String = "onCellClick";
  /**
   * "Fired when table cell is right clicked.
   * @see ext.view.TableView
   * @eventType onCellContextMenu
   * /
  public static const CELL_CONTEXT_MENU:String = "onCellContextMenu";
  /**
   * "Fired when table cell is double clicked.
   * @see ext.view.TableView
   * @eventType onCellDblclick
   * /
  public static const CELL_DBLCLICK:String = "onCellDblclick";
  /**
   * "Fired when the keydown event is captured on the cell.
   * @see ext.view.TableView
   * @eventType onCellKeyDown
   * /
  public static const CELL_KEY_DOWN:String = "onCellKeyDown";
  /**
   * "Fired when the mousedown event is captured on the cell.
   * @see ext.view.TableView
   * @eventType onCellMouseDown
   * /
  public static const CELL_MOUSE_DOWN:String = "onCellMouseDown";
  /**
   * "Fired when the mouseup event is captured on the cell.
   * @see ext.view.TableView
   * @eventType onCellMouseUp
   * /
  public static const CELL_MOUSE_UP:String = "onCellMouseUp";

  public*/
    function TableView_td_cellIndex_record_tr_rowIndex_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():TableView;

  /**
   * The TD element for the cell.
   * /
  public native function get td():HTMLElement;

  public native function get cellIndex():Number;

  public native function get record():Model;

  /**
   * The TR element for the cell.
   * /
  public native function get tr():HTMLElement;

  public native function get rowIndex():Number;

  /**
   *
   * <ul>
   *   <li><code>position</code> : ext.grid.CellContext
   * A CellContext object which defines the target cell.
   *   </li>
   * </ul>
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TableView_td_cellIndex_record_tr_rowIndex_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_CELL_CLICK: "onBeforeCellClick",
            BEFORE_CELL_CONTEXT_MENU: "onBeforeCellContextMenu",
            BEFORE_CELL_DBLCLICK: "onBeforeCellDblclick",
            BEFORE_CELL_KEY_DOWN: "onBeforeCellKeyDown",
            BEFORE_CELL_MOUSE_DOWN: "onBeforeCellMouseDown",
            BEFORE_CELL_MOUSE_UP: "onBeforeCellMouseUp",
            CELL_CLICK: "onCellClick",
            CELL_CONTEXT_MENU: "onCellContextMenu",
            CELL_DBLCLICK: "onCellDblclick",
            CELL_KEY_DOWN: "onCellKeyDown",
            CELL_MOUSE_DOWN: "onCellMouseDown",
            CELL_MOUSE_UP: "onCellMouseUp",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.view.events.TableView_view_rowBodyEl_eEvent", function(TableView_view_rowBodyEl_eEvent) {
    /*package ext.view.events {
import ext.event.Event;
import ext.view.DataView;

import js.HTMLElement;

import net.jangaroo.ext.FlExtEvent;

public class TableView_view_rowBodyEl_eEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        TableView_view_rowBodyEl_eEvent.__PARAMETER_SEQUENCE__ = ([
            "view",
            "rowBodyEl",
            "e",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires before the click event on a row body element is processed. Return false to
   * cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onBeforeRowBodyClick
   * /
  public static const BEFORE_ROW_BODY_CLICK:String = "onBeforeRowBodyClick";
  /**
   * "Fires before the contextmenu event on a row body element is processed. Return
   * false to cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onBeforeRowBodyContextMenu
   * /
  public static const BEFORE_ROW_BODY_CONTEXT_MENU:String = "onBeforeRowBodyContextMenu";
  /**
   * "Fires before the dblclick event on a row body element is processed. Return false
   * to cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onBeforeRowBodyDblclick
   * /
  public static const BEFORE_ROW_BODY_DBLCLICK:String = "onBeforeRowBodyDblclick";
  /**
   * "Fires before the keydown event on a row body element is processed. Return false
   * to cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onBeforeRowBodyKeyDown
   * /
  public static const BEFORE_ROW_BODY_KEY_DOWN:String = "onBeforeRowBodyKeyDown";
  /**
   * "Fires before the keypress event on a row body element is processed. Return false
   * to cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onBeforeRowBodyKeypress
   * /
  public static const BEFORE_ROW_BODY_KEYPRESS:String = "onBeforeRowBodyKeypress";
  /**
   * "Fires before the keyup event on a row body element is processed. Return false to
   * cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onBeforeRowBodyKeyUp
   * /
  public static const BEFORE_ROW_BODY_KEY_UP:String = "onBeforeRowBodyKeyUp";
  /**
   * "Fires before the longpress event on a row body element is processed. Return
   * false to cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onBeforeRowBodyLongPress
   * /
  public static const BEFORE_ROW_BODY_LONG_PRESS:String = "onBeforeRowBodyLongPress";
  /**
   * "Fires before the mousedown event on a row body element is processed. Return false
   * to cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onBeforeRowBodyMouseDown
   * /
  public static const BEFORE_ROW_BODY_MOUSE_DOWN:String = "onBeforeRowBodyMouseDown";
  /**
   * "Fires before the mouseup event on a row body element is processed. Return false
   * to cancel the default action.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onBeforeRowBodyMouseUp
   * /
  public static const BEFORE_ROW_BODY_MOUSE_UP:String = "onBeforeRowBodyMouseUp";
  /**
   * "Fires when a row body element is clicked
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onRowBodyClick
   * /
  public static const ROW_BODY_CLICK:String = "onRowBodyClick";
  /**
   * "Fires when a row body element is right clicked
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onRowBodyContextMenu
   * /
  public static const ROW_BODY_CONTEXT_MENU:String = "onRowBodyContextMenu";
  /**
   * "Fires when a row body element is double clicked
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onRowBodyDblclick
   * /
  public static const ROW_BODY_DBLCLICK:String = "onRowBodyDblclick";
  /**
   * "Fires when a key is pressed down while a row body element is currently selected
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onRowBodyKeyDown
   * /
  public static const ROW_BODY_KEY_DOWN:String = "onRowBodyKeyDown";
  /**
   * "Fires when a key is pressed while a row body element is currently selected.
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onRowBodyKeypress
   * /
  public static const ROW_BODY_KEYPRESS:String = "onRowBodyKeypress";
  /**
   * "Fires when a key is released while a row body element is currently selected
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onRowBodyKeyUp
   * /
  public static const ROW_BODY_KEY_UP:String = "onRowBodyKeyUp";
  /**
   * "Fires on a row body element longpress event
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onRowBodyLongPress
   * /
  public static const ROW_BODY_LONG_PRESS:String = "onRowBodyLongPress";
  /**
   * "Fires when there is a mouse down on a row body element
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onRowBodyMouseDown
   * /
  public static const ROW_BODY_MOUSE_DOWN:String = "onRowBodyMouseDown";
  /**
   * "Fires when there is a mouse up on a row body element
   *
   * <p><strong>Note:</strong> This event is fired only when the <a href="#!/api/Ext.grid.feature.RowBody" rel="Ext.grid.feature.RowBody" class="docClass">Ext.grid.feature.RowBody</a> feature is
   * used.</p>
   * @see ext.view.TableView
   * @eventType onRowBodyMouseUp
   * /
  public static const ROW_BODY_MOUSE_UP:String = "onRowBodyMouseUp";

  public*/
    function TableView_view_rowBodyEl_eEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  /**
   * The rowbody's owning View
   * /
  public native function get view():DataView;

  /**
   * The row body's element
   * /
  public native function get rowBodyEl():HTMLElement;

  /**
   * The raw event object
   * /
  public native function get e():Event;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: TableView_view_rowBodyEl_eEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            BEFORE_ROW_BODY_CLICK: "onBeforeRowBodyClick",
            BEFORE_ROW_BODY_CONTEXT_MENU: "onBeforeRowBodyContextMenu",
            BEFORE_ROW_BODY_DBLCLICK: "onBeforeRowBodyDblclick",
            BEFORE_ROW_BODY_KEY_DOWN: "onBeforeRowBodyKeyDown",
            BEFORE_ROW_BODY_KEYPRESS: "onBeforeRowBodyKeypress",
            BEFORE_ROW_BODY_KEY_UP: "onBeforeRowBodyKeyUp",
            BEFORE_ROW_BODY_LONG_PRESS: "onBeforeRowBodyLongPress",
            BEFORE_ROW_BODY_MOUSE_DOWN: "onBeforeRowBodyMouseDown",
            BEFORE_ROW_BODY_MOUSE_UP: "onBeforeRowBodyMouseUp",
            ROW_BODY_CLICK: "onRowBodyClick",
            ROW_BODY_CONTEXT_MENU: "onRowBodyContextMenu",
            ROW_BODY_DBLCLICK: "onRowBodyDblclick",
            ROW_BODY_KEY_DOWN: "onRowBodyKeyDown",
            ROW_BODY_KEYPRESS: "onRowBodyKeypress",
            ROW_BODY_KEY_UP: "onRowBodyKeyUp",
            ROW_BODY_LONG_PRESS: "onRowBodyLongPress",
            ROW_BODY_MOUSE_DOWN: "onRowBodyMouseDown",
            ROW_BODY_MOUSE_UP: "onRowBodyMouseUp",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.window.events.WindowEvent", function(WindowEvent) {
    /*package ext.window.events {
import ext.window.Window;

import net.jangaroo.ext.FlExtEvent;

public class WindowEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        WindowEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after the window has been visually activated via <a href="#!/api/Ext.window.Window-method-setActive" rel="Ext.window.Window-method-setActive" class="docClass">setActive</a>.
   * @see ext.window.Window
   * @eventType onActivate
   * /
  public static const ACTIVATE:String = "onActivate";
  /**
   * "Fires after the window has been visually deactivated via <a href="#!/api/Ext.window.Window-method-setActive" rel="Ext.window.Window-method-setActive" class="docClass">setActive</a>.
   * @see ext.window.Window
   * @eventType onDeactivate
   * /
  public static const DEACTIVATE:String = "onDeactivate";
  /**
   * "Fires when this Window's modal mask is clicked or tapped. Returning <code>false</code> from
   * a handler will veto the subsequent preocessing of the <a href="#!/api/Ext.window.Window-cfg-maskClickAction" rel="Ext.window.Window-cfg-maskClickAction" class="docClass">maskClickAction</a>..
   * @see ext.window.Window
   * @eventType onMaskClick
   * /
  public static const MASK_CLICK:String = "onMaskClick";
  /**
   * "Fires after the window has been maximized.
   * @see ext.window.Window
   * @eventType onMaximize
   * /
  public static const MAXIMIZE:String = "onMaximize";
  /**
   * "Fires after the window has been minimized.
   * @see ext.window.Window
   * @eventType onMinimize
   * /
  public static const MINIMIZE:String = "onMinimize";
  /**
   * "Fires after the window has been restored to its original size after being maximized.
   * @see ext.window.Window
   * @eventType onRestore
   * /
  public static const RESTORE:String = "onRestore";

  public*/
    function WindowEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Window;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: WindowEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            ACTIVATE: "onActivate",
            DEACTIVATE: "onDeactivate",
            MASK_CLICK: "onMaskClick",
            MAXIMIZE: "onMaximize",
            MINIMIZE: "onMinimize",
            RESTORE: "onRestore",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("ext.window.events.Window_width_heightEvent", function(Window_width_heightEvent) {
    /*package ext.window.events {
import ext.window.Window;

import net.jangaroo.ext.FlExtEvent;

public class Window_width_heightEvent extends FlExtEvent {
  public static const __PARAMETER_SEQUENCE__:Array =*/
    function __PARAMETER_SEQUENCE__$static_() {
        Window_width_heightEvent.__PARAMETER_SEQUENCE__ = ([
            "source",
            "width",
            "height",
            "eOpts"
        ]);
    }
    /*;
  /**
   * "Fires after the window has been resized.
   * @see ext.window.Window
   * @eventType onResize
   * /
  public static const RESIZE:String = "onResize";

  public*/
    function Window_width_heightEvent$(type, /*:String*/
    arguments) /*:Array*/
    {
        net.jangaroo.ext.FlExtEvent.prototype.constructor.call(this, type, arguments);
    }
    /*

  public native function get source():Window;

  /**
   * The window's new width
   * /
  public native function get width():Number;

  /**
   * The window's new height
   * /
  public native function get height():Number;
}
}

============================================== Jangaroo part ==============================================*/
    return {
        extend: "net.jangaroo.ext.FlExtEvent",
        constructor: Window_width_heightEvent$,
        statics: {
            __PARAMETER_SEQUENCE__: undefined,
            RESIZE: "onResize",
            __initStatics__: function() {
                __PARAMETER_SEQUENCE__$static_();
            }
        },
        requires: [
            "net.jangaroo.ext.FlExtEvent"
        ]
    };
});

Ext.define("net.jangaroo.ext.Exml", function(Exml) {
    /*package net.jangaroo.ext {

public class Exml {

  public static const PREPEND:int = -1;
  public static const APPEND:int = 0;

  private static const*/
    var AT$static = /*:String*/
        "$at";
    /*

  /**
   * Merge override config object into the given config object.
   * This function is mainly used by code generated from EXML source files.
   * /
  public static*/
    function apply$static(config, /*:Object*/
    overrideConfig) /*:Object*/
    /*:**/
    {
        for (var property in /*:String*/
        overrideConfig) {
            if (property.substr(property.length - AT$static.length) !== AT$static) {
                applyProperty$static(config, overrideConfig, property);
            }
        }
        return config;
    }
    /*

  private static*/
    function applyProperty$static(config, /*:Object*/
    overrideConfig, /*:Object*/
    property) /*:String*/
    /*:void*/
    {
        var overrideValue = /*:**/
            overrideConfig[property];
        if (overrideValue === undefined) {
            // completely ignore properties with a value of "undefined":
            return;
        }
        var atProperty = /*:String*/
            property + AT$static;
        var overrideAt = /*:int*/
            overrideConfig[atProperty];
        if (overrideAt === undefined) {
            // If the override does not provide an at position,
            // make sure to forget about the at position of the original config, too.
            delete config[atProperty];
        } else {
            var value = /*:**/
                config[property];
            var at = /*:int*/
                config[atProperty];
            if (value === undefined && at === undefined) {
                // If the original config does not mention the property,
                // pass the at position along with the value.
                config[atProperty] = overrideAt;
            } else {
                var overrideValueArray = /*:Array*/
                    toArray$static(overrideValue);
                if (overrideAt === Exml.PREPEND) {
                    overrideAt = overrideValueArray.length;
                }
                var valueArray = /*:Array*/
                    toArray$static(value);
                if (at !== undefined) {
                    if (at === Exml.PREPEND) {
                        at = valueArray.length;
                    }
                    config[atProperty] = at + overrideAt;
                }
                overrideValue = overrideValueArray.slice(0, overrideAt).concat(valueArray, overrideValueArray.slice(overrideAt));
            }
        }
        config[property] = overrideValue;
    }
    /*

  private static const*/
    var EMPTY_ARRAY$static;
    /*:Array*/
    /* =*/
    function EMPTY_ARRAY$static_() {
        EMPTY_ARRAY$static = ([]);
    }
    
    /*

  private static*/
    function toArray$static(value) /*:**/
    /*:Array*/
    {
        return value === undefined ? EMPTY_ARRAY$static : value instanceof Array ? value : [
            value
        ];
    }
    /*

}*/
    function Exml$() {}
    /*
}

============================================== Jangaroo part ==============================================*/
    return {
        constructor: Exml$,
        statics: {
            PREPEND: -1,
            APPEND: 0,
            apply: apply$static,
            EMPTY_ARRAY: undefined,
            __initStatics__: function() {
                EMPTY_ARRAY$static_();
            }
        }
    };
});

Ext.define("net.jangaroo.ext.create", function(create) {
    /*package net.jangaroo.ext {
import joo.JooClassDeclaration;
import joo.getQualifiedObject;

/**
 * Create a target object from the given config class and object.
 * This function is mainly used by code generated from EXML source files.
 * <p>First, an instance of the config class is created with the given config parameter.
 * Then, the target class, retrieved from the <code>ExtConfig</code> annotation in the
 * config class, is instantiated with the config class instance.
 * </p>
 * @param configClass the config class
 * @param config the untyped config object
 * @return the created target object
 * /
public*/
    function create(configClass, /*:Class*/
    config) /*:Object*/
    /*:Object*/
    {
        var typedConfig = /*:Object*/
            new configClass(config);
        var configClassDeclaration = /*:JooClassDeclaration*/
            configClass['$class'];
        var extConfigAnnotation = /*:Object*/
            configClassDeclaration.metadata.ExtConfig;
        if (!extConfigAnnotation || !extConfigAnnotation.target) {
            throw new AS3.Error("Missing [ExtConfig(target='...')] annotation in config class " + configClassDeclaration.fullClassName);
        }
        var targetClass = /*:Class*/
            joo.getQualifiedObject(extConfigAnnotation.target);
        return new targetClass(typedConfig);
    }
    /*

}

============================================== Jangaroo part ==============================================*/
    return {
        __factory__: function() {
            return create;
        },
        requires: [
            "AS3.Error"
        ]
    };
});

